/* A recursive-descent parser generated by greg 0.4.3 */

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
struct _GREG;
#define YYRULECOUNT 244

/* PEG Markdown Highlight
 * Copyright 2011-2016 Ali Rantakari -- http://hasseg.org
 * Licensed under the GPL2+ and MIT licenses (see LICENSE for more info).
 * 
 * pmh_grammar.leg
 * 
 * This is a slightly adapted version of the PEG grammar from John MacFarlane's
 * peg-markdown compiler.
 */

/* PEG Markdown Highlight
 * Copyright 2011-2016 Ali Rantakari -- http://hasseg.org
 * Licensed under the GPL2+ and MIT licenses (see LICENSE for more info).
 * 
 * pmh_parser_head.c
 * 
 * Code to be inserted into the beginning of the parser code generated
 * from the PEG grammar.
 */

#include "pmh_parser.h"

#ifndef pmh_DEBUG_OUTPUT
#define pmh_DEBUG_OUTPUT 0
#endif

#if pmh_DEBUG_OUTPUT
#define pmh_IF(x)           if (x)
#define pmh_PRINTF(x, ...)  fprintf(stderr, x, ##__VA_ARGS__)
#define pmh_PUTCHAR(x)      putchar(x)
#else
#define pmh_IF(x)
#define pmh_PRINTF(x, ...)
#define pmh_PUTCHAR(x)
#endif



// Alias strdup to _strdup on MSVC:
#ifdef _MSC_VER
#define strdup _strdup
#endif


char *strdup_or_null(char *s)
{
    return (s == NULL) ? NULL : strdup(s);
}


// Internal language element occurrence structure, containing
// both public and private members:
struct pmh_RealElement
{
    // "Public" members:
    // (these must match what's defined in pmh_definitions.h)
    // -----------------------------------------------
    pmh_element_type type;
    unsigned long pos;
    unsigned long end;
    struct pmh_RealElement *next;
    char *label;
    char *address;
    
    // "Private" members for use by the parser itself:
    // -----------------------------------------------
    
    // next element in list of all elements:
    struct pmh_RealElement *all_elems_next;
    
    // offset to text (for elements of type pmh_EXTRA_TEXT, used when the
    // parser reads the value of 'text'):
    int text_offset;
    
    // text content (for elements of type pmh_EXTRA_TEXT):
    char *text;
    
    // children of element (for elements of type pmh_RAW_LIST)
    struct pmh_RealElement *children;
};
typedef struct pmh_RealElement pmh_realelement;




// Parser state data:
typedef struct
{
    /* The original, unmodified UTF-8 input: */
    char *original_input;
    
    /* The offsets of the bytes we have stripped from original_input: */
    unsigned long *strip_positions;
    size_t strip_positions_len;
    
    /* Buffer of characters to be parsed: */
    char *charbuf;
    
    /* Linked list of {start, end} offset pairs determining which parts */
    /* of charbuf to actually parse: */
    pmh_realelement *current_elem;
    pmh_realelement *elem_head;
    
    /* Current parsing offset within charbuf: */
    unsigned long offset;
    
    /* The extensions to use for parsing (bitfield */
    /* of enum pmh_extensions): */
    int extensions;
    
    /* Array of parsing result elements, indexed by type: */
    pmh_realelement **head_elems;
    
    /* Whether we are parsing only references: */
    bool parsing_only_references;
    
    /* List of reference elements: */
    pmh_realelement *references;
} parser_data;

static parser_data *mk_parser_data(char *original_input,
                                   unsigned long *strip_positions,
                                   size_t strip_positions_len,
                                   char *charbuf,
                                   pmh_realelement *parsing_elems,
                                   unsigned long offset,
                                   int extensions,
                                   pmh_realelement **head_elems,
                                   pmh_realelement *references)
{
    parser_data *p_data = (parser_data *)malloc(sizeof(parser_data));
    p_data->extensions = extensions;
    p_data->original_input = original_input;
    p_data->strip_positions = strip_positions;
    p_data->strip_positions_len = strip_positions_len;
    p_data->charbuf = charbuf;
    p_data->offset = offset;
    p_data->elem_head = p_data->current_elem = parsing_elems;
    p_data->references = references;
    p_data->parsing_only_references = false;
    if (head_elems != NULL)
        p_data->head_elems = head_elems;
    else {
        p_data->head_elems = (pmh_realelement **)
                             malloc(sizeof(pmh_realelement *) * pmh_NUM_TYPES);
        int i;
        for (i = 0; i < pmh_NUM_TYPES; i++)
            p_data->head_elems[i] = NULL;
    }
    return p_data;
}


// Forward declarations
static void parse_markdown(parser_data *p_data);
static void parse_references(parser_data *p_data);





static char **get_element_type_names()
{
    static char **elem_type_names = NULL;
    if (elem_type_names == NULL)
    {
        elem_type_names = (char **)malloc(sizeof(char*) * pmh_NUM_LANG_TYPES);
        int i;
        for (i = 0; i < pmh_NUM_LANG_TYPES; i++)
            elem_type_names[i] = NULL;
        elem_type_names[pmh_LINK] = "LINK";
        elem_type_names[pmh_AUTO_LINK_URL] = "AUTO_LINK_URL";
        elem_type_names[pmh_AUTO_LINK_EMAIL] = "AUTO_LINK_EMAIL";
        elem_type_names[pmh_IMAGE] = "IMAGE";
        elem_type_names[pmh_CODE] = "CODE";
        elem_type_names[pmh_HTML] = "HTML";
        elem_type_names[pmh_HTML_ENTITY] = "HTML_ENTITY";
        elem_type_names[pmh_EMPH] = "EMPH";
        elem_type_names[pmh_STRONG] = "STRONG";
        elem_type_names[pmh_LIST_BULLET] = "LIST_BULLET";
        elem_type_names[pmh_LIST_ENUMERATOR] = "LIST_ENUMERATOR";
        elem_type_names[pmh_COMMENT] = "COMMENT";
        elem_type_names[pmh_H1] = "H1";
        elem_type_names[pmh_H2] = "H2";
        elem_type_names[pmh_H3] = "H3";
        elem_type_names[pmh_H4] = "H4";
        elem_type_names[pmh_H5] = "H5";
        elem_type_names[pmh_H6] = "H6";
        elem_type_names[pmh_BLOCKQUOTE] = "BLOCKQUOTE";
        elem_type_names[pmh_VERBATIM] = "VERBATIM";
        elem_type_names[pmh_HTMLBLOCK] = "HTMLBLOCK";
        elem_type_names[pmh_HRULE] = "HRULE";
        elem_type_names[pmh_REFERENCE] = "REFERENCE";
        elem_type_names[pmh_FENCEDCODEBLOCK] = "FENCEDCODEBLOCK";
        elem_type_names[pmh_NOTE] = "NOTE";
        elem_type_names[pmh_STRIKE] = "STRIKE";
        elem_type_names[pmh_FRONTMATTER] = "FRONTMATTER";
        elem_type_names[pmh_DISPLAYFORMULA] = "DISPLAYFORMULA";
        elem_type_names[pmh_INLINEEQUATION] = "INLINEEQUATION";
    }
    return elem_type_names;
}

pmh_element_type pmh_element_type_from_name(char *name)
{
    char **elem_type_names = get_element_type_names();
    
    int i;
    for (i = 0; i < pmh_NUM_LANG_TYPES; i++)
    {
        char *i_name = elem_type_names[i];
        if (i_name == NULL)
            continue;
        if (strcmp(i_name, name) == 0)
            return i;
    }
    
    return pmh_NO_TYPE;
}

char *pmh_element_name_from_type(pmh_element_type type)
{
    char **elem_type_names = get_element_type_names();
    char* ret = elem_type_names[type];
    if (ret == NULL)
        return "unknown type";
    return ret;
}




/*
Remove pmh_RAW elements with zero length; return pointer
to new head.
*/
static pmh_realelement *remove_zero_length_raw_spans(pmh_realelement *elem)
{
    pmh_realelement *head = elem;
    pmh_realelement *parent = NULL;
    pmh_realelement *c = head;
    while (c != NULL)
    {
        if (c->type == pmh_RAW && c->pos >= c->end)
        {
            if (parent != NULL)
                parent->next = c->next;
            else
                head = c->next;
            parent = c;
            c = c->next;
            continue;
        }
        parent = c;
        c = c->next;
    }
    return head;
}

#if pmh_DEBUG_OUTPUT
/*
Print null-terminated string s.t. some characters are
represented by their corresponding espace sequences
*/
static void print_str_literal_escapes(char *str)
{
    char *c = str;
    pmh_PRINTF("'");
    while (*c != '\0')
    {
        if (*c == '\n')         pmh_PRINTF("\\n");
        else if (*c == '\t')    pmh_PRINTF("\\t");
        else putchar(*c);
        c++;
    }
    pmh_PRINTF("'");
}
#endif

#if pmh_DEBUG_OUTPUT
/*
Print elements in a linked list of
pmh_RAW, pmh_SEPARATOR, pmh_EXTRA_TEXT elements
*/
static void print_raw_spans_inline(pmh_realelement *elem)
{
    pmh_realelement *cur = elem;
    while (cur != NULL)
    {
        if (cur->type == pmh_SEPARATOR)
            pmh_PRINTF("<pmh_SEP %ld> ", cur->pos);
        else if (cur->type == pmh_EXTRA_TEXT) {
            pmh_PRINTF("{pmh_ETEXT ");
            print_str_literal_escapes(cur->text);
            pmh_PRINTF("}");
        }
        else
            pmh_PRINTF("(%ld-%ld) ", cur->pos, cur->end);
        cur = cur->next;
    }
}
#endif

/*
Perform postprocessing parsing runs for pmh_RAW_LIST elements in `elem`,
iteratively until no such elements exist.
*/
static void process_raw_blocks(parser_data *p_data)
{
    pmh_PRINTF("--------process_raw_blocks---------\n");
    while (p_data->head_elems[pmh_RAW_LIST] != NULL)
    {
        pmh_PRINTF("new iteration.\n");
        pmh_realelement *cursor = p_data->head_elems[pmh_RAW_LIST];
        p_data->head_elems[pmh_RAW_LIST] = NULL;
        while (cursor != NULL)
        {
            pmh_realelement *span_list = (pmh_realelement*)cursor->children;
            
            span_list = remove_zero_length_raw_spans(span_list);
            
            #if pmh_DEBUG_OUTPUT
            pmh_PRINTF("  process: ");
            print_raw_spans_inline(span_list);
            pmh_PRINTF("\n");
            #endif
            
            while (span_list != NULL)
            {
                pmh_PRINTF("next: span_list: %ld-%ld\n",
                           span_list->pos, span_list->end);
                
                // Skip separators in the beginning, as well as
                // separators after another separator:
                if (span_list->type == pmh_SEPARATOR) {
                    span_list = span_list->next;
                    continue;
                }
                
                // Store list of spans until next separator in subspan_list:
                pmh_realelement *subspan_list = span_list;
                pmh_realelement *previous = NULL;
                while (span_list != NULL && span_list->type != pmh_SEPARATOR) {
                    previous = span_list;
                    span_list = span_list->next;
                }
                if (span_list != NULL && span_list->type == pmh_SEPARATOR) {
                    span_list = span_list->next;
                    previous->next = NULL;
                }
                
                #if pmh_DEBUG_OUTPUT
                pmh_PRINTF("    subspan process: ");
                print_raw_spans_inline(subspan_list);
                pmh_PRINTF("\n");
                #endif
                
                // Process subspan_list:
                parser_data *raw_p_data = mk_parser_data(
                    p_data->original_input,
                    p_data->strip_positions,
                    p_data->strip_positions_len,
                    p_data->charbuf,
                    subspan_list,
                    subspan_list->pos,
                    p_data->extensions,
                    p_data->head_elems,
                    p_data->references
                );
                parse_markdown(raw_p_data);
                free(raw_p_data);
                
                pmh_PRINTF("parse over\n");
            }
            
            cursor = cursor->next;
        }
    }
}


#if pmh_DEBUG_OUTPUT
static void print_raw_blocks(char *text, pmh_realelement *elem[])
{
    pmh_PRINTF("--------print_raw_blocks---------\n");
    pmh_PRINTF("block:\n");
    pmh_realelement *cursor = elem[pmh_RAW_LIST];
    while (cursor != NULL)
    {
        print_raw_spans_inline(cursor->children);
        cursor = cursor->next;
    }
}
#endif




/* Free all elements created while parsing */
void pmh_free_elements(pmh_element **elems)
{
    pmh_realelement *cursor = (pmh_realelement*)elems[pmh_ALL];
    while (cursor != NULL) {
        pmh_realelement *tofree = cursor;
        cursor = cursor->all_elems_next;
        if (tofree->text != NULL)
            free(tofree->text);
        if (tofree->label != NULL)
            free(tofree->label);
        if (tofree->address != NULL)
            free(tofree->address);
        free(tofree);
    }
    elems[pmh_ALL] = NULL;
    
    free(elems);
}






#define IS_CONTINUATION_BYTE(x) ((x & 0xC0) == 0x80)
#define HAS_UTF8_BOM(x)         ( ((*x & 0xFF) == 0xEF)\
                                  && ((*(x+1) & 0xFF) == 0xBB)\
                                  && ((*(x+2) & 0xFF) == 0xBF) )
#define ADD_STRIP_POS(x) \
    /* reallocate more space for the array, if needed: */ \
    if (strip_positions_size <= strip_positions_pos) { \
        size_t new_size = strip_positions_size * 2; \
        unsigned long *new_arr = (unsigned long *) \
                                 calloc(new_size, \
                                        sizeof(unsigned long)); \
        memcpy(new_arr, strip_positions, \
               (sizeof(unsigned long) * strip_positions_size)); \
        strip_positions_size = new_size; \
        free(strip_positions); \
        strip_positions = new_arr; \
    } \
    strip_positions[strip_positions_pos] = x; \
    strip_positions_pos++;

/*
Copy `str` to `out`, while doing the following:
  - remove UTF-8 continuation bytes
  - remove possible UTF-8 BOM (byte order mark)
  - append two newlines to the end (like peg-markdown does)
  - keep track of which bytes we have stripped (in strip_positions)
*/
static int strcpy_preformat(char *str, char **out,
                            unsigned long **out_strip_positions,
                            size_t *out_strip_positions_len)
{
    size_t strip_positions_size = 1024;
    size_t strip_positions_pos = 0;
    unsigned long *strip_positions = (unsigned long *)
                                     calloc(strip_positions_size,
                                            sizeof(unsigned long));
    
    
    // +2 in the following is due to the "\n\n" suffix:
    char *new_str = (char *)malloc(sizeof(char) * strlen(str) + 1 + 2);
    char *c = str;
    int i = 0;
    
    if (HAS_UTF8_BOM(c)) {
        c += 3;
        ADD_STRIP_POS(0);
        ADD_STRIP_POS(1);
        ADD_STRIP_POS(2);
    }
    
    while (*c != '\0')
    {
        if (!IS_CONTINUATION_BYTE(*c)) {
            *(new_str+i) = *c, i++;
        } else {
            ADD_STRIP_POS((int)(c-str));
        }
        c++;
    }
    
    *(new_str+(i++)) = '\n';
    *(new_str+(i++)) = '\n';
    *(new_str+i) = '\0';
    
    *out = new_str;
    *out_strip_positions = strip_positions;
    *out_strip_positions_len = strip_positions_pos;
    return i;
}



void pmh_markdown_to_elements(char *text, int extensions,
                              pmh_element **out_result[])
{
    char *text_copy = NULL;
    unsigned long *strip_positions = NULL;
    size_t strip_positions_len = 0;
    int text_copy_len = strcpy_preformat(text, &text_copy, &strip_positions,
                                         &strip_positions_len);
    
    pmh_realelement *parsing_elem = (pmh_realelement *)
                                    malloc(sizeof(pmh_realelement));
    parsing_elem->type = pmh_RAW;
    parsing_elem->pos = 0;
    parsing_elem->end = text_copy_len;
    parsing_elem->next = NULL;
    
    parser_data *p_data = mk_parser_data(
        text,
        strip_positions,
        strip_positions_len,
        text_copy,
        parsing_elem,
        0,
        extensions,
        NULL,
        NULL
    );
    pmh_realelement **result = p_data->head_elems;
    
    if (*text_copy != '\0')
    {
        // Get reference definitions into p_data->references
        parse_references(p_data);
        
        // Reset parser state to beginning of input
        p_data->offset = 0;
        p_data->current_elem = p_data->elem_head;
        
        // Parse whole document
        parse_markdown(p_data);
        
        #if pmh_DEBUG_OUTPUT
        print_raw_blocks(text_copy, result);
        #endif
        
        process_raw_blocks(p_data);
    }
    
    free(strip_positions);
    free(p_data);
    free(parsing_elem);
    free(text_copy);
    
    *out_result = (pmh_element**)result;
}



/*
Mergesort linked list of elements (using comparison function `compare`),
return new head. (Adapted slightly from Simon Tatham's algorithm.)
*/
static pmh_element *ll_mergesort(pmh_element *list,
                                 int (*compare)(const pmh_element*,
                                                const pmh_element*))
{
    if (!list)
        return NULL;
    
    pmh_element *out_head = list;
    
    /* Merge widths of doubling size until done */
    int merge_width = 1;
    while (1)
    {
        pmh_element *l, *r; /* left & right segment pointers */
        pmh_element *tail = NULL; /* tail of sorted section */
        
        l = out_head;
        out_head = NULL;
        
        int merge_count = 0;
        
        while (l)
        {
            merge_count++;
            
            /* Position r, determine lsize & rsize */
            r = l;
            int lsize = 0;
            int i;
            for (i = 0; i < merge_width; i++) {
                lsize++;
                r = r->next;
                if (!r)
                    break;
            }
            int rsize = merge_width;
            
            /* Merge l & r */
            while (lsize > 0 || (rsize > 0 && r))
            {
                bool get_from_left = false;
                if (lsize == 0)             get_from_left = false;
                else if (rsize == 0 || !r)  get_from_left = true;
                else if (compare(l,r) <= 0) get_from_left = true;
                
                pmh_element *e;
                if (get_from_left) {
                    e = l; l = l->next; lsize--;
                } else {
                    e = r; r = r->next; rsize--;
                }
                
                /* add the next pmh_element to the merged list */
                if (tail)
                    tail->next = e;
                else
                    out_head = e;
                tail = e;
            }
            
            l = r;
        }
        tail->next = NULL;
        
        if (merge_count <= 1)
            return out_head;
        
        merge_width *= 2;
    }
}

static int elem_compare_by_pos(const pmh_element *a, const pmh_element *b)
{
    return a->pos - b->pos;
}

void pmh_sort_elements_by_pos(pmh_element *element_lists[])
{
    int i;
    for (i = 0; i < pmh_NUM_LANG_TYPES; i++)
        element_lists[i] = ll_mergesort(element_lists[i], &elem_compare_by_pos);
}








/* return true if extension is selected */
static bool extension(parser_data *p_data, int ext)
{
    return ((p_data->extensions & ext) != 0);
}

/* return reference pmh_realelement for a given label */
static pmh_realelement *get_reference(parser_data *p_data, char *label)
{
    if (!label)
        return NULL;
    
    pmh_realelement *cursor = p_data->references;
    while (cursor != NULL)
    {
        if (cursor->label && strcmp(label, cursor->label) == 0)
            return cursor;
        cursor = cursor->next;
    }
    return NULL;
}


/* cons an element/list onto a list, returning pointer to new head */
static pmh_realelement *cons(pmh_realelement *elem, pmh_realelement *list)
{
    assert(elem != NULL);
    
    pmh_realelement *cur = elem;
    while (cur->next != NULL) {
        cur = cur->next;
    }
    cur->next = list;
    
    return elem;
}


/* reverse a list, returning pointer to new list */
static pmh_realelement *reverse(pmh_realelement *list)
{
    pmh_realelement *new_head = NULL;
    pmh_realelement *next = NULL;
    while (list != NULL) {
        next = list->next;
        list->next = new_head;
        new_head = list;
        list = next;
    }
    return new_head;
}



/* construct pmh_realelement */
static pmh_realelement *mk_element(parser_data *p_data, pmh_element_type type,
                                   long pos, long end)
{
    pmh_realelement *result = (pmh_realelement *)malloc(sizeof(pmh_realelement));
    memset(result, 0, sizeof(*result));
    result->type = type;
    result->pos = pos;
    result->end = end;
    
    pmh_realelement *old_all_elements_head = p_data->head_elems[pmh_ALL];
    p_data->head_elems[pmh_ALL] = result;
    result->all_elems_next = old_all_elements_head;
    
    //pmh_PRINTF("  mk_element: %s [%ld - %ld]\n", pmh_element_name_from_type(type), pos, end);
    
    return result;
}

static pmh_realelement *copy_element(parser_data *p_data, pmh_realelement *elem)
{
    pmh_realelement *result = mk_element(p_data, elem->type, elem->pos, elem->end);
    result->label = strdup_or_null(elem->label);
    result->text = strdup_or_null(elem->text);
    result->address = strdup_or_null(elem->address);
    return result;
}

/* construct pmh_EXTRA_TEXT pmh_realelement */
static pmh_realelement *mk_etext(parser_data *p_data, char *string)
{
    pmh_realelement *result;
    assert(string != NULL);
    result = mk_element(p_data, pmh_EXTRA_TEXT, 0,0);
    result->text = strdup_or_null(string);
    return result;
}


/*
Given an element where the offsets {pos, end} represent
locations in the *parsed text* (defined by the linked list of pmh_RAW and
pmh_EXTRA_TEXT elements in p_data->current_elem), fix these offsets to represent
corresponding offsets in the parse buffer (p_data->charbuf). Also split
the given pmh_realelement into multiple parts if its offsets span multiple
p_data->current_elem elements. Return the (list of) elements with real offsets.
*/
static pmh_realelement *fix_offsets(parser_data *p_data, pmh_realelement *elem)
{
    if (elem->type == pmh_EXTRA_TEXT)
        return mk_etext(p_data, elem->text);
    
    pmh_realelement *new_head = copy_element(p_data, elem);
    
    pmh_realelement *tail = new_head;
    pmh_realelement *prev = NULL;
    
    bool found_start = false;
    bool found_end = false;
    bool tail_needs_pos = false;
    unsigned long previous_end = 0;
    unsigned long c = 0;
    
    pmh_realelement *cursor = p_data->elem_head;
    while (cursor != NULL)
    {
        int thislen = (cursor->type == pmh_EXTRA_TEXT)
                        ? strlen(cursor->text)
                        : cursor->end - cursor->pos;
        
        if (tail_needs_pos && cursor->type != pmh_EXTRA_TEXT) {
            tail->pos = cursor->pos;
            tail_needs_pos = false;
        }
        
        unsigned int this_pos = cursor->pos;
        
        if (!found_start && (c <= elem->pos && elem->pos <= c+thislen)) {
            tail->pos = (cursor->type == pmh_EXTRA_TEXT)
                        ? previous_end
                        : cursor->pos + (elem->pos - c);
            this_pos = tail->pos;
            found_start = true;
        }
        
        if (!found_end && (c <= elem->end && elem->end <= c+thislen)) {
            tail->end = (cursor->type == pmh_EXTRA_TEXT)
                        ? previous_end
                        : cursor->pos + (elem->end - c);
            found_end = true;
        }
        
        if (found_start && found_end)
            break;
        
        if (cursor->type != pmh_EXTRA_TEXT)
            previous_end = cursor->end;
        
        if (found_start) {
            pmh_realelement *new_elem = copy_element(p_data, tail);
            new_elem->pos = this_pos;
            new_elem->end = cursor->end;
            new_elem->next = tail;
            if (prev != NULL)
                prev->next = new_elem;
            if (new_head == tail)
                new_head = new_elem;
            prev = new_elem;
            tail_needs_pos = true;
        }
        
        c += thislen;
        cursor = cursor->next;
    }
    
    return new_head;
}



/* Add an element to p_data->head_elems. */
static void add(parser_data *p_data, pmh_realelement *elem)
{
    if (elem->type != pmh_RAW_LIST)
    {
        pmh_PRINTF("  add: %s [%ld - %ld]\n",
                   pmh_element_name_from_type(elem->type), elem->pos, elem->end);
        elem = fix_offsets(p_data, elem);
        pmh_PRINTF("     > %s [%ld - %ld]\n",
                   pmh_element_name_from_type(elem->type), elem->pos, elem->end);
    }
    else
    {
        pmh_PRINTF("  add: pmh_RAW_LIST ");
        pmh_realelement *cursor = elem->children;
        pmh_realelement *previous = NULL;
        while (cursor != NULL)
        {
            pmh_realelement *next = cursor->next;
            pmh_PRINTF("(%ld-%ld)>", cursor->pos, cursor->end);
            pmh_realelement *new_cursor = fix_offsets(p_data, cursor);
            if (previous != NULL)
                previous->next = new_cursor;
            else
                elem->children = new_cursor;
            pmh_PRINTF("(%ld-%ld)", new_cursor->pos, new_cursor->end);
            while (new_cursor->next != NULL) {
                new_cursor = new_cursor->next;
                pmh_PRINTF("(%ld-%ld)", new_cursor->pos, new_cursor->end);
            }
            pmh_PRINTF(" ");
            if (next != NULL)
                new_cursor->next = next;
            previous = new_cursor;
            cursor = next;
        }
        pmh_PRINTF("\n");
    }
    
    if (p_data->head_elems[elem->type] == NULL)
        p_data->head_elems[elem->type] = elem;
    else
    {
        pmh_realelement *last = elem;
        while (last->next != NULL)
            last = last->next;
        last->next = p_data->head_elems[elem->type];
        p_data->head_elems[elem->type] = elem;
    }
}


// Given a range in the list of spans we use for parsing (pos, end), return
// a copy of the corresponding section in the original input, with all of
// the UTF-8 bytes intact:
static char *copy_input_span(parser_data *p_data,
                             unsigned long pos, unsigned long end)
{
    if (end <= pos)
        return NULL;
    
    char *ret = NULL;
    
    // Adjust (pos,end) to match actual indexes in charbuf:
    pmh_realelement *dummy = mk_element(p_data, pmh_NO_TYPE, pos, end);
    pmh_realelement *fixed_dummies = fix_offsets(p_data, dummy);
    pmh_realelement *cursor = fixed_dummies;
    while (cursor != NULL)
    {
        if (cursor->end <= cursor->pos)
        {
            cursor = cursor->next;
            continue;
        }
        
        // Adjust cursor's span to take bytes stripped from the original
        // input into account (i.e. match the corresponding span in
        // p_data->original_input):
        unsigned long adjusted_pos = cursor->pos;
        unsigned long adjusted_end = cursor->end;
        size_t i;
        for (i = 0; i < p_data->strip_positions_len; i++)
        {
            unsigned long strip_position = p_data->strip_positions[i];
            if (strip_position <= adjusted_pos)
                adjusted_pos++;
            if (strip_position <= adjusted_end)
                adjusted_end++;
            else
                break;
        }
        
        // Copy span from original input:
        size_t adjusted_len = adjusted_end - adjusted_pos;
        char *str = (char *)malloc(sizeof(char)*adjusted_len + 1);
        *str = '\0';
        strncat(str, (p_data->original_input + adjusted_pos), adjusted_len);
        
        if (ret == NULL)
            ret = str;
        else
        {
            // append str to ret:
            char *new_ret = (char *)malloc(sizeof(char)
                                           *(strlen(str) + strlen(ret)) + 1);
            *new_ret = '\0';
            strcat(new_ret, ret);
            strcat(new_ret, str);
            free(ret);
            free(str);
            ret = new_ret;
        }
        
        cursor = cursor->next;
    }
    
    return ret;
}





# define YYSTYPE pmh_realelement *
#ifdef __DEBUG__
# define YY_DEBUG 1
#endif

#define YY_INPUT(buf, result, max_size)\
        yy_input_func(buf, &result, max_size, (parser_data *)G->data)

static void yy_input_func(char *buf, int *result, int max_size,
                          parser_data *p_data)
{
    if (p_data->current_elem == NULL)
    {
        (*result) = 0;
        return;
    }
    
    if (p_data->current_elem->type == pmh_EXTRA_TEXT)
    {
        int yyc;
        bool moreToRead = (p_data->current_elem->text
                           && *(p_data->current_elem->text
                                + p_data->current_elem->text_offset) != '\0');
        if (moreToRead)
        {
            yyc = *(p_data->current_elem->text + p_data->current_elem->text_offset++);
            pmh_PRINTF("\e[47;30m"); pmh_PUTCHAR(yyc); pmh_PRINTF("\e[0m");
            pmh_IF(yyc == '\n') pmh_PRINTF("\e[47m \e[0m");
        }
        else
        {
            yyc = EOF;
            p_data->current_elem = p_data->current_elem->next;
            pmh_PRINTF("\e[41m \e[0m");
            if (p_data->current_elem != NULL)
                p_data->offset = p_data->current_elem->pos;
        }
        (*result) = (EOF == yyc) ? 0 : (*(buf) = yyc, 1);
        return;
    }
    
    *(buf) = *(p_data->charbuf + p_data->offset);
    (*result) = (*buf != '\0');
    p_data->offset++;
    
    pmh_PRINTF("\e[43;30m"); pmh_PUTCHAR(*buf); pmh_PRINTF("\e[0m");
    pmh_IF(*buf == '\n') pmh_PRINTF("\e[42m \e[0m");
    
    if (p_data->offset >= p_data->current_elem->end)
    {
        p_data->current_elem = p_data->current_elem->next;
        pmh_PRINTF("\e[41m \e[0m");
        if (p_data->current_elem != NULL)
            p_data->offset = p_data->current_elem->pos;
    }
}



#define elem(x)     mk_element((parser_data *)G->data, x, thunk->begin, thunk->end)
#define elem_s(x)   mk_element((parser_data *)G->data, x, s->pos, thunk->end)
#define mk_sep      mk_element((parser_data *)G->data, pmh_SEPARATOR, 0,0)
#define mk_notype   mk_element((parser_data *)G->data, pmh_NO_TYPE, 0,0)
#define etext(x)    mk_etext((parser_data *)G->data, x)
#define ADD(x)      add((parser_data *)G->data, x)
#define EXT(x)      extension((parser_data *)G->data, x)
#define REF_EXISTS(x) reference_exists((parser_data *)G->data, x)
#define GET_REF(x)  get_reference((parser_data *)G->data, x)
#define PARSING_REFERENCES ((parser_data *)G->data)->parsing_only_references
#define FREE_LABEL(l) { free(l->label); l->label = NULL; }
#define FREE_ADDRESS(l) { free(l->address); l->address = NULL; }

// This gives us the text matched with < > as it appears in the original input:
#define COPY_YYTEXT_ORIG() copy_input_span((parser_data *)G->data, thunk->begin, thunk->end)

// pos is the postition of next char to parse after matching one $
// Do not allow $, digit, and \ before opening $
bool inline_equation_predict_pre(char *buf, int pos)
{
    if (pos < 2) {
        return true;
    }

    unsigned char ch = buf[pos - 2];
    return ch != '$' && (ch < '0' || ch > '9') && ch != '\\';
}

// Do not allow \, space before ending $
bool inline_equation_predict_post(char *buf, int pos)
{
    unsigned char ch = buf[pos - 2];
    return ch != '\\' && ch != ' ' && ch != '\t';
}

#define IEP_PRE         inline_equation_predict_pre(G->buf, G->pos)
#define IEP_POST        inline_equation_predict_post(G->buf, G->pos)


#ifndef YY_ALLOC
#define YY_ALLOC(N, D) malloc(N)
#endif
#ifndef YY_CALLOC
#define YY_CALLOC(N, S, D) calloc(N, S)
#endif
#ifndef YY_REALLOC
#define YY_REALLOC(B, N, D) realloc(B, N)
#endif
#ifndef YY_FREE
#define YY_FREE free
#endif
#ifndef YY_LOCAL
#define YY_LOCAL(T)     static T
#endif
#ifndef YY_ACTION
#define YY_ACTION(T)    static T
#endif
#ifndef YY_RULE
#define YY_RULE(T)      static T
#endif
#ifndef YY_PARSE
#define YY_PARSE(T)     T
#endif
#ifndef YY_NAME
#define YY_NAME(N) yy##N
#endif
#ifndef YY_INPUT
#define YY_INPUT(buf, result, max_size)                 \
  {                                                     \
    int yyc= getchar();                                 \
    result= (EOF == yyc) ? 0 : (*(buf)= yyc, 1);        \
    yyprintf((stderr, "<%c>", yyc));                  \
  }
#endif
#ifndef YY_BEGIN
#define YY_BEGIN        ( G->begin= G->pos, 1)
#endif
#ifndef YY_END
#define YY_END          ( G->end= G->pos, 1)
#endif
#ifdef YY_DEBUG
# define yyprintf(args) fprintf args
#else
# define yyprintf(args)
#endif
#ifndef YYSTYPE
#define YYSTYPE int
#endif
#ifndef YY_XTYPE
#define YY_XTYPE void *
#endif
#ifndef YY_XVAR
#define YY_XVAR yyxvar
#endif

#ifndef YY_STACK_SIZE
#define YY_STACK_SIZE 128
#endif

#ifndef YY_BUFFER_START_SIZE
#define YY_BUFFER_START_SIZE 1024
#endif

#ifndef YY_PART
#define yydata G->data
#define yy G->ss

struct _yythunk; // forward declaration
typedef void (*yyaction)(struct _GREG *G, char *yytext, int yyleng, struct _yythunk *thunkpos, YY_XTYPE YY_XVAR);
typedef struct _yythunk { int begin, end;  yyaction  action;  struct _yythunk *next; } yythunk;

typedef struct _GREG {
  char *buf;
  int buflen;
  int   offset;
  int   pos;
  int   limit;
  char *text;
  int   textlen;
  int   begin;
  int   end;
  yythunk *thunks;
  int   thunkslen;
  int thunkpos;
  YYSTYPE ss;
  YYSTYPE *val;
  YYSTYPE *vals;
  int valslen;
  YY_XTYPE data;
} GREG;

YY_LOCAL(int) yyrefill(GREG *G)
{
  int yyn;
  while (G->buflen - G->pos < 512)
    {
      G->buflen *= 2;
      G->buf= (char *)YY_REALLOC(G->buf, G->buflen, G->data);
    }
  YY_INPUT((G->buf + G->pos), yyn, (G->buflen - G->pos));
  if (!yyn) return 0;
  G->limit += yyn;
  return 1;
}

YY_LOCAL(int) yymatchDot(GREG *G)
{
  if (G->pos >= G->limit && !yyrefill(G)) return 0;
  ++G->pos;
  return 1;
}

YY_LOCAL(int) yymatchChar(GREG *G, int c)
{
  if (G->pos >= G->limit && !yyrefill(G)) return 0;
  if ((unsigned char)G->buf[G->pos] == c)
    {
      ++G->pos;
      yyprintf((stderr, "  ok   yymatchChar(%c) @ %s\n", c, G->buf+G->pos));
      return 1;
    }
  yyprintf((stderr, "  fail yymatchChar(%c) @ %s\n", c, G->buf+G->pos));
  return 0;
}

YY_LOCAL(int) yymatchString(GREG *G, char *s)
{
  int yysav= G->pos;
  while (*s)
    {
      if (G->pos >= G->limit && !yyrefill(G)) return 0;
      if (G->buf[G->pos] != *s)
        {
          G->pos= yysav;
          return 0;
        }
      ++s;
      ++G->pos;
    }
  return 1;
}

YY_LOCAL(int) yymatchClass(GREG *G, unsigned char *bits)
{
  int c;
  if (G->pos >= G->limit && !yyrefill(G)) return 0;
  c= (unsigned char)G->buf[G->pos];
  if (bits[c >> 3] & (1 << (c & 7)))
    {
      ++G->pos;
      yyprintf((stderr, "  ok   yymatchClass @ %s\n", G->buf+G->pos));
      return 1;
    }
  yyprintf((stderr, "  fail yymatchClass @ %s\n", G->buf+G->pos));
  return 0;
}

YY_LOCAL(void) yyDo(GREG *G, yyaction action, int begin, int end)
{
  while (G->thunkpos >= G->thunkslen)
    {
      G->thunkslen *= 2;
      G->thunks= (yythunk *)YY_REALLOC(G->thunks, sizeof(yythunk) * G->thunkslen, G->data);
    }
  G->thunks[G->thunkpos].begin=  begin;
  G->thunks[G->thunkpos].end=    end;
  G->thunks[G->thunkpos].action= action;
  ++G->thunkpos;
}

YY_LOCAL(int) yyText(GREG *G, int begin, int end)
{
  int yyleng= end - begin;
  if (yyleng <= 0)
    yyleng= 0;
  else
    {
      while (G->textlen < (yyleng + 1))
        {
          G->textlen *= 2;
          G->text= (char *)YY_REALLOC(G->text, G->textlen, G->data);
        }
      memcpy(G->text, G->buf + begin, yyleng);
    }
  G->text[yyleng]= '\0';
  return yyleng;
}

YY_LOCAL(void) yyDone(GREG *G)
{
  int pos;
  for (pos= 0; pos < G->thunkpos; ++pos)
    {
      yythunk *thunk= &G->thunks[pos];
      int yyleng= thunk->end ? yyText(G, thunk->begin, thunk->end) : thunk->begin;
      yyprintf((stderr, "DO [%d] %p %s\n", pos, thunk->action, G->text));
      thunk->action(G, G->text, yyleng, thunk, G->data);
    }
  G->thunkpos= 0;
}

YY_LOCAL(void) yyCommit(GREG *G)
{
  if ((G->limit -= G->pos))
    {
      memmove(G->buf, G->buf + G->pos, G->limit);
    }
  G->offset += G->pos;
  G->begin -= G->pos;
  G->end -= G->pos;
  G->pos= G->thunkpos= 0;
}

YY_LOCAL(int) yyAccept(GREG *G, int tp0)
{
  if (tp0)
    {
      fprintf(stderr, "accept denied at %d\n", tp0);
      return 0;
    }
  else
    {
      yyDone(G);
      yyCommit(G);
    }
  return 1;
}

YY_LOCAL(void) yyPush(GREG *G, char *text, int count, yythunk *thunk, YY_XTYPE YY_XVAR) { G->val += count; }
YY_LOCAL(void) yyPop(GREG *G, char *text, int count, yythunk *thunk, YY_XTYPE YY_XVAR)  { G->val -= count; }
YY_LOCAL(void) yySet(GREG *G, char *text, int count, yythunk *thunk, YY_XTYPE YY_XVAR)  { G->val[count]= G->ss; }

#endif /* YY_PART */

#define YYACCEPT        yyAccept(G, yythunkpos0)

YY_RULE(int) yy_RawNoteBlock(GREG *G); /* 244 */
YY_RULE(int) yy_RawNoteReference(GREG *G); /* 243 */
YY_RULE(int) yy_ExtendedSpecialChar(GREG *G); /* 242 */
YY_RULE(int) yy_AlphanumericAscii(GREG *G); /* 241 */
YY_RULE(int) yy_Quoted(GREG *G); /* 240 */
YY_RULE(int) yy_HtmlTag(GREG *G); /* 239 */
YY_RULE(int) yy_Ticks5(GREG *G); /* 238 */
YY_RULE(int) yy_Ticks4(GREG *G); /* 237 */
YY_RULE(int) yy_Ticks3(GREG *G); /* 236 */
YY_RULE(int) yy_Ticks2(GREG *G); /* 235 */
YY_RULE(int) yy_Ticks1(GREG *G); /* 234 */
YY_RULE(int) yy_SkipBlock(GREG *G); /* 233 */
YY_RULE(int) yy_References(GREG *G); /* 232 */
YY_RULE(int) yy_EmptyTitle(GREG *G); /* 231 */
YY_RULE(int) yy_RefTitleParens(GREG *G); /* 230 */
YY_RULE(int) yy_RefTitleDouble(GREG *G); /* 229 */
YY_RULE(int) yy_RefTitleSingle(GREG *G); /* 228 */
YY_RULE(int) yy_RefTitle(GREG *G); /* 227 */
YY_RULE(int) yy_RefSrc(GREG *G); /* 226 */
YY_RULE(int) yy_AutoLinkEmail(GREG *G); /* 225 */
YY_RULE(int) yy_AutoLinkUrl(GREG *G); /* 224 */
YY_RULE(int) yy_ImageSizeHeight(GREG *G); /* 223 */
YY_RULE(int) yy_ImageSizeWidth(GREG *G); /* 222 */
YY_RULE(int) yy_ImageSizeComplete(GREG *G); /* 221 */
YY_RULE(int) yy_TitleDoubleExt(GREG *G); /* 220 */
YY_RULE(int) yy_TitleSingleExt(GREG *G); /* 219 */
YY_RULE(int) yy_TitleDouble(GREG *G); /* 218 */
YY_RULE(int) yy_TitleSingle(GREG *G); /* 217 */
YY_RULE(int) yy_SourceContents(GREG *G); /* 216 */
YY_RULE(int) yy_ImageSize(GREG *G); /* 215 */
YY_RULE(int) yy_TitleExt(GREG *G); /* 214 */
YY_RULE(int) yy_Title(GREG *G); /* 213 */
YY_RULE(int) yy_Source(GREG *G); /* 212 */
YY_RULE(int) yy_Label(GREG *G); /* 211 */
YY_RULE(int) yy_ReferenceLinkSingle(GREG *G); /* 210 */
YY_RULE(int) yy_ReferenceLinkDouble(GREG *G); /* 209 */
YY_RULE(int) yy_AutoLink(GREG *G); /* 208 */
YY_RULE(int) yy_ReferenceLink(GREG *G); /* 207 */
YY_RULE(int) yy_ExplicitLinkSize(GREG *G); /* 206 */
YY_RULE(int) yy_ExplicitLink(GREG *G); /* 205 */
YY_RULE(int) yy_StrongUl(GREG *G); /* 204 */
YY_RULE(int) yy_StrongStar(GREG *G); /* 203 */
YY_RULE(int) yy_Whitespace(GREG *G); /* 202 */
YY_RULE(int) yy_EmphUl(GREG *G); /* 201 */
YY_RULE(int) yy_EmphStar(GREG *G); /* 200 */
YY_RULE(int) yy_StarLine(GREG *G); /* 199 */
YY_RULE(int) yy_UlLine(GREG *G); /* 198 */
YY_RULE(int) yy_SpecialChar(GREG *G); /* 197 */
YY_RULE(int) yy_Eof(GREG *G); /* 196 */
YY_RULE(int) yy_NormalEndline(GREG *G); /* 195 */
YY_RULE(int) yy_TerminalEndline(GREG *G); /* 194 */
YY_RULE(int) yy_LineBreak(GREG *G); /* 193 */
YY_RULE(int) yy_CharEntity(GREG *G); /* 192 */
YY_RULE(int) yy_DecEntity(GREG *G); /* 191 */
YY_RULE(int) yy_HexEntity(GREG *G); /* 190 */
YY_RULE(int) yy_Alphanumeric(GREG *G); /* 189 */
YY_RULE(int) yy_NormalChar(GREG *G); /* 188 */
YY_RULE(int) yy_Symbol(GREG *G); /* 187 */
YY_RULE(int) yy_EscapedChar(GREG *G); /* 186 */
YY_RULE(int) yy_Entity(GREG *G); /* 185 */
YY_RULE(int) yy_RawHtml(GREG *G); /* 184 */
YY_RULE(int) yy_Code(GREG *G); /* 183 */
YY_RULE(int) yy_InlineNote(GREG *G); /* 182 */
YY_RULE(int) yy_NoteReference(GREG *G); /* 181 */
YY_RULE(int) yy_Link(GREG *G); /* 180 */
YY_RULE(int) yy_Image(GREG *G); /* 179 */
YY_RULE(int) yy_Strike(GREG *G); /* 178 */
YY_RULE(int) yy_Emph(GREG *G); /* 177 */
YY_RULE(int) yy_Strong(GREG *G); /* 176 */
YY_RULE(int) yy_UlOrStarLine(GREG *G); /* 175 */
YY_RULE(int) yy_Str(GREG *G); /* 174 */
YY_RULE(int) yy_InStyleTags(GREG *G); /* 173 */
YY_RULE(int) yy_StyleClose(GREG *G); /* 172 */
YY_RULE(int) yy_StyleOpen(GREG *G); /* 171 */
YY_RULE(int) yy_HtmlBlockType(GREG *G); /* 170 */
YY_RULE(int) yy_HtmlBlockSelfClosing(GREG *G); /* 169 */
YY_RULE(int) yy_HtmlComment(GREG *G); /* 168 */
YY_RULE(int) yy_HtmlBlockInTags(GREG *G); /* 167 */
YY_RULE(int) yy_HtmlBlockHead(GREG *G); /* 166 */
YY_RULE(int) yy_HtmlBlockCloseHead(GREG *G); /* 165 */
YY_RULE(int) yy_HtmlBlockOpenHead(GREG *G); /* 164 */
YY_RULE(int) yy_HtmlBlockScript(GREG *G); /* 163 */
YY_RULE(int) yy_HtmlBlockCloseScript(GREG *G); /* 162 */
YY_RULE(int) yy_HtmlBlockOpenScript(GREG *G); /* 161 */
YY_RULE(int) yy_HtmlBlockTr(GREG *G); /* 160 */
YY_RULE(int) yy_HtmlBlockCloseTr(GREG *G); /* 159 */
YY_RULE(int) yy_HtmlBlockOpenTr(GREG *G); /* 158 */
YY_RULE(int) yy_HtmlBlockThead(GREG *G); /* 157 */
YY_RULE(int) yy_HtmlBlockCloseThead(GREG *G); /* 156 */
YY_RULE(int) yy_HtmlBlockOpenThead(GREG *G); /* 155 */
YY_RULE(int) yy_HtmlBlockTh(GREG *G); /* 154 */
YY_RULE(int) yy_HtmlBlockCloseTh(GREG *G); /* 153 */
YY_RULE(int) yy_HtmlBlockOpenTh(GREG *G); /* 152 */
YY_RULE(int) yy_HtmlBlockTfoot(GREG *G); /* 151 */
YY_RULE(int) yy_HtmlBlockCloseTfoot(GREG *G); /* 150 */
YY_RULE(int) yy_HtmlBlockOpenTfoot(GREG *G); /* 149 */
YY_RULE(int) yy_HtmlBlockTd(GREG *G); /* 148 */
YY_RULE(int) yy_HtmlBlockCloseTd(GREG *G); /* 147 */
YY_RULE(int) yy_HtmlBlockOpenTd(GREG *G); /* 146 */
YY_RULE(int) yy_HtmlBlockTbody(GREG *G); /* 145 */
YY_RULE(int) yy_HtmlBlockCloseTbody(GREG *G); /* 144 */
YY_RULE(int) yy_HtmlBlockOpenTbody(GREG *G); /* 143 */
YY_RULE(int) yy_HtmlBlockLi(GREG *G); /* 142 */
YY_RULE(int) yy_HtmlBlockCloseLi(GREG *G); /* 141 */
YY_RULE(int) yy_HtmlBlockOpenLi(GREG *G); /* 140 */
YY_RULE(int) yy_HtmlBlockFrameset(GREG *G); /* 139 */
YY_RULE(int) yy_HtmlBlockCloseFrameset(GREG *G); /* 138 */
YY_RULE(int) yy_HtmlBlockOpenFrameset(GREG *G); /* 137 */
YY_RULE(int) yy_HtmlBlockDt(GREG *G); /* 136 */
YY_RULE(int) yy_HtmlBlockCloseDt(GREG *G); /* 135 */
YY_RULE(int) yy_HtmlBlockOpenDt(GREG *G); /* 134 */
YY_RULE(int) yy_HtmlBlockDd(GREG *G); /* 133 */
YY_RULE(int) yy_HtmlBlockCloseDd(GREG *G); /* 132 */
YY_RULE(int) yy_HtmlBlockOpenDd(GREG *G); /* 131 */
YY_RULE(int) yy_HtmlBlockUl(GREG *G); /* 130 */
YY_RULE(int) yy_HtmlBlockCloseUl(GREG *G); /* 129 */
YY_RULE(int) yy_HtmlBlockOpenUl(GREG *G); /* 128 */
YY_RULE(int) yy_HtmlBlockTable(GREG *G); /* 127 */
YY_RULE(int) yy_HtmlBlockCloseTable(GREG *G); /* 126 */
YY_RULE(int) yy_HtmlBlockOpenTable(GREG *G); /* 125 */
YY_RULE(int) yy_HtmlBlockPre(GREG *G); /* 124 */
YY_RULE(int) yy_HtmlBlockClosePre(GREG *G); /* 123 */
YY_RULE(int) yy_HtmlBlockOpenPre(GREG *G); /* 122 */
YY_RULE(int) yy_HtmlBlockP(GREG *G); /* 121 */
YY_RULE(int) yy_HtmlBlockCloseP(GREG *G); /* 120 */
YY_RULE(int) yy_HtmlBlockOpenP(GREG *G); /* 119 */
YY_RULE(int) yy_HtmlBlockOl(GREG *G); /* 118 */
YY_RULE(int) yy_HtmlBlockCloseOl(GREG *G); /* 117 */
YY_RULE(int) yy_HtmlBlockOpenOl(GREG *G); /* 116 */
YY_RULE(int) yy_HtmlBlockNoscript(GREG *G); /* 115 */
YY_RULE(int) yy_HtmlBlockCloseNoscript(GREG *G); /* 114 */
YY_RULE(int) yy_HtmlBlockOpenNoscript(GREG *G); /* 113 */
YY_RULE(int) yy_HtmlBlockNoframes(GREG *G); /* 112 */
YY_RULE(int) yy_HtmlBlockCloseNoframes(GREG *G); /* 111 */
YY_RULE(int) yy_HtmlBlockOpenNoframes(GREG *G); /* 110 */
YY_RULE(int) yy_HtmlBlockMenu(GREG *G); /* 109 */
YY_RULE(int) yy_HtmlBlockCloseMenu(GREG *G); /* 108 */
YY_RULE(int) yy_HtmlBlockOpenMenu(GREG *G); /* 107 */
YY_RULE(int) yy_HtmlBlockH6(GREG *G); /* 106 */
YY_RULE(int) yy_HtmlBlockCloseH6(GREG *G); /* 105 */
YY_RULE(int) yy_HtmlBlockOpenH6(GREG *G); /* 104 */
YY_RULE(int) yy_HtmlBlockH5(GREG *G); /* 103 */
YY_RULE(int) yy_HtmlBlockCloseH5(GREG *G); /* 102 */
YY_RULE(int) yy_HtmlBlockOpenH5(GREG *G); /* 101 */
YY_RULE(int) yy_HtmlBlockH4(GREG *G); /* 100 */
YY_RULE(int) yy_HtmlBlockCloseH4(GREG *G); /* 99 */
YY_RULE(int) yy_HtmlBlockOpenH4(GREG *G); /* 98 */
YY_RULE(int) yy_HtmlBlockH3(GREG *G); /* 97 */
YY_RULE(int) yy_HtmlBlockCloseH3(GREG *G); /* 96 */
YY_RULE(int) yy_HtmlBlockOpenH3(GREG *G); /* 95 */
YY_RULE(int) yy_HtmlBlockH2(GREG *G); /* 94 */
YY_RULE(int) yy_HtmlBlockCloseH2(GREG *G); /* 93 */
YY_RULE(int) yy_HtmlBlockOpenH2(GREG *G); /* 92 */
YY_RULE(int) yy_HtmlBlockH1(GREG *G); /* 91 */
YY_RULE(int) yy_HtmlBlockCloseH1(GREG *G); /* 90 */
YY_RULE(int) yy_HtmlBlockOpenH1(GREG *G); /* 89 */
YY_RULE(int) yy_HtmlBlockForm(GREG *G); /* 88 */
YY_RULE(int) yy_HtmlBlockCloseForm(GREG *G); /* 87 */
YY_RULE(int) yy_HtmlBlockOpenForm(GREG *G); /* 86 */
YY_RULE(int) yy_HtmlBlockFieldset(GREG *G); /* 85 */
YY_RULE(int) yy_HtmlBlockCloseFieldset(GREG *G); /* 84 */
YY_RULE(int) yy_HtmlBlockOpenFieldset(GREG *G); /* 83 */
YY_RULE(int) yy_HtmlBlockDl(GREG *G); /* 82 */
YY_RULE(int) yy_HtmlBlockCloseDl(GREG *G); /* 81 */
YY_RULE(int) yy_HtmlBlockOpenDl(GREG *G); /* 80 */
YY_RULE(int) yy_HtmlBlockDiv(GREG *G); /* 79 */
YY_RULE(int) yy_HtmlBlockCloseDiv(GREG *G); /* 78 */
YY_RULE(int) yy_HtmlBlockOpenDiv(GREG *G); /* 77 */
YY_RULE(int) yy_HtmlBlockDir(GREG *G); /* 76 */
YY_RULE(int) yy_HtmlBlockCloseDir(GREG *G); /* 75 */
YY_RULE(int) yy_HtmlBlockOpenDir(GREG *G); /* 74 */
YY_RULE(int) yy_HtmlBlockCenter(GREG *G); /* 73 */
YY_RULE(int) yy_HtmlBlockCloseCenter(GREG *G); /* 72 */
YY_RULE(int) yy_HtmlBlockOpenCenter(GREG *G); /* 71 */
YY_RULE(int) yy_HtmlBlockBlockquote(GREG *G); /* 70 */
YY_RULE(int) yy_HtmlBlockCloseBlockquote(GREG *G); /* 69 */
YY_RULE(int) yy_HtmlBlockOpenBlockquote(GREG *G); /* 68 */
YY_RULE(int) yy_HtmlBlockAddress(GREG *G); /* 67 */
YY_RULE(int) yy_HtmlBlockCloseAddress(GREG *G); /* 66 */
YY_RULE(int) yy_HtmlAttribute(GREG *G); /* 65 */
YY_RULE(int) yy_Spnl(GREG *G); /* 64 */
YY_RULE(int) yy_HtmlBlockOpenAddress(GREG *G); /* 63 */
YY_RULE(int) yy_OptionallyIndentedLine(GREG *G); /* 62 */
YY_RULE(int) yy_Indent(GREG *G); /* 61 */
YY_RULE(int) yy_ListBlockLine(GREG *G); /* 60 */
YY_RULE(int) yy_ListContinuationBlock(GREG *G); /* 59 */
YY_RULE(int) yy_ListBlock(GREG *G); /* 58 */
YY_RULE(int) yy_ListItem(GREG *G); /* 57 */
YY_RULE(int) yy_Enumerator(GREG *G); /* 56 */
YY_RULE(int) yy_ListItemTight(GREG *G); /* 55 */
YY_RULE(int) yy_ListLoose(GREG *G); /* 54 */
YY_RULE(int) yy_ListTight(GREG *G); /* 53 */
YY_RULE(int) yy_Bullet(GREG *G); /* 52 */
YY_RULE(int) yy_Nonspacechar(GREG *G); /* 51 */
YY_RULE(int) yy_InlineEquationMultiple(GREG *G); /* 50 */
YY_RULE(int) yy_InlineEquationSingle(GREG *G); /* 49 */
YY_RULE(int) yy_InlineEquation(GREG *G); /* 48 */
YY_RULE(int) yy_Spacechar(GREG *G); /* 47 */
YY_RULE(int) yy_FencedCodeBlockEnd(GREG *G); /* 46 */
YY_RULE(int) yy_FencedCodeBlockChunk(GREG *G); /* 45 */
YY_RULE(int) yy_FencedCodeBlockStart(GREG *G); /* 44 */
YY_RULE(int) yy_VerbatimChunk(GREG *G); /* 43 */
YY_RULE(int) yy_IndentedLine(GREG *G); /* 42 */
YY_RULE(int) yy_NonblankIndentedLine(GREG *G); /* 41 */
YY_RULE(int) yy_Line(GREG *G); /* 40 */
YY_RULE(int) yy_StartList(GREG *G); /* 39 */
YY_RULE(int) yy_BlockQuoteRaw(GREG *G); /* 38 */
YY_RULE(int) yy_Endline(GREG *G); /* 37 */
YY_RULE(int) yy_RawLine(GREG *G); /* 36 */
YY_RULE(int) yy_SetextBottom2(GREG *G); /* 35 */
YY_RULE(int) yy_SetextBottom1(GREG *G); /* 34 */
YY_RULE(int) yy_SetextHeading2(GREG *G); /* 33 */
YY_RULE(int) yy_SetextHeading1(GREG *G); /* 32 */
YY_RULE(int) yy_SetextHeading(GREG *G); /* 31 */
YY_RULE(int) yy_Space(GREG *G); /* 30 */
YY_RULE(int) yy_AtxHeading(GREG *G); /* 29 */
YY_RULE(int) yy_AtxStart(GREG *G); /* 28 */
YY_RULE(int) yy_Inline(GREG *G); /* 27 */
YY_RULE(int) yy_Sp(GREG *G); /* 26 */
YY_RULE(int) yy_AtxInline(GREG *G); /* 25 */
YY_RULE(int) yy_Inlines(GREG *G); /* 24 */
YY_RULE(int) yy_NonindentSpace(GREG *G); /* 23 */
YY_RULE(int) yy_Plain(GREG *G); /* 22 */
YY_RULE(int) yy_Para(GREG *G); /* 21 */
YY_RULE(int) yy_StyleBlock(GREG *G); /* 20 */
YY_RULE(int) yy_HtmlBlock(GREG *G); /* 19 */
YY_RULE(int) yy_BulletList(GREG *G); /* 18 */
YY_RULE(int) yy_OrderedList(GREG *G); /* 17 */
YY_RULE(int) yy_Heading(GREG *G); /* 16 */
YY_RULE(int) yy_HorizontalRule(GREG *G); /* 15 */
YY_RULE(int) yy_Reference(GREG *G); /* 14 */
YY_RULE(int) yy_Note(GREG *G); /* 13 */
YY_RULE(int) yy_DisplayFormula(GREG *G); /* 12 */
YY_RULE(int) yy_FencedCodeBlock(GREG *G); /* 11 */
YY_RULE(int) yy_Verbatim(GREG *G); /* 10 */
YY_RULE(int) yy_BlockQuote(GREG *G); /* 9 */
YY_RULE(int) yy_BlankLine(GREG *G); /* 8 */
YY_RULE(int) yy_FrontMatterEndMark(GREG *G); /* 7 */
YY_RULE(int) yy_FrontMatterBlock(GREG *G); /* 6 */
YY_RULE(int) yy_Newline(GREG *G); /* 5 */
YY_RULE(int) yy_LocMarker(GREG *G); /* 4 */
YY_RULE(int) yy_Block(GREG *G); /* 3 */
YY_RULE(int) yy_FrontMatter(GREG *G); /* 2 */
YY_RULE(int) yy_Doc(GREG *G); /* 1 */

YY_ACTION(void) yy_1_RawLine(GREG *G, char *yytext, int yyleng, yythunk *thunk, YY_XTYPE YY_XVAR)
{
  yyprintf((stderr, "do yy_1_RawLine\n"));
   yy = elem(pmh_RAW); ;
}
YY_ACTION(void) yy_1_Line(GREG *G, char *yytext, int yyleng, yythunk *thunk, YY_XTYPE YY_XVAR)
{
  yyprintf((stderr, "do yy_1_Line\n"));
   yy = mk_element((parser_data *)G->data, pmh_RAW, yy->pos, yy->end); ;
}
YY_ACTION(void) yy_1_StartList(GREG *G, char *yytext, int yyleng, yythunk *thunk, YY_XTYPE YY_XVAR)
{
  yyprintf((stderr, "do yy_1_StartList\n"));
   yy = NULL; ;
}
YY_ACTION(void) yy_1_HtmlComment(GREG *G, char *yytext, int yyleng, yythunk *thunk, YY_XTYPE YY_XVAR)
{
#define s G->val[-1]
  yyprintf((stderr, "do yy_1_HtmlComment\n"));
   ADD(elem_s(pmh_COMMENT)); ;
#undef s
}
YY_ACTION(void) yy_1_RawHtml(GREG *G, char *yytext, int yyleng, yythunk *thunk, YY_XTYPE YY_XVAR)
{
#define s G->val[-1]
  yyprintf((stderr, "do yy_1_RawHtml\n"));
   ADD(elem_s(pmh_HTML)); ;
#undef s
}
YY_ACTION(void) yy_1_Code(GREG *G, char *yytext, int yyleng, yythunk *thunk, YY_XTYPE YY_XVAR)
{
#define s G->val[-1]
  yyprintf((stderr, "do yy_1_Code\n"));
   ADD(elem_s(pmh_CODE)); ;
#undef s
}
YY_ACTION(void) yy_1_Ticks5(GREG *G, char *yytext, int yyleng, yythunk *thunk, YY_XTYPE YY_XVAR)
{
  yyprintf((stderr, "do yy_1_Ticks5\n"));
   yy = elem(pmh_NO_TYPE); ;
}
YY_ACTION(void) yy_1_Ticks4(GREG *G, char *yytext, int yyleng, yythunk *thunk, YY_XTYPE YY_XVAR)
{
  yyprintf((stderr, "do yy_1_Ticks4\n"));
   yy = elem(pmh_NO_TYPE); ;
}
YY_ACTION(void) yy_1_Ticks3(GREG *G, char *yytext, int yyleng, yythunk *thunk, YY_XTYPE YY_XVAR)
{
  yyprintf((stderr, "do yy_1_Ticks3\n"));
   yy = elem(pmh_NO_TYPE); ;
}
YY_ACTION(void) yy_1_Ticks2(GREG *G, char *yytext, int yyleng, yythunk *thunk, YY_XTYPE YY_XVAR)
{
  yyprintf((stderr, "do yy_1_Ticks2\n"));
   yy = elem(pmh_NO_TYPE); ;
}
YY_ACTION(void) yy_1_Ticks1(GREG *G, char *yytext, int yyleng, yythunk *thunk, YY_XTYPE YY_XVAR)
{
  yyprintf((stderr, "do yy_1_Ticks1\n"));
   yy = elem(pmh_NO_TYPE); ;
}
YY_ACTION(void) yy_1_RefSrc(GREG *G, char *yytext, int yyleng, yythunk *thunk, YY_XTYPE YY_XVAR)
{
  yyprintf((stderr, "do yy_1_RefSrc\n"));
   yy = mk_notype; yy->address = COPY_YYTEXT_ORIG(); ;
}
YY_ACTION(void) yy_2_Label(GREG *G, char *yytext, int yyleng, yythunk *thunk, YY_XTYPE YY_XVAR)
{
#define s G->val[-1]
  yyprintf((stderr, "do yy_2_Label\n"));
  
            s->pos = s->pos;
            s->end = thunk->end;
            yy = s;
        ;
#undef s
}
YY_ACTION(void) yy_1_Label(GREG *G, char *yytext, int yyleng, yythunk *thunk, YY_XTYPE YY_XVAR)
{
#define s G->val[-1]
  yyprintf((stderr, "do yy_1_Label\n"));
   s->label = COPY_YYTEXT_ORIG(); ;
#undef s
}
YY_ACTION(void) yy_1_Reference(GREG *G, char *yytext, int yyleng, yythunk *thunk, YY_XTYPE YY_XVAR)
{
#define r G->val[-1]
#define l G->val[-2]
#define s G->val[-3]
  yyprintf((stderr, "do yy_1_Reference\n"));
  
                pmh_realelement *el = elem_s(pmh_REFERENCE);
                el->label = strdup_or_null(l->label);
                el->address = strdup_or_null(r->address);
                ADD(el);
                FREE_LABEL(l);
                FREE_ADDRESS(r);
              ;
#undef r
#undef l
#undef s
}
YY_ACTION(void) yy_3_AutoLinkEmail(GREG *G, char *yytext, int yyleng, yythunk *thunk, YY_XTYPE YY_XVAR)
{
#define s G->val[-1]
  yyprintf((stderr, "do yy_3_AutoLinkEmail\n"));
  
                s->end = thunk->end;
                ADD(s);
               ;
#undef s
}
YY_ACTION(void) yy_2_AutoLinkEmail(GREG *G, char *yytext, int yyleng, yythunk *thunk, YY_XTYPE YY_XVAR)
{
#define s G->val[-1]
  yyprintf((stderr, "do yy_2_AutoLinkEmail\n"));
   s->address = COPY_YYTEXT_ORIG(); ;
#undef s
}
YY_ACTION(void) yy_1_AutoLinkEmail(GREG *G, char *yytext, int yyleng, yythunk *thunk, YY_XTYPE YY_XVAR)
{
#define s G->val[-1]
  yyprintf((stderr, "do yy_1_AutoLinkEmail\n"));
   s->type = pmh_AUTO_LINK_EMAIL; ;
#undef s
}
YY_ACTION(void) yy_3_AutoLinkUrl(GREG *G, char *yytext, int yyleng, yythunk *thunk, YY_XTYPE YY_XVAR)
{
#define s G->val[-1]
  yyprintf((stderr, "do yy_3_AutoLinkUrl\n"));
  
                s->end = thunk->end;
                ADD(s);
               ;
#undef s
}
YY_ACTION(void) yy_2_AutoLinkUrl(GREG *G, char *yytext, int yyleng, yythunk *thunk, YY_XTYPE YY_XVAR)
{
#define s G->val[-1]
  yyprintf((stderr, "do yy_2_AutoLinkUrl\n"));
   s->address = COPY_YYTEXT_ORIG(); ;
#undef s
}
YY_ACTION(void) yy_1_AutoLinkUrl(GREG *G, char *yytext, int yyleng, yythunk *thunk, YY_XTYPE YY_XVAR)
{
#define s G->val[-1]
  yyprintf((stderr, "do yy_1_AutoLinkUrl\n"));
   s->type = pmh_AUTO_LINK_URL; ;
#undef s
}
YY_ACTION(void) yy_3_Source(GREG *G, char *yytext, int yyleng, yythunk *thunk, YY_XTYPE YY_XVAR)
{
  yyprintf((stderr, "do yy_3_Source\n"));
   yy->address = COPY_YYTEXT_ORIG(); ;
}
YY_ACTION(void) yy_2_Source(GREG *G, char *yytext, int yyleng, yythunk *thunk, YY_XTYPE YY_XVAR)
{
  yyprintf((stderr, "do yy_2_Source\n"));
   yy->address = COPY_YYTEXT_ORIG(); ;
}
YY_ACTION(void) yy_1_Source(GREG *G, char *yytext, int yyleng, yythunk *thunk, YY_XTYPE YY_XVAR)
{
  yyprintf((stderr, "do yy_1_Source\n"));
   yy = mk_notype; ;
}
YY_ACTION(void) yy_1_ExplicitLinkSize(GREG *G, char *yytext, int yyleng, yythunk *thunk, YY_XTYPE YY_XVAR)
{
#define l G->val[-1]
#define s G->val[-2]
  yyprintf((stderr, "do yy_1_ExplicitLinkSize\n"));
  
                        yy = elem_s(pmh_LINK);
                        if (l->address != NULL)
                            yy->address = strdup_or_null(l->address);
                        FREE_LABEL(s);
                        FREE_ADDRESS(l);
                    ;
#undef l
#undef s
}
YY_ACTION(void) yy_1_ExplicitLink(GREG *G, char *yytext, int yyleng, yythunk *thunk, YY_XTYPE YY_XVAR)
{
#define l G->val[-1]
#define s G->val[-2]
  yyprintf((stderr, "do yy_1_ExplicitLink\n"));
  
                    yy = elem_s(pmh_LINK);
                    if (l->address != NULL)
                        yy->address = strdup_or_null(l->address);
                    FREE_LABEL(s);
                    FREE_ADDRESS(l);
                ;
#undef l
#undef s
}
YY_ACTION(void) yy_1_ReferenceLinkSingle(GREG *G, char *yytext, int yyleng, yythunk *thunk, YY_XTYPE YY_XVAR)
{
#define s G->val[-1]
  yyprintf((stderr, "do yy_1_ReferenceLinkSingle\n"));
  
                        	pmh_realelement *reference = GET_REF(s->label);
                            if (reference) {
                                yy = elem_s(pmh_LINK);
                                yy->label = strdup_or_null(s->label);
                                yy->address = strdup_or_null(reference->address);
                            } else
                                yy = NULL;
                            FREE_LABEL(s);
                        ;
#undef s
}
YY_ACTION(void) yy_1_ReferenceLinkDouble(GREG *G, char *yytext, int yyleng, yythunk *thunk, YY_XTYPE YY_XVAR)
{
#define l G->val[-1]
#define s G->val[-2]
  yyprintf((stderr, "do yy_1_ReferenceLinkDouble\n"));
  
                        	pmh_realelement *reference = GET_REF(l->label);
                            if (reference) {
                                yy = elem_s(pmh_LINK);
                                yy->label = strdup_or_null(l->label);
                                yy->address = strdup_or_null(reference->address);
                            } else
                                yy = NULL;
                            FREE_LABEL(s);
                            FREE_LABEL(l);
                        ;
#undef l
#undef s
}
YY_ACTION(void) yy_1_Link(GREG *G, char *yytext, int yyleng, yythunk *thunk, YY_XTYPE YY_XVAR)
{
  yyprintf((stderr, "do yy_1_Link\n"));
   if (yy) ADD(yy); ;
}
YY_ACTION(void) yy_1_Image(GREG *G, char *yytext, int yyleng, yythunk *thunk, YY_XTYPE YY_XVAR)
{
  yyprintf((stderr, "do yy_1_Image\n"));
  
            if (yy != NULL) {
                yy->type = pmh_IMAGE;
                yy->pos -= 1;
                ADD(yy);
            }
        ;
}
YY_ACTION(void) yy_1_Strike(GREG *G, char *yytext, int yyleng, yythunk *thunk, YY_XTYPE YY_XVAR)
{
#define s G->val[-1]
  yyprintf((stderr, "do yy_1_Strike\n"));
   ADD(elem_s(pmh_STRIKE)); ;
#undef s
}
YY_ACTION(void) yy_1_StrongUl(GREG *G, char *yytext, int yyleng, yythunk *thunk, YY_XTYPE YY_XVAR)
{
#define s G->val[-1]
  yyprintf((stderr, "do yy_1_StrongUl\n"));
   ADD(elem_s(pmh_STRONG)); ;
#undef s
}
YY_ACTION(void) yy_1_StrongStar(GREG *G, char *yytext, int yyleng, yythunk *thunk, YY_XTYPE YY_XVAR)
{
#define s G->val[-1]
  yyprintf((stderr, "do yy_1_StrongStar\n"));
   ADD(elem_s(pmh_STRONG)); ;
#undef s
}
YY_ACTION(void) yy_1_EmphUl(GREG *G, char *yytext, int yyleng, yythunk *thunk, YY_XTYPE YY_XVAR)
{
#define s G->val[-1]
  yyprintf((stderr, "do yy_1_EmphUl\n"));
   ADD(elem_s(pmh_EMPH)); ;
#undef s
}
YY_ACTION(void) yy_1_EmphStar(GREG *G, char *yytext, int yyleng, yythunk *thunk, YY_XTYPE YY_XVAR)
{
#define s G->val[-1]
  yyprintf((stderr, "do yy_1_EmphStar\n"));
   ADD(elem_s(pmh_EMPH)); ;
#undef s
}
YY_ACTION(void) yy_1_Entity(GREG *G, char *yytext, int yyleng, yythunk *thunk, YY_XTYPE YY_XVAR)
{
#define s G->val[-1]
  yyprintf((stderr, "do yy_1_Entity\n"));
   ADD(elem_s(pmh_HTML_ENTITY)); ;
#undef s
}
YY_ACTION(void) yy_1_StyleBlock(GREG *G, char *yytext, int yyleng, yythunk *thunk, YY_XTYPE YY_XVAR)
{
#define s G->val[-1]
  yyprintf((stderr, "do yy_1_StyleBlock\n"));
   ADD(elem_s(pmh_HTMLBLOCK)); ;
#undef s
}
YY_ACTION(void) yy_1_HtmlBlock(GREG *G, char *yytext, int yyleng, yythunk *thunk, YY_XTYPE YY_XVAR)
{
#define s G->val[-1]
  yyprintf((stderr, "do yy_1_HtmlBlock\n"));
   ADD(elem_s(pmh_HTMLBLOCK)); ;
#undef s
}
YY_ACTION(void) yy_1_HtmlBlockH6(GREG *G, char *yytext, int yyleng, yythunk *thunk, YY_XTYPE YY_XVAR)
{
#define s G->val[-1]
  yyprintf((stderr, "do yy_1_HtmlBlockH6\n"));
   ADD(elem_s(pmh_H6)); ;
#undef s
}
YY_ACTION(void) yy_1_HtmlBlockH5(GREG *G, char *yytext, int yyleng, yythunk *thunk, YY_XTYPE YY_XVAR)
{
#define s G->val[-1]
  yyprintf((stderr, "do yy_1_HtmlBlockH5\n"));
   ADD(elem_s(pmh_H5)); ;
#undef s
}
YY_ACTION(void) yy_1_HtmlBlockH4(GREG *G, char *yytext, int yyleng, yythunk *thunk, YY_XTYPE YY_XVAR)
{
#define s G->val[-1]
  yyprintf((stderr, "do yy_1_HtmlBlockH4\n"));
   ADD(elem_s(pmh_H4)); ;
#undef s
}
YY_ACTION(void) yy_1_HtmlBlockH3(GREG *G, char *yytext, int yyleng, yythunk *thunk, YY_XTYPE YY_XVAR)
{
#define s G->val[-1]
  yyprintf((stderr, "do yy_1_HtmlBlockH3\n"));
   ADD(elem_s(pmh_H3)); ;
#undef s
}
YY_ACTION(void) yy_1_HtmlBlockH2(GREG *G, char *yytext, int yyleng, yythunk *thunk, YY_XTYPE YY_XVAR)
{
#define s G->val[-1]
  yyprintf((stderr, "do yy_1_HtmlBlockH2\n"));
   ADD(elem_s(pmh_H2)); ;
#undef s
}
YY_ACTION(void) yy_1_HtmlBlockH1(GREG *G, char *yytext, int yyleng, yythunk *thunk, YY_XTYPE YY_XVAR)
{
#define s G->val[-1]
  yyprintf((stderr, "do yy_1_HtmlBlockH1\n"));
   ADD(elem_s(pmh_H1)); ;
#undef s
}
YY_ACTION(void) yy_1_Enumerator(GREG *G, char *yytext, int yyleng, yythunk *thunk, YY_XTYPE YY_XVAR)
{
  yyprintf((stderr, "do yy_1_Enumerator\n"));
   ADD(elem(pmh_LIST_ENUMERATOR)); ;
}
YY_ACTION(void) yy_3_ListContinuationBlock(GREG *G, char *yytext, int yyleng, yythunk *thunk, YY_XTYPE YY_XVAR)
{
#define a G->val[-1]
  yyprintf((stderr, "do yy_3_ListContinuationBlock\n"));
   yy = a; ;
#undef a
}
YY_ACTION(void) yy_2_ListContinuationBlock(GREG *G, char *yytext, int yyleng, yythunk *thunk, YY_XTYPE YY_XVAR)
{
#define a G->val[-1]
  yyprintf((stderr, "do yy_2_ListContinuationBlock\n"));
   a = cons(yy, a); ;
#undef a
}
YY_ACTION(void) yy_1_ListContinuationBlock(GREG *G, char *yytext, int yyleng, yythunk *thunk, YY_XTYPE YY_XVAR)
{
#define a G->val[-1]
  yyprintf((stderr, "do yy_1_ListContinuationBlock\n"));
   if (*yytext == '\0') /* if strlen(yytext) == 0 */
                                a = cons(elem(pmh_SEPARATOR), a);
                            else
                                a = cons(elem(pmh_RAW), a);
                          ;
#undef a
}
YY_ACTION(void) yy_3_ListBlock(GREG *G, char *yytext, int yyleng, yythunk *thunk, YY_XTYPE YY_XVAR)
{
#define a G->val[-1]
  yyprintf((stderr, "do yy_3_ListBlock\n"));
   yy = a; ;
#undef a
}
YY_ACTION(void) yy_2_ListBlock(GREG *G, char *yytext, int yyleng, yythunk *thunk, YY_XTYPE YY_XVAR)
{
#define a G->val[-1]
  yyprintf((stderr, "do yy_2_ListBlock\n"));
   a = cons(elem(pmh_RAW), a); ;
#undef a
}
YY_ACTION(void) yy_1_ListBlock(GREG *G, char *yytext, int yyleng, yythunk *thunk, YY_XTYPE YY_XVAR)
{
#define a G->val[-1]
  yyprintf((stderr, "do yy_1_ListBlock\n"));
   a = cons(yy, a); ;
#undef a
}
YY_ACTION(void) yy_3_ListItemTight(GREG *G, char *yytext, int yyleng, yythunk *thunk, YY_XTYPE YY_XVAR)
{
#define a G->val[-1]
  yyprintf((stderr, "do yy_3_ListItemTight\n"));
   yy = a; ;
#undef a
}
YY_ACTION(void) yy_2_ListItemTight(GREG *G, char *yytext, int yyleng, yythunk *thunk, YY_XTYPE YY_XVAR)
{
#define a G->val[-1]
  yyprintf((stderr, "do yy_2_ListItemTight\n"));
   a = cons(yy, a); ;
#undef a
}
YY_ACTION(void) yy_1_ListItemTight(GREG *G, char *yytext, int yyleng, yythunk *thunk, YY_XTYPE YY_XVAR)
{
#define a G->val[-1]
  yyprintf((stderr, "do yy_1_ListItemTight\n"));
   a = cons(yy, a); ;
#undef a
}
YY_ACTION(void) yy_3_ListItem(GREG *G, char *yytext, int yyleng, yythunk *thunk, YY_XTYPE YY_XVAR)
{
#define a G->val[-1]
  yyprintf((stderr, "do yy_3_ListItem\n"));
   yy = a; ;
#undef a
}
YY_ACTION(void) yy_2_ListItem(GREG *G, char *yytext, int yyleng, yythunk *thunk, YY_XTYPE YY_XVAR)
{
#define a G->val[-1]
  yyprintf((stderr, "do yy_2_ListItem\n"));
   a = cons(yy, a); ;
#undef a
}
YY_ACTION(void) yy_1_ListItem(GREG *G, char *yytext, int yyleng, yythunk *thunk, YY_XTYPE YY_XVAR)
{
#define a G->val[-1]
  yyprintf((stderr, "do yy_1_ListItem\n"));
   a = cons(yy, a); ;
#undef a
}
YY_ACTION(void) yy_2_ListLoose(GREG *G, char *yytext, int yyleng, yythunk *thunk, YY_XTYPE YY_XVAR)
{
#define b G->val[-1]
#define a G->val[-2]
  yyprintf((stderr, "do yy_2_ListLoose\n"));
   pmh_realelement *cur = a;
              while (cur != NULL) {
                  pmh_realelement *rawlist = mk_element((parser_data *)G->data, pmh_RAW_LIST, 0,0);
                  rawlist->children = reverse(cur->children);
                  ADD(rawlist);
                  cur = cur->next;
              }
            ;
#undef b
#undef a
}
YY_ACTION(void) yy_1_ListLoose(GREG *G, char *yytext, int yyleng, yythunk *thunk, YY_XTYPE YY_XVAR)
{
#define b G->val[-1]
#define a G->val[-2]
  yyprintf((stderr, "do yy_1_ListLoose\n"));
   b = cons(etext("\n\n"), b); /* In loose list, \n\n added to end of each element */
                pmh_realelement *el = mk_notype;
                el->children = b;
                a = cons(el, a);
              ;
#undef b
#undef a
}
YY_ACTION(void) yy_2_ListTight(GREG *G, char *yytext, int yyleng, yythunk *thunk, YY_XTYPE YY_XVAR)
{
#define a G->val[-1]
  yyprintf((stderr, "do yy_2_ListTight\n"));
   pmh_realelement *cur = a;
              while (cur != NULL) {
                  pmh_realelement *rawlist = mk_element((parser_data *)G->data, pmh_RAW_LIST, 0,0);
                  rawlist->children = reverse(cur->children);
                  ADD(rawlist);
                  cur = cur->next;
              }
            ;
#undef a
}
YY_ACTION(void) yy_1_ListTight(GREG *G, char *yytext, int yyleng, yythunk *thunk, YY_XTYPE YY_XVAR)
{
#define a G->val[-1]
  yyprintf((stderr, "do yy_1_ListTight\n"));
   pmh_realelement *el = mk_notype;
                el->children = yy;
                a = cons(el, a);
              ;
#undef a
}
YY_ACTION(void) yy_1_Bullet(GREG *G, char *yytext, int yyleng, yythunk *thunk, YY_XTYPE YY_XVAR)
{
  yyprintf((stderr, "do yy_1_Bullet\n"));
   ADD(elem(pmh_LIST_BULLET)); ;
}
YY_ACTION(void) yy_1_HorizontalRule(GREG *G, char *yytext, int yyleng, yythunk *thunk, YY_XTYPE YY_XVAR)
{
  yyprintf((stderr, "do yy_1_HorizontalRule\n"));
   ADD(elem(pmh_HRULE)); ;
}
YY_ACTION(void) yy_1_InlineEquation(GREG *G, char *yytext, int yyleng, yythunk *thunk, YY_XTYPE YY_XVAR)
{
  yyprintf((stderr, "do yy_1_InlineEquation\n"));
   ADD(elem(pmh_INLINEEQUATION)); ;
}
YY_ACTION(void) yy_1_DisplayFormula(GREG *G, char *yytext, int yyleng, yythunk *thunk, YY_XTYPE YY_XVAR)
{
  yyprintf((stderr, "do yy_1_DisplayFormula\n"));
   ADD(elem(pmh_DISPLAYFORMULA)); ;
}
YY_ACTION(void) yy_1_FencedCodeBlock(GREG *G, char *yytext, int yyleng, yythunk *thunk, YY_XTYPE YY_XVAR)
{
#define s G->val[-1]
  yyprintf((stderr, "do yy_1_FencedCodeBlock\n"));
   ADD(elem(pmh_FENCEDCODEBLOCK)); ;
#undef s
}
YY_ACTION(void) yy_1_Verbatim(GREG *G, char *yytext, int yyleng, yythunk *thunk, YY_XTYPE YY_XVAR)
{
#define s G->val[-1]
  yyprintf((stderr, "do yy_1_Verbatim\n"));
   ADD(elem_s(pmh_VERBATIM)); ;
#undef s
}
YY_ACTION(void) yy_5_BlockQuoteRaw(GREG *G, char *yytext, int yyleng, yythunk *thunk, YY_XTYPE YY_XVAR)
{
#define a G->val[-1]
  yyprintf((stderr, "do yy_5_BlockQuoteRaw\n"));
   yy = a; ;
#undef a
}
YY_ACTION(void) yy_4_BlockQuoteRaw(GREG *G, char *yytext, int yyleng, yythunk *thunk, YY_XTYPE YY_XVAR)
{
#define a G->val[-1]
  yyprintf((stderr, "do yy_4_BlockQuoteRaw\n"));
   a = cons(etext("\n"), a); ;
#undef a
}
YY_ACTION(void) yy_3_BlockQuoteRaw(GREG *G, char *yytext, int yyleng, yythunk *thunk, YY_XTYPE YY_XVAR)
{
#define a G->val[-1]
  yyprintf((stderr, "do yy_3_BlockQuoteRaw\n"));
   a = cons(yy, a); ;
#undef a
}
YY_ACTION(void) yy_2_BlockQuoteRaw(GREG *G, char *yytext, int yyleng, yythunk *thunk, YY_XTYPE YY_XVAR)
{
#define a G->val[-1]
  yyprintf((stderr, "do yy_2_BlockQuoteRaw\n"));
   a = cons(yy, a); ;
#undef a
}
YY_ACTION(void) yy_1_BlockQuoteRaw(GREG *G, char *yytext, int yyleng, yythunk *thunk, YY_XTYPE YY_XVAR)
{
#define a G->val[-1]
  yyprintf((stderr, "do yy_1_BlockQuoteRaw\n"));
   ADD(elem(pmh_BLOCKQUOTE)); ;
#undef a
}
YY_ACTION(void) yy_1_BlockQuote(GREG *G, char *yytext, int yyleng, yythunk *thunk, YY_XTYPE YY_XVAR)
{
#define a G->val[-1]
  yyprintf((stderr, "do yy_1_BlockQuote\n"));
   pmh_realelement *rawlist = mk_element((parser_data *)G->data, pmh_RAW_LIST, 0,0);
              rawlist->children = reverse(a);
              ADD(rawlist);
            ;
#undef a
}
YY_ACTION(void) yy_1_SetextHeading2(GREG *G, char *yytext, int yyleng, yythunk *thunk, YY_XTYPE YY_XVAR)
{
#define s G->val[-1]
  yyprintf((stderr, "do yy_1_SetextHeading2\n"));
   ADD(elem_s(pmh_H2)); ;
#undef s
}
YY_ACTION(void) yy_1_SetextHeading1(GREG *G, char *yytext, int yyleng, yythunk *thunk, YY_XTYPE YY_XVAR)
{
#define s G->val[-1]
  yyprintf((stderr, "do yy_1_SetextHeading1\n"));
   ADD(elem_s(pmh_H1)); ;
#undef s
}
YY_ACTION(void) yy_1_AtxHeading(GREG *G, char *yytext, int yyleng, yythunk *thunk, YY_XTYPE YY_XVAR)
{
#define s G->val[-1]
  yyprintf((stderr, "do yy_1_AtxHeading\n"));
   ADD(elem_s(s->type)); ;
#undef s
}
YY_ACTION(void) yy_1_AtxStart(GREG *G, char *yytext, int yyleng, yythunk *thunk, YY_XTYPE YY_XVAR)
{
  yyprintf((stderr, "do yy_1_AtxStart\n"));
   yy = elem((pmh_element_type)(pmh_H1 + (strlen(yytext) - 1))); ;
}
YY_ACTION(void) yy_1_FrontMatter(GREG *G, char *yytext, int yyleng, yythunk *thunk, YY_XTYPE YY_XVAR)
{
#define s G->val[-1]
  yyprintf((stderr, "do yy_1_FrontMatter\n"));
  
                    ADD(elem(pmh_FRONTMATTER));
                ;
#undef s
}
YY_ACTION(void) yy_1_LocMarker(GREG *G, char *yytext, int yyleng, yythunk *thunk, YY_XTYPE YY_XVAR)
{
  yyprintf((stderr, "do yy_1_LocMarker\n"));
   yy = elem(pmh_NO_TYPE); ;
}

YY_RULE(int) yy_RawNoteBlock(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "RawNoteBlock"));
  {  int yypos4= G->pos, yythunkpos4= G->thunkpos;  if (!yy_BlankLine(G)) { goto l4; }  goto l1;
  l4:;	  G->pos= yypos4; G->thunkpos= yythunkpos4;
  }  if (!yy_OptionallyIndentedLine(G)) { goto l1; }
  l2:;	
  {  int yypos3= G->pos, yythunkpos3= G->thunkpos;
  {  int yypos5= G->pos, yythunkpos5= G->thunkpos;  if (!yy_BlankLine(G)) { goto l5; }  goto l3;
  l5:;	  G->pos= yypos5; G->thunkpos= yythunkpos5;
  }  if (!yy_OptionallyIndentedLine(G)) { goto l3; }  goto l2;
  l3:;	  G->pos= yypos3; G->thunkpos= yythunkpos3;
  }
  l6:;	
  {  int yypos7= G->pos, yythunkpos7= G->thunkpos;  if (!yy_BlankLine(G)) { goto l7; }  goto l6;
  l7:;	  G->pos= yypos7; G->thunkpos= yythunkpos7;
  }
  yyprintf((stderr, "  ok   %s @ %s\n", "RawNoteBlock", G->buf+G->pos));
  return 1;
  l1:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "RawNoteBlock", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_RawNoteReference(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "RawNoteReference"));  if (!yymatchString(G, "[^")) goto l8;
  {  int yypos11= G->pos, yythunkpos11= G->thunkpos;  if (!yy_Newline(G)) { goto l11; }  goto l8;
  l11:;	  G->pos= yypos11; G->thunkpos= yythunkpos11;
  }
  {  int yypos12= G->pos, yythunkpos12= G->thunkpos;  if (!yymatchChar(G, ']')) goto l12;  goto l8;
  l12:;	  G->pos= yypos12; G->thunkpos= yythunkpos12;
  }  if (!yymatchDot(G)) goto l8;
  l9:;	
  {  int yypos10= G->pos, yythunkpos10= G->thunkpos;
  {  int yypos13= G->pos, yythunkpos13= G->thunkpos;  if (!yy_Newline(G)) { goto l13; }  goto l10;
  l13:;	  G->pos= yypos13; G->thunkpos= yythunkpos13;
  }
  {  int yypos14= G->pos, yythunkpos14= G->thunkpos;  if (!yymatchChar(G, ']')) goto l14;  goto l10;
  l14:;	  G->pos= yypos14; G->thunkpos= yythunkpos14;
  }  if (!yymatchDot(G)) goto l10;  goto l9;
  l10:;	  G->pos= yypos10; G->thunkpos= yythunkpos10;
  }  if (!yymatchChar(G, ']')) goto l8;
  yyprintf((stderr, "  ok   %s @ %s\n", "RawNoteReference", G->buf+G->pos));
  return 1;
  l8:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "RawNoteReference", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_ExtendedSpecialChar(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "ExtendedSpecialChar"));
  {  int yypos16= G->pos, yythunkpos16= G->thunkpos;  yyText(G, G->begin, G->end);  if (!( EXT(pmh_EXT_NOTES) )) goto l17;  if (!yymatchChar(G, '^')) goto l17;  goto l16;
  l17:;	  G->pos= yypos16; G->thunkpos= yythunkpos16;  yyText(G, G->begin, G->end);  if (!( EXT(pmh_EXT_MATH) )) goto l15;  if (!yymatchChar(G, '$')) goto l15;
  }
  l16:;	
  yyprintf((stderr, "  ok   %s @ %s\n", "ExtendedSpecialChar", G->buf+G->pos));
  return 1;
  l15:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "ExtendedSpecialChar", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_AlphanumericAscii(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "AlphanumericAscii"));  if (!yymatchClass(G, (unsigned char *)"\000\000\000\000\000\000\377\003\376\377\377\007\376\377\377\007\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000")) goto l18;
  yyprintf((stderr, "  ok   %s @ %s\n", "AlphanumericAscii", G->buf+G->pos));
  return 1;
  l18:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "AlphanumericAscii", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_Quoted(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "Quoted"));
  {  int yypos20= G->pos, yythunkpos20= G->thunkpos;  if (!yymatchChar(G, '"')) goto l21;
  l22:;	
  {  int yypos23= G->pos, yythunkpos23= G->thunkpos;
  {  int yypos24= G->pos, yythunkpos24= G->thunkpos;  if (!yymatchChar(G, '"')) goto l24;  goto l23;
  l24:;	  G->pos= yypos24; G->thunkpos= yythunkpos24;
  }  if (!yymatchDot(G)) goto l23;  goto l22;
  l23:;	  G->pos= yypos23; G->thunkpos= yythunkpos23;
  }  if (!yymatchChar(G, '"')) goto l21;  goto l20;
  l21:;	  G->pos= yypos20; G->thunkpos= yythunkpos20;  if (!yymatchChar(G, '\'')) goto l19;
  l25:;	
  {  int yypos26= G->pos, yythunkpos26= G->thunkpos;
  {  int yypos27= G->pos, yythunkpos27= G->thunkpos;  if (!yymatchChar(G, '\'')) goto l27;  goto l26;
  l27:;	  G->pos= yypos27; G->thunkpos= yythunkpos27;
  }  if (!yymatchDot(G)) goto l26;  goto l25;
  l26:;	  G->pos= yypos26; G->thunkpos= yythunkpos26;
  }  if (!yymatchChar(G, '\'')) goto l19;
  }
  l20:;	
  yyprintf((stderr, "  ok   %s @ %s\n", "Quoted", G->buf+G->pos));
  return 1;
  l19:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "Quoted", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_HtmlTag(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "HtmlTag"));  if (!yymatchChar(G, '<')) goto l28;  if (!yy_Spnl(G)) { goto l28; }
  {  int yypos29= G->pos, yythunkpos29= G->thunkpos;  if (!yymatchChar(G, '/')) goto l29;  goto l30;
  l29:;	  G->pos= yypos29; G->thunkpos= yythunkpos29;
  }
  l30:;	  if (!yy_AlphanumericAscii(G)) { goto l28; }
  l31:;	
  {  int yypos32= G->pos, yythunkpos32= G->thunkpos;  if (!yy_AlphanumericAscii(G)) { goto l32; }  goto l31;
  l32:;	  G->pos= yypos32; G->thunkpos= yythunkpos32;
  }  if (!yy_Spnl(G)) { goto l28; }
  l33:;	
  {  int yypos34= G->pos, yythunkpos34= G->thunkpos;  if (!yy_HtmlAttribute(G)) { goto l34; }  goto l33;
  l34:;	  G->pos= yypos34; G->thunkpos= yythunkpos34;
  }
  {  int yypos35= G->pos, yythunkpos35= G->thunkpos;  if (!yymatchChar(G, '/')) goto l35;  goto l36;
  l35:;	  G->pos= yypos35; G->thunkpos= yythunkpos35;
  }
  l36:;	  if (!yy_Spnl(G)) { goto l28; }  if (!yymatchChar(G, '>')) goto l28;
  yyprintf((stderr, "  ok   %s @ %s\n", "HtmlTag", G->buf+G->pos));
  return 1;
  l28:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "HtmlTag", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_Ticks5(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "Ticks5"));  yyText(G, G->begin, G->end);  if (!(YY_BEGIN)) goto l37;  if (!yymatchString(G, "`````")) goto l37;  yyText(G, G->begin, G->end);  if (!(YY_END)) goto l37;
  {  int yypos38= G->pos, yythunkpos38= G->thunkpos;  if (!yymatchChar(G, '`')) goto l38;  goto l37;
  l38:;	  G->pos= yypos38; G->thunkpos= yythunkpos38;
  }  yyDo(G, yy_1_Ticks5, G->begin, G->end);
  yyprintf((stderr, "  ok   %s @ %s\n", "Ticks5", G->buf+G->pos));
  return 1;
  l37:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "Ticks5", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_Ticks4(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "Ticks4"));  yyText(G, G->begin, G->end);  if (!(YY_BEGIN)) goto l39;  if (!yymatchString(G, "````")) goto l39;  yyText(G, G->begin, G->end);  if (!(YY_END)) goto l39;
  {  int yypos40= G->pos, yythunkpos40= G->thunkpos;  if (!yymatchChar(G, '`')) goto l40;  goto l39;
  l40:;	  G->pos= yypos40; G->thunkpos= yythunkpos40;
  }  yyDo(G, yy_1_Ticks4, G->begin, G->end);
  yyprintf((stderr, "  ok   %s @ %s\n", "Ticks4", G->buf+G->pos));
  return 1;
  l39:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "Ticks4", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_Ticks3(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "Ticks3"));  yyText(G, G->begin, G->end);  if (!(YY_BEGIN)) goto l41;  if (!yymatchString(G, "```")) goto l41;  yyText(G, G->begin, G->end);  if (!(YY_END)) goto l41;
  {  int yypos42= G->pos, yythunkpos42= G->thunkpos;  if (!yymatchChar(G, '`')) goto l42;  goto l41;
  l42:;	  G->pos= yypos42; G->thunkpos= yythunkpos42;
  }  yyDo(G, yy_1_Ticks3, G->begin, G->end);
  yyprintf((stderr, "  ok   %s @ %s\n", "Ticks3", G->buf+G->pos));
  return 1;
  l41:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "Ticks3", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_Ticks2(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "Ticks2"));  yyText(G, G->begin, G->end);  if (!(YY_BEGIN)) goto l43;  if (!yymatchString(G, "``")) goto l43;  yyText(G, G->begin, G->end);  if (!(YY_END)) goto l43;
  {  int yypos44= G->pos, yythunkpos44= G->thunkpos;  if (!yymatchChar(G, '`')) goto l44;  goto l43;
  l44:;	  G->pos= yypos44; G->thunkpos= yythunkpos44;
  }  yyDo(G, yy_1_Ticks2, G->begin, G->end);
  yyprintf((stderr, "  ok   %s @ %s\n", "Ticks2", G->buf+G->pos));
  return 1;
  l43:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "Ticks2", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_Ticks1(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "Ticks1"));  yyText(G, G->begin, G->end);  if (!(YY_BEGIN)) goto l45;  if (!yymatchChar(G, '`')) goto l45;  yyText(G, G->begin, G->end);  if (!(YY_END)) goto l45;
  {  int yypos46= G->pos, yythunkpos46= G->thunkpos;  if (!yymatchChar(G, '`')) goto l46;  goto l45;
  l46:;	  G->pos= yypos46; G->thunkpos= yythunkpos46;
  }  yyDo(G, yy_1_Ticks1, G->begin, G->end);
  yyprintf((stderr, "  ok   %s @ %s\n", "Ticks1", G->buf+G->pos));
  return 1;
  l45:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "Ticks1", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_SkipBlock(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "SkipBlock"));
  {  int yypos48= G->pos, yythunkpos48= G->thunkpos;
  {  int yypos52= G->pos, yythunkpos52= G->thunkpos;  if (!yy_BlankLine(G)) { goto l52; }  goto l49;
  l52:;	  G->pos= yypos52; G->thunkpos= yythunkpos52;
  }  if (!yy_RawLine(G)) { goto l49; }
  l50:;	
  {  int yypos51= G->pos, yythunkpos51= G->thunkpos;
  {  int yypos53= G->pos, yythunkpos53= G->thunkpos;  if (!yy_BlankLine(G)) { goto l53; }  goto l51;
  l53:;	  G->pos= yypos53; G->thunkpos= yythunkpos53;
  }  if (!yy_RawLine(G)) { goto l51; }  goto l50;
  l51:;	  G->pos= yypos51; G->thunkpos= yythunkpos51;
  }
  l54:;	
  {  int yypos55= G->pos, yythunkpos55= G->thunkpos;  if (!yy_BlankLine(G)) { goto l55; }  goto l54;
  l55:;	  G->pos= yypos55; G->thunkpos= yythunkpos55;
  }  goto l48;
  l49:;	  G->pos= yypos48; G->thunkpos= yythunkpos48;  if (!yy_BlankLine(G)) { goto l47; }
  l56:;	
  {  int yypos57= G->pos, yythunkpos57= G->thunkpos;  if (!yy_BlankLine(G)) { goto l57; }  goto l56;
  l57:;	  G->pos= yypos57; G->thunkpos= yythunkpos57;
  }
  }
  l48:;	
  yyprintf((stderr, "  ok   %s @ %s\n", "SkipBlock", G->buf+G->pos));
  return 1;
  l47:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "SkipBlock", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_References(GREG *G)
{
  yyprintf((stderr, "%s\n", "References"));
  l59:;	
  {  int yypos60= G->pos, yythunkpos60= G->thunkpos;
  {  int yypos61= G->pos, yythunkpos61= G->thunkpos;  if (!yy_Reference(G)) { goto l62; }  goto l61;
  l62:;	  G->pos= yypos61; G->thunkpos= yythunkpos61;  if (!yy_SkipBlock(G)) { goto l60; }
  }
  l61:;	  goto l59;
  l60:;	  G->pos= yypos60; G->thunkpos= yythunkpos60;
  }
  yyprintf((stderr, "  ok   %s @ %s\n", "References", G->buf+G->pos));
  return 1;
}
YY_RULE(int) yy_EmptyTitle(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "EmptyTitle"));  if (!yymatchString(G, "")) goto l63;
  yyprintf((stderr, "  ok   %s @ %s\n", "EmptyTitle", G->buf+G->pos));
  return 1;
  l63:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "EmptyTitle", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_RefTitleParens(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "RefTitleParens"));  if (!yy_Spnl(G)) { goto l64; }  if (!yymatchChar(G, '(')) goto l64;
  l65:;	
  {  int yypos66= G->pos, yythunkpos66= G->thunkpos;
  {  int yypos67= G->pos, yythunkpos67= G->thunkpos;
  {  int yypos68= G->pos, yythunkpos68= G->thunkpos;  if (!yymatchChar(G, ')')) goto l69;  if (!yy_Sp(G)) { goto l69; }  if (!yy_Newline(G)) { goto l69; }  goto l68;
  l69:;	  G->pos= yypos68; G->thunkpos= yythunkpos68;  if (!yy_Newline(G)) { goto l67; }
  }
  l68:;	  goto l66;
  l67:;	  G->pos= yypos67; G->thunkpos= yythunkpos67;
  }  if (!yymatchDot(G)) goto l66;  goto l65;
  l66:;	  G->pos= yypos66; G->thunkpos= yythunkpos66;
  }  if (!yymatchChar(G, ')')) goto l64;
  yyprintf((stderr, "  ok   %s @ %s\n", "RefTitleParens", G->buf+G->pos));
  return 1;
  l64:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "RefTitleParens", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_RefTitleDouble(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "RefTitleDouble"));  if (!yy_Spnl(G)) { goto l70; }  if (!yymatchChar(G, '"')) goto l70;
  l71:;	
  {  int yypos72= G->pos, yythunkpos72= G->thunkpos;
  {  int yypos73= G->pos, yythunkpos73= G->thunkpos;
  {  int yypos74= G->pos, yythunkpos74= G->thunkpos;  if (!yymatchChar(G, '"')) goto l75;  if (!yy_Sp(G)) { goto l75; }  if (!yy_Newline(G)) { goto l75; }  goto l74;
  l75:;	  G->pos= yypos74; G->thunkpos= yythunkpos74;  if (!yy_Newline(G)) { goto l73; }
  }
  l74:;	  goto l72;
  l73:;	  G->pos= yypos73; G->thunkpos= yythunkpos73;
  }  if (!yymatchDot(G)) goto l72;  goto l71;
  l72:;	  G->pos= yypos72; G->thunkpos= yythunkpos72;
  }  if (!yymatchChar(G, '"')) goto l70;
  yyprintf((stderr, "  ok   %s @ %s\n", "RefTitleDouble", G->buf+G->pos));
  return 1;
  l70:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "RefTitleDouble", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_RefTitleSingle(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "RefTitleSingle"));  if (!yy_Spnl(G)) { goto l76; }  if (!yymatchChar(G, '\'')) goto l76;
  l77:;	
  {  int yypos78= G->pos, yythunkpos78= G->thunkpos;
  {  int yypos79= G->pos, yythunkpos79= G->thunkpos;
  {  int yypos80= G->pos, yythunkpos80= G->thunkpos;  if (!yymatchChar(G, '\'')) goto l81;  if (!yy_Sp(G)) { goto l81; }  if (!yy_Newline(G)) { goto l81; }  goto l80;
  l81:;	  G->pos= yypos80; G->thunkpos= yythunkpos80;  if (!yy_Newline(G)) { goto l79; }
  }
  l80:;	  goto l78;
  l79:;	  G->pos= yypos79; G->thunkpos= yythunkpos79;
  }  if (!yymatchDot(G)) goto l78;  goto l77;
  l78:;	  G->pos= yypos78; G->thunkpos= yythunkpos78;
  }  if (!yymatchChar(G, '\'')) goto l76;
  yyprintf((stderr, "  ok   %s @ %s\n", "RefTitleSingle", G->buf+G->pos));
  return 1;
  l76:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "RefTitleSingle", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_RefTitle(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "RefTitle"));
  {  int yypos83= G->pos, yythunkpos83= G->thunkpos;  if (!yy_RefTitleSingle(G)) { goto l84; }  goto l83;
  l84:;	  G->pos= yypos83; G->thunkpos= yythunkpos83;  if (!yy_RefTitleDouble(G)) { goto l85; }  goto l83;
  l85:;	  G->pos= yypos83; G->thunkpos= yythunkpos83;  if (!yy_RefTitleParens(G)) { goto l86; }  goto l83;
  l86:;	  G->pos= yypos83; G->thunkpos= yythunkpos83;  if (!yy_EmptyTitle(G)) { goto l82; }
  }
  l83:;	
  yyprintf((stderr, "  ok   %s @ %s\n", "RefTitle", G->buf+G->pos));
  return 1;
  l82:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "RefTitle", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_RefSrc(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "RefSrc"));  yyText(G, G->begin, G->end);  if (!(YY_BEGIN)) goto l87;  if (!yy_Nonspacechar(G)) { goto l87; }
  l88:;	
  {  int yypos89= G->pos, yythunkpos89= G->thunkpos;  if (!yy_Nonspacechar(G)) { goto l89; }  goto l88;
  l89:;	  G->pos= yypos89; G->thunkpos= yythunkpos89;
  }  yyText(G, G->begin, G->end);  if (!(YY_END)) goto l87;  yyDo(G, yy_1_RefSrc, G->begin, G->end);
  yyprintf((stderr, "  ok   %s @ %s\n", "RefSrc", G->buf+G->pos));
  return 1;
  l87:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "RefSrc", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_AutoLinkEmail(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;  yyDo(G, yyPush, 1, 0);
  yyprintf((stderr, "%s\n", "AutoLinkEmail"));  yyText(G, G->begin, G->end);  if (!(YY_BEGIN)) goto l90;  if (!yy_LocMarker(G)) { goto l90; }  yyDo(G, yySet, -1, 0);  yyDo(G, yy_1_AutoLinkEmail, G->begin, G->end);  if (!yymatchChar(G, '<')) goto l90;
  {  int yypos91= G->pos, yythunkpos91= G->thunkpos;  if (!yymatchString(G, "mailto:")) goto l91;  goto l92;
  l91:;	  G->pos= yypos91; G->thunkpos= yythunkpos91;
  }
  l92:;	  yyText(G, G->begin, G->end);  if (!(YY_BEGIN)) goto l90;  if (!yymatchClass(G, (unsigned char *)"\000\000\000\000\062\350\377\003\376\377\377\207\376\377\377\107\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000")) goto l90;
  l93:;	
  {  int yypos94= G->pos, yythunkpos94= G->thunkpos;  if (!yymatchClass(G, (unsigned char *)"\000\000\000\000\062\350\377\003\376\377\377\207\376\377\377\107\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000")) goto l94;  goto l93;
  l94:;	  G->pos= yypos94; G->thunkpos= yythunkpos94;
  }  if (!yymatchChar(G, '@')) goto l90;
  {  int yypos97= G->pos, yythunkpos97= G->thunkpos;  if (!yy_Newline(G)) { goto l97; }  goto l90;
  l97:;	  G->pos= yypos97; G->thunkpos= yythunkpos97;
  }
  {  int yypos98= G->pos, yythunkpos98= G->thunkpos;  if (!yymatchChar(G, '>')) goto l98;  goto l90;
  l98:;	  G->pos= yypos98; G->thunkpos= yythunkpos98;
  }  if (!yymatchDot(G)) goto l90;
  l95:;	
  {  int yypos96= G->pos, yythunkpos96= G->thunkpos;
  {  int yypos99= G->pos, yythunkpos99= G->thunkpos;  if (!yy_Newline(G)) { goto l99; }  goto l96;
  l99:;	  G->pos= yypos99; G->thunkpos= yythunkpos99;
  }
  {  int yypos100= G->pos, yythunkpos100= G->thunkpos;  if (!yymatchChar(G, '>')) goto l100;  goto l96;
  l100:;	  G->pos= yypos100; G->thunkpos= yythunkpos100;
  }  if (!yymatchDot(G)) goto l96;  goto l95;
  l96:;	  G->pos= yypos96; G->thunkpos= yythunkpos96;
  }  yyText(G, G->begin, G->end);  if (!(YY_END)) goto l90;  yyDo(G, yy_2_AutoLinkEmail, G->begin, G->end);  if (!yymatchChar(G, '>')) goto l90;  yyText(G, G->begin, G->end);  if (!(YY_END)) goto l90;  yyDo(G, yy_3_AutoLinkEmail, G->begin, G->end);
  yyprintf((stderr, "  ok   %s @ %s\n", "AutoLinkEmail", G->buf+G->pos));  yyDo(G, yyPop, 1, 0);
  return 1;
  l90:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "AutoLinkEmail", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_AutoLinkUrl(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;  yyDo(G, yyPush, 1, 0);
  yyprintf((stderr, "%s\n", "AutoLinkUrl"));  yyText(G, G->begin, G->end);  if (!(YY_BEGIN)) goto l101;  if (!yy_LocMarker(G)) { goto l101; }  yyDo(G, yySet, -1, 0);  yyDo(G, yy_1_AutoLinkUrl, G->begin, G->end);  if (!yymatchChar(G, '<')) goto l101;  yyText(G, G->begin, G->end);  if (!(YY_BEGIN)) goto l101;  if (!yymatchClass(G, (unsigned char *)"\000\000\000\000\000\000\000\000\376\377\377\007\376\377\377\007\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000")) goto l101;
  l102:;	
  {  int yypos103= G->pos, yythunkpos103= G->thunkpos;  if (!yymatchClass(G, (unsigned char *)"\000\000\000\000\000\000\000\000\376\377\377\007\376\377\377\007\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000")) goto l103;  goto l102;
  l103:;	  G->pos= yypos103; G->thunkpos= yythunkpos103;
  }  if (!yymatchString(G, "://")) goto l101;
  {  int yypos106= G->pos, yythunkpos106= G->thunkpos;  if (!yy_Newline(G)) { goto l106; }  goto l101;
  l106:;	  G->pos= yypos106; G->thunkpos= yythunkpos106;
  }
  {  int yypos107= G->pos, yythunkpos107= G->thunkpos;  if (!yymatchChar(G, '>')) goto l107;  goto l101;
  l107:;	  G->pos= yypos107; G->thunkpos= yythunkpos107;
  }  if (!yymatchDot(G)) goto l101;
  l104:;	
  {  int yypos105= G->pos, yythunkpos105= G->thunkpos;
  {  int yypos108= G->pos, yythunkpos108= G->thunkpos;  if (!yy_Newline(G)) { goto l108; }  goto l105;
  l108:;	  G->pos= yypos108; G->thunkpos= yythunkpos108;
  }
  {  int yypos109= G->pos, yythunkpos109= G->thunkpos;  if (!yymatchChar(G, '>')) goto l109;  goto l105;
  l109:;	  G->pos= yypos109; G->thunkpos= yythunkpos109;
  }  if (!yymatchDot(G)) goto l105;  goto l104;
  l105:;	  G->pos= yypos105; G->thunkpos= yythunkpos105;
  }  yyText(G, G->begin, G->end);  if (!(YY_END)) goto l101;  yyDo(G, yy_2_AutoLinkUrl, G->begin, G->end);  if (!yymatchChar(G, '>')) goto l101;  yyText(G, G->begin, G->end);  if (!(YY_END)) goto l101;  yyDo(G, yy_3_AutoLinkUrl, G->begin, G->end);
  yyprintf((stderr, "  ok   %s @ %s\n", "AutoLinkUrl", G->buf+G->pos));  yyDo(G, yyPop, 1, 0);
  return 1;
  l101:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "AutoLinkUrl", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_ImageSizeHeight(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "ImageSizeHeight"));  if (!yymatchString(G, "=x")) goto l110;  if (!yymatchClass(G, (unsigned char *)"\000\000\000\000\000\000\377\003\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000")) goto l110;
  l111:;	
  {  int yypos112= G->pos, yythunkpos112= G->thunkpos;  if (!yymatchClass(G, (unsigned char *)"\000\000\000\000\000\000\377\003\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000")) goto l112;  goto l111;
  l112:;	  G->pos= yypos112; G->thunkpos= yythunkpos112;
  }
  yyprintf((stderr, "  ok   %s @ %s\n", "ImageSizeHeight", G->buf+G->pos));
  return 1;
  l110:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "ImageSizeHeight", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_ImageSizeWidth(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "ImageSizeWidth"));  if (!yymatchChar(G, '=')) goto l113;  if (!yymatchClass(G, (unsigned char *)"\000\000\000\000\000\000\377\003\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000")) goto l113;
  l114:;	
  {  int yypos115= G->pos, yythunkpos115= G->thunkpos;  if (!yymatchClass(G, (unsigned char *)"\000\000\000\000\000\000\377\003\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000")) goto l115;  goto l114;
  l115:;	  G->pos= yypos115; G->thunkpos= yythunkpos115;
  }  if (!yymatchChar(G, 'x')) goto l113;
  yyprintf((stderr, "  ok   %s @ %s\n", "ImageSizeWidth", G->buf+G->pos));
  return 1;
  l113:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "ImageSizeWidth", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_ImageSizeComplete(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "ImageSizeComplete"));  if (!yymatchChar(G, '=')) goto l116;  if (!yymatchClass(G, (unsigned char *)"\000\000\000\000\000\000\377\003\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000")) goto l116;
  l117:;	
  {  int yypos118= G->pos, yythunkpos118= G->thunkpos;  if (!yymatchClass(G, (unsigned char *)"\000\000\000\000\000\000\377\003\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000")) goto l118;  goto l117;
  l118:;	  G->pos= yypos118; G->thunkpos= yythunkpos118;
  }  if (!yymatchChar(G, 'x')) goto l116;  if (!yymatchClass(G, (unsigned char *)"\000\000\000\000\000\000\377\003\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000")) goto l116;
  l119:;	
  {  int yypos120= G->pos, yythunkpos120= G->thunkpos;  if (!yymatchClass(G, (unsigned char *)"\000\000\000\000\000\000\377\003\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000")) goto l120;  goto l119;
  l120:;	  G->pos= yypos120; G->thunkpos= yythunkpos120;
  }
  yyprintf((stderr, "  ok   %s @ %s\n", "ImageSizeComplete", G->buf+G->pos));
  return 1;
  l116:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "ImageSizeComplete", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_TitleDoubleExt(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "TitleDoubleExt"));  if (!yymatchChar(G, '"')) goto l121;
  l122:;	
  {  int yypos123= G->pos, yythunkpos123= G->thunkpos;
  {  int yypos124= G->pos, yythunkpos124= G->thunkpos;
  {  int yypos125= G->pos, yythunkpos125= G->thunkpos;  if (!yymatchChar(G, '"')) goto l126;  goto l125;
  l126:;	  G->pos= yypos125; G->thunkpos= yythunkpos125;  if (!yy_Newline(G)) { goto l124; }
  }
  l125:;	  goto l123;
  l124:;	  G->pos= yypos124; G->thunkpos= yythunkpos124;
  }  if (!yymatchDot(G)) goto l123;  goto l122;
  l123:;	  G->pos= yypos123; G->thunkpos= yythunkpos123;
  }  if (!yymatchChar(G, '"')) goto l121;
  yyprintf((stderr, "  ok   %s @ %s\n", "TitleDoubleExt", G->buf+G->pos));
  return 1;
  l121:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "TitleDoubleExt", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_TitleSingleExt(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "TitleSingleExt"));  if (!yymatchChar(G, '\'')) goto l127;
  l128:;	
  {  int yypos129= G->pos, yythunkpos129= G->thunkpos;
  {  int yypos130= G->pos, yythunkpos130= G->thunkpos;
  {  int yypos131= G->pos, yythunkpos131= G->thunkpos;  if (!yymatchChar(G, '\'')) goto l132;  goto l131;
  l132:;	  G->pos= yypos131; G->thunkpos= yythunkpos131;  if (!yy_Newline(G)) { goto l130; }
  }
  l131:;	  goto l129;
  l130:;	  G->pos= yypos130; G->thunkpos= yythunkpos130;
  }  if (!yymatchDot(G)) goto l129;  goto l128;
  l129:;	  G->pos= yypos129; G->thunkpos= yythunkpos129;
  }  if (!yymatchChar(G, '\'')) goto l127;
  yyprintf((stderr, "  ok   %s @ %s\n", "TitleSingleExt", G->buf+G->pos));
  return 1;
  l127:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "TitleSingleExt", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_TitleDouble(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "TitleDouble"));  if (!yymatchChar(G, '"')) goto l133;
  l134:;	
  {  int yypos135= G->pos, yythunkpos135= G->thunkpos;
  {  int yypos136= G->pos, yythunkpos136= G->thunkpos;  if (!yymatchChar(G, '"')) goto l136;  if (!yy_Sp(G)) { goto l136; }
  {  int yypos137= G->pos, yythunkpos137= G->thunkpos;  if (!yymatchChar(G, ')')) goto l138;  goto l137;
  l138:;	  G->pos= yypos137; G->thunkpos= yythunkpos137;  if (!yy_Newline(G)) { goto l136; }
  }
  l137:;	  goto l135;
  l136:;	  G->pos= yypos136; G->thunkpos= yythunkpos136;
  }  if (!yymatchDot(G)) goto l135;  goto l134;
  l135:;	  G->pos= yypos135; G->thunkpos= yythunkpos135;
  }  if (!yymatchChar(G, '"')) goto l133;
  yyprintf((stderr, "  ok   %s @ %s\n", "TitleDouble", G->buf+G->pos));
  return 1;
  l133:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "TitleDouble", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_TitleSingle(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "TitleSingle"));  if (!yymatchChar(G, '\'')) goto l139;
  l140:;	
  {  int yypos141= G->pos, yythunkpos141= G->thunkpos;
  {  int yypos142= G->pos, yythunkpos142= G->thunkpos;  if (!yymatchChar(G, '\'')) goto l142;  if (!yy_Sp(G)) { goto l142; }
  {  int yypos143= G->pos, yythunkpos143= G->thunkpos;  if (!yymatchChar(G, ')')) goto l144;  goto l143;
  l144:;	  G->pos= yypos143; G->thunkpos= yythunkpos143;  if (!yy_Newline(G)) { goto l142; }
  }
  l143:;	  goto l141;
  l142:;	  G->pos= yypos142; G->thunkpos= yythunkpos142;
  }  if (!yymatchDot(G)) goto l141;  goto l140;
  l141:;	  G->pos= yypos141; G->thunkpos= yythunkpos141;
  }  if (!yymatchChar(G, '\'')) goto l139;
  yyprintf((stderr, "  ok   %s @ %s\n", "TitleSingle", G->buf+G->pos));
  return 1;
  l139:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "TitleSingle", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_SourceContents(GREG *G)
{
  yyprintf((stderr, "%s\n", "SourceContents"));
  l146:;	
  {  int yypos147= G->pos, yythunkpos147= G->thunkpos;
  {  int yypos148= G->pos, yythunkpos148= G->thunkpos;
  {  int yypos152= G->pos, yythunkpos152= G->thunkpos;  if (!yymatchChar(G, '(')) goto l152;  goto l149;
  l152:;	  G->pos= yypos152; G->thunkpos= yythunkpos152;
  }
  {  int yypos153= G->pos, yythunkpos153= G->thunkpos;  if (!yymatchChar(G, ')')) goto l153;  goto l149;
  l153:;	  G->pos= yypos153; G->thunkpos= yythunkpos153;
  }
  {  int yypos154= G->pos, yythunkpos154= G->thunkpos;  if (!yymatchChar(G, '>')) goto l154;  goto l149;
  l154:;	  G->pos= yypos154; G->thunkpos= yythunkpos154;
  }  if (!yy_Nonspacechar(G)) { goto l149; }
  l150:;	
  {  int yypos151= G->pos, yythunkpos151= G->thunkpos;
  {  int yypos155= G->pos, yythunkpos155= G->thunkpos;  if (!yymatchChar(G, '(')) goto l155;  goto l151;
  l155:;	  G->pos= yypos155; G->thunkpos= yythunkpos155;
  }
  {  int yypos156= G->pos, yythunkpos156= G->thunkpos;  if (!yymatchChar(G, ')')) goto l156;  goto l151;
  l156:;	  G->pos= yypos156; G->thunkpos= yythunkpos156;
  }
  {  int yypos157= G->pos, yythunkpos157= G->thunkpos;  if (!yymatchChar(G, '>')) goto l157;  goto l151;
  l157:;	  G->pos= yypos157; G->thunkpos= yythunkpos157;
  }  if (!yy_Nonspacechar(G)) { goto l151; }  goto l150;
  l151:;	  G->pos= yypos151; G->thunkpos= yythunkpos151;
  }  goto l148;
  l149:;	  G->pos= yypos148; G->thunkpos= yythunkpos148;  if (!yymatchChar(G, '(')) goto l147;  if (!yy_SourceContents(G)) { goto l147; }  if (!yymatchChar(G, ')')) goto l147;
  }
  l148:;	  goto l146;
  l147:;	  G->pos= yypos147; G->thunkpos= yythunkpos147;
  }
  yyprintf((stderr, "  ok   %s @ %s\n", "SourceContents", G->buf+G->pos));
  return 1;
}
YY_RULE(int) yy_ImageSize(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "ImageSize"));
  {  int yypos159= G->pos, yythunkpos159= G->thunkpos;  if (!yy_ImageSizeComplete(G)) { goto l160; }  goto l159;
  l160:;	  G->pos= yypos159; G->thunkpos= yythunkpos159;  if (!yy_ImageSizeWidth(G)) { goto l161; }  goto l159;
  l161:;	  G->pos= yypos159; G->thunkpos= yythunkpos159;  if (!yy_ImageSizeHeight(G)) { goto l162; }  goto l159;
  l162:;	  G->pos= yypos159; G->thunkpos= yythunkpos159;  if (!yymatchString(G, "")) goto l158;
  }
  l159:;	
  yyprintf((stderr, "  ok   %s @ %s\n", "ImageSize", G->buf+G->pos));
  return 1;
  l158:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "ImageSize", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_TitleExt(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "TitleExt"));
  {  int yypos164= G->pos, yythunkpos164= G->thunkpos;  if (!yy_TitleSingleExt(G)) { goto l165; }  goto l164;
  l165:;	  G->pos= yypos164; G->thunkpos= yythunkpos164;  if (!yy_TitleDoubleExt(G)) { goto l166; }  goto l164;
  l166:;	  G->pos= yypos164; G->thunkpos= yythunkpos164;  if (!yymatchString(G, "")) goto l163;
  }
  l164:;	
  yyprintf((stderr, "  ok   %s @ %s\n", "TitleExt", G->buf+G->pos));
  return 1;
  l163:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "TitleExt", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_Title(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "Title"));
  {  int yypos168= G->pos, yythunkpos168= G->thunkpos;  if (!yy_TitleSingle(G)) { goto l169; }  goto l168;
  l169:;	  G->pos= yypos168; G->thunkpos= yythunkpos168;  if (!yy_TitleDouble(G)) { goto l170; }  goto l168;
  l170:;	  G->pos= yypos168; G->thunkpos= yythunkpos168;  if (!yymatchString(G, "")) goto l167;
  }
  l168:;	
  yyprintf((stderr, "  ok   %s @ %s\n", "Title", G->buf+G->pos));
  return 1;
  l167:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "Title", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_Source(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "Source"));  yyDo(G, yy_1_Source, G->begin, G->end);
  {  int yypos172= G->pos, yythunkpos172= G->thunkpos;  if (!yymatchChar(G, '<')) goto l173;  yyText(G, G->begin, G->end);  if (!(YY_BEGIN)) goto l173;  if (!yy_SourceContents(G)) { goto l173; }  yyText(G, G->begin, G->end);  if (!(YY_END)) goto l173;  yyDo(G, yy_2_Source, G->begin, G->end);  if (!yymatchChar(G, '>')) goto l173;  goto l172;
  l173:;	  G->pos= yypos172; G->thunkpos= yythunkpos172;  yyText(G, G->begin, G->end);  if (!(YY_BEGIN)) goto l171;  if (!yy_SourceContents(G)) { goto l171; }  yyText(G, G->begin, G->end);  if (!(YY_END)) goto l171;  yyDo(G, yy_3_Source, G->begin, G->end);
  }
  l172:;	
  yyprintf((stderr, "  ok   %s @ %s\n", "Source", G->buf+G->pos));
  return 1;
  l171:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "Source", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_Label(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;  yyDo(G, yyPush, 1, 0);
  yyprintf((stderr, "%s\n", "Label"));  yyText(G, G->begin, G->end);  if (!(YY_BEGIN)) goto l174;  if (!yy_LocMarker(G)) { goto l174; }  yyDo(G, yySet, -1, 0);  if (!yymatchChar(G, '[')) goto l174;
  {  int yypos175= G->pos, yythunkpos175= G->thunkpos;
  {  int yypos177= G->pos, yythunkpos177= G->thunkpos;  if (!yymatchChar(G, '^')) goto l177;  goto l176;
  l177:;	  G->pos= yypos177; G->thunkpos= yythunkpos177;
  }  yyText(G, G->begin, G->end);  if (!( EXT(pmh_EXT_NOTES) )) goto l176;  goto l175;
  l176:;	  G->pos= yypos175; G->thunkpos= yythunkpos175;
  {  int yypos178= G->pos, yythunkpos178= G->thunkpos;  if (!yymatchDot(G)) goto l174;  G->pos= yypos178; G->thunkpos= yythunkpos178;
  }  yyText(G, G->begin, G->end);  if (!( !EXT(pmh_EXT_NOTES) )) goto l174;
  }
  l175:;	  yyText(G, G->begin, G->end);  if (!(YY_BEGIN)) goto l174;
  l179:;	
  {  int yypos180= G->pos, yythunkpos180= G->thunkpos;
  {  int yypos181= G->pos, yythunkpos181= G->thunkpos;  if (!yymatchChar(G, ']')) goto l181;  goto l180;
  l181:;	  G->pos= yypos181; G->thunkpos= yythunkpos181;
  }  if (!yy_Inline(G)) { goto l180; }  goto l179;
  l180:;	  G->pos= yypos180; G->thunkpos= yythunkpos180;
  }  yyText(G, G->begin, G->end);  if (!(YY_END)) goto l174;  yyDo(G, yy_1_Label, G->begin, G->end);  if (!yymatchChar(G, ']')) goto l174;  yyText(G, G->begin, G->end);  if (!(YY_END)) goto l174;  yyDo(G, yy_2_Label, G->begin, G->end);
  yyprintf((stderr, "  ok   %s @ %s\n", "Label", G->buf+G->pos));  yyDo(G, yyPop, 1, 0);
  return 1;
  l174:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "Label", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_ReferenceLinkSingle(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;  yyDo(G, yyPush, 1, 0);
  yyprintf((stderr, "%s\n", "ReferenceLinkSingle"));  yyText(G, G->begin, G->end);  if (!(YY_BEGIN)) goto l182;  if (!yy_Label(G)) { goto l182; }  yyDo(G, yySet, -1, 0);
  {  int yypos183= G->pos, yythunkpos183= G->thunkpos;  if (!yy_Spnl(G)) { goto l183; }  if (!yymatchString(G, "[]")) goto l183;  goto l184;
  l183:;	  G->pos= yypos183; G->thunkpos= yythunkpos183;
  }
  l184:;	  yyText(G, G->begin, G->end);  if (!(YY_END)) goto l182;  yyDo(G, yy_1_ReferenceLinkSingle, G->begin, G->end);
  yyprintf((stderr, "  ok   %s @ %s\n", "ReferenceLinkSingle", G->buf+G->pos));  yyDo(G, yyPop, 1, 0);
  return 1;
  l182:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "ReferenceLinkSingle", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_ReferenceLinkDouble(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;  yyDo(G, yyPush, 2, 0);
  yyprintf((stderr, "%s\n", "ReferenceLinkDouble"));  yyText(G, G->begin, G->end);  if (!(YY_BEGIN)) goto l185;  if (!yy_Label(G)) { goto l185; }  yyDo(G, yySet, -2, 0);  if (!yy_Spnl(G)) { goto l185; }
  {  int yypos186= G->pos, yythunkpos186= G->thunkpos;  if (!yymatchString(G, "[]")) goto l186;  goto l185;
  l186:;	  G->pos= yypos186; G->thunkpos= yythunkpos186;
  }  if (!yy_Label(G)) { goto l185; }  yyDo(G, yySet, -1, 0);  yyText(G, G->begin, G->end);  if (!(YY_END)) goto l185;  yyDo(G, yy_1_ReferenceLinkDouble, G->begin, G->end);
  yyprintf((stderr, "  ok   %s @ %s\n", "ReferenceLinkDouble", G->buf+G->pos));  yyDo(G, yyPop, 2, 0);
  return 1;
  l185:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "ReferenceLinkDouble", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_AutoLink(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "AutoLink"));
  {  int yypos188= G->pos, yythunkpos188= G->thunkpos;  if (!yy_AutoLinkUrl(G)) { goto l189; }  goto l188;
  l189:;	  G->pos= yypos188; G->thunkpos= yythunkpos188;  if (!yy_AutoLinkEmail(G)) { goto l187; }
  }
  l188:;	
  yyprintf((stderr, "  ok   %s @ %s\n", "AutoLink", G->buf+G->pos));
  return 1;
  l187:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "AutoLink", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_ReferenceLink(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "ReferenceLink"));
  {  int yypos191= G->pos, yythunkpos191= G->thunkpos;  if (!yy_ReferenceLinkDouble(G)) { goto l192; }  goto l191;
  l192:;	  G->pos= yypos191; G->thunkpos= yythunkpos191;  if (!yy_ReferenceLinkSingle(G)) { goto l190; }
  }
  l191:;	
  yyprintf((stderr, "  ok   %s @ %s\n", "ReferenceLink", G->buf+G->pos));
  return 1;
  l190:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "ReferenceLink", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_ExplicitLinkSize(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;  yyDo(G, yyPush, 2, 0);
  yyprintf((stderr, "%s\n", "ExplicitLinkSize"));  yyText(G, G->begin, G->end);  if (!(YY_BEGIN)) goto l193;  if (!yy_Label(G)) { goto l193; }  yyDo(G, yySet, -2, 0);  if (!yy_Spnl(G)) { goto l193; }  if (!yymatchChar(G, '(')) goto l193;  if (!yy_Sp(G)) { goto l193; }  if (!yy_Source(G)) { goto l193; }  yyDo(G, yySet, -1, 0);  if (!yy_Spnl(G)) { goto l193; }  if (!yy_TitleExt(G)) { goto l193; }  if (!yy_Sp(G)) { goto l193; }  if (!yy_ImageSize(G)) { goto l193; }  if (!yy_Sp(G)) { goto l193; }  if (!yymatchChar(G, ')')) goto l193;  yyText(G, G->begin, G->end);  if (!(YY_END)) goto l193;  yyDo(G, yy_1_ExplicitLinkSize, G->begin, G->end);
  yyprintf((stderr, "  ok   %s @ %s\n", "ExplicitLinkSize", G->buf+G->pos));  yyDo(G, yyPop, 2, 0);
  return 1;
  l193:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "ExplicitLinkSize", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_ExplicitLink(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;  yyDo(G, yyPush, 2, 0);
  yyprintf((stderr, "%s\n", "ExplicitLink"));  yyText(G, G->begin, G->end);  if (!(YY_BEGIN)) goto l194;  if (!yy_Label(G)) { goto l194; }  yyDo(G, yySet, -2, 0);  if (!yy_Spnl(G)) { goto l194; }  if (!yymatchChar(G, '(')) goto l194;  if (!yy_Sp(G)) { goto l194; }  if (!yy_Source(G)) { goto l194; }  yyDo(G, yySet, -1, 0);  if (!yy_Spnl(G)) { goto l194; }  if (!yy_Title(G)) { goto l194; }  if (!yy_Sp(G)) { goto l194; }  if (!yymatchChar(G, ')')) goto l194;  yyText(G, G->begin, G->end);  if (!(YY_END)) goto l194;  yyDo(G, yy_1_ExplicitLink, G->begin, G->end);
  yyprintf((stderr, "  ok   %s @ %s\n", "ExplicitLink", G->buf+G->pos));  yyDo(G, yyPop, 2, 0);
  return 1;
  l194:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "ExplicitLink", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_StrongUl(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;  yyDo(G, yyPush, 1, 0);
  yyprintf((stderr, "%s\n", "StrongUl"));  yyText(G, G->begin, G->end);  if (!(YY_BEGIN)) goto l195;  if (!yy_LocMarker(G)) { goto l195; }  yyDo(G, yySet, -1, 0);  if (!yymatchString(G, "__")) goto l195;
  {  int yypos196= G->pos, yythunkpos196= G->thunkpos;  if (!yy_Whitespace(G)) { goto l196; }  goto l195;
  l196:;	  G->pos= yypos196; G->thunkpos= yythunkpos196;
  }
  {  int yypos199= G->pos, yythunkpos199= G->thunkpos;  if (!yymatchString(G, "__")) goto l199;  goto l195;
  l199:;	  G->pos= yypos199; G->thunkpos= yythunkpos199;
  }  if (!yy_Inline(G)) { goto l195; }
  l197:;	
  {  int yypos198= G->pos, yythunkpos198= G->thunkpos;
  {  int yypos200= G->pos, yythunkpos200= G->thunkpos;  if (!yymatchString(G, "__")) goto l200;  goto l198;
  l200:;	  G->pos= yypos200; G->thunkpos= yythunkpos200;
  }  if (!yy_Inline(G)) { goto l198; }  goto l197;
  l198:;	  G->pos= yypos198; G->thunkpos= yythunkpos198;
  }  if (!yymatchString(G, "__")) goto l195;  yyText(G, G->begin, G->end);  if (!(YY_END)) goto l195;  yyDo(G, yy_1_StrongUl, G->begin, G->end);
  yyprintf((stderr, "  ok   %s @ %s\n", "StrongUl", G->buf+G->pos));  yyDo(G, yyPop, 1, 0);
  return 1;
  l195:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "StrongUl", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_StrongStar(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;  yyDo(G, yyPush, 1, 0);
  yyprintf((stderr, "%s\n", "StrongStar"));  yyText(G, G->begin, G->end);  if (!(YY_BEGIN)) goto l201;  if (!yy_LocMarker(G)) { goto l201; }  yyDo(G, yySet, -1, 0);  if (!yymatchString(G, "**")) goto l201;
  {  int yypos202= G->pos, yythunkpos202= G->thunkpos;  if (!yy_Whitespace(G)) { goto l202; }  goto l201;
  l202:;	  G->pos= yypos202; G->thunkpos= yythunkpos202;
  }
  {  int yypos205= G->pos, yythunkpos205= G->thunkpos;  if (!yymatchString(G, "**")) goto l205;  goto l201;
  l205:;	  G->pos= yypos205; G->thunkpos= yythunkpos205;
  }  if (!yy_Inline(G)) { goto l201; }
  l203:;	
  {  int yypos204= G->pos, yythunkpos204= G->thunkpos;
  {  int yypos206= G->pos, yythunkpos206= G->thunkpos;  if (!yymatchString(G, "**")) goto l206;  goto l204;
  l206:;	  G->pos= yypos206; G->thunkpos= yythunkpos206;
  }  if (!yy_Inline(G)) { goto l204; }  goto l203;
  l204:;	  G->pos= yypos204; G->thunkpos= yythunkpos204;
  }  if (!yymatchString(G, "**")) goto l201;  yyText(G, G->begin, G->end);  if (!(YY_END)) goto l201;  yyDo(G, yy_1_StrongStar, G->begin, G->end);
  yyprintf((stderr, "  ok   %s @ %s\n", "StrongStar", G->buf+G->pos));  yyDo(G, yyPop, 1, 0);
  return 1;
  l201:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "StrongStar", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_Whitespace(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "Whitespace"));
  {  int yypos208= G->pos, yythunkpos208= G->thunkpos;  if (!yy_Spacechar(G)) { goto l209; }  goto l208;
  l209:;	  G->pos= yypos208; G->thunkpos= yythunkpos208;  if (!yy_Newline(G)) { goto l207; }
  }
  l208:;	
  yyprintf((stderr, "  ok   %s @ %s\n", "Whitespace", G->buf+G->pos));
  return 1;
  l207:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "Whitespace", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_EmphUl(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;  yyDo(G, yyPush, 1, 0);
  yyprintf((stderr, "%s\n", "EmphUl"));  yyText(G, G->begin, G->end);  if (!(YY_BEGIN)) goto l210;  if (!yy_LocMarker(G)) { goto l210; }  yyDo(G, yySet, -1, 0);  if (!yymatchChar(G, '_')) goto l210;
  {  int yypos211= G->pos, yythunkpos211= G->thunkpos;  if (!yy_Whitespace(G)) { goto l211; }  goto l210;
  l211:;	  G->pos= yypos211; G->thunkpos= yythunkpos211;
  }
  {  int yypos214= G->pos, yythunkpos214= G->thunkpos;
  {  int yypos216= G->pos, yythunkpos216= G->thunkpos;  if (!yymatchChar(G, '_')) goto l216;  goto l215;
  l216:;	  G->pos= yypos216; G->thunkpos= yythunkpos216;
  }  if (!yy_Inline(G)) { goto l215; }  goto l214;
  l215:;	  G->pos= yypos214; G->thunkpos= yythunkpos214;  if (!yy_StrongUl(G)) { goto l210; }
  }
  l214:;	
  l212:;	
  {  int yypos213= G->pos, yythunkpos213= G->thunkpos;
  {  int yypos217= G->pos, yythunkpos217= G->thunkpos;
  {  int yypos219= G->pos, yythunkpos219= G->thunkpos;  if (!yymatchChar(G, '_')) goto l219;  goto l218;
  l219:;	  G->pos= yypos219; G->thunkpos= yythunkpos219;
  }  if (!yy_Inline(G)) { goto l218; }  goto l217;
  l218:;	  G->pos= yypos217; G->thunkpos= yythunkpos217;  if (!yy_StrongUl(G)) { goto l213; }
  }
  l217:;	  goto l212;
  l213:;	  G->pos= yypos213; G->thunkpos= yythunkpos213;
  }  if (!yymatchChar(G, '_')) goto l210;  yyText(G, G->begin, G->end);  if (!(YY_END)) goto l210;  yyDo(G, yy_1_EmphUl, G->begin, G->end);
  yyprintf((stderr, "  ok   %s @ %s\n", "EmphUl", G->buf+G->pos));  yyDo(G, yyPop, 1, 0);
  return 1;
  l210:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "EmphUl", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_EmphStar(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;  yyDo(G, yyPush, 1, 0);
  yyprintf((stderr, "%s\n", "EmphStar"));  yyText(G, G->begin, G->end);  if (!(YY_BEGIN)) goto l220;  if (!yy_LocMarker(G)) { goto l220; }  yyDo(G, yySet, -1, 0);  if (!yymatchChar(G, '*')) goto l220;
  {  int yypos221= G->pos, yythunkpos221= G->thunkpos;  if (!yy_Whitespace(G)) { goto l221; }  goto l220;
  l221:;	  G->pos= yypos221; G->thunkpos= yythunkpos221;
  }
  {  int yypos224= G->pos, yythunkpos224= G->thunkpos;
  {  int yypos226= G->pos, yythunkpos226= G->thunkpos;  if (!yymatchChar(G, '*')) goto l226;  goto l225;
  l226:;	  G->pos= yypos226; G->thunkpos= yythunkpos226;
  }  if (!yy_Inline(G)) { goto l225; }  goto l224;
  l225:;	  G->pos= yypos224; G->thunkpos= yythunkpos224;  if (!yy_StrongStar(G)) { goto l220; }
  }
  l224:;	
  l222:;	
  {  int yypos223= G->pos, yythunkpos223= G->thunkpos;
  {  int yypos227= G->pos, yythunkpos227= G->thunkpos;
  {  int yypos229= G->pos, yythunkpos229= G->thunkpos;  if (!yymatchChar(G, '*')) goto l229;  goto l228;
  l229:;	  G->pos= yypos229; G->thunkpos= yythunkpos229;
  }  if (!yy_Inline(G)) { goto l228; }  goto l227;
  l228:;	  G->pos= yypos227; G->thunkpos= yythunkpos227;  if (!yy_StrongStar(G)) { goto l223; }
  }
  l227:;	  goto l222;
  l223:;	  G->pos= yypos223; G->thunkpos= yythunkpos223;
  }  if (!yymatchChar(G, '*')) goto l220;  yyText(G, G->begin, G->end);  if (!(YY_END)) goto l220;  yyDo(G, yy_1_EmphStar, G->begin, G->end);
  yyprintf((stderr, "  ok   %s @ %s\n", "EmphStar", G->buf+G->pos));  yyDo(G, yyPop, 1, 0);
  return 1;
  l220:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "EmphStar", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_StarLine(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "StarLine"));
  {  int yypos231= G->pos, yythunkpos231= G->thunkpos;  if (!yymatchString(G, "****")) goto l232;
  l233:;	
  {  int yypos234= G->pos, yythunkpos234= G->thunkpos;  if (!yymatchChar(G, '*')) goto l234;  goto l233;
  l234:;	  G->pos= yypos234; G->thunkpos= yythunkpos234;
  }  goto l231;
  l232:;	  G->pos= yypos231; G->thunkpos= yythunkpos231;  if (!yy_Spacechar(G)) { goto l230; }  if (!yymatchChar(G, '*')) goto l230;
  l235:;	
  {  int yypos236= G->pos, yythunkpos236= G->thunkpos;  if (!yymatchChar(G, '*')) goto l236;  goto l235;
  l236:;	  G->pos= yypos236; G->thunkpos= yythunkpos236;
  }
  {  int yypos237= G->pos, yythunkpos237= G->thunkpos;  if (!yy_Spacechar(G)) { goto l230; }  G->pos= yypos237; G->thunkpos= yythunkpos237;
  }
  }
  l231:;	
  yyprintf((stderr, "  ok   %s @ %s\n", "StarLine", G->buf+G->pos));
  return 1;
  l230:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "StarLine", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_UlLine(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "UlLine"));
  {  int yypos239= G->pos, yythunkpos239= G->thunkpos;  if (!yymatchString(G, "____")) goto l240;
  l241:;	
  {  int yypos242= G->pos, yythunkpos242= G->thunkpos;  if (!yymatchChar(G, '_')) goto l242;  goto l241;
  l242:;	  G->pos= yypos242; G->thunkpos= yythunkpos242;
  }  goto l239;
  l240:;	  G->pos= yypos239; G->thunkpos= yythunkpos239;  if (!yy_Spacechar(G)) { goto l238; }  if (!yymatchChar(G, '_')) goto l238;
  l243:;	
  {  int yypos244= G->pos, yythunkpos244= G->thunkpos;  if (!yymatchChar(G, '_')) goto l244;  goto l243;
  l244:;	  G->pos= yypos244; G->thunkpos= yythunkpos244;
  }
  {  int yypos245= G->pos, yythunkpos245= G->thunkpos;  if (!yy_Spacechar(G)) { goto l238; }  G->pos= yypos245; G->thunkpos= yythunkpos245;
  }
  }
  l239:;	
  yyprintf((stderr, "  ok   %s @ %s\n", "UlLine", G->buf+G->pos));
  return 1;
  l238:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "UlLine", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_SpecialChar(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "SpecialChar"));
  {  int yypos247= G->pos, yythunkpos247= G->thunkpos;  if (!yymatchChar(G, '~')) goto l248;  goto l247;
  l248:;	  G->pos= yypos247; G->thunkpos= yythunkpos247;  if (!yymatchChar(G, '*')) goto l249;  goto l247;
  l249:;	  G->pos= yypos247; G->thunkpos= yythunkpos247;  if (!yymatchChar(G, '_')) goto l250;  goto l247;
  l250:;	  G->pos= yypos247; G->thunkpos= yythunkpos247;  if (!yymatchChar(G, '`')) goto l251;  goto l247;
  l251:;	  G->pos= yypos247; G->thunkpos= yythunkpos247;  if (!yymatchChar(G, '&')) goto l252;  goto l247;
  l252:;	  G->pos= yypos247; G->thunkpos= yythunkpos247;  if (!yymatchChar(G, '[')) goto l253;  goto l247;
  l253:;	  G->pos= yypos247; G->thunkpos= yythunkpos247;  if (!yymatchChar(G, ']')) goto l254;  goto l247;
  l254:;	  G->pos= yypos247; G->thunkpos= yythunkpos247;  if (!yymatchChar(G, '(')) goto l255;  goto l247;
  l255:;	  G->pos= yypos247; G->thunkpos= yythunkpos247;  if (!yymatchChar(G, ')')) goto l256;  goto l247;
  l256:;	  G->pos= yypos247; G->thunkpos= yythunkpos247;  if (!yymatchChar(G, '<')) goto l257;  goto l247;
  l257:;	  G->pos= yypos247; G->thunkpos= yythunkpos247;  if (!yymatchChar(G, '!')) goto l258;  goto l247;
  l258:;	  G->pos= yypos247; G->thunkpos= yythunkpos247;  if (!yymatchChar(G, '#')) goto l259;  goto l247;
  l259:;	  G->pos= yypos247; G->thunkpos= yythunkpos247;  if (!yymatchChar(G, '\\')) goto l260;  goto l247;
  l260:;	  G->pos= yypos247; G->thunkpos= yythunkpos247;  if (!yymatchChar(G, '\'')) goto l261;  goto l247;
  l261:;	  G->pos= yypos247; G->thunkpos= yythunkpos247;  if (!yymatchChar(G, '"')) goto l262;  goto l247;
  l262:;	  G->pos= yypos247; G->thunkpos= yythunkpos247;  if (!yy_ExtendedSpecialChar(G)) { goto l246; }
  }
  l247:;	
  yyprintf((stderr, "  ok   %s @ %s\n", "SpecialChar", G->buf+G->pos));
  return 1;
  l246:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "SpecialChar", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_Eof(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "Eof"));
  {  int yypos264= G->pos, yythunkpos264= G->thunkpos;  if (!yymatchDot(G)) goto l264;  goto l263;
  l264:;	  G->pos= yypos264; G->thunkpos= yythunkpos264;
  }
  yyprintf((stderr, "  ok   %s @ %s\n", "Eof", G->buf+G->pos));
  return 1;
  l263:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "Eof", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_NormalEndline(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "NormalEndline"));  if (!yy_Sp(G)) { goto l265; }  if (!yy_Newline(G)) { goto l265; }
  {  int yypos266= G->pos, yythunkpos266= G->thunkpos;  if (!yy_BlankLine(G)) { goto l266; }  goto l265;
  l266:;	  G->pos= yypos266; G->thunkpos= yythunkpos266;
  }
  {  int yypos267= G->pos, yythunkpos267= G->thunkpos;  if (!yymatchChar(G, '>')) goto l267;  goto l265;
  l267:;	  G->pos= yypos267; G->thunkpos= yythunkpos267;
  }
  {  int yypos268= G->pos, yythunkpos268= G->thunkpos;  if (!yy_AtxStart(G)) { goto l268; }  goto l265;
  l268:;	  G->pos= yypos268; G->thunkpos= yythunkpos268;
  }
  {  int yypos269= G->pos, yythunkpos269= G->thunkpos;  if (!yy_Line(G)) { goto l269; }
  {  int yypos270= G->pos, yythunkpos270= G->thunkpos;  if (!yymatchChar(G, '=')) goto l271;
  l272:;	
  {  int yypos273= G->pos, yythunkpos273= G->thunkpos;  if (!yymatchChar(G, '=')) goto l273;  goto l272;
  l273:;	  G->pos= yypos273; G->thunkpos= yythunkpos273;
  }  goto l270;
  l271:;	  G->pos= yypos270; G->thunkpos= yythunkpos270;  if (!yymatchChar(G, '-')) goto l269;
  l274:;	
  {  int yypos275= G->pos, yythunkpos275= G->thunkpos;  if (!yymatchChar(G, '-')) goto l275;  goto l274;
  l275:;	  G->pos= yypos275; G->thunkpos= yythunkpos275;
  }
  }
  l270:;	  if (!yy_Newline(G)) { goto l269; }  goto l265;
  l269:;	  G->pos= yypos269; G->thunkpos= yythunkpos269;
  }
  yyprintf((stderr, "  ok   %s @ %s\n", "NormalEndline", G->buf+G->pos));
  return 1;
  l265:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "NormalEndline", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_TerminalEndline(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "TerminalEndline"));  if (!yy_Sp(G)) { goto l276; }  if (!yy_Newline(G)) { goto l276; }  if (!yy_Eof(G)) { goto l276; }
  yyprintf((stderr, "  ok   %s @ %s\n", "TerminalEndline", G->buf+G->pos));
  return 1;
  l276:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "TerminalEndline", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_LineBreak(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "LineBreak"));  if (!yymatchString(G, "  ")) goto l277;  if (!yy_NormalEndline(G)) { goto l277; }
  yyprintf((stderr, "  ok   %s @ %s\n", "LineBreak", G->buf+G->pos));
  return 1;
  l277:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "LineBreak", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_CharEntity(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "CharEntity"));  if (!yymatchChar(G, '&')) goto l278;  if (!yymatchClass(G, (unsigned char *)"\000\000\000\000\000\000\377\003\376\377\377\007\376\377\377\007\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000")) goto l278;
  l279:;	
  {  int yypos280= G->pos, yythunkpos280= G->thunkpos;  if (!yymatchClass(G, (unsigned char *)"\000\000\000\000\000\000\377\003\376\377\377\007\376\377\377\007\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000")) goto l280;  goto l279;
  l280:;	  G->pos= yypos280; G->thunkpos= yythunkpos280;
  }  if (!yymatchChar(G, ';')) goto l278;
  yyprintf((stderr, "  ok   %s @ %s\n", "CharEntity", G->buf+G->pos));
  return 1;
  l278:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "CharEntity", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_DecEntity(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "DecEntity"));  if (!yymatchChar(G, '&')) goto l281;  if (!yymatchChar(G, '#')) goto l281;  if (!yymatchClass(G, (unsigned char *)"\000\000\000\000\000\000\377\003\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000")) goto l281;
  l282:;	
  {  int yypos283= G->pos, yythunkpos283= G->thunkpos;  if (!yymatchClass(G, (unsigned char *)"\000\000\000\000\000\000\377\003\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000")) goto l283;  goto l282;
  l283:;	  G->pos= yypos283; G->thunkpos= yythunkpos283;
  }  if (!yymatchChar(G, ';')) goto l281;
  yyprintf((stderr, "  ok   %s @ %s\n", "DecEntity", G->buf+G->pos));
  return 1;
  l281:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "DecEntity", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_HexEntity(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "HexEntity"));  if (!yymatchChar(G, '&')) goto l284;  if (!yymatchChar(G, '#')) goto l284;  if (!yymatchClass(G, (unsigned char *)"\000\000\000\000\000\000\000\000\000\000\000\001\000\000\000\001\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000")) goto l284;  if (!yymatchClass(G, (unsigned char *)"\000\000\000\000\000\000\377\003\176\000\000\000\176\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000")) goto l284;
  l285:;	
  {  int yypos286= G->pos, yythunkpos286= G->thunkpos;  if (!yymatchClass(G, (unsigned char *)"\000\000\000\000\000\000\377\003\176\000\000\000\176\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000")) goto l286;  goto l285;
  l286:;	  G->pos= yypos286; G->thunkpos= yythunkpos286;
  }  if (!yymatchChar(G, ';')) goto l284;
  yyprintf((stderr, "  ok   %s @ %s\n", "HexEntity", G->buf+G->pos));
  return 1;
  l284:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "HexEntity", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_Alphanumeric(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "Alphanumeric"));
  {  int yypos288= G->pos, yythunkpos288= G->thunkpos;  if (!yymatchClass(G, (unsigned char *)"\000\000\000\000\000\000\377\003\376\377\377\007\376\377\377\007\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000")) goto l289;  goto l288;
  l289:;	  G->pos= yypos288; G->thunkpos= yythunkpos288;  if (!yymatchString(G, "\200")) goto l290;  goto l288;
  l290:;	  G->pos= yypos288; G->thunkpos= yythunkpos288;  if (!yymatchString(G, "\201")) goto l291;  goto l288;
  l291:;	  G->pos= yypos288; G->thunkpos= yythunkpos288;  if (!yymatchString(G, "\202")) goto l292;  goto l288;
  l292:;	  G->pos= yypos288; G->thunkpos= yythunkpos288;  if (!yymatchString(G, "\203")) goto l293;  goto l288;
  l293:;	  G->pos= yypos288; G->thunkpos= yythunkpos288;  if (!yymatchString(G, "\204")) goto l294;  goto l288;
  l294:;	  G->pos= yypos288; G->thunkpos= yythunkpos288;  if (!yymatchString(G, "\205")) goto l295;  goto l288;
  l295:;	  G->pos= yypos288; G->thunkpos= yythunkpos288;  if (!yymatchString(G, "\206")) goto l296;  goto l288;
  l296:;	  G->pos= yypos288; G->thunkpos= yythunkpos288;  if (!yymatchString(G, "\207")) goto l297;  goto l288;
  l297:;	  G->pos= yypos288; G->thunkpos= yythunkpos288;  if (!yymatchString(G, "\210")) goto l298;  goto l288;
  l298:;	  G->pos= yypos288; G->thunkpos= yythunkpos288;  if (!yymatchString(G, "\211")) goto l299;  goto l288;
  l299:;	  G->pos= yypos288; G->thunkpos= yythunkpos288;  if (!yymatchString(G, "\212")) goto l300;  goto l288;
  l300:;	  G->pos= yypos288; G->thunkpos= yythunkpos288;  if (!yymatchString(G, "\213")) goto l301;  goto l288;
  l301:;	  G->pos= yypos288; G->thunkpos= yythunkpos288;  if (!yymatchString(G, "\214")) goto l302;  goto l288;
  l302:;	  G->pos= yypos288; G->thunkpos= yythunkpos288;  if (!yymatchString(G, "\215")) goto l303;  goto l288;
  l303:;	  G->pos= yypos288; G->thunkpos= yythunkpos288;  if (!yymatchString(G, "\216")) goto l304;  goto l288;
  l304:;	  G->pos= yypos288; G->thunkpos= yythunkpos288;  if (!yymatchString(G, "\217")) goto l305;  goto l288;
  l305:;	  G->pos= yypos288; G->thunkpos= yythunkpos288;  if (!yymatchString(G, "\220")) goto l306;  goto l288;
  l306:;	  G->pos= yypos288; G->thunkpos= yythunkpos288;  if (!yymatchString(G, "\221")) goto l307;  goto l288;
  l307:;	  G->pos= yypos288; G->thunkpos= yythunkpos288;  if (!yymatchString(G, "\222")) goto l308;  goto l288;
  l308:;	  G->pos= yypos288; G->thunkpos= yythunkpos288;  if (!yymatchString(G, "\223")) goto l309;  goto l288;
  l309:;	  G->pos= yypos288; G->thunkpos= yythunkpos288;  if (!yymatchString(G, "\224")) goto l310;  goto l288;
  l310:;	  G->pos= yypos288; G->thunkpos= yythunkpos288;  if (!yymatchString(G, "\225")) goto l311;  goto l288;
  l311:;	  G->pos= yypos288; G->thunkpos= yythunkpos288;  if (!yymatchString(G, "\226")) goto l312;  goto l288;
  l312:;	  G->pos= yypos288; G->thunkpos= yythunkpos288;  if (!yymatchString(G, "\227")) goto l313;  goto l288;
  l313:;	  G->pos= yypos288; G->thunkpos= yythunkpos288;  if (!yymatchString(G, "\230")) goto l314;  goto l288;
  l314:;	  G->pos= yypos288; G->thunkpos= yythunkpos288;  if (!yymatchString(G, "\231")) goto l315;  goto l288;
  l315:;	  G->pos= yypos288; G->thunkpos= yythunkpos288;  if (!yymatchString(G, "\232")) goto l316;  goto l288;
  l316:;	  G->pos= yypos288; G->thunkpos= yythunkpos288;  if (!yymatchString(G, "\233")) goto l317;  goto l288;
  l317:;	  G->pos= yypos288; G->thunkpos= yythunkpos288;  if (!yymatchString(G, "\234")) goto l318;  goto l288;
  l318:;	  G->pos= yypos288; G->thunkpos= yythunkpos288;  if (!yymatchString(G, "\235")) goto l319;  goto l288;
  l319:;	  G->pos= yypos288; G->thunkpos= yythunkpos288;  if (!yymatchString(G, "\236")) goto l320;  goto l288;
  l320:;	  G->pos= yypos288; G->thunkpos= yythunkpos288;  if (!yymatchString(G, "\237")) goto l321;  goto l288;
  l321:;	  G->pos= yypos288; G->thunkpos= yythunkpos288;  if (!yymatchString(G, "\240")) goto l322;  goto l288;
  l322:;	  G->pos= yypos288; G->thunkpos= yythunkpos288;  if (!yymatchString(G, "\241")) goto l323;  goto l288;
  l323:;	  G->pos= yypos288; G->thunkpos= yythunkpos288;  if (!yymatchString(G, "\242")) goto l324;  goto l288;
  l324:;	  G->pos= yypos288; G->thunkpos= yythunkpos288;  if (!yymatchString(G, "\243")) goto l325;  goto l288;
  l325:;	  G->pos= yypos288; G->thunkpos= yythunkpos288;  if (!yymatchString(G, "\244")) goto l326;  goto l288;
  l326:;	  G->pos= yypos288; G->thunkpos= yythunkpos288;  if (!yymatchString(G, "\245")) goto l327;  goto l288;
  l327:;	  G->pos= yypos288; G->thunkpos= yythunkpos288;  if (!yymatchString(G, "\246")) goto l328;  goto l288;
  l328:;	  G->pos= yypos288; G->thunkpos= yythunkpos288;  if (!yymatchString(G, "\247")) goto l329;  goto l288;
  l329:;	  G->pos= yypos288; G->thunkpos= yythunkpos288;  if (!yymatchString(G, "\250")) goto l330;  goto l288;
  l330:;	  G->pos= yypos288; G->thunkpos= yythunkpos288;  if (!yymatchString(G, "\251")) goto l331;  goto l288;
  l331:;	  G->pos= yypos288; G->thunkpos= yythunkpos288;  if (!yymatchString(G, "\252")) goto l332;  goto l288;
  l332:;	  G->pos= yypos288; G->thunkpos= yythunkpos288;  if (!yymatchString(G, "\253")) goto l333;  goto l288;
  l333:;	  G->pos= yypos288; G->thunkpos= yythunkpos288;  if (!yymatchString(G, "\254")) goto l334;  goto l288;
  l334:;	  G->pos= yypos288; G->thunkpos= yythunkpos288;  if (!yymatchString(G, "\255")) goto l335;  goto l288;
  l335:;	  G->pos= yypos288; G->thunkpos= yythunkpos288;  if (!yymatchString(G, "\256")) goto l336;  goto l288;
  l336:;	  G->pos= yypos288; G->thunkpos= yythunkpos288;  if (!yymatchString(G, "\257")) goto l337;  goto l288;
  l337:;	  G->pos= yypos288; G->thunkpos= yythunkpos288;  if (!yymatchString(G, "\260")) goto l338;  goto l288;
  l338:;	  G->pos= yypos288; G->thunkpos= yythunkpos288;  if (!yymatchString(G, "\261")) goto l339;  goto l288;
  l339:;	  G->pos= yypos288; G->thunkpos= yythunkpos288;  if (!yymatchString(G, "\262")) goto l340;  goto l288;
  l340:;	  G->pos= yypos288; G->thunkpos= yythunkpos288;  if (!yymatchString(G, "\263")) goto l341;  goto l288;
  l341:;	  G->pos= yypos288; G->thunkpos= yythunkpos288;  if (!yymatchString(G, "\264")) goto l342;  goto l288;
  l342:;	  G->pos= yypos288; G->thunkpos= yythunkpos288;  if (!yymatchString(G, "\265")) goto l343;  goto l288;
  l343:;	  G->pos= yypos288; G->thunkpos= yythunkpos288;  if (!yymatchString(G, "\266")) goto l344;  goto l288;
  l344:;	  G->pos= yypos288; G->thunkpos= yythunkpos288;  if (!yymatchString(G, "\267")) goto l345;  goto l288;
  l345:;	  G->pos= yypos288; G->thunkpos= yythunkpos288;  if (!yymatchString(G, "\270")) goto l346;  goto l288;
  l346:;	  G->pos= yypos288; G->thunkpos= yythunkpos288;  if (!yymatchString(G, "\271")) goto l347;  goto l288;
  l347:;	  G->pos= yypos288; G->thunkpos= yythunkpos288;  if (!yymatchString(G, "\272")) goto l348;  goto l288;
  l348:;	  G->pos= yypos288; G->thunkpos= yythunkpos288;  if (!yymatchString(G, "\273")) goto l349;  goto l288;
  l349:;	  G->pos= yypos288; G->thunkpos= yythunkpos288;  if (!yymatchString(G, "\274")) goto l350;  goto l288;
  l350:;	  G->pos= yypos288; G->thunkpos= yythunkpos288;  if (!yymatchString(G, "\275")) goto l351;  goto l288;
  l351:;	  G->pos= yypos288; G->thunkpos= yythunkpos288;  if (!yymatchString(G, "\276")) goto l352;  goto l288;
  l352:;	  G->pos= yypos288; G->thunkpos= yythunkpos288;  if (!yymatchString(G, "\277")) goto l353;  goto l288;
  l353:;	  G->pos= yypos288; G->thunkpos= yythunkpos288;  if (!yymatchString(G, "\300")) goto l354;  goto l288;
  l354:;	  G->pos= yypos288; G->thunkpos= yythunkpos288;  if (!yymatchString(G, "\301")) goto l355;  goto l288;
  l355:;	  G->pos= yypos288; G->thunkpos= yythunkpos288;  if (!yymatchString(G, "\302")) goto l356;  goto l288;
  l356:;	  G->pos= yypos288; G->thunkpos= yythunkpos288;  if (!yymatchString(G, "\303")) goto l357;  goto l288;
  l357:;	  G->pos= yypos288; G->thunkpos= yythunkpos288;  if (!yymatchString(G, "\304")) goto l358;  goto l288;
  l358:;	  G->pos= yypos288; G->thunkpos= yythunkpos288;  if (!yymatchString(G, "\305")) goto l359;  goto l288;
  l359:;	  G->pos= yypos288; G->thunkpos= yythunkpos288;  if (!yymatchString(G, "\306")) goto l360;  goto l288;
  l360:;	  G->pos= yypos288; G->thunkpos= yythunkpos288;  if (!yymatchString(G, "\307")) goto l361;  goto l288;
  l361:;	  G->pos= yypos288; G->thunkpos= yythunkpos288;  if (!yymatchString(G, "\310")) goto l362;  goto l288;
  l362:;	  G->pos= yypos288; G->thunkpos= yythunkpos288;  if (!yymatchString(G, "\311")) goto l363;  goto l288;
  l363:;	  G->pos= yypos288; G->thunkpos= yythunkpos288;  if (!yymatchString(G, "\312")) goto l364;  goto l288;
  l364:;	  G->pos= yypos288; G->thunkpos= yythunkpos288;  if (!yymatchString(G, "\313")) goto l365;  goto l288;
  l365:;	  G->pos= yypos288; G->thunkpos= yythunkpos288;  if (!yymatchString(G, "\314")) goto l366;  goto l288;
  l366:;	  G->pos= yypos288; G->thunkpos= yythunkpos288;  if (!yymatchString(G, "\315")) goto l367;  goto l288;
  l367:;	  G->pos= yypos288; G->thunkpos= yythunkpos288;  if (!yymatchString(G, "\316")) goto l368;  goto l288;
  l368:;	  G->pos= yypos288; G->thunkpos= yythunkpos288;  if (!yymatchString(G, "\317")) goto l369;  goto l288;
  l369:;	  G->pos= yypos288; G->thunkpos= yythunkpos288;  if (!yymatchString(G, "\320")) goto l370;  goto l288;
  l370:;	  G->pos= yypos288; G->thunkpos= yythunkpos288;  if (!yymatchString(G, "\321")) goto l371;  goto l288;
  l371:;	  G->pos= yypos288; G->thunkpos= yythunkpos288;  if (!yymatchString(G, "\322")) goto l372;  goto l288;
  l372:;	  G->pos= yypos288; G->thunkpos= yythunkpos288;  if (!yymatchString(G, "\323")) goto l373;  goto l288;
  l373:;	  G->pos= yypos288; G->thunkpos= yythunkpos288;  if (!yymatchString(G, "\324")) goto l374;  goto l288;
  l374:;	  G->pos= yypos288; G->thunkpos= yythunkpos288;  if (!yymatchString(G, "\325")) goto l375;  goto l288;
  l375:;	  G->pos= yypos288; G->thunkpos= yythunkpos288;  if (!yymatchString(G, "\326")) goto l376;  goto l288;
  l376:;	  G->pos= yypos288; G->thunkpos= yythunkpos288;  if (!yymatchString(G, "\327")) goto l377;  goto l288;
  l377:;	  G->pos= yypos288; G->thunkpos= yythunkpos288;  if (!yymatchString(G, "\330")) goto l378;  goto l288;
  l378:;	  G->pos= yypos288; G->thunkpos= yythunkpos288;  if (!yymatchString(G, "\331")) goto l379;  goto l288;
  l379:;	  G->pos= yypos288; G->thunkpos= yythunkpos288;  if (!yymatchString(G, "\332")) goto l380;  goto l288;
  l380:;	  G->pos= yypos288; G->thunkpos= yythunkpos288;  if (!yymatchString(G, "\333")) goto l381;  goto l288;
  l381:;	  G->pos= yypos288; G->thunkpos= yythunkpos288;  if (!yymatchString(G, "\334")) goto l382;  goto l288;
  l382:;	  G->pos= yypos288; G->thunkpos= yythunkpos288;  if (!yymatchString(G, "\335")) goto l383;  goto l288;
  l383:;	  G->pos= yypos288; G->thunkpos= yythunkpos288;  if (!yymatchString(G, "\336")) goto l384;  goto l288;
  l384:;	  G->pos= yypos288; G->thunkpos= yythunkpos288;  if (!yymatchString(G, "\337")) goto l385;  goto l288;
  l385:;	  G->pos= yypos288; G->thunkpos= yythunkpos288;  if (!yymatchString(G, "\340")) goto l386;  goto l288;
  l386:;	  G->pos= yypos288; G->thunkpos= yythunkpos288;  if (!yymatchString(G, "\341")) goto l387;  goto l288;
  l387:;	  G->pos= yypos288; G->thunkpos= yythunkpos288;  if (!yymatchString(G, "\342")) goto l388;  goto l288;
  l388:;	  G->pos= yypos288; G->thunkpos= yythunkpos288;  if (!yymatchString(G, "\343")) goto l389;  goto l288;
  l389:;	  G->pos= yypos288; G->thunkpos= yythunkpos288;  if (!yymatchString(G, "\344")) goto l390;  goto l288;
  l390:;	  G->pos= yypos288; G->thunkpos= yythunkpos288;  if (!yymatchString(G, "\345")) goto l391;  goto l288;
  l391:;	  G->pos= yypos288; G->thunkpos= yythunkpos288;  if (!yymatchString(G, "\346")) goto l392;  goto l288;
  l392:;	  G->pos= yypos288; G->thunkpos= yythunkpos288;  if (!yymatchString(G, "\347")) goto l393;  goto l288;
  l393:;	  G->pos= yypos288; G->thunkpos= yythunkpos288;  if (!yymatchString(G, "\350")) goto l394;  goto l288;
  l394:;	  G->pos= yypos288; G->thunkpos= yythunkpos288;  if (!yymatchString(G, "\351")) goto l395;  goto l288;
  l395:;	  G->pos= yypos288; G->thunkpos= yythunkpos288;  if (!yymatchString(G, "\352")) goto l396;  goto l288;
  l396:;	  G->pos= yypos288; G->thunkpos= yythunkpos288;  if (!yymatchString(G, "\353")) goto l397;  goto l288;
  l397:;	  G->pos= yypos288; G->thunkpos= yythunkpos288;  if (!yymatchString(G, "\354")) goto l398;  goto l288;
  l398:;	  G->pos= yypos288; G->thunkpos= yythunkpos288;  if (!yymatchString(G, "\355")) goto l399;  goto l288;
  l399:;	  G->pos= yypos288; G->thunkpos= yythunkpos288;  if (!yymatchString(G, "\356")) goto l400;  goto l288;
  l400:;	  G->pos= yypos288; G->thunkpos= yythunkpos288;  if (!yymatchString(G, "\357")) goto l401;  goto l288;
  l401:;	  G->pos= yypos288; G->thunkpos= yythunkpos288;  if (!yymatchString(G, "\360")) goto l402;  goto l288;
  l402:;	  G->pos= yypos288; G->thunkpos= yythunkpos288;  if (!yymatchString(G, "\361")) goto l403;  goto l288;
  l403:;	  G->pos= yypos288; G->thunkpos= yythunkpos288;  if (!yymatchString(G, "\362")) goto l404;  goto l288;
  l404:;	  G->pos= yypos288; G->thunkpos= yythunkpos288;  if (!yymatchString(G, "\363")) goto l405;  goto l288;
  l405:;	  G->pos= yypos288; G->thunkpos= yythunkpos288;  if (!yymatchString(G, "\364")) goto l406;  goto l288;
  l406:;	  G->pos= yypos288; G->thunkpos= yythunkpos288;  if (!yymatchString(G, "\365")) goto l407;  goto l288;
  l407:;	  G->pos= yypos288; G->thunkpos= yythunkpos288;  if (!yymatchString(G, "\366")) goto l408;  goto l288;
  l408:;	  G->pos= yypos288; G->thunkpos= yythunkpos288;  if (!yymatchString(G, "\367")) goto l409;  goto l288;
  l409:;	  G->pos= yypos288; G->thunkpos= yythunkpos288;  if (!yymatchString(G, "\370")) goto l410;  goto l288;
  l410:;	  G->pos= yypos288; G->thunkpos= yythunkpos288;  if (!yymatchString(G, "\371")) goto l411;  goto l288;
  l411:;	  G->pos= yypos288; G->thunkpos= yythunkpos288;  if (!yymatchString(G, "\372")) goto l412;  goto l288;
  l412:;	  G->pos= yypos288; G->thunkpos= yythunkpos288;  if (!yymatchString(G, "\373")) goto l413;  goto l288;
  l413:;	  G->pos= yypos288; G->thunkpos= yythunkpos288;  if (!yymatchString(G, "\374")) goto l414;  goto l288;
  l414:;	  G->pos= yypos288; G->thunkpos= yythunkpos288;  if (!yymatchString(G, "\375")) goto l415;  goto l288;
  l415:;	  G->pos= yypos288; G->thunkpos= yythunkpos288;  if (!yymatchString(G, "\376")) goto l416;  goto l288;
  l416:;	  G->pos= yypos288; G->thunkpos= yythunkpos288;  if (!yymatchString(G, "\377")) goto l287;
  }
  l288:;	
  yyprintf((stderr, "  ok   %s @ %s\n", "Alphanumeric", G->buf+G->pos));
  return 1;
  l287:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "Alphanumeric", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_NormalChar(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "NormalChar"));
  {  int yypos418= G->pos, yythunkpos418= G->thunkpos;
  {  int yypos419= G->pos, yythunkpos419= G->thunkpos;  if (!yy_SpecialChar(G)) { goto l420; }  goto l419;
  l420:;	  G->pos= yypos419; G->thunkpos= yythunkpos419;  if (!yy_Spacechar(G)) { goto l421; }  goto l419;
  l421:;	  G->pos= yypos419; G->thunkpos= yythunkpos419;  if (!yy_Newline(G)) { goto l418; }
  }
  l419:;	  goto l417;
  l418:;	  G->pos= yypos418; G->thunkpos= yythunkpos418;
  }  if (!yymatchDot(G)) goto l417;
  yyprintf((stderr, "  ok   %s @ %s\n", "NormalChar", G->buf+G->pos));
  return 1;
  l417:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "NormalChar", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_Symbol(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "Symbol"));  if (!yy_SpecialChar(G)) { goto l422; }
  yyprintf((stderr, "  ok   %s @ %s\n", "Symbol", G->buf+G->pos));
  return 1;
  l422:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "Symbol", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_EscapedChar(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "EscapedChar"));  if (!yymatchChar(G, '\\')) goto l423;
  {  int yypos424= G->pos, yythunkpos424= G->thunkpos;  if (!yy_Newline(G)) { goto l424; }  goto l423;
  l424:;	  G->pos= yypos424; G->thunkpos= yythunkpos424;
  }  if (!yymatchClass(G, (unsigned char *)"\000\000\000\000\012\157\000\120\000\000\000\270\001\000\000\070\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000")) goto l423;
  yyprintf((stderr, "  ok   %s @ %s\n", "EscapedChar", G->buf+G->pos));
  return 1;
  l423:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "EscapedChar", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_Entity(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;  yyDo(G, yyPush, 1, 0);
  yyprintf((stderr, "%s\n", "Entity"));  yyText(G, G->begin, G->end);  if (!(YY_BEGIN)) goto l425;  if (!yy_LocMarker(G)) { goto l425; }  yyDo(G, yySet, -1, 0);
  {  int yypos426= G->pos, yythunkpos426= G->thunkpos;  if (!yy_HexEntity(G)) { goto l427; }  goto l426;
  l427:;	  G->pos= yypos426; G->thunkpos= yythunkpos426;  if (!yy_DecEntity(G)) { goto l428; }  goto l426;
  l428:;	  G->pos= yypos426; G->thunkpos= yythunkpos426;  if (!yy_CharEntity(G)) { goto l425; }
  }
  l426:;	  yyText(G, G->begin, G->end);  if (!(YY_END)) goto l425;  yyDo(G, yy_1_Entity, G->begin, G->end);
  yyprintf((stderr, "  ok   %s @ %s\n", "Entity", G->buf+G->pos));  yyDo(G, yyPop, 1, 0);
  return 1;
  l425:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "Entity", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_RawHtml(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;  yyDo(G, yyPush, 1, 0);
  yyprintf((stderr, "%s\n", "RawHtml"));  yyText(G, G->begin, G->end);  if (!(YY_BEGIN)) goto l429;  if (!yy_LocMarker(G)) { goto l429; }  yyDo(G, yySet, -1, 0);
  {  int yypos430= G->pos, yythunkpos430= G->thunkpos;  if (!yy_HtmlComment(G)) { goto l431; }  goto l430;
  l431:;	  G->pos= yypos430; G->thunkpos= yythunkpos430;  if (!yy_HtmlBlockScript(G)) { goto l432; }  goto l430;
  l432:;	  G->pos= yypos430; G->thunkpos= yythunkpos430;  if (!yy_HtmlTag(G)) { goto l429; }
  }
  l430:;	  yyText(G, G->begin, G->end);  if (!(YY_END)) goto l429;  yyDo(G, yy_1_RawHtml, G->begin, G->end);
  yyprintf((stderr, "  ok   %s @ %s\n", "RawHtml", G->buf+G->pos));  yyDo(G, yyPop, 1, 0);
  return 1;
  l429:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "RawHtml", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_Code(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;  yyDo(G, yyPush, 1, 0);
  yyprintf((stderr, "%s\n", "Code"));  yyText(G, G->begin, G->end);  if (!(YY_BEGIN)) goto l433;
  {  int yypos434= G->pos, yythunkpos434= G->thunkpos;  if (!yy_Ticks1(G)) { goto l435; }  yyDo(G, yySet, -1, 0);  if (!yy_Sp(G)) { goto l435; }
  {  int yypos438= G->pos, yythunkpos438= G->thunkpos;
  {  int yypos442= G->pos, yythunkpos442= G->thunkpos;  if (!yymatchChar(G, '`')) goto l442;  goto l439;
  l442:;	  G->pos= yypos442; G->thunkpos= yythunkpos442;
  }  if (!yy_Nonspacechar(G)) { goto l439; }
  l440:;	
  {  int yypos441= G->pos, yythunkpos441= G->thunkpos;
  {  int yypos443= G->pos, yythunkpos443= G->thunkpos;  if (!yymatchChar(G, '`')) goto l443;  goto l441;
  l443:;	  G->pos= yypos443; G->thunkpos= yythunkpos443;
  }  if (!yy_Nonspacechar(G)) { goto l441; }  goto l440;
  l441:;	  G->pos= yypos441; G->thunkpos= yythunkpos441;
  }  goto l438;
  l439:;	  G->pos= yypos438; G->thunkpos= yythunkpos438;
  {  int yypos445= G->pos, yythunkpos445= G->thunkpos;  if (!yy_Ticks1(G)) { goto l445; }  goto l444;
  l445:;	  G->pos= yypos445; G->thunkpos= yythunkpos445;
  }  if (!yymatchChar(G, '`')) goto l444;
  l446:;	
  {  int yypos447= G->pos, yythunkpos447= G->thunkpos;  if (!yymatchChar(G, '`')) goto l447;  goto l446;
  l447:;	  G->pos= yypos447; G->thunkpos= yythunkpos447;
  }  goto l438;
  l444:;	  G->pos= yypos438; G->thunkpos= yythunkpos438;
  {  int yypos448= G->pos, yythunkpos448= G->thunkpos;  if (!yy_Sp(G)) { goto l448; }  if (!yy_Ticks1(G)) { goto l448; }  goto l435;
  l448:;	  G->pos= yypos448; G->thunkpos= yythunkpos448;
  }
  {  int yypos449= G->pos, yythunkpos449= G->thunkpos;  if (!yy_Spacechar(G)) { goto l450; }  goto l449;
  l450:;	  G->pos= yypos449; G->thunkpos= yythunkpos449;  if (!yy_Newline(G)) { goto l435; }
  {  int yypos451= G->pos, yythunkpos451= G->thunkpos;  if (!yy_BlankLine(G)) { goto l451; }  goto l435;
  l451:;	  G->pos= yypos451; G->thunkpos= yythunkpos451;
  }
  }
  l449:;	
  }
  l438:;	
  l436:;	
  {  int yypos437= G->pos, yythunkpos437= G->thunkpos;
  {  int yypos452= G->pos, yythunkpos452= G->thunkpos;
  {  int yypos456= G->pos, yythunkpos456= G->thunkpos;  if (!yymatchChar(G, '`')) goto l456;  goto l453;
  l456:;	  G->pos= yypos456; G->thunkpos= yythunkpos456;
  }  if (!yy_Nonspacechar(G)) { goto l453; }
  l454:;	
  {  int yypos455= G->pos, yythunkpos455= G->thunkpos;
  {  int yypos457= G->pos, yythunkpos457= G->thunkpos;  if (!yymatchChar(G, '`')) goto l457;  goto l455;
  l457:;	  G->pos= yypos457; G->thunkpos= yythunkpos457;
  }  if (!yy_Nonspacechar(G)) { goto l455; }  goto l454;
  l455:;	  G->pos= yypos455; G->thunkpos= yythunkpos455;
  }  goto l452;
  l453:;	  G->pos= yypos452; G->thunkpos= yythunkpos452;
  {  int yypos459= G->pos, yythunkpos459= G->thunkpos;  if (!yy_Ticks1(G)) { goto l459; }  goto l458;
  l459:;	  G->pos= yypos459; G->thunkpos= yythunkpos459;
  }  if (!yymatchChar(G, '`')) goto l458;
  l460:;	
  {  int yypos461= G->pos, yythunkpos461= G->thunkpos;  if (!yymatchChar(G, '`')) goto l461;  goto l460;
  l461:;	  G->pos= yypos461; G->thunkpos= yythunkpos461;
  }  goto l452;
  l458:;	  G->pos= yypos452; G->thunkpos= yythunkpos452;
  {  int yypos462= G->pos, yythunkpos462= G->thunkpos;  if (!yy_Sp(G)) { goto l462; }  if (!yy_Ticks1(G)) { goto l462; }  goto l437;
  l462:;	  G->pos= yypos462; G->thunkpos= yythunkpos462;
  }
  {  int yypos463= G->pos, yythunkpos463= G->thunkpos;  if (!yy_Spacechar(G)) { goto l464; }  goto l463;
  l464:;	  G->pos= yypos463; G->thunkpos= yythunkpos463;  if (!yy_Newline(G)) { goto l437; }
  {  int yypos465= G->pos, yythunkpos465= G->thunkpos;  if (!yy_BlankLine(G)) { goto l465; }  goto l437;
  l465:;	  G->pos= yypos465; G->thunkpos= yythunkpos465;
  }
  }
  l463:;	
  }
  l452:;	  goto l436;
  l437:;	  G->pos= yypos437; G->thunkpos= yythunkpos437;
  }  if (!yy_Sp(G)) { goto l435; }  if (!yy_Ticks1(G)) { goto l435; }  goto l434;
  l435:;	  G->pos= yypos434; G->thunkpos= yythunkpos434;  if (!yy_Ticks2(G)) { goto l466; }  yyDo(G, yySet, -1, 0);  if (!yy_Sp(G)) { goto l466; }
  {  int yypos469= G->pos, yythunkpos469= G->thunkpos;
  {  int yypos473= G->pos, yythunkpos473= G->thunkpos;  if (!yymatchChar(G, '`')) goto l473;  goto l470;
  l473:;	  G->pos= yypos473; G->thunkpos= yythunkpos473;
  }  if (!yy_Nonspacechar(G)) { goto l470; }
  l471:;	
  {  int yypos472= G->pos, yythunkpos472= G->thunkpos;
  {  int yypos474= G->pos, yythunkpos474= G->thunkpos;  if (!yymatchChar(G, '`')) goto l474;  goto l472;
  l474:;	  G->pos= yypos474; G->thunkpos= yythunkpos474;
  }  if (!yy_Nonspacechar(G)) { goto l472; }  goto l471;
  l472:;	  G->pos= yypos472; G->thunkpos= yythunkpos472;
  }  goto l469;
  l470:;	  G->pos= yypos469; G->thunkpos= yythunkpos469;
  {  int yypos476= G->pos, yythunkpos476= G->thunkpos;  if (!yy_Ticks2(G)) { goto l476; }  goto l475;
  l476:;	  G->pos= yypos476; G->thunkpos= yythunkpos476;
  }  if (!yymatchChar(G, '`')) goto l475;
  l477:;	
  {  int yypos478= G->pos, yythunkpos478= G->thunkpos;  if (!yymatchChar(G, '`')) goto l478;  goto l477;
  l478:;	  G->pos= yypos478; G->thunkpos= yythunkpos478;
  }  goto l469;
  l475:;	  G->pos= yypos469; G->thunkpos= yythunkpos469;
  {  int yypos479= G->pos, yythunkpos479= G->thunkpos;  if (!yy_Sp(G)) { goto l479; }  if (!yy_Ticks2(G)) { goto l479; }  goto l466;
  l479:;	  G->pos= yypos479; G->thunkpos= yythunkpos479;
  }
  {  int yypos480= G->pos, yythunkpos480= G->thunkpos;  if (!yy_Spacechar(G)) { goto l481; }  goto l480;
  l481:;	  G->pos= yypos480; G->thunkpos= yythunkpos480;  if (!yy_Newline(G)) { goto l466; }
  {  int yypos482= G->pos, yythunkpos482= G->thunkpos;  if (!yy_BlankLine(G)) { goto l482; }  goto l466;
  l482:;	  G->pos= yypos482; G->thunkpos= yythunkpos482;
  }
  }
  l480:;	
  }
  l469:;	
  l467:;	
  {  int yypos468= G->pos, yythunkpos468= G->thunkpos;
  {  int yypos483= G->pos, yythunkpos483= G->thunkpos;
  {  int yypos487= G->pos, yythunkpos487= G->thunkpos;  if (!yymatchChar(G, '`')) goto l487;  goto l484;
  l487:;	  G->pos= yypos487; G->thunkpos= yythunkpos487;
  }  if (!yy_Nonspacechar(G)) { goto l484; }
  l485:;	
  {  int yypos486= G->pos, yythunkpos486= G->thunkpos;
  {  int yypos488= G->pos, yythunkpos488= G->thunkpos;  if (!yymatchChar(G, '`')) goto l488;  goto l486;
  l488:;	  G->pos= yypos488; G->thunkpos= yythunkpos488;
  }  if (!yy_Nonspacechar(G)) { goto l486; }  goto l485;
  l486:;	  G->pos= yypos486; G->thunkpos= yythunkpos486;
  }  goto l483;
  l484:;	  G->pos= yypos483; G->thunkpos= yythunkpos483;
  {  int yypos490= G->pos, yythunkpos490= G->thunkpos;  if (!yy_Ticks2(G)) { goto l490; }  goto l489;
  l490:;	  G->pos= yypos490; G->thunkpos= yythunkpos490;
  }  if (!yymatchChar(G, '`')) goto l489;
  l491:;	
  {  int yypos492= G->pos, yythunkpos492= G->thunkpos;  if (!yymatchChar(G, '`')) goto l492;  goto l491;
  l492:;	  G->pos= yypos492; G->thunkpos= yythunkpos492;
  }  goto l483;
  l489:;	  G->pos= yypos483; G->thunkpos= yythunkpos483;
  {  int yypos493= G->pos, yythunkpos493= G->thunkpos;  if (!yy_Sp(G)) { goto l493; }  if (!yy_Ticks2(G)) { goto l493; }  goto l468;
  l493:;	  G->pos= yypos493; G->thunkpos= yythunkpos493;
  }
  {  int yypos494= G->pos, yythunkpos494= G->thunkpos;  if (!yy_Spacechar(G)) { goto l495; }  goto l494;
  l495:;	  G->pos= yypos494; G->thunkpos= yythunkpos494;  if (!yy_Newline(G)) { goto l468; }
  {  int yypos496= G->pos, yythunkpos496= G->thunkpos;  if (!yy_BlankLine(G)) { goto l496; }  goto l468;
  l496:;	  G->pos= yypos496; G->thunkpos= yythunkpos496;
  }
  }
  l494:;	
  }
  l483:;	  goto l467;
  l468:;	  G->pos= yypos468; G->thunkpos= yythunkpos468;
  }  if (!yy_Sp(G)) { goto l466; }  if (!yy_Ticks2(G)) { goto l466; }  goto l434;
  l466:;	  G->pos= yypos434; G->thunkpos= yythunkpos434;  if (!yy_Ticks3(G)) { goto l497; }  yyDo(G, yySet, -1, 0);  if (!yy_Sp(G)) { goto l497; }
  {  int yypos500= G->pos, yythunkpos500= G->thunkpos;
  {  int yypos504= G->pos, yythunkpos504= G->thunkpos;  if (!yymatchChar(G, '`')) goto l504;  goto l501;
  l504:;	  G->pos= yypos504; G->thunkpos= yythunkpos504;
  }  if (!yy_Nonspacechar(G)) { goto l501; }
  l502:;	
  {  int yypos503= G->pos, yythunkpos503= G->thunkpos;
  {  int yypos505= G->pos, yythunkpos505= G->thunkpos;  if (!yymatchChar(G, '`')) goto l505;  goto l503;
  l505:;	  G->pos= yypos505; G->thunkpos= yythunkpos505;
  }  if (!yy_Nonspacechar(G)) { goto l503; }  goto l502;
  l503:;	  G->pos= yypos503; G->thunkpos= yythunkpos503;
  }  goto l500;
  l501:;	  G->pos= yypos500; G->thunkpos= yythunkpos500;
  {  int yypos507= G->pos, yythunkpos507= G->thunkpos;  if (!yy_Ticks3(G)) { goto l507; }  goto l506;
  l507:;	  G->pos= yypos507; G->thunkpos= yythunkpos507;
  }  if (!yymatchChar(G, '`')) goto l506;
  l508:;	
  {  int yypos509= G->pos, yythunkpos509= G->thunkpos;  if (!yymatchChar(G, '`')) goto l509;  goto l508;
  l509:;	  G->pos= yypos509; G->thunkpos= yythunkpos509;
  }  goto l500;
  l506:;	  G->pos= yypos500; G->thunkpos= yythunkpos500;
  {  int yypos510= G->pos, yythunkpos510= G->thunkpos;  if (!yy_Sp(G)) { goto l510; }  if (!yy_Ticks3(G)) { goto l510; }  goto l497;
  l510:;	  G->pos= yypos510; G->thunkpos= yythunkpos510;
  }
  {  int yypos511= G->pos, yythunkpos511= G->thunkpos;  if (!yy_Spacechar(G)) { goto l512; }  goto l511;
  l512:;	  G->pos= yypos511; G->thunkpos= yythunkpos511;  if (!yy_Newline(G)) { goto l497; }
  {  int yypos513= G->pos, yythunkpos513= G->thunkpos;  if (!yy_BlankLine(G)) { goto l513; }  goto l497;
  l513:;	  G->pos= yypos513; G->thunkpos= yythunkpos513;
  }
  }
  l511:;	
  }
  l500:;	
  l498:;	
  {  int yypos499= G->pos, yythunkpos499= G->thunkpos;
  {  int yypos514= G->pos, yythunkpos514= G->thunkpos;
  {  int yypos518= G->pos, yythunkpos518= G->thunkpos;  if (!yymatchChar(G, '`')) goto l518;  goto l515;
  l518:;	  G->pos= yypos518; G->thunkpos= yythunkpos518;
  }  if (!yy_Nonspacechar(G)) { goto l515; }
  l516:;	
  {  int yypos517= G->pos, yythunkpos517= G->thunkpos;
  {  int yypos519= G->pos, yythunkpos519= G->thunkpos;  if (!yymatchChar(G, '`')) goto l519;  goto l517;
  l519:;	  G->pos= yypos519; G->thunkpos= yythunkpos519;
  }  if (!yy_Nonspacechar(G)) { goto l517; }  goto l516;
  l517:;	  G->pos= yypos517; G->thunkpos= yythunkpos517;
  }  goto l514;
  l515:;	  G->pos= yypos514; G->thunkpos= yythunkpos514;
  {  int yypos521= G->pos, yythunkpos521= G->thunkpos;  if (!yy_Ticks3(G)) { goto l521; }  goto l520;
  l521:;	  G->pos= yypos521; G->thunkpos= yythunkpos521;
  }  if (!yymatchChar(G, '`')) goto l520;
  l522:;	
  {  int yypos523= G->pos, yythunkpos523= G->thunkpos;  if (!yymatchChar(G, '`')) goto l523;  goto l522;
  l523:;	  G->pos= yypos523; G->thunkpos= yythunkpos523;
  }  goto l514;
  l520:;	  G->pos= yypos514; G->thunkpos= yythunkpos514;
  {  int yypos524= G->pos, yythunkpos524= G->thunkpos;  if (!yy_Sp(G)) { goto l524; }  if (!yy_Ticks3(G)) { goto l524; }  goto l499;
  l524:;	  G->pos= yypos524; G->thunkpos= yythunkpos524;
  }
  {  int yypos525= G->pos, yythunkpos525= G->thunkpos;  if (!yy_Spacechar(G)) { goto l526; }  goto l525;
  l526:;	  G->pos= yypos525; G->thunkpos= yythunkpos525;  if (!yy_Newline(G)) { goto l499; }
  {  int yypos527= G->pos, yythunkpos527= G->thunkpos;  if (!yy_BlankLine(G)) { goto l527; }  goto l499;
  l527:;	  G->pos= yypos527; G->thunkpos= yythunkpos527;
  }
  }
  l525:;	
  }
  l514:;	  goto l498;
  l499:;	  G->pos= yypos499; G->thunkpos= yythunkpos499;
  }  if (!yy_Sp(G)) { goto l497; }  if (!yy_Ticks3(G)) { goto l497; }  goto l434;
  l497:;	  G->pos= yypos434; G->thunkpos= yythunkpos434;  if (!yy_Ticks4(G)) { goto l528; }  yyDo(G, yySet, -1, 0);  if (!yy_Sp(G)) { goto l528; }
  {  int yypos531= G->pos, yythunkpos531= G->thunkpos;
  {  int yypos535= G->pos, yythunkpos535= G->thunkpos;  if (!yymatchChar(G, '`')) goto l535;  goto l532;
  l535:;	  G->pos= yypos535; G->thunkpos= yythunkpos535;
  }  if (!yy_Nonspacechar(G)) { goto l532; }
  l533:;	
  {  int yypos534= G->pos, yythunkpos534= G->thunkpos;
  {  int yypos536= G->pos, yythunkpos536= G->thunkpos;  if (!yymatchChar(G, '`')) goto l536;  goto l534;
  l536:;	  G->pos= yypos536; G->thunkpos= yythunkpos536;
  }  if (!yy_Nonspacechar(G)) { goto l534; }  goto l533;
  l534:;	  G->pos= yypos534; G->thunkpos= yythunkpos534;
  }  goto l531;
  l532:;	  G->pos= yypos531; G->thunkpos= yythunkpos531;
  {  int yypos538= G->pos, yythunkpos538= G->thunkpos;  if (!yy_Ticks4(G)) { goto l538; }  goto l537;
  l538:;	  G->pos= yypos538; G->thunkpos= yythunkpos538;
  }  if (!yymatchChar(G, '`')) goto l537;
  l539:;	
  {  int yypos540= G->pos, yythunkpos540= G->thunkpos;  if (!yymatchChar(G, '`')) goto l540;  goto l539;
  l540:;	  G->pos= yypos540; G->thunkpos= yythunkpos540;
  }  goto l531;
  l537:;	  G->pos= yypos531; G->thunkpos= yythunkpos531;
  {  int yypos541= G->pos, yythunkpos541= G->thunkpos;  if (!yy_Sp(G)) { goto l541; }  if (!yy_Ticks4(G)) { goto l541; }  goto l528;
  l541:;	  G->pos= yypos541; G->thunkpos= yythunkpos541;
  }
  {  int yypos542= G->pos, yythunkpos542= G->thunkpos;  if (!yy_Spacechar(G)) { goto l543; }  goto l542;
  l543:;	  G->pos= yypos542; G->thunkpos= yythunkpos542;  if (!yy_Newline(G)) { goto l528; }
  {  int yypos544= G->pos, yythunkpos544= G->thunkpos;  if (!yy_BlankLine(G)) { goto l544; }  goto l528;
  l544:;	  G->pos= yypos544; G->thunkpos= yythunkpos544;
  }
  }
  l542:;	
  }
  l531:;	
  l529:;	
  {  int yypos530= G->pos, yythunkpos530= G->thunkpos;
  {  int yypos545= G->pos, yythunkpos545= G->thunkpos;
  {  int yypos549= G->pos, yythunkpos549= G->thunkpos;  if (!yymatchChar(G, '`')) goto l549;  goto l546;
  l549:;	  G->pos= yypos549; G->thunkpos= yythunkpos549;
  }  if (!yy_Nonspacechar(G)) { goto l546; }
  l547:;	
  {  int yypos548= G->pos, yythunkpos548= G->thunkpos;
  {  int yypos550= G->pos, yythunkpos550= G->thunkpos;  if (!yymatchChar(G, '`')) goto l550;  goto l548;
  l550:;	  G->pos= yypos550; G->thunkpos= yythunkpos550;
  }  if (!yy_Nonspacechar(G)) { goto l548; }  goto l547;
  l548:;	  G->pos= yypos548; G->thunkpos= yythunkpos548;
  }  goto l545;
  l546:;	  G->pos= yypos545; G->thunkpos= yythunkpos545;
  {  int yypos552= G->pos, yythunkpos552= G->thunkpos;  if (!yy_Ticks4(G)) { goto l552; }  goto l551;
  l552:;	  G->pos= yypos552; G->thunkpos= yythunkpos552;
  }  if (!yymatchChar(G, '`')) goto l551;
  l553:;	
  {  int yypos554= G->pos, yythunkpos554= G->thunkpos;  if (!yymatchChar(G, '`')) goto l554;  goto l553;
  l554:;	  G->pos= yypos554; G->thunkpos= yythunkpos554;
  }  goto l545;
  l551:;	  G->pos= yypos545; G->thunkpos= yythunkpos545;
  {  int yypos555= G->pos, yythunkpos555= G->thunkpos;  if (!yy_Sp(G)) { goto l555; }  if (!yy_Ticks4(G)) { goto l555; }  goto l530;
  l555:;	  G->pos= yypos555; G->thunkpos= yythunkpos555;
  }
  {  int yypos556= G->pos, yythunkpos556= G->thunkpos;  if (!yy_Spacechar(G)) { goto l557; }  goto l556;
  l557:;	  G->pos= yypos556; G->thunkpos= yythunkpos556;  if (!yy_Newline(G)) { goto l530; }
  {  int yypos558= G->pos, yythunkpos558= G->thunkpos;  if (!yy_BlankLine(G)) { goto l558; }  goto l530;
  l558:;	  G->pos= yypos558; G->thunkpos= yythunkpos558;
  }
  }
  l556:;	
  }
  l545:;	  goto l529;
  l530:;	  G->pos= yypos530; G->thunkpos= yythunkpos530;
  }  if (!yy_Sp(G)) { goto l528; }  if (!yy_Ticks4(G)) { goto l528; }  goto l434;
  l528:;	  G->pos= yypos434; G->thunkpos= yythunkpos434;  if (!yy_Ticks5(G)) { goto l433; }  yyDo(G, yySet, -1, 0);  if (!yy_Sp(G)) { goto l433; }
  {  int yypos561= G->pos, yythunkpos561= G->thunkpos;
  {  int yypos565= G->pos, yythunkpos565= G->thunkpos;  if (!yymatchChar(G, '`')) goto l565;  goto l562;
  l565:;	  G->pos= yypos565; G->thunkpos= yythunkpos565;
  }  if (!yy_Nonspacechar(G)) { goto l562; }
  l563:;	
  {  int yypos564= G->pos, yythunkpos564= G->thunkpos;
  {  int yypos566= G->pos, yythunkpos566= G->thunkpos;  if (!yymatchChar(G, '`')) goto l566;  goto l564;
  l566:;	  G->pos= yypos566; G->thunkpos= yythunkpos566;
  }  if (!yy_Nonspacechar(G)) { goto l564; }  goto l563;
  l564:;	  G->pos= yypos564; G->thunkpos= yythunkpos564;
  }  goto l561;
  l562:;	  G->pos= yypos561; G->thunkpos= yythunkpos561;
  {  int yypos568= G->pos, yythunkpos568= G->thunkpos;  if (!yy_Ticks5(G)) { goto l568; }  goto l567;
  l568:;	  G->pos= yypos568; G->thunkpos= yythunkpos568;
  }  if (!yymatchChar(G, '`')) goto l567;
  l569:;	
  {  int yypos570= G->pos, yythunkpos570= G->thunkpos;  if (!yymatchChar(G, '`')) goto l570;  goto l569;
  l570:;	  G->pos= yypos570; G->thunkpos= yythunkpos570;
  }  goto l561;
  l567:;	  G->pos= yypos561; G->thunkpos= yythunkpos561;
  {  int yypos571= G->pos, yythunkpos571= G->thunkpos;  if (!yy_Sp(G)) { goto l571; }  if (!yy_Ticks5(G)) { goto l571; }  goto l433;
  l571:;	  G->pos= yypos571; G->thunkpos= yythunkpos571;
  }
  {  int yypos572= G->pos, yythunkpos572= G->thunkpos;  if (!yy_Spacechar(G)) { goto l573; }  goto l572;
  l573:;	  G->pos= yypos572; G->thunkpos= yythunkpos572;  if (!yy_Newline(G)) { goto l433; }
  {  int yypos574= G->pos, yythunkpos574= G->thunkpos;  if (!yy_BlankLine(G)) { goto l574; }  goto l433;
  l574:;	  G->pos= yypos574; G->thunkpos= yythunkpos574;
  }
  }
  l572:;	
  }
  l561:;	
  l559:;	
  {  int yypos560= G->pos, yythunkpos560= G->thunkpos;
  {  int yypos575= G->pos, yythunkpos575= G->thunkpos;
  {  int yypos579= G->pos, yythunkpos579= G->thunkpos;  if (!yymatchChar(G, '`')) goto l579;  goto l576;
  l579:;	  G->pos= yypos579; G->thunkpos= yythunkpos579;
  }  if (!yy_Nonspacechar(G)) { goto l576; }
  l577:;	
  {  int yypos578= G->pos, yythunkpos578= G->thunkpos;
  {  int yypos580= G->pos, yythunkpos580= G->thunkpos;  if (!yymatchChar(G, '`')) goto l580;  goto l578;
  l580:;	  G->pos= yypos580; G->thunkpos= yythunkpos580;
  }  if (!yy_Nonspacechar(G)) { goto l578; }  goto l577;
  l578:;	  G->pos= yypos578; G->thunkpos= yythunkpos578;
  }  goto l575;
  l576:;	  G->pos= yypos575; G->thunkpos= yythunkpos575;
  {  int yypos582= G->pos, yythunkpos582= G->thunkpos;  if (!yy_Ticks5(G)) { goto l582; }  goto l581;
  l582:;	  G->pos= yypos582; G->thunkpos= yythunkpos582;
  }  if (!yymatchChar(G, '`')) goto l581;
  l583:;	
  {  int yypos584= G->pos, yythunkpos584= G->thunkpos;  if (!yymatchChar(G, '`')) goto l584;  goto l583;
  l584:;	  G->pos= yypos584; G->thunkpos= yythunkpos584;
  }  goto l575;
  l581:;	  G->pos= yypos575; G->thunkpos= yythunkpos575;
  {  int yypos585= G->pos, yythunkpos585= G->thunkpos;  if (!yy_Sp(G)) { goto l585; }  if (!yy_Ticks5(G)) { goto l585; }  goto l560;
  l585:;	  G->pos= yypos585; G->thunkpos= yythunkpos585;
  }
  {  int yypos586= G->pos, yythunkpos586= G->thunkpos;  if (!yy_Spacechar(G)) { goto l587; }  goto l586;
  l587:;	  G->pos= yypos586; G->thunkpos= yythunkpos586;  if (!yy_Newline(G)) { goto l560; }
  {  int yypos588= G->pos, yythunkpos588= G->thunkpos;  if (!yy_BlankLine(G)) { goto l588; }  goto l560;
  l588:;	  G->pos= yypos588; G->thunkpos= yythunkpos588;
  }
  }
  l586:;	
  }
  l575:;	  goto l559;
  l560:;	  G->pos= yypos560; G->thunkpos= yythunkpos560;
  }  if (!yy_Sp(G)) { goto l433; }  if (!yy_Ticks5(G)) { goto l433; }
  }
  l434:;	  yyText(G, G->begin, G->end);  if (!(YY_END)) goto l433;  yyDo(G, yy_1_Code, G->begin, G->end);
  yyprintf((stderr, "  ok   %s @ %s\n", "Code", G->buf+G->pos));  yyDo(G, yyPop, 1, 0);
  return 1;
  l433:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "Code", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_InlineNote(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "InlineNote"));  yyText(G, G->begin, G->end);  if (!( EXT(pmh_EXT_NOTES) )) goto l589;  if (!yymatchString(G, "^[")) goto l589;
  {  int yypos592= G->pos, yythunkpos592= G->thunkpos;  if (!yymatchChar(G, ']')) goto l592;  goto l589;
  l592:;	  G->pos= yypos592; G->thunkpos= yythunkpos592;
  }  if (!yy_Inline(G)) { goto l589; }
  l590:;	
  {  int yypos591= G->pos, yythunkpos591= G->thunkpos;
  {  int yypos593= G->pos, yythunkpos593= G->thunkpos;  if (!yymatchChar(G, ']')) goto l593;  goto l591;
  l593:;	  G->pos= yypos593; G->thunkpos= yythunkpos593;
  }  if (!yy_Inline(G)) { goto l591; }  goto l590;
  l591:;	  G->pos= yypos591; G->thunkpos= yythunkpos591;
  }  if (!yymatchChar(G, ']')) goto l589;
  yyprintf((stderr, "  ok   %s @ %s\n", "InlineNote", G->buf+G->pos));
  return 1;
  l589:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "InlineNote", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_NoteReference(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "NoteReference"));  yyText(G, G->begin, G->end);  if (!( EXT(pmh_EXT_NOTES) )) goto l594;  if (!yy_RawNoteReference(G)) { goto l594; }
  yyprintf((stderr, "  ok   %s @ %s\n", "NoteReference", G->buf+G->pos));
  return 1;
  l594:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "NoteReference", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_Link(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "Link"));
  {  int yypos596= G->pos, yythunkpos596= G->thunkpos;  if (!yy_ExplicitLink(G)) { goto l597; }  goto l596;
  l597:;	  G->pos= yypos596; G->thunkpos= yythunkpos596;  if (!yy_ReferenceLink(G)) { goto l598; }  goto l596;
  l598:;	  G->pos= yypos596; G->thunkpos= yythunkpos596;  if (!yy_AutoLink(G)) { goto l595; }
  }
  l596:;	  yyDo(G, yy_1_Link, G->begin, G->end);
  yyprintf((stderr, "  ok   %s @ %s\n", "Link", G->buf+G->pos));
  return 1;
  l595:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "Link", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_Image(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "Image"));  if (!yymatchChar(G, '!')) goto l599;
  {  int yypos600= G->pos, yythunkpos600= G->thunkpos;  if (!yy_ExplicitLink(G)) { goto l601; }  goto l600;
  l601:;	  G->pos= yypos600; G->thunkpos= yythunkpos600;  if (!yy_ExplicitLinkSize(G)) { goto l602; }  goto l600;
  l602:;	  G->pos= yypos600; G->thunkpos= yythunkpos600;  if (!yy_ReferenceLink(G)) { goto l599; }
  }
  l600:;	  yyDo(G, yy_1_Image, G->begin, G->end);
  yyprintf((stderr, "  ok   %s @ %s\n", "Image", G->buf+G->pos));
  return 1;
  l599:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "Image", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_Strike(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;  yyDo(G, yyPush, 1, 0);
  yyprintf((stderr, "%s\n", "Strike"));  yyText(G, G->begin, G->end);  if (!( EXT(pmh_EXT_STRIKE) )) goto l603;  yyText(G, G->begin, G->end);  if (!(YY_BEGIN)) goto l603;  if (!yy_LocMarker(G)) { goto l603; }  yyDo(G, yySet, -1, 0);  if (!yymatchString(G, "~~")) goto l603;
  {  int yypos604= G->pos, yythunkpos604= G->thunkpos;  if (!yy_Whitespace(G)) { goto l604; }  goto l603;
  l604:;	  G->pos= yypos604; G->thunkpos= yythunkpos604;
  }
  {  int yypos607= G->pos, yythunkpos607= G->thunkpos;  if (!yymatchString(G, "~~")) goto l607;  goto l603;
  l607:;	  G->pos= yypos607; G->thunkpos= yythunkpos607;
  }  if (!yy_Inline(G)) { goto l603; }
  l605:;	
  {  int yypos606= G->pos, yythunkpos606= G->thunkpos;
  {  int yypos608= G->pos, yythunkpos608= G->thunkpos;  if (!yymatchString(G, "~~")) goto l608;  goto l606;
  l608:;	  G->pos= yypos608; G->thunkpos= yythunkpos608;
  }  if (!yy_Inline(G)) { goto l606; }  goto l605;
  l606:;	  G->pos= yypos606; G->thunkpos= yythunkpos606;
  }  if (!yymatchString(G, "~~")) goto l603;  yyText(G, G->begin, G->end);  if (!(YY_END)) goto l603;  yyDo(G, yy_1_Strike, G->begin, G->end);
  yyprintf((stderr, "  ok   %s @ %s\n", "Strike", G->buf+G->pos));  yyDo(G, yyPop, 1, 0);
  return 1;
  l603:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "Strike", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_Emph(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "Emph"));
  {  int yypos610= G->pos, yythunkpos610= G->thunkpos;  if (!yy_EmphStar(G)) { goto l611; }  goto l610;
  l611:;	  G->pos= yypos610; G->thunkpos= yythunkpos610;  if (!yy_EmphUl(G)) { goto l609; }
  }
  l610:;	
  yyprintf((stderr, "  ok   %s @ %s\n", "Emph", G->buf+G->pos));
  return 1;
  l609:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "Emph", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_Strong(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "Strong"));
  {  int yypos613= G->pos, yythunkpos613= G->thunkpos;  if (!yy_StrongStar(G)) { goto l614; }  goto l613;
  l614:;	  G->pos= yypos613; G->thunkpos= yythunkpos613;  if (!yy_StrongUl(G)) { goto l612; }
  }
  l613:;	
  yyprintf((stderr, "  ok   %s @ %s\n", "Strong", G->buf+G->pos));
  return 1;
  l612:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "Strong", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_UlOrStarLine(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "UlOrStarLine"));
  {  int yypos616= G->pos, yythunkpos616= G->thunkpos;  if (!yy_UlLine(G)) { goto l617; }  goto l616;
  l617:;	  G->pos= yypos616; G->thunkpos= yythunkpos616;  if (!yy_StarLine(G)) { goto l615; }
  }
  l616:;	
  yyprintf((stderr, "  ok   %s @ %s\n", "UlOrStarLine", G->buf+G->pos));
  return 1;
  l615:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "UlOrStarLine", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_Str(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "Str"));  if (!yy_NormalChar(G)) { goto l618; }
  l619:;	
  {  int yypos620= G->pos, yythunkpos620= G->thunkpos;
  {  int yypos621= G->pos, yythunkpos621= G->thunkpos;  if (!yy_NormalChar(G)) { goto l622; }  goto l621;
  l622:;	  G->pos= yypos621; G->thunkpos= yythunkpos621;  if (!yymatchChar(G, '_')) goto l620;
  l623:;	
  {  int yypos624= G->pos, yythunkpos624= G->thunkpos;  if (!yymatchChar(G, '_')) goto l624;  goto l623;
  l624:;	  G->pos= yypos624; G->thunkpos= yythunkpos624;
  }
  {  int yypos625= G->pos, yythunkpos625= G->thunkpos;  if (!yy_Alphanumeric(G)) { goto l620; }  G->pos= yypos625; G->thunkpos= yythunkpos625;
  }
  }
  l621:;	  goto l619;
  l620:;	  G->pos= yypos620; G->thunkpos= yythunkpos620;
  }
  yyprintf((stderr, "  ok   %s @ %s\n", "Str", G->buf+G->pos));
  return 1;
  l618:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "Str", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_InStyleTags(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "InStyleTags"));  if (!yy_StyleOpen(G)) { goto l626; }
  l627:;	
  {  int yypos628= G->pos, yythunkpos628= G->thunkpos;
  {  int yypos629= G->pos, yythunkpos629= G->thunkpos;  if (!yy_StyleClose(G)) { goto l629; }  goto l628;
  l629:;	  G->pos= yypos629; G->thunkpos= yythunkpos629;
  }  if (!yymatchDot(G)) goto l628;  goto l627;
  l628:;	  G->pos= yypos628; G->thunkpos= yythunkpos628;
  }  if (!yy_StyleClose(G)) { goto l626; }
  yyprintf((stderr, "  ok   %s @ %s\n", "InStyleTags", G->buf+G->pos));
  return 1;
  l626:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "InStyleTags", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_StyleClose(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "StyleClose"));  if (!yymatchChar(G, '<')) goto l630;  if (!yy_Spnl(G)) { goto l630; }  if (!yymatchChar(G, '/')) goto l630;
  {  int yypos631= G->pos, yythunkpos631= G->thunkpos;  if (!yymatchString(G, "style")) goto l632;  goto l631;
  l632:;	  G->pos= yypos631; G->thunkpos= yythunkpos631;  if (!yymatchString(G, "STYLE")) goto l630;
  }
  l631:;	  if (!yy_Spnl(G)) { goto l630; }  if (!yymatchChar(G, '>')) goto l630;
  yyprintf((stderr, "  ok   %s @ %s\n", "StyleClose", G->buf+G->pos));
  return 1;
  l630:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "StyleClose", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_StyleOpen(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "StyleOpen"));  if (!yymatchChar(G, '<')) goto l633;  if (!yy_Spnl(G)) { goto l633; }
  {  int yypos634= G->pos, yythunkpos634= G->thunkpos;  if (!yymatchString(G, "style")) goto l635;  goto l634;
  l635:;	  G->pos= yypos634; G->thunkpos= yythunkpos634;  if (!yymatchString(G, "STYLE")) goto l633;
  }
  l634:;	  if (!yy_Spnl(G)) { goto l633; }
  l636:;	
  {  int yypos637= G->pos, yythunkpos637= G->thunkpos;  if (!yy_HtmlAttribute(G)) { goto l637; }  goto l636;
  l637:;	  G->pos= yypos637; G->thunkpos= yythunkpos637;
  }  if (!yymatchChar(G, '>')) goto l633;
  yyprintf((stderr, "  ok   %s @ %s\n", "StyleOpen", G->buf+G->pos));
  return 1;
  l633:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "StyleOpen", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_HtmlBlockType(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "HtmlBlockType"));
  {  int yypos639= G->pos, yythunkpos639= G->thunkpos;  if (!yymatchString(G, "address")) goto l640;  goto l639;
  l640:;	  G->pos= yypos639; G->thunkpos= yythunkpos639;  if (!yymatchString(G, "blockquote")) goto l641;  goto l639;
  l641:;	  G->pos= yypos639; G->thunkpos= yythunkpos639;  if (!yymatchString(G, "center")) goto l642;  goto l639;
  l642:;	  G->pos= yypos639; G->thunkpos= yythunkpos639;  if (!yymatchString(G, "dir")) goto l643;  goto l639;
  l643:;	  G->pos= yypos639; G->thunkpos= yythunkpos639;  if (!yymatchString(G, "div")) goto l644;  goto l639;
  l644:;	  G->pos= yypos639; G->thunkpos= yythunkpos639;  if (!yymatchString(G, "dl")) goto l645;  goto l639;
  l645:;	  G->pos= yypos639; G->thunkpos= yythunkpos639;  if (!yymatchString(G, "fieldset")) goto l646;  goto l639;
  l646:;	  G->pos= yypos639; G->thunkpos= yythunkpos639;  if (!yymatchString(G, "form")) goto l647;  goto l639;
  l647:;	  G->pos= yypos639; G->thunkpos= yythunkpos639;  if (!yymatchString(G, "h1")) goto l648;  goto l639;
  l648:;	  G->pos= yypos639; G->thunkpos= yythunkpos639;  if (!yymatchString(G, "h2")) goto l649;  goto l639;
  l649:;	  G->pos= yypos639; G->thunkpos= yythunkpos639;  if (!yymatchString(G, "h3")) goto l650;  goto l639;
  l650:;	  G->pos= yypos639; G->thunkpos= yythunkpos639;  if (!yymatchString(G, "h4")) goto l651;  goto l639;
  l651:;	  G->pos= yypos639; G->thunkpos= yythunkpos639;  if (!yymatchString(G, "h5")) goto l652;  goto l639;
  l652:;	  G->pos= yypos639; G->thunkpos= yythunkpos639;  if (!yymatchString(G, "h6")) goto l653;  goto l639;
  l653:;	  G->pos= yypos639; G->thunkpos= yythunkpos639;  if (!yymatchString(G, "hr")) goto l654;  goto l639;
  l654:;	  G->pos= yypos639; G->thunkpos= yythunkpos639;  if (!yymatchString(G, "isindex")) goto l655;  goto l639;
  l655:;	  G->pos= yypos639; G->thunkpos= yythunkpos639;  if (!yymatchString(G, "menu")) goto l656;  goto l639;
  l656:;	  G->pos= yypos639; G->thunkpos= yythunkpos639;  if (!yymatchString(G, "noframes")) goto l657;  goto l639;
  l657:;	  G->pos= yypos639; G->thunkpos= yythunkpos639;  if (!yymatchString(G, "noscript")) goto l658;  goto l639;
  l658:;	  G->pos= yypos639; G->thunkpos= yythunkpos639;  if (!yymatchString(G, "ol")) goto l659;  goto l639;
  l659:;	  G->pos= yypos639; G->thunkpos= yythunkpos639;  if (!yymatchChar(G, 'p')) goto l660;  goto l639;
  l660:;	  G->pos= yypos639; G->thunkpos= yythunkpos639;  if (!yymatchString(G, "pre")) goto l661;  goto l639;
  l661:;	  G->pos= yypos639; G->thunkpos= yythunkpos639;  if (!yymatchString(G, "table")) goto l662;  goto l639;
  l662:;	  G->pos= yypos639; G->thunkpos= yythunkpos639;  if (!yymatchString(G, "ul")) goto l663;  goto l639;
  l663:;	  G->pos= yypos639; G->thunkpos= yythunkpos639;  if (!yymatchString(G, "dd")) goto l664;  goto l639;
  l664:;	  G->pos= yypos639; G->thunkpos= yythunkpos639;  if (!yymatchString(G, "dt")) goto l665;  goto l639;
  l665:;	  G->pos= yypos639; G->thunkpos= yythunkpos639;  if (!yymatchString(G, "frameset")) goto l666;  goto l639;
  l666:;	  G->pos= yypos639; G->thunkpos= yythunkpos639;  if (!yymatchString(G, "li")) goto l667;  goto l639;
  l667:;	  G->pos= yypos639; G->thunkpos= yythunkpos639;  if (!yymatchString(G, "tbody")) goto l668;  goto l639;
  l668:;	  G->pos= yypos639; G->thunkpos= yythunkpos639;  if (!yymatchString(G, "td")) goto l669;  goto l639;
  l669:;	  G->pos= yypos639; G->thunkpos= yythunkpos639;  if (!yymatchString(G, "tfoot")) goto l670;  goto l639;
  l670:;	  G->pos= yypos639; G->thunkpos= yythunkpos639;  if (!yymatchString(G, "th")) goto l671;  goto l639;
  l671:;	  G->pos= yypos639; G->thunkpos= yythunkpos639;  if (!yymatchString(G, "thead")) goto l672;  goto l639;
  l672:;	  G->pos= yypos639; G->thunkpos= yythunkpos639;  if (!yymatchString(G, "tr")) goto l673;  goto l639;
  l673:;	  G->pos= yypos639; G->thunkpos= yythunkpos639;  if (!yymatchString(G, "script")) goto l674;  goto l639;
  l674:;	  G->pos= yypos639; G->thunkpos= yythunkpos639;  if (!yymatchString(G, "ADDRESS")) goto l675;  goto l639;
  l675:;	  G->pos= yypos639; G->thunkpos= yythunkpos639;  if (!yymatchString(G, "BLOCKQUOTE")) goto l676;  goto l639;
  l676:;	  G->pos= yypos639; G->thunkpos= yythunkpos639;  if (!yymatchString(G, "CENTER")) goto l677;  goto l639;
  l677:;	  G->pos= yypos639; G->thunkpos= yythunkpos639;  if (!yymatchString(G, "DIR")) goto l678;  goto l639;
  l678:;	  G->pos= yypos639; G->thunkpos= yythunkpos639;  if (!yymatchString(G, "DIV")) goto l679;  goto l639;
  l679:;	  G->pos= yypos639; G->thunkpos= yythunkpos639;  if (!yymatchString(G, "DL")) goto l680;  goto l639;
  l680:;	  G->pos= yypos639; G->thunkpos= yythunkpos639;  if (!yymatchString(G, "FIELDSET")) goto l681;  goto l639;
  l681:;	  G->pos= yypos639; G->thunkpos= yythunkpos639;  if (!yymatchString(G, "FORM")) goto l682;  goto l639;
  l682:;	  G->pos= yypos639; G->thunkpos= yythunkpos639;  if (!yymatchString(G, "H1")) goto l683;  goto l639;
  l683:;	  G->pos= yypos639; G->thunkpos= yythunkpos639;  if (!yymatchString(G, "H2")) goto l684;  goto l639;
  l684:;	  G->pos= yypos639; G->thunkpos= yythunkpos639;  if (!yymatchString(G, "H3")) goto l685;  goto l639;
  l685:;	  G->pos= yypos639; G->thunkpos= yythunkpos639;  if (!yymatchString(G, "H4")) goto l686;  goto l639;
  l686:;	  G->pos= yypos639; G->thunkpos= yythunkpos639;  if (!yymatchString(G, "H5")) goto l687;  goto l639;
  l687:;	  G->pos= yypos639; G->thunkpos= yythunkpos639;  if (!yymatchString(G, "H6")) goto l688;  goto l639;
  l688:;	  G->pos= yypos639; G->thunkpos= yythunkpos639;  if (!yymatchString(G, "HR")) goto l689;  goto l639;
  l689:;	  G->pos= yypos639; G->thunkpos= yythunkpos639;  if (!yymatchString(G, "ISINDEX")) goto l690;  goto l639;
  l690:;	  G->pos= yypos639; G->thunkpos= yythunkpos639;  if (!yymatchString(G, "MENU")) goto l691;  goto l639;
  l691:;	  G->pos= yypos639; G->thunkpos= yythunkpos639;  if (!yymatchString(G, "NOFRAMES")) goto l692;  goto l639;
  l692:;	  G->pos= yypos639; G->thunkpos= yythunkpos639;  if (!yymatchString(G, "NOSCRIPT")) goto l693;  goto l639;
  l693:;	  G->pos= yypos639; G->thunkpos= yythunkpos639;  if (!yymatchString(G, "OL")) goto l694;  goto l639;
  l694:;	  G->pos= yypos639; G->thunkpos= yythunkpos639;  if (!yymatchChar(G, 'P')) goto l695;  goto l639;
  l695:;	  G->pos= yypos639; G->thunkpos= yythunkpos639;  if (!yymatchString(G, "PRE")) goto l696;  goto l639;
  l696:;	  G->pos= yypos639; G->thunkpos= yythunkpos639;  if (!yymatchString(G, "TABLE")) goto l697;  goto l639;
  l697:;	  G->pos= yypos639; G->thunkpos= yythunkpos639;  if (!yymatchString(G, "UL")) goto l698;  goto l639;
  l698:;	  G->pos= yypos639; G->thunkpos= yythunkpos639;  if (!yymatchString(G, "DD")) goto l699;  goto l639;
  l699:;	  G->pos= yypos639; G->thunkpos= yythunkpos639;  if (!yymatchString(G, "DT")) goto l700;  goto l639;
  l700:;	  G->pos= yypos639; G->thunkpos= yythunkpos639;  if (!yymatchString(G, "FRAMESET")) goto l701;  goto l639;
  l701:;	  G->pos= yypos639; G->thunkpos= yythunkpos639;  if (!yymatchString(G, "LI")) goto l702;  goto l639;
  l702:;	  G->pos= yypos639; G->thunkpos= yythunkpos639;  if (!yymatchString(G, "TBODY")) goto l703;  goto l639;
  l703:;	  G->pos= yypos639; G->thunkpos= yythunkpos639;  if (!yymatchString(G, "TD")) goto l704;  goto l639;
  l704:;	  G->pos= yypos639; G->thunkpos= yythunkpos639;  if (!yymatchString(G, "TFOOT")) goto l705;  goto l639;
  l705:;	  G->pos= yypos639; G->thunkpos= yythunkpos639;  if (!yymatchString(G, "TH")) goto l706;  goto l639;
  l706:;	  G->pos= yypos639; G->thunkpos= yythunkpos639;  if (!yymatchString(G, "THEAD")) goto l707;  goto l639;
  l707:;	  G->pos= yypos639; G->thunkpos= yythunkpos639;  if (!yymatchString(G, "TR")) goto l708;  goto l639;
  l708:;	  G->pos= yypos639; G->thunkpos= yythunkpos639;  if (!yymatchString(G, "SCRIPT")) goto l638;
  }
  l639:;	
  yyprintf((stderr, "  ok   %s @ %s\n", "HtmlBlockType", G->buf+G->pos));
  return 1;
  l638:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "HtmlBlockType", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_HtmlBlockSelfClosing(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "HtmlBlockSelfClosing"));  if (!yymatchChar(G, '<')) goto l709;  if (!yy_Spnl(G)) { goto l709; }  if (!yy_HtmlBlockType(G)) { goto l709; }  if (!yy_Spnl(G)) { goto l709; }
  l710:;	
  {  int yypos711= G->pos, yythunkpos711= G->thunkpos;  if (!yy_HtmlAttribute(G)) { goto l711; }  goto l710;
  l711:;	  G->pos= yypos711; G->thunkpos= yythunkpos711;
  }  if (!yymatchChar(G, '/')) goto l709;  if (!yy_Spnl(G)) { goto l709; }  if (!yymatchChar(G, '>')) goto l709;
  yyprintf((stderr, "  ok   %s @ %s\n", "HtmlBlockSelfClosing", G->buf+G->pos));
  return 1;
  l709:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "HtmlBlockSelfClosing", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_HtmlComment(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;  yyDo(G, yyPush, 1, 0);
  yyprintf((stderr, "%s\n", "HtmlComment"));  yyText(G, G->begin, G->end);  if (!(YY_BEGIN)) goto l712;  if (!yy_LocMarker(G)) { goto l712; }  yyDo(G, yySet, -1, 0);  if (!yymatchString(G, "<!--")) goto l712;
  l713:;	
  {  int yypos714= G->pos, yythunkpos714= G->thunkpos;
  {  int yypos715= G->pos, yythunkpos715= G->thunkpos;  if (!yymatchString(G, "-->")) goto l715;  goto l714;
  l715:;	  G->pos= yypos715; G->thunkpos= yythunkpos715;
  }  if (!yymatchDot(G)) goto l714;  goto l713;
  l714:;	  G->pos= yypos714; G->thunkpos= yythunkpos714;
  }  if (!yymatchString(G, "-->")) goto l712;  yyText(G, G->begin, G->end);  if (!(YY_END)) goto l712;  yyDo(G, yy_1_HtmlComment, G->begin, G->end);
  yyprintf((stderr, "  ok   %s @ %s\n", "HtmlComment", G->buf+G->pos));  yyDo(G, yyPop, 1, 0);
  return 1;
  l712:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "HtmlComment", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_HtmlBlockInTags(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "HtmlBlockInTags"));
  {  int yypos717= G->pos, yythunkpos717= G->thunkpos;  if (!yy_HtmlBlockAddress(G)) { goto l718; }  goto l717;
  l718:;	  G->pos= yypos717; G->thunkpos= yythunkpos717;  if (!yy_HtmlBlockBlockquote(G)) { goto l719; }  goto l717;
  l719:;	  G->pos= yypos717; G->thunkpos= yythunkpos717;  if (!yy_HtmlBlockCenter(G)) { goto l720; }  goto l717;
  l720:;	  G->pos= yypos717; G->thunkpos= yythunkpos717;  if (!yy_HtmlBlockDir(G)) { goto l721; }  goto l717;
  l721:;	  G->pos= yypos717; G->thunkpos= yythunkpos717;  if (!yy_HtmlBlockDiv(G)) { goto l722; }  goto l717;
  l722:;	  G->pos= yypos717; G->thunkpos= yythunkpos717;  if (!yy_HtmlBlockDl(G)) { goto l723; }  goto l717;
  l723:;	  G->pos= yypos717; G->thunkpos= yythunkpos717;  if (!yy_HtmlBlockFieldset(G)) { goto l724; }  goto l717;
  l724:;	  G->pos= yypos717; G->thunkpos= yythunkpos717;  if (!yy_HtmlBlockForm(G)) { goto l725; }  goto l717;
  l725:;	  G->pos= yypos717; G->thunkpos= yythunkpos717;  if (!yy_HtmlBlockH1(G)) { goto l726; }  goto l717;
  l726:;	  G->pos= yypos717; G->thunkpos= yythunkpos717;  if (!yy_HtmlBlockH2(G)) { goto l727; }  goto l717;
  l727:;	  G->pos= yypos717; G->thunkpos= yythunkpos717;  if (!yy_HtmlBlockH3(G)) { goto l728; }  goto l717;
  l728:;	  G->pos= yypos717; G->thunkpos= yythunkpos717;  if (!yy_HtmlBlockH4(G)) { goto l729; }  goto l717;
  l729:;	  G->pos= yypos717; G->thunkpos= yythunkpos717;  if (!yy_HtmlBlockH5(G)) { goto l730; }  goto l717;
  l730:;	  G->pos= yypos717; G->thunkpos= yythunkpos717;  if (!yy_HtmlBlockH6(G)) { goto l731; }  goto l717;
  l731:;	  G->pos= yypos717; G->thunkpos= yythunkpos717;  if (!yy_HtmlBlockMenu(G)) { goto l732; }  goto l717;
  l732:;	  G->pos= yypos717; G->thunkpos= yythunkpos717;  if (!yy_HtmlBlockNoframes(G)) { goto l733; }  goto l717;
  l733:;	  G->pos= yypos717; G->thunkpos= yythunkpos717;  if (!yy_HtmlBlockNoscript(G)) { goto l734; }  goto l717;
  l734:;	  G->pos= yypos717; G->thunkpos= yythunkpos717;  if (!yy_HtmlBlockOl(G)) { goto l735; }  goto l717;
  l735:;	  G->pos= yypos717; G->thunkpos= yythunkpos717;  if (!yy_HtmlBlockP(G)) { goto l736; }  goto l717;
  l736:;	  G->pos= yypos717; G->thunkpos= yythunkpos717;  if (!yy_HtmlBlockPre(G)) { goto l737; }  goto l717;
  l737:;	  G->pos= yypos717; G->thunkpos= yythunkpos717;  if (!yy_HtmlBlockTable(G)) { goto l738; }  goto l717;
  l738:;	  G->pos= yypos717; G->thunkpos= yythunkpos717;  if (!yy_HtmlBlockUl(G)) { goto l739; }  goto l717;
  l739:;	  G->pos= yypos717; G->thunkpos= yythunkpos717;  if (!yy_HtmlBlockDd(G)) { goto l740; }  goto l717;
  l740:;	  G->pos= yypos717; G->thunkpos= yythunkpos717;  if (!yy_HtmlBlockDt(G)) { goto l741; }  goto l717;
  l741:;	  G->pos= yypos717; G->thunkpos= yythunkpos717;  if (!yy_HtmlBlockFrameset(G)) { goto l742; }  goto l717;
  l742:;	  G->pos= yypos717; G->thunkpos= yythunkpos717;  if (!yy_HtmlBlockLi(G)) { goto l743; }  goto l717;
  l743:;	  G->pos= yypos717; G->thunkpos= yythunkpos717;  if (!yy_HtmlBlockTbody(G)) { goto l744; }  goto l717;
  l744:;	  G->pos= yypos717; G->thunkpos= yythunkpos717;  if (!yy_HtmlBlockTd(G)) { goto l745; }  goto l717;
  l745:;	  G->pos= yypos717; G->thunkpos= yythunkpos717;  if (!yy_HtmlBlockTfoot(G)) { goto l746; }  goto l717;
  l746:;	  G->pos= yypos717; G->thunkpos= yythunkpos717;  if (!yy_HtmlBlockTh(G)) { goto l747; }  goto l717;
  l747:;	  G->pos= yypos717; G->thunkpos= yythunkpos717;  if (!yy_HtmlBlockThead(G)) { goto l748; }  goto l717;
  l748:;	  G->pos= yypos717; G->thunkpos= yythunkpos717;  if (!yy_HtmlBlockTr(G)) { goto l749; }  goto l717;
  l749:;	  G->pos= yypos717; G->thunkpos= yythunkpos717;  if (!yy_HtmlBlockScript(G)) { goto l750; }  goto l717;
  l750:;	  G->pos= yypos717; G->thunkpos= yythunkpos717;  if (!yy_HtmlBlockHead(G)) { goto l716; }
  }
  l717:;	
  yyprintf((stderr, "  ok   %s @ %s\n", "HtmlBlockInTags", G->buf+G->pos));
  return 1;
  l716:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "HtmlBlockInTags", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_HtmlBlockHead(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "HtmlBlockHead"));  if (!yy_HtmlBlockOpenHead(G)) { goto l751; }
  l752:;	
  {  int yypos753= G->pos, yythunkpos753= G->thunkpos;
  {  int yypos754= G->pos, yythunkpos754= G->thunkpos;  if (!yy_HtmlBlockCloseHead(G)) { goto l754; }  goto l753;
  l754:;	  G->pos= yypos754; G->thunkpos= yythunkpos754;
  }  if (!yymatchDot(G)) goto l753;  goto l752;
  l753:;	  G->pos= yypos753; G->thunkpos= yythunkpos753;
  }  if (!yy_HtmlBlockCloseHead(G)) { goto l751; }
  yyprintf((stderr, "  ok   %s @ %s\n", "HtmlBlockHead", G->buf+G->pos));
  return 1;
  l751:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "HtmlBlockHead", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_HtmlBlockCloseHead(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "HtmlBlockCloseHead"));  if (!yymatchChar(G, '<')) goto l755;  if (!yy_Spnl(G)) { goto l755; }  if (!yymatchChar(G, '/')) goto l755;
  {  int yypos756= G->pos, yythunkpos756= G->thunkpos;  if (!yymatchString(G, "head")) goto l757;  goto l756;
  l757:;	  G->pos= yypos756; G->thunkpos= yythunkpos756;  if (!yymatchString(G, "HEAD")) goto l755;
  }
  l756:;	  if (!yy_Spnl(G)) { goto l755; }  if (!yymatchChar(G, '>')) goto l755;
  yyprintf((stderr, "  ok   %s @ %s\n", "HtmlBlockCloseHead", G->buf+G->pos));
  return 1;
  l755:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "HtmlBlockCloseHead", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_HtmlBlockOpenHead(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "HtmlBlockOpenHead"));  if (!yymatchChar(G, '<')) goto l758;  if (!yy_Spnl(G)) { goto l758; }
  {  int yypos759= G->pos, yythunkpos759= G->thunkpos;  if (!yymatchString(G, "head")) goto l760;  goto l759;
  l760:;	  G->pos= yypos759; G->thunkpos= yythunkpos759;  if (!yymatchString(G, "HEAD")) goto l758;
  }
  l759:;	  if (!yy_Spnl(G)) { goto l758; }
  l761:;	
  {  int yypos762= G->pos, yythunkpos762= G->thunkpos;  if (!yy_HtmlAttribute(G)) { goto l762; }  goto l761;
  l762:;	  G->pos= yypos762; G->thunkpos= yythunkpos762;
  }  if (!yymatchChar(G, '>')) goto l758;
  yyprintf((stderr, "  ok   %s @ %s\n", "HtmlBlockOpenHead", G->buf+G->pos));
  return 1;
  l758:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "HtmlBlockOpenHead", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_HtmlBlockScript(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "HtmlBlockScript"));  if (!yy_HtmlBlockOpenScript(G)) { goto l763; }
  l764:;	
  {  int yypos765= G->pos, yythunkpos765= G->thunkpos;
  {  int yypos766= G->pos, yythunkpos766= G->thunkpos;  if (!yy_HtmlBlockCloseScript(G)) { goto l766; }  goto l765;
  l766:;	  G->pos= yypos766; G->thunkpos= yythunkpos766;
  }  if (!yymatchDot(G)) goto l765;  goto l764;
  l765:;	  G->pos= yypos765; G->thunkpos= yythunkpos765;
  }  if (!yy_HtmlBlockCloseScript(G)) { goto l763; }
  yyprintf((stderr, "  ok   %s @ %s\n", "HtmlBlockScript", G->buf+G->pos));
  return 1;
  l763:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "HtmlBlockScript", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_HtmlBlockCloseScript(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "HtmlBlockCloseScript"));  if (!yymatchChar(G, '<')) goto l767;  if (!yy_Spnl(G)) { goto l767; }  if (!yymatchChar(G, '/')) goto l767;
  {  int yypos768= G->pos, yythunkpos768= G->thunkpos;  if (!yymatchString(G, "script")) goto l769;  goto l768;
  l769:;	  G->pos= yypos768; G->thunkpos= yythunkpos768;  if (!yymatchString(G, "SCRIPT")) goto l767;
  }
  l768:;	  if (!yy_Spnl(G)) { goto l767; }  if (!yymatchChar(G, '>')) goto l767;
  yyprintf((stderr, "  ok   %s @ %s\n", "HtmlBlockCloseScript", G->buf+G->pos));
  return 1;
  l767:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "HtmlBlockCloseScript", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_HtmlBlockOpenScript(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "HtmlBlockOpenScript"));  if (!yymatchChar(G, '<')) goto l770;  if (!yy_Spnl(G)) { goto l770; }
  {  int yypos771= G->pos, yythunkpos771= G->thunkpos;  if (!yymatchString(G, "script")) goto l772;  goto l771;
  l772:;	  G->pos= yypos771; G->thunkpos= yythunkpos771;  if (!yymatchString(G, "SCRIPT")) goto l770;
  }
  l771:;	  if (!yy_Spnl(G)) { goto l770; }
  l773:;	
  {  int yypos774= G->pos, yythunkpos774= G->thunkpos;  if (!yy_HtmlAttribute(G)) { goto l774; }  goto l773;
  l774:;	  G->pos= yypos774; G->thunkpos= yythunkpos774;
  }  if (!yymatchChar(G, '>')) goto l770;
  yyprintf((stderr, "  ok   %s @ %s\n", "HtmlBlockOpenScript", G->buf+G->pos));
  return 1;
  l770:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "HtmlBlockOpenScript", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_HtmlBlockTr(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "HtmlBlockTr"));  if (!yy_HtmlBlockOpenTr(G)) { goto l775; }
  l776:;	
  {  int yypos777= G->pos, yythunkpos777= G->thunkpos;
  {  int yypos778= G->pos, yythunkpos778= G->thunkpos;  if (!yy_HtmlBlockTr(G)) { goto l779; }  goto l778;
  l779:;	  G->pos= yypos778; G->thunkpos= yythunkpos778;
  {  int yypos780= G->pos, yythunkpos780= G->thunkpos;  if (!yy_HtmlBlockCloseTr(G)) { goto l780; }  goto l777;
  l780:;	  G->pos= yypos780; G->thunkpos= yythunkpos780;
  }  if (!yymatchDot(G)) goto l777;
  }
  l778:;	  goto l776;
  l777:;	  G->pos= yypos777; G->thunkpos= yythunkpos777;
  }  if (!yy_HtmlBlockCloseTr(G)) { goto l775; }
  yyprintf((stderr, "  ok   %s @ %s\n", "HtmlBlockTr", G->buf+G->pos));
  return 1;
  l775:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "HtmlBlockTr", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_HtmlBlockCloseTr(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "HtmlBlockCloseTr"));  if (!yymatchChar(G, '<')) goto l781;  if (!yy_Spnl(G)) { goto l781; }  if (!yymatchChar(G, '/')) goto l781;
  {  int yypos782= G->pos, yythunkpos782= G->thunkpos;  if (!yymatchString(G, "tr")) goto l783;  goto l782;
  l783:;	  G->pos= yypos782; G->thunkpos= yythunkpos782;  if (!yymatchString(G, "TR")) goto l781;
  }
  l782:;	  if (!yy_Spnl(G)) { goto l781; }  if (!yymatchChar(G, '>')) goto l781;
  yyprintf((stderr, "  ok   %s @ %s\n", "HtmlBlockCloseTr", G->buf+G->pos));
  return 1;
  l781:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "HtmlBlockCloseTr", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_HtmlBlockOpenTr(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "HtmlBlockOpenTr"));  if (!yymatchChar(G, '<')) goto l784;  if (!yy_Spnl(G)) { goto l784; }
  {  int yypos785= G->pos, yythunkpos785= G->thunkpos;  if (!yymatchString(G, "tr")) goto l786;  goto l785;
  l786:;	  G->pos= yypos785; G->thunkpos= yythunkpos785;  if (!yymatchString(G, "TR")) goto l784;
  }
  l785:;	  if (!yy_Spnl(G)) { goto l784; }
  l787:;	
  {  int yypos788= G->pos, yythunkpos788= G->thunkpos;  if (!yy_HtmlAttribute(G)) { goto l788; }  goto l787;
  l788:;	  G->pos= yypos788; G->thunkpos= yythunkpos788;
  }  if (!yymatchChar(G, '>')) goto l784;
  yyprintf((stderr, "  ok   %s @ %s\n", "HtmlBlockOpenTr", G->buf+G->pos));
  return 1;
  l784:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "HtmlBlockOpenTr", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_HtmlBlockThead(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "HtmlBlockThead"));  if (!yy_HtmlBlockOpenThead(G)) { goto l789; }
  l790:;	
  {  int yypos791= G->pos, yythunkpos791= G->thunkpos;
  {  int yypos792= G->pos, yythunkpos792= G->thunkpos;  if (!yy_HtmlBlockThead(G)) { goto l793; }  goto l792;
  l793:;	  G->pos= yypos792; G->thunkpos= yythunkpos792;
  {  int yypos794= G->pos, yythunkpos794= G->thunkpos;  if (!yy_HtmlBlockCloseThead(G)) { goto l794; }  goto l791;
  l794:;	  G->pos= yypos794; G->thunkpos= yythunkpos794;
  }  if (!yymatchDot(G)) goto l791;
  }
  l792:;	  goto l790;
  l791:;	  G->pos= yypos791; G->thunkpos= yythunkpos791;
  }  if (!yy_HtmlBlockCloseThead(G)) { goto l789; }
  yyprintf((stderr, "  ok   %s @ %s\n", "HtmlBlockThead", G->buf+G->pos));
  return 1;
  l789:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "HtmlBlockThead", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_HtmlBlockCloseThead(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "HtmlBlockCloseThead"));  if (!yymatchChar(G, '<')) goto l795;  if (!yy_Spnl(G)) { goto l795; }  if (!yymatchChar(G, '/')) goto l795;
  {  int yypos796= G->pos, yythunkpos796= G->thunkpos;  if (!yymatchString(G, "thead")) goto l797;  goto l796;
  l797:;	  G->pos= yypos796; G->thunkpos= yythunkpos796;  if (!yymatchString(G, "THEAD")) goto l795;
  }
  l796:;	  if (!yy_Spnl(G)) { goto l795; }  if (!yymatchChar(G, '>')) goto l795;
  yyprintf((stderr, "  ok   %s @ %s\n", "HtmlBlockCloseThead", G->buf+G->pos));
  return 1;
  l795:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "HtmlBlockCloseThead", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_HtmlBlockOpenThead(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "HtmlBlockOpenThead"));  if (!yymatchChar(G, '<')) goto l798;  if (!yy_Spnl(G)) { goto l798; }
  {  int yypos799= G->pos, yythunkpos799= G->thunkpos;  if (!yymatchString(G, "thead")) goto l800;  goto l799;
  l800:;	  G->pos= yypos799; G->thunkpos= yythunkpos799;  if (!yymatchString(G, "THEAD")) goto l798;
  }
  l799:;	  if (!yy_Spnl(G)) { goto l798; }
  l801:;	
  {  int yypos802= G->pos, yythunkpos802= G->thunkpos;  if (!yy_HtmlAttribute(G)) { goto l802; }  goto l801;
  l802:;	  G->pos= yypos802; G->thunkpos= yythunkpos802;
  }  if (!yymatchChar(G, '>')) goto l798;
  yyprintf((stderr, "  ok   %s @ %s\n", "HtmlBlockOpenThead", G->buf+G->pos));
  return 1;
  l798:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "HtmlBlockOpenThead", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_HtmlBlockTh(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "HtmlBlockTh"));  if (!yy_HtmlBlockOpenTh(G)) { goto l803; }
  l804:;	
  {  int yypos805= G->pos, yythunkpos805= G->thunkpos;
  {  int yypos806= G->pos, yythunkpos806= G->thunkpos;  if (!yy_HtmlBlockTh(G)) { goto l807; }  goto l806;
  l807:;	  G->pos= yypos806; G->thunkpos= yythunkpos806;
  {  int yypos808= G->pos, yythunkpos808= G->thunkpos;  if (!yy_HtmlBlockCloseTh(G)) { goto l808; }  goto l805;
  l808:;	  G->pos= yypos808; G->thunkpos= yythunkpos808;
  }  if (!yymatchDot(G)) goto l805;
  }
  l806:;	  goto l804;
  l805:;	  G->pos= yypos805; G->thunkpos= yythunkpos805;
  }  if (!yy_HtmlBlockCloseTh(G)) { goto l803; }
  yyprintf((stderr, "  ok   %s @ %s\n", "HtmlBlockTh", G->buf+G->pos));
  return 1;
  l803:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "HtmlBlockTh", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_HtmlBlockCloseTh(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "HtmlBlockCloseTh"));  if (!yymatchChar(G, '<')) goto l809;  if (!yy_Spnl(G)) { goto l809; }  if (!yymatchChar(G, '/')) goto l809;
  {  int yypos810= G->pos, yythunkpos810= G->thunkpos;  if (!yymatchString(G, "th")) goto l811;  goto l810;
  l811:;	  G->pos= yypos810; G->thunkpos= yythunkpos810;  if (!yymatchString(G, "TH")) goto l809;
  }
  l810:;	  if (!yy_Spnl(G)) { goto l809; }  if (!yymatchChar(G, '>')) goto l809;
  yyprintf((stderr, "  ok   %s @ %s\n", "HtmlBlockCloseTh", G->buf+G->pos));
  return 1;
  l809:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "HtmlBlockCloseTh", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_HtmlBlockOpenTh(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "HtmlBlockOpenTh"));  if (!yymatchChar(G, '<')) goto l812;  if (!yy_Spnl(G)) { goto l812; }
  {  int yypos813= G->pos, yythunkpos813= G->thunkpos;  if (!yymatchString(G, "th")) goto l814;  goto l813;
  l814:;	  G->pos= yypos813; G->thunkpos= yythunkpos813;  if (!yymatchString(G, "TH")) goto l812;
  }
  l813:;	  if (!yy_Spnl(G)) { goto l812; }
  l815:;	
  {  int yypos816= G->pos, yythunkpos816= G->thunkpos;  if (!yy_HtmlAttribute(G)) { goto l816; }  goto l815;
  l816:;	  G->pos= yypos816; G->thunkpos= yythunkpos816;
  }  if (!yymatchChar(G, '>')) goto l812;
  yyprintf((stderr, "  ok   %s @ %s\n", "HtmlBlockOpenTh", G->buf+G->pos));
  return 1;
  l812:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "HtmlBlockOpenTh", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_HtmlBlockTfoot(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "HtmlBlockTfoot"));  if (!yy_HtmlBlockOpenTfoot(G)) { goto l817; }
  l818:;	
  {  int yypos819= G->pos, yythunkpos819= G->thunkpos;
  {  int yypos820= G->pos, yythunkpos820= G->thunkpos;  if (!yy_HtmlBlockTfoot(G)) { goto l821; }  goto l820;
  l821:;	  G->pos= yypos820; G->thunkpos= yythunkpos820;
  {  int yypos822= G->pos, yythunkpos822= G->thunkpos;  if (!yy_HtmlBlockCloseTfoot(G)) { goto l822; }  goto l819;
  l822:;	  G->pos= yypos822; G->thunkpos= yythunkpos822;
  }  if (!yymatchDot(G)) goto l819;
  }
  l820:;	  goto l818;
  l819:;	  G->pos= yypos819; G->thunkpos= yythunkpos819;
  }  if (!yy_HtmlBlockCloseTfoot(G)) { goto l817; }
  yyprintf((stderr, "  ok   %s @ %s\n", "HtmlBlockTfoot", G->buf+G->pos));
  return 1;
  l817:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "HtmlBlockTfoot", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_HtmlBlockCloseTfoot(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "HtmlBlockCloseTfoot"));  if (!yymatchChar(G, '<')) goto l823;  if (!yy_Spnl(G)) { goto l823; }  if (!yymatchChar(G, '/')) goto l823;
  {  int yypos824= G->pos, yythunkpos824= G->thunkpos;  if (!yymatchString(G, "tfoot")) goto l825;  goto l824;
  l825:;	  G->pos= yypos824; G->thunkpos= yythunkpos824;  if (!yymatchString(G, "TFOOT")) goto l823;
  }
  l824:;	  if (!yy_Spnl(G)) { goto l823; }  if (!yymatchChar(G, '>')) goto l823;
  yyprintf((stderr, "  ok   %s @ %s\n", "HtmlBlockCloseTfoot", G->buf+G->pos));
  return 1;
  l823:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "HtmlBlockCloseTfoot", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_HtmlBlockOpenTfoot(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "HtmlBlockOpenTfoot"));  if (!yymatchChar(G, '<')) goto l826;  if (!yy_Spnl(G)) { goto l826; }
  {  int yypos827= G->pos, yythunkpos827= G->thunkpos;  if (!yymatchString(G, "tfoot")) goto l828;  goto l827;
  l828:;	  G->pos= yypos827; G->thunkpos= yythunkpos827;  if (!yymatchString(G, "TFOOT")) goto l826;
  }
  l827:;	  if (!yy_Spnl(G)) { goto l826; }
  l829:;	
  {  int yypos830= G->pos, yythunkpos830= G->thunkpos;  if (!yy_HtmlAttribute(G)) { goto l830; }  goto l829;
  l830:;	  G->pos= yypos830; G->thunkpos= yythunkpos830;
  }  if (!yymatchChar(G, '>')) goto l826;
  yyprintf((stderr, "  ok   %s @ %s\n", "HtmlBlockOpenTfoot", G->buf+G->pos));
  return 1;
  l826:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "HtmlBlockOpenTfoot", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_HtmlBlockTd(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "HtmlBlockTd"));  if (!yy_HtmlBlockOpenTd(G)) { goto l831; }
  l832:;	
  {  int yypos833= G->pos, yythunkpos833= G->thunkpos;
  {  int yypos834= G->pos, yythunkpos834= G->thunkpos;  if (!yy_HtmlBlockTd(G)) { goto l835; }  goto l834;
  l835:;	  G->pos= yypos834; G->thunkpos= yythunkpos834;
  {  int yypos836= G->pos, yythunkpos836= G->thunkpos;  if (!yy_HtmlBlockCloseTd(G)) { goto l836; }  goto l833;
  l836:;	  G->pos= yypos836; G->thunkpos= yythunkpos836;
  }  if (!yymatchDot(G)) goto l833;
  }
  l834:;	  goto l832;
  l833:;	  G->pos= yypos833; G->thunkpos= yythunkpos833;
  }  if (!yy_HtmlBlockCloseTd(G)) { goto l831; }
  yyprintf((stderr, "  ok   %s @ %s\n", "HtmlBlockTd", G->buf+G->pos));
  return 1;
  l831:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "HtmlBlockTd", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_HtmlBlockCloseTd(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "HtmlBlockCloseTd"));  if (!yymatchChar(G, '<')) goto l837;  if (!yy_Spnl(G)) { goto l837; }  if (!yymatchChar(G, '/')) goto l837;
  {  int yypos838= G->pos, yythunkpos838= G->thunkpos;  if (!yymatchString(G, "td")) goto l839;  goto l838;
  l839:;	  G->pos= yypos838; G->thunkpos= yythunkpos838;  if (!yymatchString(G, "TD")) goto l837;
  }
  l838:;	  if (!yy_Spnl(G)) { goto l837; }  if (!yymatchChar(G, '>')) goto l837;
  yyprintf((stderr, "  ok   %s @ %s\n", "HtmlBlockCloseTd", G->buf+G->pos));
  return 1;
  l837:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "HtmlBlockCloseTd", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_HtmlBlockOpenTd(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "HtmlBlockOpenTd"));  if (!yymatchChar(G, '<')) goto l840;  if (!yy_Spnl(G)) { goto l840; }
  {  int yypos841= G->pos, yythunkpos841= G->thunkpos;  if (!yymatchString(G, "td")) goto l842;  goto l841;
  l842:;	  G->pos= yypos841; G->thunkpos= yythunkpos841;  if (!yymatchString(G, "TD")) goto l840;
  }
  l841:;	  if (!yy_Spnl(G)) { goto l840; }
  l843:;	
  {  int yypos844= G->pos, yythunkpos844= G->thunkpos;  if (!yy_HtmlAttribute(G)) { goto l844; }  goto l843;
  l844:;	  G->pos= yypos844; G->thunkpos= yythunkpos844;
  }  if (!yymatchChar(G, '>')) goto l840;
  yyprintf((stderr, "  ok   %s @ %s\n", "HtmlBlockOpenTd", G->buf+G->pos));
  return 1;
  l840:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "HtmlBlockOpenTd", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_HtmlBlockTbody(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "HtmlBlockTbody"));  if (!yy_HtmlBlockOpenTbody(G)) { goto l845; }
  l846:;	
  {  int yypos847= G->pos, yythunkpos847= G->thunkpos;
  {  int yypos848= G->pos, yythunkpos848= G->thunkpos;  if (!yy_HtmlBlockTbody(G)) { goto l849; }  goto l848;
  l849:;	  G->pos= yypos848; G->thunkpos= yythunkpos848;
  {  int yypos850= G->pos, yythunkpos850= G->thunkpos;  if (!yy_HtmlBlockCloseTbody(G)) { goto l850; }  goto l847;
  l850:;	  G->pos= yypos850; G->thunkpos= yythunkpos850;
  }  if (!yymatchDot(G)) goto l847;
  }
  l848:;	  goto l846;
  l847:;	  G->pos= yypos847; G->thunkpos= yythunkpos847;
  }  if (!yy_HtmlBlockCloseTbody(G)) { goto l845; }
  yyprintf((stderr, "  ok   %s @ %s\n", "HtmlBlockTbody", G->buf+G->pos));
  return 1;
  l845:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "HtmlBlockTbody", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_HtmlBlockCloseTbody(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "HtmlBlockCloseTbody"));  if (!yymatchChar(G, '<')) goto l851;  if (!yy_Spnl(G)) { goto l851; }  if (!yymatchChar(G, '/')) goto l851;
  {  int yypos852= G->pos, yythunkpos852= G->thunkpos;  if (!yymatchString(G, "tbody")) goto l853;  goto l852;
  l853:;	  G->pos= yypos852; G->thunkpos= yythunkpos852;  if (!yymatchString(G, "TBODY")) goto l851;
  }
  l852:;	  if (!yy_Spnl(G)) { goto l851; }  if (!yymatchChar(G, '>')) goto l851;
  yyprintf((stderr, "  ok   %s @ %s\n", "HtmlBlockCloseTbody", G->buf+G->pos));
  return 1;
  l851:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "HtmlBlockCloseTbody", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_HtmlBlockOpenTbody(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "HtmlBlockOpenTbody"));  if (!yymatchChar(G, '<')) goto l854;  if (!yy_Spnl(G)) { goto l854; }
  {  int yypos855= G->pos, yythunkpos855= G->thunkpos;  if (!yymatchString(G, "tbody")) goto l856;  goto l855;
  l856:;	  G->pos= yypos855; G->thunkpos= yythunkpos855;  if (!yymatchString(G, "TBODY")) goto l854;
  }
  l855:;	  if (!yy_Spnl(G)) { goto l854; }
  l857:;	
  {  int yypos858= G->pos, yythunkpos858= G->thunkpos;  if (!yy_HtmlAttribute(G)) { goto l858; }  goto l857;
  l858:;	  G->pos= yypos858; G->thunkpos= yythunkpos858;
  }  if (!yymatchChar(G, '>')) goto l854;
  yyprintf((stderr, "  ok   %s @ %s\n", "HtmlBlockOpenTbody", G->buf+G->pos));
  return 1;
  l854:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "HtmlBlockOpenTbody", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_HtmlBlockLi(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "HtmlBlockLi"));  if (!yy_HtmlBlockOpenLi(G)) { goto l859; }
  l860:;	
  {  int yypos861= G->pos, yythunkpos861= G->thunkpos;
  {  int yypos862= G->pos, yythunkpos862= G->thunkpos;  if (!yy_HtmlBlockLi(G)) { goto l863; }  goto l862;
  l863:;	  G->pos= yypos862; G->thunkpos= yythunkpos862;
  {  int yypos864= G->pos, yythunkpos864= G->thunkpos;  if (!yy_HtmlBlockCloseLi(G)) { goto l864; }  goto l861;
  l864:;	  G->pos= yypos864; G->thunkpos= yythunkpos864;
  }  if (!yymatchDot(G)) goto l861;
  }
  l862:;	  goto l860;
  l861:;	  G->pos= yypos861; G->thunkpos= yythunkpos861;
  }  if (!yy_HtmlBlockCloseLi(G)) { goto l859; }
  yyprintf((stderr, "  ok   %s @ %s\n", "HtmlBlockLi", G->buf+G->pos));
  return 1;
  l859:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "HtmlBlockLi", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_HtmlBlockCloseLi(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "HtmlBlockCloseLi"));  if (!yymatchChar(G, '<')) goto l865;  if (!yy_Spnl(G)) { goto l865; }  if (!yymatchChar(G, '/')) goto l865;
  {  int yypos866= G->pos, yythunkpos866= G->thunkpos;  if (!yymatchString(G, "li")) goto l867;  goto l866;
  l867:;	  G->pos= yypos866; G->thunkpos= yythunkpos866;  if (!yymatchString(G, "LI")) goto l865;
  }
  l866:;	  if (!yy_Spnl(G)) { goto l865; }  if (!yymatchChar(G, '>')) goto l865;
  yyprintf((stderr, "  ok   %s @ %s\n", "HtmlBlockCloseLi", G->buf+G->pos));
  return 1;
  l865:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "HtmlBlockCloseLi", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_HtmlBlockOpenLi(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "HtmlBlockOpenLi"));  if (!yymatchChar(G, '<')) goto l868;  if (!yy_Spnl(G)) { goto l868; }
  {  int yypos869= G->pos, yythunkpos869= G->thunkpos;  if (!yymatchString(G, "li")) goto l870;  goto l869;
  l870:;	  G->pos= yypos869; G->thunkpos= yythunkpos869;  if (!yymatchString(G, "LI")) goto l868;
  }
  l869:;	  if (!yy_Spnl(G)) { goto l868; }
  l871:;	
  {  int yypos872= G->pos, yythunkpos872= G->thunkpos;  if (!yy_HtmlAttribute(G)) { goto l872; }  goto l871;
  l872:;	  G->pos= yypos872; G->thunkpos= yythunkpos872;
  }  if (!yymatchChar(G, '>')) goto l868;
  yyprintf((stderr, "  ok   %s @ %s\n", "HtmlBlockOpenLi", G->buf+G->pos));
  return 1;
  l868:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "HtmlBlockOpenLi", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_HtmlBlockFrameset(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "HtmlBlockFrameset"));  if (!yy_HtmlBlockOpenFrameset(G)) { goto l873; }
  l874:;	
  {  int yypos875= G->pos, yythunkpos875= G->thunkpos;
  {  int yypos876= G->pos, yythunkpos876= G->thunkpos;  if (!yy_HtmlBlockFrameset(G)) { goto l877; }  goto l876;
  l877:;	  G->pos= yypos876; G->thunkpos= yythunkpos876;
  {  int yypos878= G->pos, yythunkpos878= G->thunkpos;  if (!yy_HtmlBlockCloseFrameset(G)) { goto l878; }  goto l875;
  l878:;	  G->pos= yypos878; G->thunkpos= yythunkpos878;
  }  if (!yymatchDot(G)) goto l875;
  }
  l876:;	  goto l874;
  l875:;	  G->pos= yypos875; G->thunkpos= yythunkpos875;
  }  if (!yy_HtmlBlockCloseFrameset(G)) { goto l873; }
  yyprintf((stderr, "  ok   %s @ %s\n", "HtmlBlockFrameset", G->buf+G->pos));
  return 1;
  l873:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "HtmlBlockFrameset", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_HtmlBlockCloseFrameset(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "HtmlBlockCloseFrameset"));  if (!yymatchChar(G, '<')) goto l879;  if (!yy_Spnl(G)) { goto l879; }  if (!yymatchChar(G, '/')) goto l879;
  {  int yypos880= G->pos, yythunkpos880= G->thunkpos;  if (!yymatchString(G, "frameset")) goto l881;  goto l880;
  l881:;	  G->pos= yypos880; G->thunkpos= yythunkpos880;  if (!yymatchString(G, "FRAMESET")) goto l879;
  }
  l880:;	  if (!yy_Spnl(G)) { goto l879; }  if (!yymatchChar(G, '>')) goto l879;
  yyprintf((stderr, "  ok   %s @ %s\n", "HtmlBlockCloseFrameset", G->buf+G->pos));
  return 1;
  l879:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "HtmlBlockCloseFrameset", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_HtmlBlockOpenFrameset(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "HtmlBlockOpenFrameset"));  if (!yymatchChar(G, '<')) goto l882;  if (!yy_Spnl(G)) { goto l882; }
  {  int yypos883= G->pos, yythunkpos883= G->thunkpos;  if (!yymatchString(G, "frameset")) goto l884;  goto l883;
  l884:;	  G->pos= yypos883; G->thunkpos= yythunkpos883;  if (!yymatchString(G, "FRAMESET")) goto l882;
  }
  l883:;	  if (!yy_Spnl(G)) { goto l882; }
  l885:;	
  {  int yypos886= G->pos, yythunkpos886= G->thunkpos;  if (!yy_HtmlAttribute(G)) { goto l886; }  goto l885;
  l886:;	  G->pos= yypos886; G->thunkpos= yythunkpos886;
  }  if (!yymatchChar(G, '>')) goto l882;
  yyprintf((stderr, "  ok   %s @ %s\n", "HtmlBlockOpenFrameset", G->buf+G->pos));
  return 1;
  l882:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "HtmlBlockOpenFrameset", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_HtmlBlockDt(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "HtmlBlockDt"));  if (!yy_HtmlBlockOpenDt(G)) { goto l887; }
  l888:;	
  {  int yypos889= G->pos, yythunkpos889= G->thunkpos;
  {  int yypos890= G->pos, yythunkpos890= G->thunkpos;  if (!yy_HtmlBlockDt(G)) { goto l891; }  goto l890;
  l891:;	  G->pos= yypos890; G->thunkpos= yythunkpos890;
  {  int yypos892= G->pos, yythunkpos892= G->thunkpos;  if (!yy_HtmlBlockCloseDt(G)) { goto l892; }  goto l889;
  l892:;	  G->pos= yypos892; G->thunkpos= yythunkpos892;
  }  if (!yymatchDot(G)) goto l889;
  }
  l890:;	  goto l888;
  l889:;	  G->pos= yypos889; G->thunkpos= yythunkpos889;
  }  if (!yy_HtmlBlockCloseDt(G)) { goto l887; }
  yyprintf((stderr, "  ok   %s @ %s\n", "HtmlBlockDt", G->buf+G->pos));
  return 1;
  l887:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "HtmlBlockDt", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_HtmlBlockCloseDt(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "HtmlBlockCloseDt"));  if (!yymatchChar(G, '<')) goto l893;  if (!yy_Spnl(G)) { goto l893; }  if (!yymatchChar(G, '/')) goto l893;
  {  int yypos894= G->pos, yythunkpos894= G->thunkpos;  if (!yymatchString(G, "dt")) goto l895;  goto l894;
  l895:;	  G->pos= yypos894; G->thunkpos= yythunkpos894;  if (!yymatchString(G, "DT")) goto l893;
  }
  l894:;	  if (!yy_Spnl(G)) { goto l893; }  if (!yymatchChar(G, '>')) goto l893;
  yyprintf((stderr, "  ok   %s @ %s\n", "HtmlBlockCloseDt", G->buf+G->pos));
  return 1;
  l893:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "HtmlBlockCloseDt", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_HtmlBlockOpenDt(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "HtmlBlockOpenDt"));  if (!yymatchChar(G, '<')) goto l896;  if (!yy_Spnl(G)) { goto l896; }
  {  int yypos897= G->pos, yythunkpos897= G->thunkpos;  if (!yymatchString(G, "dt")) goto l898;  goto l897;
  l898:;	  G->pos= yypos897; G->thunkpos= yythunkpos897;  if (!yymatchString(G, "DT")) goto l896;
  }
  l897:;	  if (!yy_Spnl(G)) { goto l896; }
  l899:;	
  {  int yypos900= G->pos, yythunkpos900= G->thunkpos;  if (!yy_HtmlAttribute(G)) { goto l900; }  goto l899;
  l900:;	  G->pos= yypos900; G->thunkpos= yythunkpos900;
  }  if (!yymatchChar(G, '>')) goto l896;
  yyprintf((stderr, "  ok   %s @ %s\n", "HtmlBlockOpenDt", G->buf+G->pos));
  return 1;
  l896:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "HtmlBlockOpenDt", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_HtmlBlockDd(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "HtmlBlockDd"));  if (!yy_HtmlBlockOpenDd(G)) { goto l901; }
  l902:;	
  {  int yypos903= G->pos, yythunkpos903= G->thunkpos;
  {  int yypos904= G->pos, yythunkpos904= G->thunkpos;  if (!yy_HtmlBlockDd(G)) { goto l905; }  goto l904;
  l905:;	  G->pos= yypos904; G->thunkpos= yythunkpos904;
  {  int yypos906= G->pos, yythunkpos906= G->thunkpos;  if (!yy_HtmlBlockCloseDd(G)) { goto l906; }  goto l903;
  l906:;	  G->pos= yypos906; G->thunkpos= yythunkpos906;
  }  if (!yymatchDot(G)) goto l903;
  }
  l904:;	  goto l902;
  l903:;	  G->pos= yypos903; G->thunkpos= yythunkpos903;
  }  if (!yy_HtmlBlockCloseDd(G)) { goto l901; }
  yyprintf((stderr, "  ok   %s @ %s\n", "HtmlBlockDd", G->buf+G->pos));
  return 1;
  l901:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "HtmlBlockDd", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_HtmlBlockCloseDd(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "HtmlBlockCloseDd"));  if (!yymatchChar(G, '<')) goto l907;  if (!yy_Spnl(G)) { goto l907; }  if (!yymatchChar(G, '/')) goto l907;
  {  int yypos908= G->pos, yythunkpos908= G->thunkpos;  if (!yymatchString(G, "dd")) goto l909;  goto l908;
  l909:;	  G->pos= yypos908; G->thunkpos= yythunkpos908;  if (!yymatchString(G, "DD")) goto l907;
  }
  l908:;	  if (!yy_Spnl(G)) { goto l907; }  if (!yymatchChar(G, '>')) goto l907;
  yyprintf((stderr, "  ok   %s @ %s\n", "HtmlBlockCloseDd", G->buf+G->pos));
  return 1;
  l907:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "HtmlBlockCloseDd", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_HtmlBlockOpenDd(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "HtmlBlockOpenDd"));  if (!yymatchChar(G, '<')) goto l910;  if (!yy_Spnl(G)) { goto l910; }
  {  int yypos911= G->pos, yythunkpos911= G->thunkpos;  if (!yymatchString(G, "dd")) goto l912;  goto l911;
  l912:;	  G->pos= yypos911; G->thunkpos= yythunkpos911;  if (!yymatchString(G, "DD")) goto l910;
  }
  l911:;	  if (!yy_Spnl(G)) { goto l910; }
  l913:;	
  {  int yypos914= G->pos, yythunkpos914= G->thunkpos;  if (!yy_HtmlAttribute(G)) { goto l914; }  goto l913;
  l914:;	  G->pos= yypos914; G->thunkpos= yythunkpos914;
  }  if (!yymatchChar(G, '>')) goto l910;
  yyprintf((stderr, "  ok   %s @ %s\n", "HtmlBlockOpenDd", G->buf+G->pos));
  return 1;
  l910:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "HtmlBlockOpenDd", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_HtmlBlockUl(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "HtmlBlockUl"));  if (!yy_HtmlBlockOpenUl(G)) { goto l915; }
  l916:;	
  {  int yypos917= G->pos, yythunkpos917= G->thunkpos;
  {  int yypos918= G->pos, yythunkpos918= G->thunkpos;  if (!yy_HtmlBlockUl(G)) { goto l919; }  goto l918;
  l919:;	  G->pos= yypos918; G->thunkpos= yythunkpos918;
  {  int yypos920= G->pos, yythunkpos920= G->thunkpos;  if (!yy_HtmlBlockCloseUl(G)) { goto l920; }  goto l917;
  l920:;	  G->pos= yypos920; G->thunkpos= yythunkpos920;
  }  if (!yymatchDot(G)) goto l917;
  }
  l918:;	  goto l916;
  l917:;	  G->pos= yypos917; G->thunkpos= yythunkpos917;
  }  if (!yy_HtmlBlockCloseUl(G)) { goto l915; }
  yyprintf((stderr, "  ok   %s @ %s\n", "HtmlBlockUl", G->buf+G->pos));
  return 1;
  l915:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "HtmlBlockUl", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_HtmlBlockCloseUl(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "HtmlBlockCloseUl"));  if (!yymatchChar(G, '<')) goto l921;  if (!yy_Spnl(G)) { goto l921; }  if (!yymatchChar(G, '/')) goto l921;
  {  int yypos922= G->pos, yythunkpos922= G->thunkpos;  if (!yymatchString(G, "ul")) goto l923;  goto l922;
  l923:;	  G->pos= yypos922; G->thunkpos= yythunkpos922;  if (!yymatchString(G, "UL")) goto l921;
  }
  l922:;	  if (!yy_Spnl(G)) { goto l921; }  if (!yymatchChar(G, '>')) goto l921;
  yyprintf((stderr, "  ok   %s @ %s\n", "HtmlBlockCloseUl", G->buf+G->pos));
  return 1;
  l921:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "HtmlBlockCloseUl", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_HtmlBlockOpenUl(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "HtmlBlockOpenUl"));  if (!yymatchChar(G, '<')) goto l924;  if (!yy_Spnl(G)) { goto l924; }
  {  int yypos925= G->pos, yythunkpos925= G->thunkpos;  if (!yymatchString(G, "ul")) goto l926;  goto l925;
  l926:;	  G->pos= yypos925; G->thunkpos= yythunkpos925;  if (!yymatchString(G, "UL")) goto l924;
  }
  l925:;	  if (!yy_Spnl(G)) { goto l924; }
  l927:;	
  {  int yypos928= G->pos, yythunkpos928= G->thunkpos;  if (!yy_HtmlAttribute(G)) { goto l928; }  goto l927;
  l928:;	  G->pos= yypos928; G->thunkpos= yythunkpos928;
  }  if (!yymatchChar(G, '>')) goto l924;
  yyprintf((stderr, "  ok   %s @ %s\n", "HtmlBlockOpenUl", G->buf+G->pos));
  return 1;
  l924:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "HtmlBlockOpenUl", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_HtmlBlockTable(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "HtmlBlockTable"));  if (!yy_HtmlBlockOpenTable(G)) { goto l929; }
  l930:;	
  {  int yypos931= G->pos, yythunkpos931= G->thunkpos;
  {  int yypos932= G->pos, yythunkpos932= G->thunkpos;  if (!yy_HtmlBlockTable(G)) { goto l933; }  goto l932;
  l933:;	  G->pos= yypos932; G->thunkpos= yythunkpos932;
  {  int yypos934= G->pos, yythunkpos934= G->thunkpos;  if (!yy_HtmlBlockCloseTable(G)) { goto l934; }  goto l931;
  l934:;	  G->pos= yypos934; G->thunkpos= yythunkpos934;
  }  if (!yymatchDot(G)) goto l931;
  }
  l932:;	  goto l930;
  l931:;	  G->pos= yypos931; G->thunkpos= yythunkpos931;
  }  if (!yy_HtmlBlockCloseTable(G)) { goto l929; }
  yyprintf((stderr, "  ok   %s @ %s\n", "HtmlBlockTable", G->buf+G->pos));
  return 1;
  l929:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "HtmlBlockTable", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_HtmlBlockCloseTable(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "HtmlBlockCloseTable"));  if (!yymatchChar(G, '<')) goto l935;  if (!yy_Spnl(G)) { goto l935; }  if (!yymatchChar(G, '/')) goto l935;
  {  int yypos936= G->pos, yythunkpos936= G->thunkpos;  if (!yymatchString(G, "table")) goto l937;  goto l936;
  l937:;	  G->pos= yypos936; G->thunkpos= yythunkpos936;  if (!yymatchString(G, "TABLE")) goto l935;
  }
  l936:;	  if (!yy_Spnl(G)) { goto l935; }  if (!yymatchChar(G, '>')) goto l935;
  yyprintf((stderr, "  ok   %s @ %s\n", "HtmlBlockCloseTable", G->buf+G->pos));
  return 1;
  l935:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "HtmlBlockCloseTable", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_HtmlBlockOpenTable(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "HtmlBlockOpenTable"));  if (!yymatchChar(G, '<')) goto l938;  if (!yy_Spnl(G)) { goto l938; }
  {  int yypos939= G->pos, yythunkpos939= G->thunkpos;  if (!yymatchString(G, "table")) goto l940;  goto l939;
  l940:;	  G->pos= yypos939; G->thunkpos= yythunkpos939;  if (!yymatchString(G, "TABLE")) goto l938;
  }
  l939:;	  if (!yy_Spnl(G)) { goto l938; }
  l941:;	
  {  int yypos942= G->pos, yythunkpos942= G->thunkpos;  if (!yy_HtmlAttribute(G)) { goto l942; }  goto l941;
  l942:;	  G->pos= yypos942; G->thunkpos= yythunkpos942;
  }  if (!yymatchChar(G, '>')) goto l938;
  yyprintf((stderr, "  ok   %s @ %s\n", "HtmlBlockOpenTable", G->buf+G->pos));
  return 1;
  l938:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "HtmlBlockOpenTable", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_HtmlBlockPre(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "HtmlBlockPre"));  if (!yy_HtmlBlockOpenPre(G)) { goto l943; }
  l944:;	
  {  int yypos945= G->pos, yythunkpos945= G->thunkpos;
  {  int yypos946= G->pos, yythunkpos946= G->thunkpos;  if (!yy_HtmlBlockPre(G)) { goto l947; }  goto l946;
  l947:;	  G->pos= yypos946; G->thunkpos= yythunkpos946;
  {  int yypos948= G->pos, yythunkpos948= G->thunkpos;  if (!yy_HtmlBlockClosePre(G)) { goto l948; }  goto l945;
  l948:;	  G->pos= yypos948; G->thunkpos= yythunkpos948;
  }  if (!yymatchDot(G)) goto l945;
  }
  l946:;	  goto l944;
  l945:;	  G->pos= yypos945; G->thunkpos= yythunkpos945;
  }  if (!yy_HtmlBlockClosePre(G)) { goto l943; }
  yyprintf((stderr, "  ok   %s @ %s\n", "HtmlBlockPre", G->buf+G->pos));
  return 1;
  l943:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "HtmlBlockPre", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_HtmlBlockClosePre(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "HtmlBlockClosePre"));  if (!yymatchChar(G, '<')) goto l949;  if (!yy_Spnl(G)) { goto l949; }  if (!yymatchChar(G, '/')) goto l949;
  {  int yypos950= G->pos, yythunkpos950= G->thunkpos;  if (!yymatchString(G, "pre")) goto l951;  goto l950;
  l951:;	  G->pos= yypos950; G->thunkpos= yythunkpos950;  if (!yymatchString(G, "PRE")) goto l949;
  }
  l950:;	  if (!yy_Spnl(G)) { goto l949; }  if (!yymatchChar(G, '>')) goto l949;
  yyprintf((stderr, "  ok   %s @ %s\n", "HtmlBlockClosePre", G->buf+G->pos));
  return 1;
  l949:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "HtmlBlockClosePre", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_HtmlBlockOpenPre(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "HtmlBlockOpenPre"));  if (!yymatchChar(G, '<')) goto l952;  if (!yy_Spnl(G)) { goto l952; }
  {  int yypos953= G->pos, yythunkpos953= G->thunkpos;  if (!yymatchString(G, "pre")) goto l954;  goto l953;
  l954:;	  G->pos= yypos953; G->thunkpos= yythunkpos953;  if (!yymatchString(G, "PRE")) goto l952;
  }
  l953:;	  if (!yy_Spnl(G)) { goto l952; }
  l955:;	
  {  int yypos956= G->pos, yythunkpos956= G->thunkpos;  if (!yy_HtmlAttribute(G)) { goto l956; }  goto l955;
  l956:;	  G->pos= yypos956; G->thunkpos= yythunkpos956;
  }  if (!yymatchChar(G, '>')) goto l952;
  yyprintf((stderr, "  ok   %s @ %s\n", "HtmlBlockOpenPre", G->buf+G->pos));
  return 1;
  l952:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "HtmlBlockOpenPre", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_HtmlBlockP(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "HtmlBlockP"));  if (!yy_HtmlBlockOpenP(G)) { goto l957; }
  l958:;	
  {  int yypos959= G->pos, yythunkpos959= G->thunkpos;
  {  int yypos960= G->pos, yythunkpos960= G->thunkpos;  if (!yy_HtmlBlockP(G)) { goto l961; }  goto l960;
  l961:;	  G->pos= yypos960; G->thunkpos= yythunkpos960;
  {  int yypos962= G->pos, yythunkpos962= G->thunkpos;  if (!yy_HtmlBlockCloseP(G)) { goto l962; }  goto l959;
  l962:;	  G->pos= yypos962; G->thunkpos= yythunkpos962;
  }  if (!yymatchDot(G)) goto l959;
  }
  l960:;	  goto l958;
  l959:;	  G->pos= yypos959; G->thunkpos= yythunkpos959;
  }  if (!yy_HtmlBlockCloseP(G)) { goto l957; }
  yyprintf((stderr, "  ok   %s @ %s\n", "HtmlBlockP", G->buf+G->pos));
  return 1;
  l957:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "HtmlBlockP", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_HtmlBlockCloseP(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "HtmlBlockCloseP"));  if (!yymatchChar(G, '<')) goto l963;  if (!yy_Spnl(G)) { goto l963; }  if (!yymatchChar(G, '/')) goto l963;
  {  int yypos964= G->pos, yythunkpos964= G->thunkpos;  if (!yymatchChar(G, 'p')) goto l965;  goto l964;
  l965:;	  G->pos= yypos964; G->thunkpos= yythunkpos964;  if (!yymatchChar(G, 'P')) goto l963;
  }
  l964:;	  if (!yy_Spnl(G)) { goto l963; }  if (!yymatchChar(G, '>')) goto l963;
  yyprintf((stderr, "  ok   %s @ %s\n", "HtmlBlockCloseP", G->buf+G->pos));
  return 1;
  l963:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "HtmlBlockCloseP", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_HtmlBlockOpenP(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "HtmlBlockOpenP"));  if (!yymatchChar(G, '<')) goto l966;  if (!yy_Spnl(G)) { goto l966; }
  {  int yypos967= G->pos, yythunkpos967= G->thunkpos;  if (!yymatchChar(G, 'p')) goto l968;  goto l967;
  l968:;	  G->pos= yypos967; G->thunkpos= yythunkpos967;  if (!yymatchChar(G, 'P')) goto l966;
  }
  l967:;	  if (!yy_Spnl(G)) { goto l966; }
  l969:;	
  {  int yypos970= G->pos, yythunkpos970= G->thunkpos;  if (!yy_HtmlAttribute(G)) { goto l970; }  goto l969;
  l970:;	  G->pos= yypos970; G->thunkpos= yythunkpos970;
  }  if (!yymatchChar(G, '>')) goto l966;
  yyprintf((stderr, "  ok   %s @ %s\n", "HtmlBlockOpenP", G->buf+G->pos));
  return 1;
  l966:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "HtmlBlockOpenP", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_HtmlBlockOl(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "HtmlBlockOl"));  if (!yy_HtmlBlockOpenOl(G)) { goto l971; }
  l972:;	
  {  int yypos973= G->pos, yythunkpos973= G->thunkpos;
  {  int yypos974= G->pos, yythunkpos974= G->thunkpos;  if (!yy_HtmlBlockOl(G)) { goto l975; }  goto l974;
  l975:;	  G->pos= yypos974; G->thunkpos= yythunkpos974;
  {  int yypos976= G->pos, yythunkpos976= G->thunkpos;  if (!yy_HtmlBlockCloseOl(G)) { goto l976; }  goto l973;
  l976:;	  G->pos= yypos976; G->thunkpos= yythunkpos976;
  }  if (!yymatchDot(G)) goto l973;
  }
  l974:;	  goto l972;
  l973:;	  G->pos= yypos973; G->thunkpos= yythunkpos973;
  }  if (!yy_HtmlBlockCloseOl(G)) { goto l971; }
  yyprintf((stderr, "  ok   %s @ %s\n", "HtmlBlockOl", G->buf+G->pos));
  return 1;
  l971:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "HtmlBlockOl", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_HtmlBlockCloseOl(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "HtmlBlockCloseOl"));  if (!yymatchChar(G, '<')) goto l977;  if (!yy_Spnl(G)) { goto l977; }  if (!yymatchChar(G, '/')) goto l977;
  {  int yypos978= G->pos, yythunkpos978= G->thunkpos;  if (!yymatchString(G, "ol")) goto l979;  goto l978;
  l979:;	  G->pos= yypos978; G->thunkpos= yythunkpos978;  if (!yymatchString(G, "OL")) goto l977;
  }
  l978:;	  if (!yy_Spnl(G)) { goto l977; }  if (!yymatchChar(G, '>')) goto l977;
  yyprintf((stderr, "  ok   %s @ %s\n", "HtmlBlockCloseOl", G->buf+G->pos));
  return 1;
  l977:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "HtmlBlockCloseOl", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_HtmlBlockOpenOl(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "HtmlBlockOpenOl"));  if (!yymatchChar(G, '<')) goto l980;  if (!yy_Spnl(G)) { goto l980; }
  {  int yypos981= G->pos, yythunkpos981= G->thunkpos;  if (!yymatchString(G, "ol")) goto l982;  goto l981;
  l982:;	  G->pos= yypos981; G->thunkpos= yythunkpos981;  if (!yymatchString(G, "OL")) goto l980;
  }
  l981:;	  if (!yy_Spnl(G)) { goto l980; }
  l983:;	
  {  int yypos984= G->pos, yythunkpos984= G->thunkpos;  if (!yy_HtmlAttribute(G)) { goto l984; }  goto l983;
  l984:;	  G->pos= yypos984; G->thunkpos= yythunkpos984;
  }  if (!yymatchChar(G, '>')) goto l980;
  yyprintf((stderr, "  ok   %s @ %s\n", "HtmlBlockOpenOl", G->buf+G->pos));
  return 1;
  l980:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "HtmlBlockOpenOl", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_HtmlBlockNoscript(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "HtmlBlockNoscript"));  if (!yy_HtmlBlockOpenNoscript(G)) { goto l985; }
  l986:;	
  {  int yypos987= G->pos, yythunkpos987= G->thunkpos;
  {  int yypos988= G->pos, yythunkpos988= G->thunkpos;  if (!yy_HtmlBlockNoscript(G)) { goto l989; }  goto l988;
  l989:;	  G->pos= yypos988; G->thunkpos= yythunkpos988;
  {  int yypos990= G->pos, yythunkpos990= G->thunkpos;  if (!yy_HtmlBlockCloseNoscript(G)) { goto l990; }  goto l987;
  l990:;	  G->pos= yypos990; G->thunkpos= yythunkpos990;
  }  if (!yymatchDot(G)) goto l987;
  }
  l988:;	  goto l986;
  l987:;	  G->pos= yypos987; G->thunkpos= yythunkpos987;
  }  if (!yy_HtmlBlockCloseNoscript(G)) { goto l985; }
  yyprintf((stderr, "  ok   %s @ %s\n", "HtmlBlockNoscript", G->buf+G->pos));
  return 1;
  l985:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "HtmlBlockNoscript", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_HtmlBlockCloseNoscript(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "HtmlBlockCloseNoscript"));  if (!yymatchChar(G, '<')) goto l991;  if (!yy_Spnl(G)) { goto l991; }  if (!yymatchChar(G, '/')) goto l991;
  {  int yypos992= G->pos, yythunkpos992= G->thunkpos;  if (!yymatchString(G, "noscript")) goto l993;  goto l992;
  l993:;	  G->pos= yypos992; G->thunkpos= yythunkpos992;  if (!yymatchString(G, "NOSCRIPT")) goto l991;
  }
  l992:;	  if (!yy_Spnl(G)) { goto l991; }  if (!yymatchChar(G, '>')) goto l991;
  yyprintf((stderr, "  ok   %s @ %s\n", "HtmlBlockCloseNoscript", G->buf+G->pos));
  return 1;
  l991:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "HtmlBlockCloseNoscript", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_HtmlBlockOpenNoscript(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "HtmlBlockOpenNoscript"));  if (!yymatchChar(G, '<')) goto l994;  if (!yy_Spnl(G)) { goto l994; }
  {  int yypos995= G->pos, yythunkpos995= G->thunkpos;  if (!yymatchString(G, "noscript")) goto l996;  goto l995;
  l996:;	  G->pos= yypos995; G->thunkpos= yythunkpos995;  if (!yymatchString(G, "NOSCRIPT")) goto l994;
  }
  l995:;	  if (!yy_Spnl(G)) { goto l994; }
  l997:;	
  {  int yypos998= G->pos, yythunkpos998= G->thunkpos;  if (!yy_HtmlAttribute(G)) { goto l998; }  goto l997;
  l998:;	  G->pos= yypos998; G->thunkpos= yythunkpos998;
  }  if (!yymatchChar(G, '>')) goto l994;
  yyprintf((stderr, "  ok   %s @ %s\n", "HtmlBlockOpenNoscript", G->buf+G->pos));
  return 1;
  l994:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "HtmlBlockOpenNoscript", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_HtmlBlockNoframes(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "HtmlBlockNoframes"));  if (!yy_HtmlBlockOpenNoframes(G)) { goto l999; }
  l1000:;	
  {  int yypos1001= G->pos, yythunkpos1001= G->thunkpos;
  {  int yypos1002= G->pos, yythunkpos1002= G->thunkpos;  if (!yy_HtmlBlockNoframes(G)) { goto l1003; }  goto l1002;
  l1003:;	  G->pos= yypos1002; G->thunkpos= yythunkpos1002;
  {  int yypos1004= G->pos, yythunkpos1004= G->thunkpos;  if (!yy_HtmlBlockCloseNoframes(G)) { goto l1004; }  goto l1001;
  l1004:;	  G->pos= yypos1004; G->thunkpos= yythunkpos1004;
  }  if (!yymatchDot(G)) goto l1001;
  }
  l1002:;	  goto l1000;
  l1001:;	  G->pos= yypos1001; G->thunkpos= yythunkpos1001;
  }  if (!yy_HtmlBlockCloseNoframes(G)) { goto l999; }
  yyprintf((stderr, "  ok   %s @ %s\n", "HtmlBlockNoframes", G->buf+G->pos));
  return 1;
  l999:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "HtmlBlockNoframes", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_HtmlBlockCloseNoframes(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "HtmlBlockCloseNoframes"));  if (!yymatchChar(G, '<')) goto l1005;  if (!yy_Spnl(G)) { goto l1005; }  if (!yymatchChar(G, '/')) goto l1005;
  {  int yypos1006= G->pos, yythunkpos1006= G->thunkpos;  if (!yymatchString(G, "noframes")) goto l1007;  goto l1006;
  l1007:;	  G->pos= yypos1006; G->thunkpos= yythunkpos1006;  if (!yymatchString(G, "NOFRAMES")) goto l1005;
  }
  l1006:;	  if (!yy_Spnl(G)) { goto l1005; }  if (!yymatchChar(G, '>')) goto l1005;
  yyprintf((stderr, "  ok   %s @ %s\n", "HtmlBlockCloseNoframes", G->buf+G->pos));
  return 1;
  l1005:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "HtmlBlockCloseNoframes", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_HtmlBlockOpenNoframes(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "HtmlBlockOpenNoframes"));  if (!yymatchChar(G, '<')) goto l1008;  if (!yy_Spnl(G)) { goto l1008; }
  {  int yypos1009= G->pos, yythunkpos1009= G->thunkpos;  if (!yymatchString(G, "noframes")) goto l1010;  goto l1009;
  l1010:;	  G->pos= yypos1009; G->thunkpos= yythunkpos1009;  if (!yymatchString(G, "NOFRAMES")) goto l1008;
  }
  l1009:;	  if (!yy_Spnl(G)) { goto l1008; }
  l1011:;	
  {  int yypos1012= G->pos, yythunkpos1012= G->thunkpos;  if (!yy_HtmlAttribute(G)) { goto l1012; }  goto l1011;
  l1012:;	  G->pos= yypos1012; G->thunkpos= yythunkpos1012;
  }  if (!yymatchChar(G, '>')) goto l1008;
  yyprintf((stderr, "  ok   %s @ %s\n", "HtmlBlockOpenNoframes", G->buf+G->pos));
  return 1;
  l1008:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "HtmlBlockOpenNoframes", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_HtmlBlockMenu(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "HtmlBlockMenu"));  if (!yy_HtmlBlockOpenMenu(G)) { goto l1013; }
  l1014:;	
  {  int yypos1015= G->pos, yythunkpos1015= G->thunkpos;
  {  int yypos1016= G->pos, yythunkpos1016= G->thunkpos;  if (!yy_HtmlBlockMenu(G)) { goto l1017; }  goto l1016;
  l1017:;	  G->pos= yypos1016; G->thunkpos= yythunkpos1016;
  {  int yypos1018= G->pos, yythunkpos1018= G->thunkpos;  if (!yy_HtmlBlockCloseMenu(G)) { goto l1018; }  goto l1015;
  l1018:;	  G->pos= yypos1018; G->thunkpos= yythunkpos1018;
  }  if (!yymatchDot(G)) goto l1015;
  }
  l1016:;	  goto l1014;
  l1015:;	  G->pos= yypos1015; G->thunkpos= yythunkpos1015;
  }  if (!yy_HtmlBlockCloseMenu(G)) { goto l1013; }
  yyprintf((stderr, "  ok   %s @ %s\n", "HtmlBlockMenu", G->buf+G->pos));
  return 1;
  l1013:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "HtmlBlockMenu", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_HtmlBlockCloseMenu(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "HtmlBlockCloseMenu"));  if (!yymatchChar(G, '<')) goto l1019;  if (!yy_Spnl(G)) { goto l1019; }  if (!yymatchChar(G, '/')) goto l1019;
  {  int yypos1020= G->pos, yythunkpos1020= G->thunkpos;  if (!yymatchString(G, "menu")) goto l1021;  goto l1020;
  l1021:;	  G->pos= yypos1020; G->thunkpos= yythunkpos1020;  if (!yymatchString(G, "MENU")) goto l1019;
  }
  l1020:;	  if (!yy_Spnl(G)) { goto l1019; }  if (!yymatchChar(G, '>')) goto l1019;
  yyprintf((stderr, "  ok   %s @ %s\n", "HtmlBlockCloseMenu", G->buf+G->pos));
  return 1;
  l1019:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "HtmlBlockCloseMenu", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_HtmlBlockOpenMenu(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "HtmlBlockOpenMenu"));  if (!yymatchChar(G, '<')) goto l1022;  if (!yy_Spnl(G)) { goto l1022; }
  {  int yypos1023= G->pos, yythunkpos1023= G->thunkpos;  if (!yymatchString(G, "menu")) goto l1024;  goto l1023;
  l1024:;	  G->pos= yypos1023; G->thunkpos= yythunkpos1023;  if (!yymatchString(G, "MENU")) goto l1022;
  }
  l1023:;	  if (!yy_Spnl(G)) { goto l1022; }
  l1025:;	
  {  int yypos1026= G->pos, yythunkpos1026= G->thunkpos;  if (!yy_HtmlAttribute(G)) { goto l1026; }  goto l1025;
  l1026:;	  G->pos= yypos1026; G->thunkpos= yythunkpos1026;
  }  if (!yymatchChar(G, '>')) goto l1022;
  yyprintf((stderr, "  ok   %s @ %s\n", "HtmlBlockOpenMenu", G->buf+G->pos));
  return 1;
  l1022:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "HtmlBlockOpenMenu", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_HtmlBlockH6(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;  yyDo(G, yyPush, 1, 0);
  yyprintf((stderr, "%s\n", "HtmlBlockH6"));  yyText(G, G->begin, G->end);  if (!(YY_BEGIN)) goto l1027;  if (!yy_LocMarker(G)) { goto l1027; }  yyDo(G, yySet, -1, 0);  if (!yy_HtmlBlockOpenH6(G)) { goto l1027; }
  l1028:;	
  {  int yypos1029= G->pos, yythunkpos1029= G->thunkpos;
  {  int yypos1030= G->pos, yythunkpos1030= G->thunkpos;  if (!yy_HtmlBlockH6(G)) { goto l1031; }  goto l1030;
  l1031:;	  G->pos= yypos1030; G->thunkpos= yythunkpos1030;
  {  int yypos1032= G->pos, yythunkpos1032= G->thunkpos;  if (!yy_HtmlBlockCloseH6(G)) { goto l1032; }  goto l1029;
  l1032:;	  G->pos= yypos1032; G->thunkpos= yythunkpos1032;
  }  if (!yymatchDot(G)) goto l1029;
  }
  l1030:;	  goto l1028;
  l1029:;	  G->pos= yypos1029; G->thunkpos= yythunkpos1029;
  }  if (!yy_HtmlBlockCloseH6(G)) { goto l1027; }  yyText(G, G->begin, G->end);  if (!(YY_END)) goto l1027;  yyDo(G, yy_1_HtmlBlockH6, G->begin, G->end);
  yyprintf((stderr, "  ok   %s @ %s\n", "HtmlBlockH6", G->buf+G->pos));  yyDo(G, yyPop, 1, 0);
  return 1;
  l1027:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "HtmlBlockH6", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_HtmlBlockCloseH6(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "HtmlBlockCloseH6"));  if (!yymatchChar(G, '<')) goto l1033;  if (!yy_Spnl(G)) { goto l1033; }  if (!yymatchChar(G, '/')) goto l1033;
  {  int yypos1034= G->pos, yythunkpos1034= G->thunkpos;  if (!yymatchString(G, "h6")) goto l1035;  goto l1034;
  l1035:;	  G->pos= yypos1034; G->thunkpos= yythunkpos1034;  if (!yymatchString(G, "H6")) goto l1033;
  }
  l1034:;	  if (!yy_Spnl(G)) { goto l1033; }  if (!yymatchChar(G, '>')) goto l1033;
  yyprintf((stderr, "  ok   %s @ %s\n", "HtmlBlockCloseH6", G->buf+G->pos));
  return 1;
  l1033:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "HtmlBlockCloseH6", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_HtmlBlockOpenH6(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "HtmlBlockOpenH6"));  if (!yymatchChar(G, '<')) goto l1036;  if (!yy_Spnl(G)) { goto l1036; }
  {  int yypos1037= G->pos, yythunkpos1037= G->thunkpos;  if (!yymatchString(G, "h6")) goto l1038;  goto l1037;
  l1038:;	  G->pos= yypos1037; G->thunkpos= yythunkpos1037;  if (!yymatchString(G, "H6")) goto l1036;
  }
  l1037:;	  if (!yy_Spnl(G)) { goto l1036; }
  l1039:;	
  {  int yypos1040= G->pos, yythunkpos1040= G->thunkpos;  if (!yy_HtmlAttribute(G)) { goto l1040; }  goto l1039;
  l1040:;	  G->pos= yypos1040; G->thunkpos= yythunkpos1040;
  }  if (!yymatchChar(G, '>')) goto l1036;
  yyprintf((stderr, "  ok   %s @ %s\n", "HtmlBlockOpenH6", G->buf+G->pos));
  return 1;
  l1036:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "HtmlBlockOpenH6", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_HtmlBlockH5(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;  yyDo(G, yyPush, 1, 0);
  yyprintf((stderr, "%s\n", "HtmlBlockH5"));  yyText(G, G->begin, G->end);  if (!(YY_BEGIN)) goto l1041;  if (!yy_LocMarker(G)) { goto l1041; }  yyDo(G, yySet, -1, 0);  if (!yy_HtmlBlockOpenH5(G)) { goto l1041; }
  l1042:;	
  {  int yypos1043= G->pos, yythunkpos1043= G->thunkpos;
  {  int yypos1044= G->pos, yythunkpos1044= G->thunkpos;  if (!yy_HtmlBlockH5(G)) { goto l1045; }  goto l1044;
  l1045:;	  G->pos= yypos1044; G->thunkpos= yythunkpos1044;
  {  int yypos1046= G->pos, yythunkpos1046= G->thunkpos;  if (!yy_HtmlBlockCloseH5(G)) { goto l1046; }  goto l1043;
  l1046:;	  G->pos= yypos1046; G->thunkpos= yythunkpos1046;
  }  if (!yymatchDot(G)) goto l1043;
  }
  l1044:;	  goto l1042;
  l1043:;	  G->pos= yypos1043; G->thunkpos= yythunkpos1043;
  }  if (!yy_HtmlBlockCloseH5(G)) { goto l1041; }  yyText(G, G->begin, G->end);  if (!(YY_END)) goto l1041;  yyDo(G, yy_1_HtmlBlockH5, G->begin, G->end);
  yyprintf((stderr, "  ok   %s @ %s\n", "HtmlBlockH5", G->buf+G->pos));  yyDo(G, yyPop, 1, 0);
  return 1;
  l1041:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "HtmlBlockH5", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_HtmlBlockCloseH5(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "HtmlBlockCloseH5"));  if (!yymatchChar(G, '<')) goto l1047;  if (!yy_Spnl(G)) { goto l1047; }  if (!yymatchChar(G, '/')) goto l1047;
  {  int yypos1048= G->pos, yythunkpos1048= G->thunkpos;  if (!yymatchString(G, "h5")) goto l1049;  goto l1048;
  l1049:;	  G->pos= yypos1048; G->thunkpos= yythunkpos1048;  if (!yymatchString(G, "H5")) goto l1047;
  }
  l1048:;	  if (!yy_Spnl(G)) { goto l1047; }  if (!yymatchChar(G, '>')) goto l1047;
  yyprintf((stderr, "  ok   %s @ %s\n", "HtmlBlockCloseH5", G->buf+G->pos));
  return 1;
  l1047:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "HtmlBlockCloseH5", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_HtmlBlockOpenH5(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "HtmlBlockOpenH5"));  if (!yymatchChar(G, '<')) goto l1050;  if (!yy_Spnl(G)) { goto l1050; }
  {  int yypos1051= G->pos, yythunkpos1051= G->thunkpos;  if (!yymatchString(G, "h5")) goto l1052;  goto l1051;
  l1052:;	  G->pos= yypos1051; G->thunkpos= yythunkpos1051;  if (!yymatchString(G, "H5")) goto l1050;
  }
  l1051:;	  if (!yy_Spnl(G)) { goto l1050; }
  l1053:;	
  {  int yypos1054= G->pos, yythunkpos1054= G->thunkpos;  if (!yy_HtmlAttribute(G)) { goto l1054; }  goto l1053;
  l1054:;	  G->pos= yypos1054; G->thunkpos= yythunkpos1054;
  }  if (!yymatchChar(G, '>')) goto l1050;
  yyprintf((stderr, "  ok   %s @ %s\n", "HtmlBlockOpenH5", G->buf+G->pos));
  return 1;
  l1050:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "HtmlBlockOpenH5", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_HtmlBlockH4(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;  yyDo(G, yyPush, 1, 0);
  yyprintf((stderr, "%s\n", "HtmlBlockH4"));  yyText(G, G->begin, G->end);  if (!(YY_BEGIN)) goto l1055;  if (!yy_LocMarker(G)) { goto l1055; }  yyDo(G, yySet, -1, 0);  if (!yy_HtmlBlockOpenH4(G)) { goto l1055; }
  l1056:;	
  {  int yypos1057= G->pos, yythunkpos1057= G->thunkpos;
  {  int yypos1058= G->pos, yythunkpos1058= G->thunkpos;  if (!yy_HtmlBlockH4(G)) { goto l1059; }  goto l1058;
  l1059:;	  G->pos= yypos1058; G->thunkpos= yythunkpos1058;
  {  int yypos1060= G->pos, yythunkpos1060= G->thunkpos;  if (!yy_HtmlBlockCloseH4(G)) { goto l1060; }  goto l1057;
  l1060:;	  G->pos= yypos1060; G->thunkpos= yythunkpos1060;
  }  if (!yymatchDot(G)) goto l1057;
  }
  l1058:;	  goto l1056;
  l1057:;	  G->pos= yypos1057; G->thunkpos= yythunkpos1057;
  }  if (!yy_HtmlBlockCloseH4(G)) { goto l1055; }  yyText(G, G->begin, G->end);  if (!(YY_END)) goto l1055;  yyDo(G, yy_1_HtmlBlockH4, G->begin, G->end);
  yyprintf((stderr, "  ok   %s @ %s\n", "HtmlBlockH4", G->buf+G->pos));  yyDo(G, yyPop, 1, 0);
  return 1;
  l1055:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "HtmlBlockH4", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_HtmlBlockCloseH4(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "HtmlBlockCloseH4"));  if (!yymatchChar(G, '<')) goto l1061;  if (!yy_Spnl(G)) { goto l1061; }  if (!yymatchChar(G, '/')) goto l1061;
  {  int yypos1062= G->pos, yythunkpos1062= G->thunkpos;  if (!yymatchString(G, "h4")) goto l1063;  goto l1062;
  l1063:;	  G->pos= yypos1062; G->thunkpos= yythunkpos1062;  if (!yymatchString(G, "H4")) goto l1061;
  }
  l1062:;	  if (!yy_Spnl(G)) { goto l1061; }  if (!yymatchChar(G, '>')) goto l1061;
  yyprintf((stderr, "  ok   %s @ %s\n", "HtmlBlockCloseH4", G->buf+G->pos));
  return 1;
  l1061:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "HtmlBlockCloseH4", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_HtmlBlockOpenH4(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "HtmlBlockOpenH4"));  if (!yymatchChar(G, '<')) goto l1064;  if (!yy_Spnl(G)) { goto l1064; }
  {  int yypos1065= G->pos, yythunkpos1065= G->thunkpos;  if (!yymatchString(G, "h4")) goto l1066;  goto l1065;
  l1066:;	  G->pos= yypos1065; G->thunkpos= yythunkpos1065;  if (!yymatchString(G, "H4")) goto l1064;
  }
  l1065:;	  if (!yy_Spnl(G)) { goto l1064; }
  l1067:;	
  {  int yypos1068= G->pos, yythunkpos1068= G->thunkpos;  if (!yy_HtmlAttribute(G)) { goto l1068; }  goto l1067;
  l1068:;	  G->pos= yypos1068; G->thunkpos= yythunkpos1068;
  }  if (!yymatchChar(G, '>')) goto l1064;
  yyprintf((stderr, "  ok   %s @ %s\n", "HtmlBlockOpenH4", G->buf+G->pos));
  return 1;
  l1064:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "HtmlBlockOpenH4", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_HtmlBlockH3(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;  yyDo(G, yyPush, 1, 0);
  yyprintf((stderr, "%s\n", "HtmlBlockH3"));  yyText(G, G->begin, G->end);  if (!(YY_BEGIN)) goto l1069;  if (!yy_LocMarker(G)) { goto l1069; }  yyDo(G, yySet, -1, 0);  if (!yy_HtmlBlockOpenH3(G)) { goto l1069; }
  l1070:;	
  {  int yypos1071= G->pos, yythunkpos1071= G->thunkpos;
  {  int yypos1072= G->pos, yythunkpos1072= G->thunkpos;  if (!yy_HtmlBlockH3(G)) { goto l1073; }  goto l1072;
  l1073:;	  G->pos= yypos1072; G->thunkpos= yythunkpos1072;
  {  int yypos1074= G->pos, yythunkpos1074= G->thunkpos;  if (!yy_HtmlBlockCloseH3(G)) { goto l1074; }  goto l1071;
  l1074:;	  G->pos= yypos1074; G->thunkpos= yythunkpos1074;
  }  if (!yymatchDot(G)) goto l1071;
  }
  l1072:;	  goto l1070;
  l1071:;	  G->pos= yypos1071; G->thunkpos= yythunkpos1071;
  }  if (!yy_HtmlBlockCloseH3(G)) { goto l1069; }  yyText(G, G->begin, G->end);  if (!(YY_END)) goto l1069;  yyDo(G, yy_1_HtmlBlockH3, G->begin, G->end);
  yyprintf((stderr, "  ok   %s @ %s\n", "HtmlBlockH3", G->buf+G->pos));  yyDo(G, yyPop, 1, 0);
  return 1;
  l1069:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "HtmlBlockH3", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_HtmlBlockCloseH3(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "HtmlBlockCloseH3"));  if (!yymatchChar(G, '<')) goto l1075;  if (!yy_Spnl(G)) { goto l1075; }  if (!yymatchChar(G, '/')) goto l1075;
  {  int yypos1076= G->pos, yythunkpos1076= G->thunkpos;  if (!yymatchString(G, "h3")) goto l1077;  goto l1076;
  l1077:;	  G->pos= yypos1076; G->thunkpos= yythunkpos1076;  if (!yymatchString(G, "H3")) goto l1075;
  }
  l1076:;	  if (!yy_Spnl(G)) { goto l1075; }  if (!yymatchChar(G, '>')) goto l1075;
  yyprintf((stderr, "  ok   %s @ %s\n", "HtmlBlockCloseH3", G->buf+G->pos));
  return 1;
  l1075:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "HtmlBlockCloseH3", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_HtmlBlockOpenH3(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "HtmlBlockOpenH3"));  if (!yymatchChar(G, '<')) goto l1078;  if (!yy_Spnl(G)) { goto l1078; }
  {  int yypos1079= G->pos, yythunkpos1079= G->thunkpos;  if (!yymatchString(G, "h3")) goto l1080;  goto l1079;
  l1080:;	  G->pos= yypos1079; G->thunkpos= yythunkpos1079;  if (!yymatchString(G, "H3")) goto l1078;
  }
  l1079:;	  if (!yy_Spnl(G)) { goto l1078; }
  l1081:;	
  {  int yypos1082= G->pos, yythunkpos1082= G->thunkpos;  if (!yy_HtmlAttribute(G)) { goto l1082; }  goto l1081;
  l1082:;	  G->pos= yypos1082; G->thunkpos= yythunkpos1082;
  }  if (!yymatchChar(G, '>')) goto l1078;
  yyprintf((stderr, "  ok   %s @ %s\n", "HtmlBlockOpenH3", G->buf+G->pos));
  return 1;
  l1078:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "HtmlBlockOpenH3", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_HtmlBlockH2(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;  yyDo(G, yyPush, 1, 0);
  yyprintf((stderr, "%s\n", "HtmlBlockH2"));  yyText(G, G->begin, G->end);  if (!(YY_BEGIN)) goto l1083;  if (!yy_LocMarker(G)) { goto l1083; }  yyDo(G, yySet, -1, 0);  if (!yy_HtmlBlockOpenH2(G)) { goto l1083; }
  l1084:;	
  {  int yypos1085= G->pos, yythunkpos1085= G->thunkpos;
  {  int yypos1086= G->pos, yythunkpos1086= G->thunkpos;  if (!yy_HtmlBlockH2(G)) { goto l1087; }  goto l1086;
  l1087:;	  G->pos= yypos1086; G->thunkpos= yythunkpos1086;
  {  int yypos1088= G->pos, yythunkpos1088= G->thunkpos;  if (!yy_HtmlBlockCloseH2(G)) { goto l1088; }  goto l1085;
  l1088:;	  G->pos= yypos1088; G->thunkpos= yythunkpos1088;
  }  if (!yymatchDot(G)) goto l1085;
  }
  l1086:;	  goto l1084;
  l1085:;	  G->pos= yypos1085; G->thunkpos= yythunkpos1085;
  }  if (!yy_HtmlBlockCloseH2(G)) { goto l1083; }  yyText(G, G->begin, G->end);  if (!(YY_END)) goto l1083;  yyDo(G, yy_1_HtmlBlockH2, G->begin, G->end);
  yyprintf((stderr, "  ok   %s @ %s\n", "HtmlBlockH2", G->buf+G->pos));  yyDo(G, yyPop, 1, 0);
  return 1;
  l1083:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "HtmlBlockH2", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_HtmlBlockCloseH2(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "HtmlBlockCloseH2"));  if (!yymatchChar(G, '<')) goto l1089;  if (!yy_Spnl(G)) { goto l1089; }  if (!yymatchChar(G, '/')) goto l1089;
  {  int yypos1090= G->pos, yythunkpos1090= G->thunkpos;  if (!yymatchString(G, "h2")) goto l1091;  goto l1090;
  l1091:;	  G->pos= yypos1090; G->thunkpos= yythunkpos1090;  if (!yymatchString(G, "H2")) goto l1089;
  }
  l1090:;	  if (!yy_Spnl(G)) { goto l1089; }  if (!yymatchChar(G, '>')) goto l1089;
  yyprintf((stderr, "  ok   %s @ %s\n", "HtmlBlockCloseH2", G->buf+G->pos));
  return 1;
  l1089:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "HtmlBlockCloseH2", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_HtmlBlockOpenH2(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "HtmlBlockOpenH2"));  if (!yymatchChar(G, '<')) goto l1092;  if (!yy_Spnl(G)) { goto l1092; }
  {  int yypos1093= G->pos, yythunkpos1093= G->thunkpos;  if (!yymatchString(G, "h2")) goto l1094;  goto l1093;
  l1094:;	  G->pos= yypos1093; G->thunkpos= yythunkpos1093;  if (!yymatchString(G, "H2")) goto l1092;
  }
  l1093:;	  if (!yy_Spnl(G)) { goto l1092; }
  l1095:;	
  {  int yypos1096= G->pos, yythunkpos1096= G->thunkpos;  if (!yy_HtmlAttribute(G)) { goto l1096; }  goto l1095;
  l1096:;	  G->pos= yypos1096; G->thunkpos= yythunkpos1096;
  }  if (!yymatchChar(G, '>')) goto l1092;
  yyprintf((stderr, "  ok   %s @ %s\n", "HtmlBlockOpenH2", G->buf+G->pos));
  return 1;
  l1092:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "HtmlBlockOpenH2", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_HtmlBlockH1(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;  yyDo(G, yyPush, 1, 0);
  yyprintf((stderr, "%s\n", "HtmlBlockH1"));  yyText(G, G->begin, G->end);  if (!(YY_BEGIN)) goto l1097;  if (!yy_LocMarker(G)) { goto l1097; }  yyDo(G, yySet, -1, 0);  if (!yy_HtmlBlockOpenH1(G)) { goto l1097; }
  l1098:;	
  {  int yypos1099= G->pos, yythunkpos1099= G->thunkpos;
  {  int yypos1100= G->pos, yythunkpos1100= G->thunkpos;  if (!yy_HtmlBlockH1(G)) { goto l1101; }  goto l1100;
  l1101:;	  G->pos= yypos1100; G->thunkpos= yythunkpos1100;
  {  int yypos1102= G->pos, yythunkpos1102= G->thunkpos;  if (!yy_HtmlBlockCloseH1(G)) { goto l1102; }  goto l1099;
  l1102:;	  G->pos= yypos1102; G->thunkpos= yythunkpos1102;
  }  if (!yymatchDot(G)) goto l1099;
  }
  l1100:;	  goto l1098;
  l1099:;	  G->pos= yypos1099; G->thunkpos= yythunkpos1099;
  }  if (!yy_HtmlBlockCloseH1(G)) { goto l1097; }  yyText(G, G->begin, G->end);  if (!(YY_END)) goto l1097;  yyDo(G, yy_1_HtmlBlockH1, G->begin, G->end);
  yyprintf((stderr, "  ok   %s @ %s\n", "HtmlBlockH1", G->buf+G->pos));  yyDo(G, yyPop, 1, 0);
  return 1;
  l1097:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "HtmlBlockH1", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_HtmlBlockCloseH1(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "HtmlBlockCloseH1"));  if (!yymatchChar(G, '<')) goto l1103;  if (!yy_Spnl(G)) { goto l1103; }  if (!yymatchChar(G, '/')) goto l1103;
  {  int yypos1104= G->pos, yythunkpos1104= G->thunkpos;  if (!yymatchString(G, "h1")) goto l1105;  goto l1104;
  l1105:;	  G->pos= yypos1104; G->thunkpos= yythunkpos1104;  if (!yymatchString(G, "H1")) goto l1103;
  }
  l1104:;	  if (!yy_Spnl(G)) { goto l1103; }  if (!yymatchChar(G, '>')) goto l1103;
  yyprintf((stderr, "  ok   %s @ %s\n", "HtmlBlockCloseH1", G->buf+G->pos));
  return 1;
  l1103:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "HtmlBlockCloseH1", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_HtmlBlockOpenH1(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "HtmlBlockOpenH1"));  if (!yymatchChar(G, '<')) goto l1106;  if (!yy_Spnl(G)) { goto l1106; }
  {  int yypos1107= G->pos, yythunkpos1107= G->thunkpos;  if (!yymatchString(G, "h1")) goto l1108;  goto l1107;
  l1108:;	  G->pos= yypos1107; G->thunkpos= yythunkpos1107;  if (!yymatchString(G, "H1")) goto l1106;
  }
  l1107:;	  if (!yy_Spnl(G)) { goto l1106; }
  l1109:;	
  {  int yypos1110= G->pos, yythunkpos1110= G->thunkpos;  if (!yy_HtmlAttribute(G)) { goto l1110; }  goto l1109;
  l1110:;	  G->pos= yypos1110; G->thunkpos= yythunkpos1110;
  }  if (!yymatchChar(G, '>')) goto l1106;
  yyprintf((stderr, "  ok   %s @ %s\n", "HtmlBlockOpenH1", G->buf+G->pos));
  return 1;
  l1106:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "HtmlBlockOpenH1", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_HtmlBlockForm(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "HtmlBlockForm"));  if (!yy_HtmlBlockOpenForm(G)) { goto l1111; }
  l1112:;	
  {  int yypos1113= G->pos, yythunkpos1113= G->thunkpos;
  {  int yypos1114= G->pos, yythunkpos1114= G->thunkpos;  if (!yy_HtmlBlockForm(G)) { goto l1115; }  goto l1114;
  l1115:;	  G->pos= yypos1114; G->thunkpos= yythunkpos1114;
  {  int yypos1116= G->pos, yythunkpos1116= G->thunkpos;  if (!yy_HtmlBlockCloseForm(G)) { goto l1116; }  goto l1113;
  l1116:;	  G->pos= yypos1116; G->thunkpos= yythunkpos1116;
  }  if (!yymatchDot(G)) goto l1113;
  }
  l1114:;	  goto l1112;
  l1113:;	  G->pos= yypos1113; G->thunkpos= yythunkpos1113;
  }  if (!yy_HtmlBlockCloseForm(G)) { goto l1111; }
  yyprintf((stderr, "  ok   %s @ %s\n", "HtmlBlockForm", G->buf+G->pos));
  return 1;
  l1111:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "HtmlBlockForm", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_HtmlBlockCloseForm(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "HtmlBlockCloseForm"));  if (!yymatchChar(G, '<')) goto l1117;  if (!yy_Spnl(G)) { goto l1117; }  if (!yymatchChar(G, '/')) goto l1117;
  {  int yypos1118= G->pos, yythunkpos1118= G->thunkpos;  if (!yymatchString(G, "form")) goto l1119;  goto l1118;
  l1119:;	  G->pos= yypos1118; G->thunkpos= yythunkpos1118;  if (!yymatchString(G, "FORM")) goto l1117;
  }
  l1118:;	  if (!yy_Spnl(G)) { goto l1117; }  if (!yymatchChar(G, '>')) goto l1117;
  yyprintf((stderr, "  ok   %s @ %s\n", "HtmlBlockCloseForm", G->buf+G->pos));
  return 1;
  l1117:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "HtmlBlockCloseForm", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_HtmlBlockOpenForm(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "HtmlBlockOpenForm"));  if (!yymatchChar(G, '<')) goto l1120;  if (!yy_Spnl(G)) { goto l1120; }
  {  int yypos1121= G->pos, yythunkpos1121= G->thunkpos;  if (!yymatchString(G, "form")) goto l1122;  goto l1121;
  l1122:;	  G->pos= yypos1121; G->thunkpos= yythunkpos1121;  if (!yymatchString(G, "FORM")) goto l1120;
  }
  l1121:;	  if (!yy_Spnl(G)) { goto l1120; }
  l1123:;	
  {  int yypos1124= G->pos, yythunkpos1124= G->thunkpos;  if (!yy_HtmlAttribute(G)) { goto l1124; }  goto l1123;
  l1124:;	  G->pos= yypos1124; G->thunkpos= yythunkpos1124;
  }  if (!yymatchChar(G, '>')) goto l1120;
  yyprintf((stderr, "  ok   %s @ %s\n", "HtmlBlockOpenForm", G->buf+G->pos));
  return 1;
  l1120:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "HtmlBlockOpenForm", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_HtmlBlockFieldset(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "HtmlBlockFieldset"));  if (!yy_HtmlBlockOpenFieldset(G)) { goto l1125; }
  l1126:;	
  {  int yypos1127= G->pos, yythunkpos1127= G->thunkpos;
  {  int yypos1128= G->pos, yythunkpos1128= G->thunkpos;  if (!yy_HtmlBlockFieldset(G)) { goto l1129; }  goto l1128;
  l1129:;	  G->pos= yypos1128; G->thunkpos= yythunkpos1128;
  {  int yypos1130= G->pos, yythunkpos1130= G->thunkpos;  if (!yy_HtmlBlockCloseFieldset(G)) { goto l1130; }  goto l1127;
  l1130:;	  G->pos= yypos1130; G->thunkpos= yythunkpos1130;
  }  if (!yymatchDot(G)) goto l1127;
  }
  l1128:;	  goto l1126;
  l1127:;	  G->pos= yypos1127; G->thunkpos= yythunkpos1127;
  }  if (!yy_HtmlBlockCloseFieldset(G)) { goto l1125; }
  yyprintf((stderr, "  ok   %s @ %s\n", "HtmlBlockFieldset", G->buf+G->pos));
  return 1;
  l1125:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "HtmlBlockFieldset", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_HtmlBlockCloseFieldset(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "HtmlBlockCloseFieldset"));  if (!yymatchChar(G, '<')) goto l1131;  if (!yy_Spnl(G)) { goto l1131; }  if (!yymatchChar(G, '/')) goto l1131;
  {  int yypos1132= G->pos, yythunkpos1132= G->thunkpos;  if (!yymatchString(G, "fieldset")) goto l1133;  goto l1132;
  l1133:;	  G->pos= yypos1132; G->thunkpos= yythunkpos1132;  if (!yymatchString(G, "FIELDSET")) goto l1131;
  }
  l1132:;	  if (!yy_Spnl(G)) { goto l1131; }  if (!yymatchChar(G, '>')) goto l1131;
  yyprintf((stderr, "  ok   %s @ %s\n", "HtmlBlockCloseFieldset", G->buf+G->pos));
  return 1;
  l1131:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "HtmlBlockCloseFieldset", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_HtmlBlockOpenFieldset(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "HtmlBlockOpenFieldset"));  if (!yymatchChar(G, '<')) goto l1134;  if (!yy_Spnl(G)) { goto l1134; }
  {  int yypos1135= G->pos, yythunkpos1135= G->thunkpos;  if (!yymatchString(G, "fieldset")) goto l1136;  goto l1135;
  l1136:;	  G->pos= yypos1135; G->thunkpos= yythunkpos1135;  if (!yymatchString(G, "FIELDSET")) goto l1134;
  }
  l1135:;	  if (!yy_Spnl(G)) { goto l1134; }
  l1137:;	
  {  int yypos1138= G->pos, yythunkpos1138= G->thunkpos;  if (!yy_HtmlAttribute(G)) { goto l1138; }  goto l1137;
  l1138:;	  G->pos= yypos1138; G->thunkpos= yythunkpos1138;
  }  if (!yymatchChar(G, '>')) goto l1134;
  yyprintf((stderr, "  ok   %s @ %s\n", "HtmlBlockOpenFieldset", G->buf+G->pos));
  return 1;
  l1134:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "HtmlBlockOpenFieldset", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_HtmlBlockDl(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "HtmlBlockDl"));  if (!yy_HtmlBlockOpenDl(G)) { goto l1139; }
  l1140:;	
  {  int yypos1141= G->pos, yythunkpos1141= G->thunkpos;
  {  int yypos1142= G->pos, yythunkpos1142= G->thunkpos;  if (!yy_HtmlBlockDl(G)) { goto l1143; }  goto l1142;
  l1143:;	  G->pos= yypos1142; G->thunkpos= yythunkpos1142;
  {  int yypos1144= G->pos, yythunkpos1144= G->thunkpos;  if (!yy_HtmlBlockCloseDl(G)) { goto l1144; }  goto l1141;
  l1144:;	  G->pos= yypos1144; G->thunkpos= yythunkpos1144;
  }  if (!yymatchDot(G)) goto l1141;
  }
  l1142:;	  goto l1140;
  l1141:;	  G->pos= yypos1141; G->thunkpos= yythunkpos1141;
  }  if (!yy_HtmlBlockCloseDl(G)) { goto l1139; }
  yyprintf((stderr, "  ok   %s @ %s\n", "HtmlBlockDl", G->buf+G->pos));
  return 1;
  l1139:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "HtmlBlockDl", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_HtmlBlockCloseDl(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "HtmlBlockCloseDl"));  if (!yymatchChar(G, '<')) goto l1145;  if (!yy_Spnl(G)) { goto l1145; }  if (!yymatchChar(G, '/')) goto l1145;
  {  int yypos1146= G->pos, yythunkpos1146= G->thunkpos;  if (!yymatchString(G, "dl")) goto l1147;  goto l1146;
  l1147:;	  G->pos= yypos1146; G->thunkpos= yythunkpos1146;  if (!yymatchString(G, "DL")) goto l1145;
  }
  l1146:;	  if (!yy_Spnl(G)) { goto l1145; }  if (!yymatchChar(G, '>')) goto l1145;
  yyprintf((stderr, "  ok   %s @ %s\n", "HtmlBlockCloseDl", G->buf+G->pos));
  return 1;
  l1145:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "HtmlBlockCloseDl", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_HtmlBlockOpenDl(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "HtmlBlockOpenDl"));  if (!yymatchChar(G, '<')) goto l1148;  if (!yy_Spnl(G)) { goto l1148; }
  {  int yypos1149= G->pos, yythunkpos1149= G->thunkpos;  if (!yymatchString(G, "dl")) goto l1150;  goto l1149;
  l1150:;	  G->pos= yypos1149; G->thunkpos= yythunkpos1149;  if (!yymatchString(G, "DL")) goto l1148;
  }
  l1149:;	  if (!yy_Spnl(G)) { goto l1148; }
  l1151:;	
  {  int yypos1152= G->pos, yythunkpos1152= G->thunkpos;  if (!yy_HtmlAttribute(G)) { goto l1152; }  goto l1151;
  l1152:;	  G->pos= yypos1152; G->thunkpos= yythunkpos1152;
  }  if (!yymatchChar(G, '>')) goto l1148;
  yyprintf((stderr, "  ok   %s @ %s\n", "HtmlBlockOpenDl", G->buf+G->pos));
  return 1;
  l1148:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "HtmlBlockOpenDl", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_HtmlBlockDiv(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "HtmlBlockDiv"));  if (!yy_HtmlBlockOpenDiv(G)) { goto l1153; }
  l1154:;	
  {  int yypos1155= G->pos, yythunkpos1155= G->thunkpos;
  {  int yypos1156= G->pos, yythunkpos1156= G->thunkpos;  if (!yy_HtmlBlockDiv(G)) { goto l1157; }  goto l1156;
  l1157:;	  G->pos= yypos1156; G->thunkpos= yythunkpos1156;
  {  int yypos1158= G->pos, yythunkpos1158= G->thunkpos;  if (!yy_HtmlBlockCloseDiv(G)) { goto l1158; }  goto l1155;
  l1158:;	  G->pos= yypos1158; G->thunkpos= yythunkpos1158;
  }  if (!yymatchDot(G)) goto l1155;
  }
  l1156:;	  goto l1154;
  l1155:;	  G->pos= yypos1155; G->thunkpos= yythunkpos1155;
  }  if (!yy_HtmlBlockCloseDiv(G)) { goto l1153; }
  yyprintf((stderr, "  ok   %s @ %s\n", "HtmlBlockDiv", G->buf+G->pos));
  return 1;
  l1153:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "HtmlBlockDiv", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_HtmlBlockCloseDiv(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "HtmlBlockCloseDiv"));  if (!yymatchChar(G, '<')) goto l1159;  if (!yy_Spnl(G)) { goto l1159; }  if (!yymatchChar(G, '/')) goto l1159;
  {  int yypos1160= G->pos, yythunkpos1160= G->thunkpos;  if (!yymatchString(G, "div")) goto l1161;  goto l1160;
  l1161:;	  G->pos= yypos1160; G->thunkpos= yythunkpos1160;  if (!yymatchString(G, "DIV")) goto l1159;
  }
  l1160:;	  if (!yy_Spnl(G)) { goto l1159; }  if (!yymatchChar(G, '>')) goto l1159;
  yyprintf((stderr, "  ok   %s @ %s\n", "HtmlBlockCloseDiv", G->buf+G->pos));
  return 1;
  l1159:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "HtmlBlockCloseDiv", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_HtmlBlockOpenDiv(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "HtmlBlockOpenDiv"));  if (!yymatchChar(G, '<')) goto l1162;  if (!yy_Spnl(G)) { goto l1162; }
  {  int yypos1163= G->pos, yythunkpos1163= G->thunkpos;  if (!yymatchString(G, "div")) goto l1164;  goto l1163;
  l1164:;	  G->pos= yypos1163; G->thunkpos= yythunkpos1163;  if (!yymatchString(G, "DIV")) goto l1162;
  }
  l1163:;	  if (!yy_Spnl(G)) { goto l1162; }
  l1165:;	
  {  int yypos1166= G->pos, yythunkpos1166= G->thunkpos;  if (!yy_HtmlAttribute(G)) { goto l1166; }  goto l1165;
  l1166:;	  G->pos= yypos1166; G->thunkpos= yythunkpos1166;
  }  if (!yymatchChar(G, '>')) goto l1162;
  yyprintf((stderr, "  ok   %s @ %s\n", "HtmlBlockOpenDiv", G->buf+G->pos));
  return 1;
  l1162:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "HtmlBlockOpenDiv", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_HtmlBlockDir(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "HtmlBlockDir"));  if (!yy_HtmlBlockOpenDir(G)) { goto l1167; }
  l1168:;	
  {  int yypos1169= G->pos, yythunkpos1169= G->thunkpos;
  {  int yypos1170= G->pos, yythunkpos1170= G->thunkpos;  if (!yy_HtmlBlockDir(G)) { goto l1171; }  goto l1170;
  l1171:;	  G->pos= yypos1170; G->thunkpos= yythunkpos1170;
  {  int yypos1172= G->pos, yythunkpos1172= G->thunkpos;  if (!yy_HtmlBlockCloseDir(G)) { goto l1172; }  goto l1169;
  l1172:;	  G->pos= yypos1172; G->thunkpos= yythunkpos1172;
  }  if (!yymatchDot(G)) goto l1169;
  }
  l1170:;	  goto l1168;
  l1169:;	  G->pos= yypos1169; G->thunkpos= yythunkpos1169;
  }  if (!yy_HtmlBlockCloseDir(G)) { goto l1167; }
  yyprintf((stderr, "  ok   %s @ %s\n", "HtmlBlockDir", G->buf+G->pos));
  return 1;
  l1167:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "HtmlBlockDir", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_HtmlBlockCloseDir(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "HtmlBlockCloseDir"));  if (!yymatchChar(G, '<')) goto l1173;  if (!yy_Spnl(G)) { goto l1173; }  if (!yymatchChar(G, '/')) goto l1173;
  {  int yypos1174= G->pos, yythunkpos1174= G->thunkpos;  if (!yymatchString(G, "dir")) goto l1175;  goto l1174;
  l1175:;	  G->pos= yypos1174; G->thunkpos= yythunkpos1174;  if (!yymatchString(G, "DIR")) goto l1173;
  }
  l1174:;	  if (!yy_Spnl(G)) { goto l1173; }  if (!yymatchChar(G, '>')) goto l1173;
  yyprintf((stderr, "  ok   %s @ %s\n", "HtmlBlockCloseDir", G->buf+G->pos));
  return 1;
  l1173:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "HtmlBlockCloseDir", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_HtmlBlockOpenDir(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "HtmlBlockOpenDir"));  if (!yymatchChar(G, '<')) goto l1176;  if (!yy_Spnl(G)) { goto l1176; }
  {  int yypos1177= G->pos, yythunkpos1177= G->thunkpos;  if (!yymatchString(G, "dir")) goto l1178;  goto l1177;
  l1178:;	  G->pos= yypos1177; G->thunkpos= yythunkpos1177;  if (!yymatchString(G, "DIR")) goto l1176;
  }
  l1177:;	  if (!yy_Spnl(G)) { goto l1176; }
  l1179:;	
  {  int yypos1180= G->pos, yythunkpos1180= G->thunkpos;  if (!yy_HtmlAttribute(G)) { goto l1180; }  goto l1179;
  l1180:;	  G->pos= yypos1180; G->thunkpos= yythunkpos1180;
  }  if (!yymatchChar(G, '>')) goto l1176;
  yyprintf((stderr, "  ok   %s @ %s\n", "HtmlBlockOpenDir", G->buf+G->pos));
  return 1;
  l1176:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "HtmlBlockOpenDir", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_HtmlBlockCenter(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "HtmlBlockCenter"));  if (!yy_HtmlBlockOpenCenter(G)) { goto l1181; }
  l1182:;	
  {  int yypos1183= G->pos, yythunkpos1183= G->thunkpos;
  {  int yypos1184= G->pos, yythunkpos1184= G->thunkpos;  if (!yy_HtmlBlockCenter(G)) { goto l1185; }  goto l1184;
  l1185:;	  G->pos= yypos1184; G->thunkpos= yythunkpos1184;
  {  int yypos1186= G->pos, yythunkpos1186= G->thunkpos;  if (!yy_HtmlBlockCloseCenter(G)) { goto l1186; }  goto l1183;
  l1186:;	  G->pos= yypos1186; G->thunkpos= yythunkpos1186;
  }  if (!yymatchDot(G)) goto l1183;
  }
  l1184:;	  goto l1182;
  l1183:;	  G->pos= yypos1183; G->thunkpos= yythunkpos1183;
  }  if (!yy_HtmlBlockCloseCenter(G)) { goto l1181; }
  yyprintf((stderr, "  ok   %s @ %s\n", "HtmlBlockCenter", G->buf+G->pos));
  return 1;
  l1181:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "HtmlBlockCenter", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_HtmlBlockCloseCenter(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "HtmlBlockCloseCenter"));  if (!yymatchChar(G, '<')) goto l1187;  if (!yy_Spnl(G)) { goto l1187; }  if (!yymatchChar(G, '/')) goto l1187;
  {  int yypos1188= G->pos, yythunkpos1188= G->thunkpos;  if (!yymatchString(G, "center")) goto l1189;  goto l1188;
  l1189:;	  G->pos= yypos1188; G->thunkpos= yythunkpos1188;  if (!yymatchString(G, "CENTER")) goto l1187;
  }
  l1188:;	  if (!yy_Spnl(G)) { goto l1187; }  if (!yymatchChar(G, '>')) goto l1187;
  yyprintf((stderr, "  ok   %s @ %s\n", "HtmlBlockCloseCenter", G->buf+G->pos));
  return 1;
  l1187:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "HtmlBlockCloseCenter", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_HtmlBlockOpenCenter(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "HtmlBlockOpenCenter"));  if (!yymatchChar(G, '<')) goto l1190;  if (!yy_Spnl(G)) { goto l1190; }
  {  int yypos1191= G->pos, yythunkpos1191= G->thunkpos;  if (!yymatchString(G, "center")) goto l1192;  goto l1191;
  l1192:;	  G->pos= yypos1191; G->thunkpos= yythunkpos1191;  if (!yymatchString(G, "CENTER")) goto l1190;
  }
  l1191:;	  if (!yy_Spnl(G)) { goto l1190; }
  l1193:;	
  {  int yypos1194= G->pos, yythunkpos1194= G->thunkpos;  if (!yy_HtmlAttribute(G)) { goto l1194; }  goto l1193;
  l1194:;	  G->pos= yypos1194; G->thunkpos= yythunkpos1194;
  }  if (!yymatchChar(G, '>')) goto l1190;
  yyprintf((stderr, "  ok   %s @ %s\n", "HtmlBlockOpenCenter", G->buf+G->pos));
  return 1;
  l1190:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "HtmlBlockOpenCenter", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_HtmlBlockBlockquote(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "HtmlBlockBlockquote"));  if (!yy_HtmlBlockOpenBlockquote(G)) { goto l1195; }
  l1196:;	
  {  int yypos1197= G->pos, yythunkpos1197= G->thunkpos;
  {  int yypos1198= G->pos, yythunkpos1198= G->thunkpos;  if (!yy_HtmlBlockBlockquote(G)) { goto l1199; }  goto l1198;
  l1199:;	  G->pos= yypos1198; G->thunkpos= yythunkpos1198;
  {  int yypos1200= G->pos, yythunkpos1200= G->thunkpos;  if (!yy_HtmlBlockCloseBlockquote(G)) { goto l1200; }  goto l1197;
  l1200:;	  G->pos= yypos1200; G->thunkpos= yythunkpos1200;
  }  if (!yymatchDot(G)) goto l1197;
  }
  l1198:;	  goto l1196;
  l1197:;	  G->pos= yypos1197; G->thunkpos= yythunkpos1197;
  }  if (!yy_HtmlBlockCloseBlockquote(G)) { goto l1195; }
  yyprintf((stderr, "  ok   %s @ %s\n", "HtmlBlockBlockquote", G->buf+G->pos));
  return 1;
  l1195:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "HtmlBlockBlockquote", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_HtmlBlockCloseBlockquote(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "HtmlBlockCloseBlockquote"));  if (!yymatchChar(G, '<')) goto l1201;  if (!yy_Spnl(G)) { goto l1201; }  if (!yymatchChar(G, '/')) goto l1201;
  {  int yypos1202= G->pos, yythunkpos1202= G->thunkpos;  if (!yymatchString(G, "blockquote")) goto l1203;  goto l1202;
  l1203:;	  G->pos= yypos1202; G->thunkpos= yythunkpos1202;  if (!yymatchString(G, "BLOCKQUOTE")) goto l1201;
  }
  l1202:;	  if (!yy_Spnl(G)) { goto l1201; }  if (!yymatchChar(G, '>')) goto l1201;
  yyprintf((stderr, "  ok   %s @ %s\n", "HtmlBlockCloseBlockquote", G->buf+G->pos));
  return 1;
  l1201:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "HtmlBlockCloseBlockquote", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_HtmlBlockOpenBlockquote(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "HtmlBlockOpenBlockquote"));  if (!yymatchChar(G, '<')) goto l1204;  if (!yy_Spnl(G)) { goto l1204; }
  {  int yypos1205= G->pos, yythunkpos1205= G->thunkpos;  if (!yymatchString(G, "blockquote")) goto l1206;  goto l1205;
  l1206:;	  G->pos= yypos1205; G->thunkpos= yythunkpos1205;  if (!yymatchString(G, "BLOCKQUOTE")) goto l1204;
  }
  l1205:;	  if (!yy_Spnl(G)) { goto l1204; }
  l1207:;	
  {  int yypos1208= G->pos, yythunkpos1208= G->thunkpos;  if (!yy_HtmlAttribute(G)) { goto l1208; }  goto l1207;
  l1208:;	  G->pos= yypos1208; G->thunkpos= yythunkpos1208;
  }  if (!yymatchChar(G, '>')) goto l1204;
  yyprintf((stderr, "  ok   %s @ %s\n", "HtmlBlockOpenBlockquote", G->buf+G->pos));
  return 1;
  l1204:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "HtmlBlockOpenBlockquote", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_HtmlBlockAddress(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "HtmlBlockAddress"));  if (!yy_HtmlBlockOpenAddress(G)) { goto l1209; }
  l1210:;	
  {  int yypos1211= G->pos, yythunkpos1211= G->thunkpos;
  {  int yypos1212= G->pos, yythunkpos1212= G->thunkpos;  if (!yy_HtmlBlockAddress(G)) { goto l1213; }  goto l1212;
  l1213:;	  G->pos= yypos1212; G->thunkpos= yythunkpos1212;
  {  int yypos1214= G->pos, yythunkpos1214= G->thunkpos;  if (!yy_HtmlBlockCloseAddress(G)) { goto l1214; }  goto l1211;
  l1214:;	  G->pos= yypos1214; G->thunkpos= yythunkpos1214;
  }  if (!yymatchDot(G)) goto l1211;
  }
  l1212:;	  goto l1210;
  l1211:;	  G->pos= yypos1211; G->thunkpos= yythunkpos1211;
  }  if (!yy_HtmlBlockCloseAddress(G)) { goto l1209; }
  yyprintf((stderr, "  ok   %s @ %s\n", "HtmlBlockAddress", G->buf+G->pos));
  return 1;
  l1209:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "HtmlBlockAddress", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_HtmlBlockCloseAddress(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "HtmlBlockCloseAddress"));  if (!yymatchChar(G, '<')) goto l1215;  if (!yy_Spnl(G)) { goto l1215; }  if (!yymatchChar(G, '/')) goto l1215;
  {  int yypos1216= G->pos, yythunkpos1216= G->thunkpos;  if (!yymatchString(G, "address")) goto l1217;  goto l1216;
  l1217:;	  G->pos= yypos1216; G->thunkpos= yythunkpos1216;  if (!yymatchString(G, "ADDRESS")) goto l1215;
  }
  l1216:;	  if (!yy_Spnl(G)) { goto l1215; }  if (!yymatchChar(G, '>')) goto l1215;
  yyprintf((stderr, "  ok   %s @ %s\n", "HtmlBlockCloseAddress", G->buf+G->pos));
  return 1;
  l1215:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "HtmlBlockCloseAddress", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_HtmlAttribute(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "HtmlAttribute"));
  {  int yypos1221= G->pos, yythunkpos1221= G->thunkpos;  if (!yy_AlphanumericAscii(G)) { goto l1222; }  goto l1221;
  l1222:;	  G->pos= yypos1221; G->thunkpos= yythunkpos1221;  if (!yymatchChar(G, '-')) goto l1218;
  }
  l1221:;	
  l1219:;	
  {  int yypos1220= G->pos, yythunkpos1220= G->thunkpos;
  {  int yypos1223= G->pos, yythunkpos1223= G->thunkpos;  if (!yy_AlphanumericAscii(G)) { goto l1224; }  goto l1223;
  l1224:;	  G->pos= yypos1223; G->thunkpos= yythunkpos1223;  if (!yymatchChar(G, '-')) goto l1220;
  }
  l1223:;	  goto l1219;
  l1220:;	  G->pos= yypos1220; G->thunkpos= yythunkpos1220;
  }  if (!yy_Spnl(G)) { goto l1218; }
  {  int yypos1225= G->pos, yythunkpos1225= G->thunkpos;  if (!yymatchChar(G, '=')) goto l1225;  if (!yy_Spnl(G)) { goto l1225; }
  {  int yypos1227= G->pos, yythunkpos1227= G->thunkpos;  if (!yy_Quoted(G)) { goto l1228; }  goto l1227;
  l1228:;	  G->pos= yypos1227; G->thunkpos= yythunkpos1227;
  {  int yypos1231= G->pos, yythunkpos1231= G->thunkpos;  if (!yymatchChar(G, '>')) goto l1231;  goto l1225;
  l1231:;	  G->pos= yypos1231; G->thunkpos= yythunkpos1231;
  }  if (!yy_Nonspacechar(G)) { goto l1225; }
  l1229:;	
  {  int yypos1230= G->pos, yythunkpos1230= G->thunkpos;
  {  int yypos1232= G->pos, yythunkpos1232= G->thunkpos;  if (!yymatchChar(G, '>')) goto l1232;  goto l1230;
  l1232:;	  G->pos= yypos1232; G->thunkpos= yythunkpos1232;
  }  if (!yy_Nonspacechar(G)) { goto l1230; }  goto l1229;
  l1230:;	  G->pos= yypos1230; G->thunkpos= yythunkpos1230;
  }
  }
  l1227:;	  goto l1226;
  l1225:;	  G->pos= yypos1225; G->thunkpos= yythunkpos1225;
  }
  l1226:;	  if (!yy_Spnl(G)) { goto l1218; }
  yyprintf((stderr, "  ok   %s @ %s\n", "HtmlAttribute", G->buf+G->pos));
  return 1;
  l1218:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "HtmlAttribute", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_Spnl(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "Spnl"));  if (!yy_Sp(G)) { goto l1233; }
  {  int yypos1234= G->pos, yythunkpos1234= G->thunkpos;  if (!yy_Newline(G)) { goto l1234; }  if (!yy_Sp(G)) { goto l1234; }  goto l1235;
  l1234:;	  G->pos= yypos1234; G->thunkpos= yythunkpos1234;
  }
  l1235:;	
  yyprintf((stderr, "  ok   %s @ %s\n", "Spnl", G->buf+G->pos));
  return 1;
  l1233:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "Spnl", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_HtmlBlockOpenAddress(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "HtmlBlockOpenAddress"));  if (!yymatchChar(G, '<')) goto l1236;  if (!yy_Spnl(G)) { goto l1236; }
  {  int yypos1237= G->pos, yythunkpos1237= G->thunkpos;  if (!yymatchString(G, "address")) goto l1238;  goto l1237;
  l1238:;	  G->pos= yypos1237; G->thunkpos= yythunkpos1237;  if (!yymatchString(G, "ADDRESS")) goto l1236;
  }
  l1237:;	  if (!yy_Spnl(G)) { goto l1236; }
  l1239:;	
  {  int yypos1240= G->pos, yythunkpos1240= G->thunkpos;  if (!yy_HtmlAttribute(G)) { goto l1240; }  goto l1239;
  l1240:;	  G->pos= yypos1240; G->thunkpos= yythunkpos1240;
  }  if (!yymatchChar(G, '>')) goto l1236;
  yyprintf((stderr, "  ok   %s @ %s\n", "HtmlBlockOpenAddress", G->buf+G->pos));
  return 1;
  l1236:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "HtmlBlockOpenAddress", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_OptionallyIndentedLine(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "OptionallyIndentedLine"));
  {  int yypos1242= G->pos, yythunkpos1242= G->thunkpos;  if (!yy_Indent(G)) { goto l1242; }  goto l1243;
  l1242:;	  G->pos= yypos1242; G->thunkpos= yythunkpos1242;
  }
  l1243:;	  if (!yy_Line(G)) { goto l1241; }
  yyprintf((stderr, "  ok   %s @ %s\n", "OptionallyIndentedLine", G->buf+G->pos));
  return 1;
  l1241:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "OptionallyIndentedLine", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_Indent(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "Indent"));
  {  int yypos1245= G->pos, yythunkpos1245= G->thunkpos;  if (!yymatchChar(G, '\t')) goto l1246;  goto l1245;
  l1246:;	  G->pos= yypos1245; G->thunkpos= yythunkpos1245;  if (!yymatchString(G, "    ")) goto l1244;
  }
  l1245:;	
  yyprintf((stderr, "  ok   %s @ %s\n", "Indent", G->buf+G->pos));
  return 1;
  l1244:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "Indent", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_ListBlockLine(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "ListBlockLine"));
  {  int yypos1248= G->pos, yythunkpos1248= G->thunkpos;  if (!yy_BlankLine(G)) { goto l1248; }  goto l1247;
  l1248:;	  G->pos= yypos1248; G->thunkpos= yythunkpos1248;
  }
  {  int yypos1249= G->pos, yythunkpos1249= G->thunkpos;
  {  int yypos1250= G->pos, yythunkpos1250= G->thunkpos;  if (!yy_Indent(G)) { goto l1250; }  goto l1251;
  l1250:;	  G->pos= yypos1250; G->thunkpos= yythunkpos1250;
  }
  l1251:;	
  {  int yypos1252= G->pos, yythunkpos1252= G->thunkpos;  if (!yy_Bullet(G)) { goto l1253; }  goto l1252;
  l1253:;	  G->pos= yypos1252; G->thunkpos= yythunkpos1252;  if (!yy_Enumerator(G)) { goto l1249; }
  }
  l1252:;	  goto l1247;
  l1249:;	  G->pos= yypos1249; G->thunkpos= yythunkpos1249;
  }
  {  int yypos1254= G->pos, yythunkpos1254= G->thunkpos;  if (!yy_HorizontalRule(G)) { goto l1254; }  goto l1247;
  l1254:;	  G->pos= yypos1254; G->thunkpos= yythunkpos1254;
  }  if (!yy_OptionallyIndentedLine(G)) { goto l1247; }
  yyprintf((stderr, "  ok   %s @ %s\n", "ListBlockLine", G->buf+G->pos));
  return 1;
  l1247:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "ListBlockLine", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_ListContinuationBlock(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;  yyDo(G, yyPush, 1, 0);
  yyprintf((stderr, "%s\n", "ListContinuationBlock"));  if (!yy_StartList(G)) { goto l1255; }  yyDo(G, yySet, -1, 0);  yyText(G, G->begin, G->end);  if (!(YY_BEGIN)) goto l1255;
  l1256:;	
  {  int yypos1257= G->pos, yythunkpos1257= G->thunkpos;  if (!yy_BlankLine(G)) { goto l1257; }  goto l1256;
  l1257:;	  G->pos= yypos1257; G->thunkpos= yythunkpos1257;
  }  yyText(G, G->begin, G->end);  if (!(YY_END)) goto l1255;  yyDo(G, yy_1_ListContinuationBlock, G->begin, G->end);  if (!yy_Indent(G)) { goto l1255; }  if (!yy_ListBlock(G)) { goto l1255; }  yyDo(G, yy_2_ListContinuationBlock, G->begin, G->end);
  l1258:;	
  {  int yypos1259= G->pos, yythunkpos1259= G->thunkpos;  if (!yy_Indent(G)) { goto l1259; }  if (!yy_ListBlock(G)) { goto l1259; }  yyDo(G, yy_2_ListContinuationBlock, G->begin, G->end);  goto l1258;
  l1259:;	  G->pos= yypos1259; G->thunkpos= yythunkpos1259;
  }  yyDo(G, yy_3_ListContinuationBlock, G->begin, G->end);
  yyprintf((stderr, "  ok   %s @ %s\n", "ListContinuationBlock", G->buf+G->pos));  yyDo(G, yyPop, 1, 0);
  return 1;
  l1255:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "ListContinuationBlock", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_ListBlock(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;  yyDo(G, yyPush, 1, 0);
  yyprintf((stderr, "%s\n", "ListBlock"));  if (!yy_StartList(G)) { goto l1260; }  yyDo(G, yySet, -1, 0);
  {  int yypos1261= G->pos, yythunkpos1261= G->thunkpos;  if (!yy_BlankLine(G)) { goto l1261; }  goto l1260;
  l1261:;	  G->pos= yypos1261; G->thunkpos= yythunkpos1261;
  }  if (!yy_Line(G)) { goto l1260; }  yyDo(G, yy_1_ListBlock, G->begin, G->end);
  l1262:;	
  {  int yypos1263= G->pos, yythunkpos1263= G->thunkpos;  if (!yy_ListBlockLine(G)) { goto l1263; }  yyDo(G, yy_2_ListBlock, G->begin, G->end);  goto l1262;
  l1263:;	  G->pos= yypos1263; G->thunkpos= yythunkpos1263;
  }  yyDo(G, yy_3_ListBlock, G->begin, G->end);
  yyprintf((stderr, "  ok   %s @ %s\n", "ListBlock", G->buf+G->pos));  yyDo(G, yyPop, 1, 0);
  return 1;
  l1260:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "ListBlock", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_ListItem(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;  yyDo(G, yyPush, 1, 0);
  yyprintf((stderr, "%s\n", "ListItem"));
  {  int yypos1265= G->pos, yythunkpos1265= G->thunkpos;  if (!yy_Bullet(G)) { goto l1266; }  goto l1265;
  l1266:;	  G->pos= yypos1265; G->thunkpos= yythunkpos1265;  if (!yy_Enumerator(G)) { goto l1264; }
  }
  l1265:;	  if (!yy_StartList(G)) { goto l1264; }  yyDo(G, yySet, -1, 0);  if (!yy_ListBlock(G)) { goto l1264; }  yyDo(G, yy_1_ListItem, G->begin, G->end);
  l1267:;	
  {  int yypos1268= G->pos, yythunkpos1268= G->thunkpos;  if (!yy_ListContinuationBlock(G)) { goto l1268; }  yyDo(G, yy_2_ListItem, G->begin, G->end);  goto l1267;
  l1268:;	  G->pos= yypos1268; G->thunkpos= yythunkpos1268;
  }  yyDo(G, yy_3_ListItem, G->begin, G->end);
  yyprintf((stderr, "  ok   %s @ %s\n", "ListItem", G->buf+G->pos));  yyDo(G, yyPop, 1, 0);
  return 1;
  l1264:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "ListItem", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_Enumerator(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "Enumerator"));  if (!yy_NonindentSpace(G)) { goto l1269; }  yyText(G, G->begin, G->end);  if (!(YY_BEGIN)) goto l1269;  if (!yymatchClass(G, (unsigned char *)"\000\000\000\000\000\000\377\003\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000")) goto l1269;
  l1270:;	
  {  int yypos1271= G->pos, yythunkpos1271= G->thunkpos;  if (!yymatchClass(G, (unsigned char *)"\000\000\000\000\000\000\377\003\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000")) goto l1271;  goto l1270;
  l1271:;	  G->pos= yypos1271; G->thunkpos= yythunkpos1271;
  }  if (!yymatchChar(G, '.')) goto l1269;  yyText(G, G->begin, G->end);  if (!(YY_END)) goto l1269;  if (!yy_Spacechar(G)) { goto l1269; }
  l1272:;	
  {  int yypos1273= G->pos, yythunkpos1273= G->thunkpos;  if (!yy_Spacechar(G)) { goto l1273; }  goto l1272;
  l1273:;	  G->pos= yypos1273; G->thunkpos= yythunkpos1273;
  }  yyDo(G, yy_1_Enumerator, G->begin, G->end);
  yyprintf((stderr, "  ok   %s @ %s\n", "Enumerator", G->buf+G->pos));
  return 1;
  l1269:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "Enumerator", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_ListItemTight(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;  yyDo(G, yyPush, 1, 0);
  yyprintf((stderr, "%s\n", "ListItemTight"));
  {  int yypos1275= G->pos, yythunkpos1275= G->thunkpos;  if (!yy_Bullet(G)) { goto l1276; }  goto l1275;
  l1276:;	  G->pos= yypos1275; G->thunkpos= yythunkpos1275;  if (!yy_Enumerator(G)) { goto l1274; }
  }
  l1275:;	  if (!yy_StartList(G)) { goto l1274; }  yyDo(G, yySet, -1, 0);  if (!yy_ListBlock(G)) { goto l1274; }  yyDo(G, yy_1_ListItemTight, G->begin, G->end);
  l1277:;	
  {  int yypos1278= G->pos, yythunkpos1278= G->thunkpos;
  {  int yypos1279= G->pos, yythunkpos1279= G->thunkpos;  if (!yy_BlankLine(G)) { goto l1279; }  goto l1278;
  l1279:;	  G->pos= yypos1279; G->thunkpos= yythunkpos1279;
  }  if (!yy_ListContinuationBlock(G)) { goto l1278; }  yyDo(G, yy_2_ListItemTight, G->begin, G->end);  goto l1277;
  l1278:;	  G->pos= yypos1278; G->thunkpos= yythunkpos1278;
  }
  {  int yypos1280= G->pos, yythunkpos1280= G->thunkpos;  if (!yy_ListContinuationBlock(G)) { goto l1280; }  goto l1274;
  l1280:;	  G->pos= yypos1280; G->thunkpos= yythunkpos1280;
  }  yyDo(G, yy_3_ListItemTight, G->begin, G->end);
  yyprintf((stderr, "  ok   %s @ %s\n", "ListItemTight", G->buf+G->pos));  yyDo(G, yyPop, 1, 0);
  return 1;
  l1274:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "ListItemTight", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_ListLoose(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;  yyDo(G, yyPush, 2, 0);
  yyprintf((stderr, "%s\n", "ListLoose"));  if (!yy_StartList(G)) { goto l1281; }  yyDo(G, yySet, -2, 0);  if (!yy_ListItem(G)) { goto l1281; }  yyDo(G, yySet, -1, 0);
  l1284:;	
  {  int yypos1285= G->pos, yythunkpos1285= G->thunkpos;  if (!yy_BlankLine(G)) { goto l1285; }  goto l1284;
  l1285:;	  G->pos= yypos1285; G->thunkpos= yythunkpos1285;
  }  yyDo(G, yy_1_ListLoose, G->begin, G->end);
  l1282:;	
  {  int yypos1283= G->pos, yythunkpos1283= G->thunkpos;  if (!yy_ListItem(G)) { goto l1283; }  yyDo(G, yySet, -1, 0);
  l1286:;	
  {  int yypos1287= G->pos, yythunkpos1287= G->thunkpos;  if (!yy_BlankLine(G)) { goto l1287; }  goto l1286;
  l1287:;	  G->pos= yypos1287; G->thunkpos= yythunkpos1287;
  }  yyDo(G, yy_1_ListLoose, G->begin, G->end);  goto l1282;
  l1283:;	  G->pos= yypos1283; G->thunkpos= yythunkpos1283;
  }  yyDo(G, yy_2_ListLoose, G->begin, G->end);
  yyprintf((stderr, "  ok   %s @ %s\n", "ListLoose", G->buf+G->pos));  yyDo(G, yyPop, 2, 0);
  return 1;
  l1281:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "ListLoose", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_ListTight(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;  yyDo(G, yyPush, 1, 0);
  yyprintf((stderr, "%s\n", "ListTight"));  if (!yy_StartList(G)) { goto l1288; }  yyDo(G, yySet, -1, 0);  if (!yy_ListItemTight(G)) { goto l1288; }  yyDo(G, yy_1_ListTight, G->begin, G->end);
  l1289:;	
  {  int yypos1290= G->pos, yythunkpos1290= G->thunkpos;  if (!yy_ListItemTight(G)) { goto l1290; }  yyDo(G, yy_1_ListTight, G->begin, G->end);  goto l1289;
  l1290:;	  G->pos= yypos1290; G->thunkpos= yythunkpos1290;
  }
  l1291:;	
  {  int yypos1292= G->pos, yythunkpos1292= G->thunkpos;  if (!yy_BlankLine(G)) { goto l1292; }  goto l1291;
  l1292:;	  G->pos= yypos1292; G->thunkpos= yythunkpos1292;
  }
  {  int yypos1293= G->pos, yythunkpos1293= G->thunkpos;
  {  int yypos1294= G->pos, yythunkpos1294= G->thunkpos;  if (!yy_Bullet(G)) { goto l1295; }  goto l1294;
  l1295:;	  G->pos= yypos1294; G->thunkpos= yythunkpos1294;  if (!yy_Enumerator(G)) { goto l1293; }
  }
  l1294:;	  goto l1288;
  l1293:;	  G->pos= yypos1293; G->thunkpos= yythunkpos1293;
  }  yyDo(G, yy_2_ListTight, G->begin, G->end);
  yyprintf((stderr, "  ok   %s @ %s\n", "ListTight", G->buf+G->pos));  yyDo(G, yyPop, 1, 0);
  return 1;
  l1288:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "ListTight", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_Bullet(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "Bullet"));
  {  int yypos1297= G->pos, yythunkpos1297= G->thunkpos;  if (!yy_HorizontalRule(G)) { goto l1297; }  goto l1296;
  l1297:;	  G->pos= yypos1297; G->thunkpos= yythunkpos1297;
  }  if (!yy_NonindentSpace(G)) { goto l1296; }  yyText(G, G->begin, G->end);  if (!(YY_BEGIN)) goto l1296;
  {  int yypos1298= G->pos, yythunkpos1298= G->thunkpos;  if (!yymatchChar(G, '+')) goto l1299;  goto l1298;
  l1299:;	  G->pos= yypos1298; G->thunkpos= yythunkpos1298;  if (!yymatchChar(G, '*')) goto l1300;  goto l1298;
  l1300:;	  G->pos= yypos1298; G->thunkpos= yythunkpos1298;  if (!yymatchChar(G, '-')) goto l1296;
  }
  l1298:;	  yyText(G, G->begin, G->end);  if (!(YY_END)) goto l1296;  if (!yy_Spacechar(G)) { goto l1296; }
  l1301:;	
  {  int yypos1302= G->pos, yythunkpos1302= G->thunkpos;  if (!yy_Spacechar(G)) { goto l1302; }  goto l1301;
  l1302:;	  G->pos= yypos1302; G->thunkpos= yythunkpos1302;
  }  yyDo(G, yy_1_Bullet, G->begin, G->end);
  yyprintf((stderr, "  ok   %s @ %s\n", "Bullet", G->buf+G->pos));
  return 1;
  l1296:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "Bullet", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_Nonspacechar(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "Nonspacechar"));
  {  int yypos1304= G->pos, yythunkpos1304= G->thunkpos;  if (!yy_Spacechar(G)) { goto l1304; }  goto l1303;
  l1304:;	  G->pos= yypos1304; G->thunkpos= yythunkpos1304;
  }
  {  int yypos1305= G->pos, yythunkpos1305= G->thunkpos;  if (!yy_Newline(G)) { goto l1305; }  goto l1303;
  l1305:;	  G->pos= yypos1305; G->thunkpos= yythunkpos1305;
  }  if (!yymatchDot(G)) goto l1303;
  yyprintf((stderr, "  ok   %s @ %s\n", "Nonspacechar", G->buf+G->pos));
  return 1;
  l1303:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "Nonspacechar", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_InlineEquationMultiple(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "InlineEquationMultiple"));
  {  int yypos1307= G->pos, yythunkpos1307= G->thunkpos;  if (!yymatchChar(G, '$')) goto l1307;  goto l1306;
  l1307:;	  G->pos= yypos1307; G->thunkpos= yythunkpos1307;
  }  if (!yy_Nonspacechar(G)) { goto l1306; }
  {  int yypos1310= G->pos, yythunkpos1310= G->thunkpos;  if (!yymatchChar(G, '$')) goto l1310;  goto l1306;
  l1310:;	  G->pos= yypos1310; G->thunkpos= yythunkpos1310;
  }
  {  int yypos1311= G->pos, yythunkpos1311= G->thunkpos;  if (!yy_Newline(G)) { goto l1311; }  goto l1306;
  l1311:;	  G->pos= yypos1311; G->thunkpos= yythunkpos1311;
  }  if (!yymatchDot(G)) goto l1306;
  l1308:;	
  {  int yypos1309= G->pos, yythunkpos1309= G->thunkpos;
  {  int yypos1312= G->pos, yythunkpos1312= G->thunkpos;  if (!yymatchChar(G, '$')) goto l1312;  goto l1309;
  l1312:;	  G->pos= yypos1312; G->thunkpos= yythunkpos1312;
  }
  {  int yypos1313= G->pos, yythunkpos1313= G->thunkpos;  if (!yy_Newline(G)) { goto l1313; }  goto l1309;
  l1313:;	  G->pos= yypos1313; G->thunkpos= yythunkpos1313;
  }  if (!yymatchDot(G)) goto l1309;  goto l1308;
  l1309:;	  G->pos= yypos1309; G->thunkpos= yythunkpos1309;
  }  if (!yymatchChar(G, '$')) goto l1306;  yyText(G, G->begin, G->end);  if (!( IEP_POST )) goto l1306;
  yyprintf((stderr, "  ok   %s @ %s\n", "InlineEquationMultiple", G->buf+G->pos));
  return 1;
  l1306:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "InlineEquationMultiple", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_InlineEquationSingle(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "InlineEquationSingle"));
  {  int yypos1315= G->pos, yythunkpos1315= G->thunkpos;  if (!yymatchChar(G, '$')) goto l1315;  goto l1314;
  l1315:;	  G->pos= yypos1315; G->thunkpos= yythunkpos1315;
  }
  {  int yypos1316= G->pos, yythunkpos1316= G->thunkpos;  if (!yymatchChar(G, '\\')) goto l1316;  goto l1314;
  l1316:;	  G->pos= yypos1316; G->thunkpos= yythunkpos1316;
  }  if (!yy_Nonspacechar(G)) { goto l1314; }  if (!yymatchChar(G, '$')) goto l1314;
  yyprintf((stderr, "  ok   %s @ %s\n", "InlineEquationSingle", G->buf+G->pos));
  return 1;
  l1314:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "InlineEquationSingle", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_InlineEquation(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "InlineEquation"));  yyText(G, G->begin, G->end);  if (!( EXT(pmh_EXT_MATH) )) goto l1317;  yyText(G, G->begin, G->end);  if (!(YY_BEGIN)) goto l1317;  if (!yymatchChar(G, '$')) goto l1317;  yyText(G, G->begin, G->end);  if (!( IEP_PRE )) goto l1317;
  {  int yypos1318= G->pos, yythunkpos1318= G->thunkpos;  if (!yy_InlineEquationSingle(G)) { goto l1319; }  goto l1318;
  l1319:;	  G->pos= yypos1318; G->thunkpos= yythunkpos1318;  if (!yy_InlineEquationMultiple(G)) { goto l1317; }
  }
  l1318:;	
  {  int yypos1320= G->pos, yythunkpos1320= G->thunkpos;  if (!yymatchClass(G, (unsigned char *)"\000\000\000\000\000\000\377\003\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000")) goto l1320;  goto l1317;
  l1320:;	  G->pos= yypos1320; G->thunkpos= yythunkpos1320;
  }  yyText(G, G->begin, G->end);  if (!(YY_END)) goto l1317;  yyDo(G, yy_1_InlineEquation, G->begin, G->end);
  yyprintf((stderr, "  ok   %s @ %s\n", "InlineEquation", G->buf+G->pos));
  return 1;
  l1317:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "InlineEquation", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_Spacechar(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "Spacechar"));
  {  int yypos1322= G->pos, yythunkpos1322= G->thunkpos;  if (!yymatchChar(G, ' ')) goto l1323;  goto l1322;
  l1323:;	  G->pos= yypos1322; G->thunkpos= yythunkpos1322;  if (!yymatchChar(G, '\t')) goto l1321;
  }
  l1322:;	
  yyprintf((stderr, "  ok   %s @ %s\n", "Spacechar", G->buf+G->pos));
  return 1;
  l1321:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "Spacechar", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_FencedCodeBlockEnd(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "FencedCodeBlockEnd"));  if (!yymatchString(G, "```")) goto l1324;
  l1325:;	
  {  int yypos1326= G->pos, yythunkpos1326= G->thunkpos;  if (!yy_Spacechar(G)) { goto l1326; }  goto l1325;
  l1326:;	  G->pos= yypos1326; G->thunkpos= yythunkpos1326;
  }  if (!yy_Newline(G)) { goto l1324; }
  yyprintf((stderr, "  ok   %s @ %s\n", "FencedCodeBlockEnd", G->buf+G->pos));
  return 1;
  l1324:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "FencedCodeBlockEnd", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_FencedCodeBlockChunk(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "FencedCodeBlockChunk"));
  {  int yypos1328= G->pos, yythunkpos1328= G->thunkpos;  if (!yy_FencedCodeBlockEnd(G)) { goto l1328; }  goto l1327;
  l1328:;	  G->pos= yypos1328; G->thunkpos= yythunkpos1328;
  }
  l1329:;	
  {  int yypos1330= G->pos, yythunkpos1330= G->thunkpos;
  {  int yypos1331= G->pos, yythunkpos1331= G->thunkpos;  if (!yy_Newline(G)) { goto l1331; }  goto l1330;
  l1331:;	  G->pos= yypos1331; G->thunkpos= yythunkpos1331;
  }  if (!yymatchDot(G)) goto l1330;  goto l1329;
  l1330:;	  G->pos= yypos1330; G->thunkpos= yythunkpos1330;
  }  if (!yy_Newline(G)) { goto l1327; }
  yyprintf((stderr, "  ok   %s @ %s\n", "FencedCodeBlockChunk", G->buf+G->pos));
  return 1;
  l1327:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "FencedCodeBlockChunk", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_FencedCodeBlockStart(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "FencedCodeBlockStart"));  if (!yymatchString(G, "```")) goto l1332;
  l1333:;	
  {  int yypos1334= G->pos, yythunkpos1334= G->thunkpos;
  {  int yypos1335= G->pos, yythunkpos1335= G->thunkpos;  if (!yy_Newline(G)) { goto l1335; }  goto l1334;
  l1335:;	  G->pos= yypos1335; G->thunkpos= yythunkpos1335;
  }
  {  int yypos1336= G->pos, yythunkpos1336= G->thunkpos;  if (!yymatchChar(G, '`')) goto l1336;  goto l1334;
  l1336:;	  G->pos= yypos1336; G->thunkpos= yythunkpos1336;
  }  if (!yymatchDot(G)) goto l1334;  goto l1333;
  l1334:;	  G->pos= yypos1334; G->thunkpos= yythunkpos1334;
  }  if (!yy_Newline(G)) { goto l1332; }
  yyprintf((stderr, "  ok   %s @ %s\n", "FencedCodeBlockStart", G->buf+G->pos));
  return 1;
  l1332:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "FencedCodeBlockStart", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_VerbatimChunk(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "VerbatimChunk"));
  l1338:;	
  {  int yypos1339= G->pos, yythunkpos1339= G->thunkpos;  if (!yy_BlankLine(G)) { goto l1339; }  goto l1338;
  l1339:;	  G->pos= yypos1339; G->thunkpos= yythunkpos1339;
  }  if (!yy_NonblankIndentedLine(G)) { goto l1337; }
  l1340:;	
  {  int yypos1341= G->pos, yythunkpos1341= G->thunkpos;  if (!yy_NonblankIndentedLine(G)) { goto l1341; }  goto l1340;
  l1341:;	  G->pos= yypos1341; G->thunkpos= yythunkpos1341;
  }
  yyprintf((stderr, "  ok   %s @ %s\n", "VerbatimChunk", G->buf+G->pos));
  return 1;
  l1337:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "VerbatimChunk", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_IndentedLine(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "IndentedLine"));  if (!yy_Indent(G)) { goto l1342; }  if (!yy_Line(G)) { goto l1342; }
  yyprintf((stderr, "  ok   %s @ %s\n", "IndentedLine", G->buf+G->pos));
  return 1;
  l1342:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "IndentedLine", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_NonblankIndentedLine(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "NonblankIndentedLine"));
  {  int yypos1344= G->pos, yythunkpos1344= G->thunkpos;  if (!yy_BlankLine(G)) { goto l1344; }  goto l1343;
  l1344:;	  G->pos= yypos1344; G->thunkpos= yythunkpos1344;
  }  if (!yy_IndentedLine(G)) { goto l1343; }
  yyprintf((stderr, "  ok   %s @ %s\n", "NonblankIndentedLine", G->buf+G->pos));
  return 1;
  l1343:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "NonblankIndentedLine", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_Line(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "Line"));  if (!yy_RawLine(G)) { goto l1345; }  yyDo(G, yy_1_Line, G->begin, G->end);
  yyprintf((stderr, "  ok   %s @ %s\n", "Line", G->buf+G->pos));
  return 1;
  l1345:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "Line", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_StartList(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "StartList"));
  {  int yypos1347= G->pos, yythunkpos1347= G->thunkpos;  if (!yymatchDot(G)) goto l1346;  G->pos= yypos1347; G->thunkpos= yythunkpos1347;
  }  yyDo(G, yy_1_StartList, G->begin, G->end);
  yyprintf((stderr, "  ok   %s @ %s\n", "StartList", G->buf+G->pos));
  return 1;
  l1346:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "StartList", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_BlockQuoteRaw(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;  yyDo(G, yyPush, 1, 0);
  yyprintf((stderr, "%s\n", "BlockQuoteRaw"));  if (!yy_StartList(G)) { goto l1348; }  yyDo(G, yySet, -1, 0);  yyText(G, G->begin, G->end);  if (!(YY_BEGIN)) goto l1348;  if (!yymatchChar(G, '>')) goto l1348;
  {  int yypos1351= G->pos, yythunkpos1351= G->thunkpos;  if (!yymatchChar(G, ' ')) goto l1351;  goto l1352;
  l1351:;	  G->pos= yypos1351; G->thunkpos= yythunkpos1351;
  }
  l1352:;	  yyText(G, G->begin, G->end);  if (!(YY_END)) goto l1348;  yyDo(G, yy_1_BlockQuoteRaw, G->begin, G->end);  if (!yy_Line(G)) { goto l1348; }  yyDo(G, yy_2_BlockQuoteRaw, G->begin, G->end);
  l1353:;	
  {  int yypos1354= G->pos, yythunkpos1354= G->thunkpos;
  {  int yypos1355= G->pos, yythunkpos1355= G->thunkpos;  if (!yymatchChar(G, '>')) goto l1355;  goto l1354;
  l1355:;	  G->pos= yypos1355; G->thunkpos= yythunkpos1355;
  }
  {  int yypos1356= G->pos, yythunkpos1356= G->thunkpos;  if (!yy_BlankLine(G)) { goto l1356; }  goto l1354;
  l1356:;	  G->pos= yypos1356; G->thunkpos= yythunkpos1356;
  }  if (!yy_Line(G)) { goto l1354; }  yyDo(G, yy_3_BlockQuoteRaw, G->begin, G->end);  goto l1353;
  l1354:;	  G->pos= yypos1354; G->thunkpos= yythunkpos1354;
  }
  l1357:;	
  {  int yypos1358= G->pos, yythunkpos1358= G->thunkpos;  yyText(G, G->begin, G->end);  if (!(YY_BEGIN)) goto l1358;  if (!yy_BlankLine(G)) { goto l1358; }  yyText(G, G->begin, G->end);  if (!(YY_END)) goto l1358;  yyDo(G, yy_4_BlockQuoteRaw, G->begin, G->end);  goto l1357;
  l1358:;	  G->pos= yypos1358; G->thunkpos= yythunkpos1358;
  }
  l1349:;	
  {  int yypos1350= G->pos, yythunkpos1350= G->thunkpos;  yyText(G, G->begin, G->end);  if (!(YY_BEGIN)) goto l1350;  if (!yymatchChar(G, '>')) goto l1350;
  {  int yypos1359= G->pos, yythunkpos1359= G->thunkpos;  if (!yymatchChar(G, ' ')) goto l1359;  goto l1360;
  l1359:;	  G->pos= yypos1359; G->thunkpos= yythunkpos1359;
  }
  l1360:;	  yyText(G, G->begin, G->end);  if (!(YY_END)) goto l1350;  yyDo(G, yy_1_BlockQuoteRaw, G->begin, G->end);  if (!yy_Line(G)) { goto l1350; }  yyDo(G, yy_2_BlockQuoteRaw, G->begin, G->end);
  l1361:;	
  {  int yypos1362= G->pos, yythunkpos1362= G->thunkpos;
  {  int yypos1363= G->pos, yythunkpos1363= G->thunkpos;  if (!yymatchChar(G, '>')) goto l1363;  goto l1362;
  l1363:;	  G->pos= yypos1363; G->thunkpos= yythunkpos1363;
  }
  {  int yypos1364= G->pos, yythunkpos1364= G->thunkpos;  if (!yy_BlankLine(G)) { goto l1364; }  goto l1362;
  l1364:;	  G->pos= yypos1364; G->thunkpos= yythunkpos1364;
  }  if (!yy_Line(G)) { goto l1362; }  yyDo(G, yy_3_BlockQuoteRaw, G->begin, G->end);  goto l1361;
  l1362:;	  G->pos= yypos1362; G->thunkpos= yythunkpos1362;
  }
  l1365:;	
  {  int yypos1366= G->pos, yythunkpos1366= G->thunkpos;  yyText(G, G->begin, G->end);  if (!(YY_BEGIN)) goto l1366;  if (!yy_BlankLine(G)) { goto l1366; }  yyText(G, G->begin, G->end);  if (!(YY_END)) goto l1366;  yyDo(G, yy_4_BlockQuoteRaw, G->begin, G->end);  goto l1365;
  l1366:;	  G->pos= yypos1366; G->thunkpos= yythunkpos1366;
  }  goto l1349;
  l1350:;	  G->pos= yypos1350; G->thunkpos= yythunkpos1350;
  }  yyDo(G, yy_5_BlockQuoteRaw, G->begin, G->end);
  yyprintf((stderr, "  ok   %s @ %s\n", "BlockQuoteRaw", G->buf+G->pos));  yyDo(G, yyPop, 1, 0);
  return 1;
  l1348:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "BlockQuoteRaw", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_Endline(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "Endline"));
  {  int yypos1368= G->pos, yythunkpos1368= G->thunkpos;  if (!yy_LineBreak(G)) { goto l1369; }  goto l1368;
  l1369:;	  G->pos= yypos1368; G->thunkpos= yythunkpos1368;  if (!yy_TerminalEndline(G)) { goto l1370; }  goto l1368;
  l1370:;	  G->pos= yypos1368; G->thunkpos= yythunkpos1368;  if (!yy_NormalEndline(G)) { goto l1367; }
  }
  l1368:;	
  yyprintf((stderr, "  ok   %s @ %s\n", "Endline", G->buf+G->pos));
  return 1;
  l1367:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "Endline", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_RawLine(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "RawLine"));
  {  int yypos1372= G->pos, yythunkpos1372= G->thunkpos;  yyText(G, G->begin, G->end);  if (!(YY_BEGIN)) goto l1373;
  l1374:;	
  {  int yypos1375= G->pos, yythunkpos1375= G->thunkpos;
  {  int yypos1376= G->pos, yythunkpos1376= G->thunkpos;  if (!yymatchChar(G, '\r')) goto l1376;  goto l1375;
  l1376:;	  G->pos= yypos1376; G->thunkpos= yythunkpos1376;
  }
  {  int yypos1377= G->pos, yythunkpos1377= G->thunkpos;  if (!yymatchChar(G, '\n')) goto l1377;  goto l1375;
  l1377:;	  G->pos= yypos1377; G->thunkpos= yythunkpos1377;
  }  if (!yymatchDot(G)) goto l1375;  goto l1374;
  l1375:;	  G->pos= yypos1375; G->thunkpos= yythunkpos1375;
  }  if (!yy_Newline(G)) { goto l1373; }  yyText(G, G->begin, G->end);  if (!(YY_END)) goto l1373;  goto l1372;
  l1373:;	  G->pos= yypos1372; G->thunkpos= yythunkpos1372;  yyText(G, G->begin, G->end);  if (!(YY_BEGIN)) goto l1371;  if (!yymatchDot(G)) goto l1371;
  l1378:;	
  {  int yypos1379= G->pos, yythunkpos1379= G->thunkpos;  if (!yymatchDot(G)) goto l1379;  goto l1378;
  l1379:;	  G->pos= yypos1379; G->thunkpos= yythunkpos1379;
  }  yyText(G, G->begin, G->end);  if (!(YY_END)) goto l1371;  if (!yy_Eof(G)) { goto l1371; }
  }
  l1372:;	  yyDo(G, yy_1_RawLine, G->begin, G->end);
  yyprintf((stderr, "  ok   %s @ %s\n", "RawLine", G->buf+G->pos));
  return 1;
  l1371:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "RawLine", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_SetextBottom2(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "SetextBottom2"));  if (!yymatchChar(G, '-')) goto l1380;
  l1381:;	
  {  int yypos1382= G->pos, yythunkpos1382= G->thunkpos;  if (!yymatchChar(G, '-')) goto l1382;  goto l1381;
  l1382:;	  G->pos= yypos1382; G->thunkpos= yythunkpos1382;
  }  if (!yy_Newline(G)) { goto l1380; }
  yyprintf((stderr, "  ok   %s @ %s\n", "SetextBottom2", G->buf+G->pos));
  return 1;
  l1380:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "SetextBottom2", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_SetextBottom1(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "SetextBottom1"));  if (!yymatchChar(G, '=')) goto l1383;
  l1384:;	
  {  int yypos1385= G->pos, yythunkpos1385= G->thunkpos;  if (!yymatchChar(G, '=')) goto l1385;  goto l1384;
  l1385:;	  G->pos= yypos1385; G->thunkpos= yythunkpos1385;
  }  if (!yy_Newline(G)) { goto l1383; }
  yyprintf((stderr, "  ok   %s @ %s\n", "SetextBottom1", G->buf+G->pos));
  return 1;
  l1383:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "SetextBottom1", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_SetextHeading2(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;  yyDo(G, yyPush, 1, 0);
  yyprintf((stderr, "%s\n", "SetextHeading2"));
  {  int yypos1387= G->pos, yythunkpos1387= G->thunkpos;  if (!yy_RawLine(G)) { goto l1386; }  if (!yy_SetextBottom2(G)) { goto l1386; }  G->pos= yypos1387; G->thunkpos= yythunkpos1387;
  }  if (!yy_LocMarker(G)) { goto l1386; }  yyDo(G, yySet, -1, 0);  yyText(G, G->begin, G->end);  if (!(YY_BEGIN)) goto l1386;
  {  int yypos1390= G->pos, yythunkpos1390= G->thunkpos;  if (!yy_Endline(G)) { goto l1390; }  goto l1386;
  l1390:;	  G->pos= yypos1390; G->thunkpos= yythunkpos1390;
  }  if (!yy_Inline(G)) { goto l1386; }
  l1388:;	
  {  int yypos1389= G->pos, yythunkpos1389= G->thunkpos;
  {  int yypos1391= G->pos, yythunkpos1391= G->thunkpos;  if (!yy_Endline(G)) { goto l1391; }  goto l1389;
  l1391:;	  G->pos= yypos1391; G->thunkpos= yythunkpos1391;
  }  if (!yy_Inline(G)) { goto l1389; }  goto l1388;
  l1389:;	  G->pos= yypos1389; G->thunkpos= yythunkpos1389;
  }  if (!yy_Sp(G)) { goto l1386; }  if (!yy_Newline(G)) { goto l1386; }  if (!yy_SetextBottom2(G)) { goto l1386; }  yyText(G, G->begin, G->end);  if (!(YY_END)) goto l1386;  yyDo(G, yy_1_SetextHeading2, G->begin, G->end);
  yyprintf((stderr, "  ok   %s @ %s\n", "SetextHeading2", G->buf+G->pos));  yyDo(G, yyPop, 1, 0);
  return 1;
  l1386:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "SetextHeading2", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_SetextHeading1(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;  yyDo(G, yyPush, 1, 0);
  yyprintf((stderr, "%s\n", "SetextHeading1"));
  {  int yypos1393= G->pos, yythunkpos1393= G->thunkpos;  if (!yy_RawLine(G)) { goto l1392; }  if (!yy_SetextBottom1(G)) { goto l1392; }  G->pos= yypos1393; G->thunkpos= yythunkpos1393;
  }  if (!yy_LocMarker(G)) { goto l1392; }  yyDo(G, yySet, -1, 0);  yyText(G, G->begin, G->end);  if (!(YY_BEGIN)) goto l1392;
  {  int yypos1396= G->pos, yythunkpos1396= G->thunkpos;  if (!yy_Endline(G)) { goto l1396; }  goto l1392;
  l1396:;	  G->pos= yypos1396; G->thunkpos= yythunkpos1396;
  }  if (!yy_Inline(G)) { goto l1392; }
  l1394:;	
  {  int yypos1395= G->pos, yythunkpos1395= G->thunkpos;
  {  int yypos1397= G->pos, yythunkpos1397= G->thunkpos;  if (!yy_Endline(G)) { goto l1397; }  goto l1395;
  l1397:;	  G->pos= yypos1397; G->thunkpos= yythunkpos1397;
  }  if (!yy_Inline(G)) { goto l1395; }  goto l1394;
  l1395:;	  G->pos= yypos1395; G->thunkpos= yythunkpos1395;
  }  if (!yy_Sp(G)) { goto l1392; }  if (!yy_Newline(G)) { goto l1392; }  if (!yy_SetextBottom1(G)) { goto l1392; }  yyText(G, G->begin, G->end);  if (!(YY_END)) goto l1392;  yyDo(G, yy_1_SetextHeading1, G->begin, G->end);
  yyprintf((stderr, "  ok   %s @ %s\n", "SetextHeading1", G->buf+G->pos));  yyDo(G, yyPop, 1, 0);
  return 1;
  l1392:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "SetextHeading1", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_SetextHeading(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "SetextHeading"));
  {  int yypos1399= G->pos, yythunkpos1399= G->thunkpos;  if (!yy_SetextHeading1(G)) { goto l1400; }  goto l1399;
  l1400:;	  G->pos= yypos1399; G->thunkpos= yythunkpos1399;  if (!yy_SetextHeading2(G)) { goto l1398; }
  }
  l1399:;	
  yyprintf((stderr, "  ok   %s @ %s\n", "SetextHeading", G->buf+G->pos));
  return 1;
  l1398:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "SetextHeading", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_Space(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "Space"));  if (!yy_Spacechar(G)) { goto l1401; }
  l1402:;	
  {  int yypos1403= G->pos, yythunkpos1403= G->thunkpos;  if (!yy_Spacechar(G)) { goto l1403; }  goto l1402;
  l1403:;	  G->pos= yypos1403; G->thunkpos= yythunkpos1403;
  }
  yyprintf((stderr, "  ok   %s @ %s\n", "Space", G->buf+G->pos));
  return 1;
  l1401:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "Space", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_AtxHeading(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;  yyDo(G, yyPush, 1, 0);
  yyprintf((stderr, "%s\n", "AtxHeading"));  yyText(G, G->begin, G->end);  if (!(YY_BEGIN)) goto l1404;  if (!yy_AtxStart(G)) { goto l1404; }  yyDo(G, yySet, -1, 0);  if (!yy_Space(G)) { goto l1404; }  if (!yy_AtxInline(G)) { goto l1404; }
  l1405:;	
  {  int yypos1406= G->pos, yythunkpos1406= G->thunkpos;  if (!yy_AtxInline(G)) { goto l1406; }  goto l1405;
  l1406:;	  G->pos= yypos1406; G->thunkpos= yythunkpos1406;
  }
  {  int yypos1407= G->pos, yythunkpos1407= G->thunkpos;  if (!yy_Sp(G)) { goto l1407; }
  l1409:;	
  {  int yypos1410= G->pos, yythunkpos1410= G->thunkpos;  if (!yymatchChar(G, '#')) goto l1410;  goto l1409;
  l1410:;	  G->pos= yypos1410; G->thunkpos= yythunkpos1410;
  }  if (!yy_Sp(G)) { goto l1407; }  goto l1408;
  l1407:;	  G->pos= yypos1407; G->thunkpos= yythunkpos1407;
  }
  l1408:;	  if (!yy_Newline(G)) { goto l1404; }  yyText(G, G->begin, G->end);  if (!(YY_END)) goto l1404;  yyDo(G, yy_1_AtxHeading, G->begin, G->end);
  yyprintf((stderr, "  ok   %s @ %s\n", "AtxHeading", G->buf+G->pos));  yyDo(G, yyPop, 1, 0);
  return 1;
  l1404:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "AtxHeading", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_AtxStart(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "AtxStart"));  yyText(G, G->begin, G->end);  if (!(YY_BEGIN)) goto l1411;
  {  int yypos1412= G->pos, yythunkpos1412= G->thunkpos;  if (!yymatchString(G, "######")) goto l1413;  goto l1412;
  l1413:;	  G->pos= yypos1412; G->thunkpos= yythunkpos1412;  if (!yymatchString(G, "#####")) goto l1414;  goto l1412;
  l1414:;	  G->pos= yypos1412; G->thunkpos= yythunkpos1412;  if (!yymatchString(G, "####")) goto l1415;  goto l1412;
  l1415:;	  G->pos= yypos1412; G->thunkpos= yythunkpos1412;  if (!yymatchString(G, "###")) goto l1416;  goto l1412;
  l1416:;	  G->pos= yypos1412; G->thunkpos= yythunkpos1412;  if (!yymatchString(G, "##")) goto l1417;  goto l1412;
  l1417:;	  G->pos= yypos1412; G->thunkpos= yythunkpos1412;  if (!yymatchChar(G, '#')) goto l1411;
  }
  l1412:;	  yyText(G, G->begin, G->end);  if (!(YY_END)) goto l1411;  yyDo(G, yy_1_AtxStart, G->begin, G->end);
  yyprintf((stderr, "  ok   %s @ %s\n", "AtxStart", G->buf+G->pos));
  return 1;
  l1411:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "AtxStart", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_Inline(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "Inline"));
  {  int yypos1419= G->pos, yythunkpos1419= G->thunkpos;  if (!yy_Str(G)) { goto l1420; }  goto l1419;
  l1420:;	  G->pos= yypos1419; G->thunkpos= yythunkpos1419;  if (!yy_Endline(G)) { goto l1421; }  goto l1419;
  l1421:;	  G->pos= yypos1419; G->thunkpos= yythunkpos1419;  if (!yy_UlOrStarLine(G)) { goto l1422; }  goto l1419;
  l1422:;	  G->pos= yypos1419; G->thunkpos= yythunkpos1419;  if (!yy_Space(G)) { goto l1423; }  goto l1419;
  l1423:;	  G->pos= yypos1419; G->thunkpos= yythunkpos1419;  if (!yy_Strong(G)) { goto l1424; }  goto l1419;
  l1424:;	  G->pos= yypos1419; G->thunkpos= yythunkpos1419;  if (!yy_Emph(G)) { goto l1425; }  goto l1419;
  l1425:;	  G->pos= yypos1419; G->thunkpos= yythunkpos1419;  if (!yy_Strike(G)) { goto l1426; }  goto l1419;
  l1426:;	  G->pos= yypos1419; G->thunkpos= yythunkpos1419;  if (!yy_Image(G)) { goto l1427; }  goto l1419;
  l1427:;	  G->pos= yypos1419; G->thunkpos= yythunkpos1419;  if (!yy_Link(G)) { goto l1428; }  goto l1419;
  l1428:;	  G->pos= yypos1419; G->thunkpos= yythunkpos1419;  if (!yy_NoteReference(G)) { goto l1429; }  goto l1419;
  l1429:;	  G->pos= yypos1419; G->thunkpos= yythunkpos1419;  if (!yy_InlineNote(G)) { goto l1430; }  goto l1419;
  l1430:;	  G->pos= yypos1419; G->thunkpos= yythunkpos1419;  if (!yy_Code(G)) { goto l1431; }  goto l1419;
  l1431:;	  G->pos= yypos1419; G->thunkpos= yythunkpos1419;  if (!yy_InlineEquation(G)) { goto l1432; }  goto l1419;
  l1432:;	  G->pos= yypos1419; G->thunkpos= yythunkpos1419;  if (!yy_RawHtml(G)) { goto l1433; }  goto l1419;
  l1433:;	  G->pos= yypos1419; G->thunkpos= yythunkpos1419;  if (!yy_Entity(G)) { goto l1434; }  goto l1419;
  l1434:;	  G->pos= yypos1419; G->thunkpos= yythunkpos1419;  if (!yy_EscapedChar(G)) { goto l1435; }  goto l1419;
  l1435:;	  G->pos= yypos1419; G->thunkpos= yythunkpos1419;  if (!yy_Symbol(G)) { goto l1418; }
  }
  l1419:;	
  yyprintf((stderr, "  ok   %s @ %s\n", "Inline", G->buf+G->pos));
  return 1;
  l1418:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "Inline", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_Sp(GREG *G)
{
  yyprintf((stderr, "%s\n", "Sp"));
  l1437:;	
  {  int yypos1438= G->pos, yythunkpos1438= G->thunkpos;  if (!yy_Spacechar(G)) { goto l1438; }  goto l1437;
  l1438:;	  G->pos= yypos1438; G->thunkpos= yythunkpos1438;
  }
  yyprintf((stderr, "  ok   %s @ %s\n", "Sp", G->buf+G->pos));
  return 1;
}
YY_RULE(int) yy_AtxInline(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "AtxInline"));
  {  int yypos1440= G->pos, yythunkpos1440= G->thunkpos;  if (!yy_Newline(G)) { goto l1440; }  goto l1439;
  l1440:;	  G->pos= yypos1440; G->thunkpos= yythunkpos1440;
  }
  {  int yypos1441= G->pos, yythunkpos1441= G->thunkpos;  if (!yy_Sp(G)) { goto l1441; }
  l1442:;	
  {  int yypos1443= G->pos, yythunkpos1443= G->thunkpos;  if (!yymatchChar(G, '#')) goto l1443;  goto l1442;
  l1443:;	  G->pos= yypos1443; G->thunkpos= yythunkpos1443;
  }  if (!yy_Sp(G)) { goto l1441; }  if (!yy_Newline(G)) { goto l1441; }  goto l1439;
  l1441:;	  G->pos= yypos1441; G->thunkpos= yythunkpos1441;
  }  if (!yy_Inline(G)) { goto l1439; }
  yyprintf((stderr, "  ok   %s @ %s\n", "AtxInline", G->buf+G->pos));
  return 1;
  l1439:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "AtxInline", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_Inlines(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "Inlines"));
  {  int yypos1447= G->pos, yythunkpos1447= G->thunkpos;
  {  int yypos1449= G->pos, yythunkpos1449= G->thunkpos;  if (!yy_Endline(G)) { goto l1449; }  goto l1448;
  l1449:;	  G->pos= yypos1449; G->thunkpos= yythunkpos1449;
  }  if (!yy_Inline(G)) { goto l1448; }  goto l1447;
  l1448:;	  G->pos= yypos1447; G->thunkpos= yythunkpos1447;  if (!yy_Endline(G)) { goto l1444; }
  {  int yypos1450= G->pos, yythunkpos1450= G->thunkpos;  if (!yy_Inline(G)) { goto l1444; }  G->pos= yypos1450; G->thunkpos= yythunkpos1450;
  }
  }
  l1447:;	
  l1445:;	
  {  int yypos1446= G->pos, yythunkpos1446= G->thunkpos;
  {  int yypos1451= G->pos, yythunkpos1451= G->thunkpos;
  {  int yypos1453= G->pos, yythunkpos1453= G->thunkpos;  if (!yy_Endline(G)) { goto l1453; }  goto l1452;
  l1453:;	  G->pos= yypos1453; G->thunkpos= yythunkpos1453;
  }  if (!yy_Inline(G)) { goto l1452; }  goto l1451;
  l1452:;	  G->pos= yypos1451; G->thunkpos= yythunkpos1451;  if (!yy_Endline(G)) { goto l1446; }
  {  int yypos1454= G->pos, yythunkpos1454= G->thunkpos;  if (!yy_Inline(G)) { goto l1446; }  G->pos= yypos1454; G->thunkpos= yythunkpos1454;
  }
  }
  l1451:;	  goto l1445;
  l1446:;	  G->pos= yypos1446; G->thunkpos= yythunkpos1446;
  }
  {  int yypos1455= G->pos, yythunkpos1455= G->thunkpos;  if (!yy_Endline(G)) { goto l1455; }  goto l1456;
  l1455:;	  G->pos= yypos1455; G->thunkpos= yythunkpos1455;
  }
  l1456:;	
  yyprintf((stderr, "  ok   %s @ %s\n", "Inlines", G->buf+G->pos));
  return 1;
  l1444:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "Inlines", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_NonindentSpace(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "NonindentSpace"));
  {  int yypos1458= G->pos, yythunkpos1458= G->thunkpos;  if (!yymatchString(G, "   ")) goto l1459;  goto l1458;
  l1459:;	  G->pos= yypos1458; G->thunkpos= yythunkpos1458;  if (!yymatchString(G, "  ")) goto l1460;  goto l1458;
  l1460:;	  G->pos= yypos1458; G->thunkpos= yythunkpos1458;  if (!yymatchChar(G, ' ')) goto l1461;  goto l1458;
  l1461:;	  G->pos= yypos1458; G->thunkpos= yythunkpos1458;  if (!yymatchString(G, "")) goto l1457;
  }
  l1458:;	
  yyprintf((stderr, "  ok   %s @ %s\n", "NonindentSpace", G->buf+G->pos));
  return 1;
  l1457:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "NonindentSpace", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_Plain(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "Plain"));  if (!yy_Inlines(G)) { goto l1462; }
  yyprintf((stderr, "  ok   %s @ %s\n", "Plain", G->buf+G->pos));
  return 1;
  l1462:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "Plain", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_Para(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "Para"));  if (!yy_NonindentSpace(G)) { goto l1463; }  if (!yy_Inlines(G)) { goto l1463; }  if (!yy_BlankLine(G)) { goto l1463; }
  l1464:;	
  {  int yypos1465= G->pos, yythunkpos1465= G->thunkpos;  if (!yy_BlankLine(G)) { goto l1465; }  goto l1464;
  l1465:;	  G->pos= yypos1465; G->thunkpos= yythunkpos1465;
  }
  yyprintf((stderr, "  ok   %s @ %s\n", "Para", G->buf+G->pos));
  return 1;
  l1463:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "Para", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_StyleBlock(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;  yyDo(G, yyPush, 1, 0);
  yyprintf((stderr, "%s\n", "StyleBlock"));  yyText(G, G->begin, G->end);  if (!(YY_BEGIN)) goto l1466;  if (!yy_LocMarker(G)) { goto l1466; }  yyDo(G, yySet, -1, 0);  if (!yy_InStyleTags(G)) { goto l1466; }  yyText(G, G->begin, G->end);  if (!(YY_END)) goto l1466;
  l1467:;	
  {  int yypos1468= G->pos, yythunkpos1468= G->thunkpos;  if (!yy_BlankLine(G)) { goto l1468; }  goto l1467;
  l1468:;	  G->pos= yypos1468; G->thunkpos= yythunkpos1468;
  }  yyDo(G, yy_1_StyleBlock, G->begin, G->end);
  yyprintf((stderr, "  ok   %s @ %s\n", "StyleBlock", G->buf+G->pos));  yyDo(G, yyPop, 1, 0);
  return 1;
  l1466:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "StyleBlock", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_HtmlBlock(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;  yyDo(G, yyPush, 1, 0);
  yyprintf((stderr, "%s\n", "HtmlBlock"));  yyText(G, G->begin, G->end);  if (!(YY_BEGIN)) goto l1469;  if (!yy_LocMarker(G)) { goto l1469; }  yyDo(G, yySet, -1, 0);
  {  int yypos1470= G->pos, yythunkpos1470= G->thunkpos;  if (!yy_HtmlBlockInTags(G)) { goto l1471; }  goto l1470;
  l1471:;	  G->pos= yypos1470; G->thunkpos= yythunkpos1470;  if (!yy_HtmlComment(G)) { goto l1472; }  goto l1470;
  l1472:;	  G->pos= yypos1470; G->thunkpos= yythunkpos1470;  if (!yy_HtmlBlockSelfClosing(G)) { goto l1469; }
  }
  l1470:;	  yyText(G, G->begin, G->end);  if (!(YY_END)) goto l1469;  if (!yy_BlankLine(G)) { goto l1469; }
  l1473:;	
  {  int yypos1474= G->pos, yythunkpos1474= G->thunkpos;  if (!yy_BlankLine(G)) { goto l1474; }  goto l1473;
  l1474:;	  G->pos= yypos1474; G->thunkpos= yythunkpos1474;
  }  yyDo(G, yy_1_HtmlBlock, G->begin, G->end);
  yyprintf((stderr, "  ok   %s @ %s\n", "HtmlBlock", G->buf+G->pos));  yyDo(G, yyPop, 1, 0);
  return 1;
  l1469:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "HtmlBlock", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_BulletList(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "BulletList"));
  {  int yypos1476= G->pos, yythunkpos1476= G->thunkpos;  if (!yy_Bullet(G)) { goto l1475; }  G->pos= yypos1476; G->thunkpos= yythunkpos1476;
  }
  {  int yypos1477= G->pos, yythunkpos1477= G->thunkpos;  if (!yy_ListTight(G)) { goto l1478; }  goto l1477;
  l1478:;	  G->pos= yypos1477; G->thunkpos= yythunkpos1477;  if (!yy_ListLoose(G)) { goto l1475; }
  }
  l1477:;	
  yyprintf((stderr, "  ok   %s @ %s\n", "BulletList", G->buf+G->pos));
  return 1;
  l1475:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "BulletList", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_OrderedList(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "OrderedList"));
  {  int yypos1480= G->pos, yythunkpos1480= G->thunkpos;  if (!yy_Enumerator(G)) { goto l1479; }  G->pos= yypos1480; G->thunkpos= yythunkpos1480;
  }
  {  int yypos1481= G->pos, yythunkpos1481= G->thunkpos;  if (!yy_ListTight(G)) { goto l1482; }  goto l1481;
  l1482:;	  G->pos= yypos1481; G->thunkpos= yythunkpos1481;  if (!yy_ListLoose(G)) { goto l1479; }
  }
  l1481:;	
  yyprintf((stderr, "  ok   %s @ %s\n", "OrderedList", G->buf+G->pos));
  return 1;
  l1479:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "OrderedList", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_Heading(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "Heading"));
  {  int yypos1484= G->pos, yythunkpos1484= G->thunkpos;  if (!yy_SetextHeading(G)) { goto l1485; }  goto l1484;
  l1485:;	  G->pos= yypos1484; G->thunkpos= yythunkpos1484;  if (!yy_AtxHeading(G)) { goto l1483; }
  }
  l1484:;	
  yyprintf((stderr, "  ok   %s @ %s\n", "Heading", G->buf+G->pos));
  return 1;
  l1483:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "Heading", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_HorizontalRule(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "HorizontalRule"));  yyText(G, G->begin, G->end);  if (!(YY_BEGIN)) goto l1486;  if (!yy_NonindentSpace(G)) { goto l1486; }
  {  int yypos1487= G->pos, yythunkpos1487= G->thunkpos;  if (!yymatchChar(G, '*')) goto l1488;  if (!yy_Sp(G)) { goto l1488; }  if (!yymatchChar(G, '*')) goto l1488;  if (!yy_Sp(G)) { goto l1488; }  if (!yymatchChar(G, '*')) goto l1488;
  l1489:;	
  {  int yypos1490= G->pos, yythunkpos1490= G->thunkpos;  if (!yy_Sp(G)) { goto l1490; }  if (!yymatchChar(G, '*')) goto l1490;  goto l1489;
  l1490:;	  G->pos= yypos1490; G->thunkpos= yythunkpos1490;
  }  goto l1487;
  l1488:;	  G->pos= yypos1487; G->thunkpos= yythunkpos1487;  if (!yymatchChar(G, '-')) goto l1491;  if (!yy_Sp(G)) { goto l1491; }  if (!yymatchChar(G, '-')) goto l1491;  if (!yy_Sp(G)) { goto l1491; }  if (!yymatchChar(G, '-')) goto l1491;
  l1492:;	
  {  int yypos1493= G->pos, yythunkpos1493= G->thunkpos;  if (!yy_Sp(G)) { goto l1493; }  if (!yymatchChar(G, '-')) goto l1493;  goto l1492;
  l1493:;	  G->pos= yypos1493; G->thunkpos= yythunkpos1493;
  }  goto l1487;
  l1491:;	  G->pos= yypos1487; G->thunkpos= yythunkpos1487;  if (!yymatchChar(G, '_')) goto l1486;  if (!yy_Sp(G)) { goto l1486; }  if (!yymatchChar(G, '_')) goto l1486;  if (!yy_Sp(G)) { goto l1486; }  if (!yymatchChar(G, '_')) goto l1486;
  l1494:;	
  {  int yypos1495= G->pos, yythunkpos1495= G->thunkpos;  if (!yy_Sp(G)) { goto l1495; }  if (!yymatchChar(G, '_')) goto l1495;  goto l1494;
  l1495:;	  G->pos= yypos1495; G->thunkpos= yythunkpos1495;
  }
  }
  l1487:;	  if (!yy_Sp(G)) { goto l1486; }  if (!yy_Newline(G)) { goto l1486; }  yyText(G, G->begin, G->end);  if (!(YY_END)) goto l1486;  if (!yy_BlankLine(G)) { goto l1486; }
  l1496:;	
  {  int yypos1497= G->pos, yythunkpos1497= G->thunkpos;  if (!yy_BlankLine(G)) { goto l1497; }  goto l1496;
  l1497:;	  G->pos= yypos1497; G->thunkpos= yythunkpos1497;
  }  yyDo(G, yy_1_HorizontalRule, G->begin, G->end);
  yyprintf((stderr, "  ok   %s @ %s\n", "HorizontalRule", G->buf+G->pos));
  return 1;
  l1486:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "HorizontalRule", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_Reference(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;  yyDo(G, yyPush, 3, 0);
  yyprintf((stderr, "%s\n", "Reference"));  yyText(G, G->begin, G->end);  if (!(YY_BEGIN)) goto l1498;  if (!yy_LocMarker(G)) { goto l1498; }  yyDo(G, yySet, -3, 0);  if (!yy_NonindentSpace(G)) { goto l1498; }
  {  int yypos1499= G->pos, yythunkpos1499= G->thunkpos;  if (!yymatchString(G, "[]")) goto l1499;  goto l1498;
  l1499:;	  G->pos= yypos1499; G->thunkpos= yythunkpos1499;
  }  if (!yy_Label(G)) { goto l1498; }  yyDo(G, yySet, -2, 0);  if (!yymatchChar(G, ':')) goto l1498;  if (!yy_Spnl(G)) { goto l1498; }  if (!yy_RefSrc(G)) { goto l1498; }  yyDo(G, yySet, -1, 0);  if (!yy_RefTitle(G)) { goto l1498; }  yyText(G, G->begin, G->end);  if (!(YY_END)) goto l1498;  if (!yy_BlankLine(G)) { goto l1498; }
  l1500:;	
  {  int yypos1501= G->pos, yythunkpos1501= G->thunkpos;  if (!yy_BlankLine(G)) { goto l1501; }  goto l1500;
  l1501:;	  G->pos= yypos1501; G->thunkpos= yythunkpos1501;
  }  yyDo(G, yy_1_Reference, G->begin, G->end);
  yyprintf((stderr, "  ok   %s @ %s\n", "Reference", G->buf+G->pos));  yyDo(G, yyPop, 3, 0);
  return 1;
  l1498:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "Reference", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_Note(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "Note"));  yyText(G, G->begin, G->end);  if (!( EXT(pmh_EXT_NOTES) )) goto l1502;  if (!yy_NonindentSpace(G)) { goto l1502; }  if (!yy_RawNoteReference(G)) { goto l1502; }  if (!yymatchChar(G, ':')) goto l1502;  if (!yy_Sp(G)) { goto l1502; }  if (!yy_RawNoteBlock(G)) { goto l1502; }
  l1503:;	
  {  int yypos1504= G->pos, yythunkpos1504= G->thunkpos;
  {  int yypos1505= G->pos, yythunkpos1505= G->thunkpos;  if (!yy_Indent(G)) { goto l1504; }  G->pos= yypos1505; G->thunkpos= yythunkpos1505;
  }  if (!yy_RawNoteBlock(G)) { goto l1504; }  goto l1503;
  l1504:;	  G->pos= yypos1504; G->thunkpos= yythunkpos1504;
  }
  yyprintf((stderr, "  ok   %s @ %s\n", "Note", G->buf+G->pos));
  return 1;
  l1502:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "Note", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_DisplayFormula(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "DisplayFormula"));  yyText(G, G->begin, G->end);  if (!( EXT(pmh_EXT_MATH) )) goto l1506;  if (!yy_NonindentSpace(G)) { goto l1506; }  yyText(G, G->begin, G->end);  if (!(YY_BEGIN)) goto l1506;  if (!yymatchString(G, "$$")) goto l1506;
  l1507:;	
  {  int yypos1508= G->pos, yythunkpos1508= G->thunkpos;
  {  int yypos1509= G->pos, yythunkpos1509= G->thunkpos;  if (!yymatchChar(G, '$')) goto l1509;  goto l1508;
  l1509:;	  G->pos= yypos1509; G->thunkpos= yythunkpos1509;
  }  if (!yymatchDot(G)) goto l1508;  goto l1507;
  l1508:;	  G->pos= yypos1508; G->thunkpos= yythunkpos1508;
  }  if (!yymatchString(G, "$$")) goto l1506;  yyText(G, G->begin, G->end);  if (!(YY_END)) goto l1506;
  l1510:;	
  {  int yypos1511= G->pos, yythunkpos1511= G->thunkpos;  if (!yy_Spacechar(G)) { goto l1511; }  goto l1510;
  l1511:;	  G->pos= yypos1511; G->thunkpos= yythunkpos1511;
  }  if (!yy_Newline(G)) { goto l1506; }  yyDo(G, yy_1_DisplayFormula, G->begin, G->end);
  yyprintf((stderr, "  ok   %s @ %s\n", "DisplayFormula", G->buf+G->pos));
  return 1;
  l1506:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "DisplayFormula", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_FencedCodeBlock(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;  yyDo(G, yyPush, 1, 0);
  yyprintf((stderr, "%s\n", "FencedCodeBlock"));  yyText(G, G->begin, G->end);  if (!(YY_BEGIN)) goto l1512;  if (!yy_LocMarker(G)) { goto l1512; }  yyDo(G, yySet, -1, 0);  if (!yy_FencedCodeBlockStart(G)) { goto l1512; }
  l1513:;	
  {  int yypos1514= G->pos, yythunkpos1514= G->thunkpos;  if (!yy_FencedCodeBlockChunk(G)) { goto l1514; }  goto l1513;
  l1514:;	  G->pos= yypos1514; G->thunkpos= yythunkpos1514;
  }  if (!yy_FencedCodeBlockEnd(G)) { goto l1512; }  yyText(G, G->begin, G->end);  if (!(YY_END)) goto l1512;  yyDo(G, yy_1_FencedCodeBlock, G->begin, G->end);
  yyprintf((stderr, "  ok   %s @ %s\n", "FencedCodeBlock", G->buf+G->pos));  yyDo(G, yyPop, 1, 0);
  return 1;
  l1512:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "FencedCodeBlock", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_Verbatim(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;  yyDo(G, yyPush, 1, 0);
  yyprintf((stderr, "%s\n", "Verbatim"));  yyText(G, G->begin, G->end);  if (!(YY_BEGIN)) goto l1515;  if (!yy_LocMarker(G)) { goto l1515; }  yyDo(G, yySet, -1, 0);  if (!yy_VerbatimChunk(G)) { goto l1515; }
  l1516:;	
  {  int yypos1517= G->pos, yythunkpos1517= G->thunkpos;  if (!yy_VerbatimChunk(G)) { goto l1517; }  goto l1516;
  l1517:;	  G->pos= yypos1517; G->thunkpos= yythunkpos1517;
  }  yyText(G, G->begin, G->end);  if (!(YY_END)) goto l1515;  yyDo(G, yy_1_Verbatim, G->begin, G->end);
  yyprintf((stderr, "  ok   %s @ %s\n", "Verbatim", G->buf+G->pos));  yyDo(G, yyPop, 1, 0);
  return 1;
  l1515:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "Verbatim", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_BlockQuote(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;  yyDo(G, yyPush, 1, 0);
  yyprintf((stderr, "%s\n", "BlockQuote"));  if (!yy_BlockQuoteRaw(G)) { goto l1518; }  yyDo(G, yySet, -1, 0);  yyDo(G, yy_1_BlockQuote, G->begin, G->end);
  yyprintf((stderr, "  ok   %s @ %s\n", "BlockQuote", G->buf+G->pos));  yyDo(G, yyPop, 1, 0);
  return 1;
  l1518:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "BlockQuote", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_BlankLine(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "BlankLine"));  if (!yy_Sp(G)) { goto l1519; }  if (!yy_Newline(G)) { goto l1519; }
  yyprintf((stderr, "  ok   %s @ %s\n", "BlankLine", G->buf+G->pos));
  return 1;
  l1519:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "BlankLine", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_FrontMatterEndMark(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "FrontMatterEndMark"));
  {  int yypos1521= G->pos, yythunkpos1521= G->thunkpos;  if (!yymatchString(G, "---")) goto l1522;  goto l1521;
  l1522:;	  G->pos= yypos1521; G->thunkpos= yythunkpos1521;  if (!yymatchString(G, "...")) goto l1520;
  }
  l1521:;	
  yyprintf((stderr, "  ok   %s @ %s\n", "FrontMatterEndMark", G->buf+G->pos));
  return 1;
  l1520:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "FrontMatterEndMark", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_FrontMatterBlock(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "FrontMatterBlock"));
  {  int yypos1524= G->pos, yythunkpos1524= G->thunkpos;  if (!yy_FrontMatterEndMark(G)) { goto l1524; }  goto l1523;
  l1524:;	  G->pos= yypos1524; G->thunkpos= yythunkpos1524;
  }
  l1525:;	
  {  int yypos1526= G->pos, yythunkpos1526= G->thunkpos;
  {  int yypos1527= G->pos, yythunkpos1527= G->thunkpos;  if (!yy_Newline(G)) { goto l1527; }  goto l1526;
  l1527:;	  G->pos= yypos1527; G->thunkpos= yythunkpos1527;
  }  if (!yymatchDot(G)) goto l1526;  goto l1525;
  l1526:;	  G->pos= yypos1526; G->thunkpos= yythunkpos1526;
  }  if (!yy_Newline(G)) { goto l1523; }
  yyprintf((stderr, "  ok   %s @ %s\n", "FrontMatterBlock", G->buf+G->pos));
  return 1;
  l1523:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "FrontMatterBlock", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_Newline(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "Newline"));
  {  int yypos1529= G->pos, yythunkpos1529= G->thunkpos;  if (!yymatchChar(G, '\n')) goto l1530;  goto l1529;
  l1530:;	  G->pos= yypos1529; G->thunkpos= yythunkpos1529;  if (!yymatchChar(G, '\r')) goto l1528;
  {  int yypos1531= G->pos, yythunkpos1531= G->thunkpos;  if (!yymatchChar(G, '\n')) goto l1531;  goto l1532;
  l1531:;	  G->pos= yypos1531; G->thunkpos= yythunkpos1531;
  }
  l1532:;	
  }
  l1529:;	
  yyprintf((stderr, "  ok   %s @ %s\n", "Newline", G->buf+G->pos));
  return 1;
  l1528:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "Newline", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_LocMarker(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "LocMarker"));
  {  int yypos1534= G->pos, yythunkpos1534= G->thunkpos;  if (!yymatchDot(G)) goto l1533;  G->pos= yypos1534; G->thunkpos= yythunkpos1534;
  }  yyDo(G, yy_1_LocMarker, G->begin, G->end);
  yyprintf((stderr, "  ok   %s @ %s\n", "LocMarker", G->buf+G->pos));
  return 1;
  l1533:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "LocMarker", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_Block(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "Block"));
  l1536:;	
  {  int yypos1537= G->pos, yythunkpos1537= G->thunkpos;  if (!yy_BlankLine(G)) { goto l1537; }  goto l1536;
  l1537:;	  G->pos= yypos1537; G->thunkpos= yythunkpos1537;
  }
  {  int yypos1538= G->pos, yythunkpos1538= G->thunkpos;  if (!yy_BlockQuote(G)) { goto l1539; }  goto l1538;
  l1539:;	  G->pos= yypos1538; G->thunkpos= yythunkpos1538;  if (!yy_Verbatim(G)) { goto l1540; }  goto l1538;
  l1540:;	  G->pos= yypos1538; G->thunkpos= yythunkpos1538;  if (!yy_FencedCodeBlock(G)) { goto l1541; }  goto l1538;
  l1541:;	  G->pos= yypos1538; G->thunkpos= yythunkpos1538;  if (!yy_DisplayFormula(G)) { goto l1542; }  goto l1538;
  l1542:;	  G->pos= yypos1538; G->thunkpos= yythunkpos1538;  if (!yy_Note(G)) { goto l1543; }  goto l1538;
  l1543:;	  G->pos= yypos1538; G->thunkpos= yythunkpos1538;  if (!yy_Reference(G)) { goto l1544; }  goto l1538;
  l1544:;	  G->pos= yypos1538; G->thunkpos= yythunkpos1538;  if (!yy_HorizontalRule(G)) { goto l1545; }  goto l1538;
  l1545:;	  G->pos= yypos1538; G->thunkpos= yythunkpos1538;  if (!yy_Heading(G)) { goto l1546; }  goto l1538;
  l1546:;	  G->pos= yypos1538; G->thunkpos= yythunkpos1538;  if (!yy_OrderedList(G)) { goto l1547; }  goto l1538;
  l1547:;	  G->pos= yypos1538; G->thunkpos= yythunkpos1538;  if (!yy_BulletList(G)) { goto l1548; }  goto l1538;
  l1548:;	  G->pos= yypos1538; G->thunkpos= yythunkpos1538;  if (!yy_HtmlBlock(G)) { goto l1549; }  goto l1538;
  l1549:;	  G->pos= yypos1538; G->thunkpos= yythunkpos1538;  if (!yy_StyleBlock(G)) { goto l1550; }  goto l1538;
  l1550:;	  G->pos= yypos1538; G->thunkpos= yythunkpos1538;  if (!yy_Para(G)) { goto l1551; }  goto l1538;
  l1551:;	  G->pos= yypos1538; G->thunkpos= yythunkpos1538;  if (!yy_Plain(G)) { goto l1535; }
  }
  l1538:;	
  yyprintf((stderr, "  ok   %s @ %s\n", "Block", G->buf+G->pos));
  return 1;
  l1535:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "Block", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_FrontMatter(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;  yyDo(G, yyPush, 1, 0);
  yyprintf((stderr, "%s\n", "FrontMatter"));  if (!yy_LocMarker(G)) { goto l1552; }  yyDo(G, yySet, -1, 0);
  {  int yypos1553= G->pos, yythunkpos1553= G->thunkpos;  yyText(G, G->begin, G->end);  if (!( EXT(pmh_EXT_FRONTMATTER) )) goto l1553;  yyText(G, G->begin, G->end);  if (!(YY_BEGIN)) goto l1553;  if (!yymatchString(G, "---")) goto l1553;  if (!yy_Newline(G)) { goto l1553; }
  l1555:;	
  {  int yypos1556= G->pos, yythunkpos1556= G->thunkpos;  if (!yy_FrontMatterBlock(G)) { goto l1556; }  goto l1555;
  l1556:;	  G->pos= yypos1556; G->thunkpos= yythunkpos1556;
  }  if (!yy_FrontMatterEndMark(G)) { goto l1553; }  if (!yy_Newline(G)) { goto l1553; }  yyText(G, G->begin, G->end);  if (!(YY_END)) goto l1553;  yyDo(G, yy_1_FrontMatter, G->begin, G->end);  goto l1554;
  l1553:;	  G->pos= yypos1553; G->thunkpos= yythunkpos1553;
  }
  l1554:;	
  yyprintf((stderr, "  ok   %s @ %s\n", "FrontMatter", G->buf+G->pos));  yyDo(G, yyPop, 1, 0);
  return 1;
  l1552:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "FrontMatter", G->buf+G->pos));
  return 0;
}
YY_RULE(int) yy_Doc(GREG *G)
{  int yypos0= G->pos, yythunkpos0= G->thunkpos;
  yyprintf((stderr, "%s\n", "Doc"));  if (!yy_FrontMatter(G)) { goto l1557; }
  l1558:;	
  {  int yypos1559= G->pos, yythunkpos1559= G->thunkpos;  if (!yy_Block(G)) { goto l1559; }  goto l1558;
  l1559:;	  G->pos= yypos1559; G->thunkpos= yythunkpos1559;
  }
  yyprintf((stderr, "  ok   %s @ %s\n", "Doc", G->buf+G->pos));
  return 1;
  l1557:;	  G->pos= yypos0; G->thunkpos= yythunkpos0;
  yyprintf((stderr, "  fail %s @ %s\n", "Doc", G->buf+G->pos));
  return 0;
}

#ifndef YY_PART

typedef int (*yyrule)(GREG *G);

YY_PARSE(int) YY_NAME(parse_from)(GREG *G, yyrule yystart)
{
  int yyok;
  if (!G->buflen)
    {
      G->buflen= YY_BUFFER_START_SIZE;
      G->buf= (char *)YY_ALLOC(G->buflen, G->data);
      G->textlen= YY_BUFFER_START_SIZE;
      G->text= (char *)YY_ALLOC(G->textlen, G->data);
      G->thunkslen= YY_STACK_SIZE;
      G->thunks= (yythunk *)YY_ALLOC(sizeof(yythunk) * G->thunkslen, G->data);
      G->valslen= YY_STACK_SIZE;
      G->vals= (YYSTYPE*)YY_ALLOC(sizeof(YYSTYPE) * G->valslen, G->data);
      G->begin= G->end= G->pos= G->limit= G->thunkpos= 0;
    }
  G->pos = 0;
  G->begin= G->end= G->pos;
  G->thunkpos= 0;
  G->val= G->vals;
  yyok= yystart(G);
  if (yyok) yyDone(G);
  yyCommit(G);
  return yyok;
  (void)yyrefill(NULL);
  (void)yymatchDot(NULL);
  (void)yymatchChar(NULL, 0);
  (void)yymatchString(NULL, NULL);
  (void)yymatchClass(NULL, NULL);
  (void)yyDo(NULL, NULL, 0, 0);
  (void)yyText(NULL, 0, 0);
  (void)yyDone(NULL);
  (void)yyCommit(NULL);
  (void)yyAccept(NULL, 0);
  (void)yyPush(NULL, NULL, 0, NULL, NULL);
  (void)yyPop(NULL, NULL, 0, NULL, NULL);
  (void)yySet(NULL, NULL, 0, NULL, NULL);
}

YY_PARSE(int) YY_NAME(parse)(GREG *G)
{
  return YY_NAME(parse_from)(G, yy_Doc);
}

YY_PARSE(GREG *) YY_NAME(parse_new)(YY_XTYPE data)
{
  GREG *G = (GREG *)YY_CALLOC(1, sizeof(GREG), G->data);
  G->data = data;
  return G;
}

YY_PARSE(void) YY_NAME(parse_free)(GREG *G)
{
  YY_FREE(G->buf);
  YY_FREE(G->text);
  YY_FREE(G->thunks);
  YY_FREE(G->vals);
  YY_FREE(G);
}

#endif




/* PEG Markdown Highlight
 * Copyright 2011-2016 Ali Rantakari -- http://hasseg.org
 * Licensed under the GPL2+ and MIT licenses (see LICENSE for more info).
 * 
 * pmh_parser_foot.c
 * 
 * Code to be appended to the end of the parser code generated from the
 * PEG grammar.
 */


static void _parse(parser_data *p_data, yyrule start_rule)
{
    GREG *g = YY_NAME(parse_new)(p_data);
    if (start_rule == NULL)
        YY_NAME(parse)(g);
    else
        YY_NAME(parse_from)(g, start_rule);
    YY_NAME(parse_free)(g);
    
    pmh_PRINTF("\n\n");
}

static void parse_markdown(parser_data *p_data)
{
    pmh_PRINTF("\nPARSING DOCUMENT: ");
    
    _parse(p_data, NULL);
}

static void parse_references(parser_data *p_data)
{
    pmh_PRINTF("\nPARSING REFERENCES: ");
    
    p_data->parsing_only_references = true;
    _parse(p_data, yy_References);
    p_data->parsing_only_references = false;
    
    p_data->references = p_data->head_elems[pmh_REFERENCE];
    p_data->head_elems[pmh_REFERENCE] = NULL;
}

